��X<?php exit; ?>a:1:{s:7:"content";O:8:"stdClass":24:{s:2:"ID";i:6870;s:11:"post_author";s:1:"1";s:9:"post_date";s:19:"2016-07-12 15:41:04";s:13:"post_date_gmt";s:19:"2016-07-12 07:41:04";s:12:"post_content";s:1920:"[vc_row type="full_width_background" bg_image="9" bg_position="center center" bg_repeat="no-repeat" scene_position="center" video_bg="use_video" enable_video_color_overlay="true" video_overlay_color="#0d598d" video_webm="http://www.vbits.com.hk/wp-content/uploads/2016/fp-clouds.webmhd.webm" video_mp4="http://www.vbits.com.hk/wp-content/uploads/2016/fp-clouds.mp4" video_image="6770" text_color="light" text_align="left" top_padding="5%" bottom_padding="5%" overlay_strength="0.3"][vc_column centered_text="true" column_padding="padding-3-percent" column_padding_position="left-right" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][vc_column_text]
<h1>Vbits</h1>
[/vc_column_text][vc_column_text]
<h2>Your <span style="color: #00afcb;">i</span>nnova<span style="color: #00afcb;">t</span>ive partner</h2>
<h5>網頁設計, IT解決方案, SEO 搜索引擎優化, 網路營銷, 品牌設計</h5>
[/vc_column_text][divider line_type="No Line"][vc_column_text]
<h5>我們的願景是運用持續更新、不斷完善的趨時高新IT科技提供資訊科技方案。</h5>
[/vc_column_text][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][image_with_animation image_url="6223" alignment="" animation="Fade In" delay="150"][divider line_type="No Line"][vc_column_text]
<h2>Vbits是什麼</h2>
<h5></h5>
[/vc_column_text][divider line_type="No Line"][vc_column_text]
<h5>/' V bits/</h5>
Vbits 是我們公司名字的英文縮寫 (Vision Beta IT Solutions Ltd.)
<h5>/' V/</h5>
"V" 是 願景(Vision)
<h5>/' bits/</h5>
<ol>
 	<li>bits是beta IT solutions的英文縮寫，beta 是持續更新的意思</li>
 	<li>bit也是電腦的最小位元，用0和1去記錄。bits也代表了每一項的資訊科技方案</li>
</ol>
[/vc_column_text][/vc_column][/vc_row]";s:10:"post_title";s:12:"關於我們";s:12:"post_excerpt";s:0:"";s:11:"post_status";s:7:"publish";s:14:"comment_status";s:6:"closed";s:11:"ping_status";s:6:"closed";s:13:"post_password";s:0:"";s:9:"post_name";s:5:"about";s:7:"to_ping";s:0:"";s:6:"pinged";s:0:"";s:13:"post_modified";s:19:"2016-08-04 13:06:17";s:17:"post_modified_gmt";s:19:"2016-08-04 05:06:17";s:21:"post_content_filtered";s:0:"";s:11:"post_parent";i:0;s:4:"guid";s:41:"http://web2.vbits.com.hk/zh/?page_id=6870";s:10:"menu_order";i:0;s:9:"post_type";s:4:"page";s:14:"post_mime_type";s:0:"";s:13:"comment_count";s:1:"0";s:6:"filter";s:3:"raw";}}