<?php
const Baz = 1;
const abstract = 1;
const and = 1;
const array = 1;
const as = 1;
const break = 1;
const callable = 1;
const case = 1;
const catch = 1;
const class = 1;
const clone = 1;
const const = 1;
const continue = 1;
const declare = 1;
const default = 1;
const do = 1;
const else = 1;
const elseif = 1;
const enddeclare = 1;
const endfor = 1;
const endforeach = 1;
const endif = 1;
const endswitch = 1;
const endwhile = 1;
const extends = 1;
const final = 1;
const finally = 1;
const for = 1;
const foreach = 1;
const function = 1;
const global = 1;
const goto = 1;
const if = 1;
const implements = 1;
const interface = 1;
const instanceof = 1;
const insteadof = 1;
const namespace = 1;
const new = 1;
const or = 1;
const private = 1;
const protected = 1;
const public = 1;
const static = 1;
const switch = 1;
const throw = 1;
const trait = 1;
const try = 1;
const use = 1;
const var = 1;
const while = 1;
const xor = 1;
const __CLASS__ = 1;
const __DIR__ = 1;
const __FILE__ = 1;
const __FUNCTION__ = 1;
const __METHOD__ = 1;
const __NAMESPACE__ = 1;
