��X<?php exit; ?>a:6:{s:10:"last_error";s:0:"";s:10:"last_query";s:46:"SELECT * FROM wp_posts WHERE ID = 6800 LIMIT 1";s:11:"last_result";a:1:{i:0;O:8:"stdClass":23:{s:2:"ID";s:4:"6800";s:11:"post_author";s:1:"1";s:9:"post_date";s:19:"2016-07-05 12:15:02";s:13:"post_date_gmt";s:19:"2016-07-05 04:15:02";s:12:"post_content";s:5793:"[vc_row type="full_width_content" bg_image="9" bg_position="center center" bg_repeat="no-repeat" scene_position="center" video_bg="use_video" enable_video_color_overlay="true" video_overlay_color="#0d598d" video_webm="http://www.vbits.com.hk/wp-content/uploads/2016/fp-clouds.webmhd.webm" video_mp4="http://www.vbits.com.hk/wp-content/uploads/2016/fp-clouds.mp4" video_image="6770" text_color="light" text_align="left" top_padding="5%" bottom_padding="5%" overlay_strength="0.3"][vc_column centered_text="true" column_padding="no-extra-padding" column_padding_position="left-right" background_color_opacity="1" background_hover_color_opacity="1" width="1/1"][vc_column_text]
<h1>Vbits</h1>
[/vc_column_text][vc_column_text]
<h2>Your <span style="color: #00afcb;">i</span>nnova<span style="color: #00afcb;">t</span>ive partner</h2>
<h5>網頁設計, IT解決方案, SEO 搜索引擎優化, 社交網絡行銷, 品牌設計</h5>
[/vc_column_text][/vc_column][/vc_row][vc_row type="full_width_content" scene_position="center" text_color="dark" text_align="center" overlay_strength="0.3"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color="#00d4ff" background_color_opacity="1" background_hover_color_opacity="1" width="1/3"][divider line_type="No Line"][vc_column_text]
<h2>網頁設計</h2>
<h5><span style="color: #ffffff;">符合不同設備的網頁設計</span></h5>
[/vc_column_text][image_with_animation image_url="6712" alignment="center" animation="Fade In" delay="150"][divider line_type="No Line"][vc_column_text][button open_new_tab="true" color="see-through-2" hover_text_color_override="#fff" image="default-arrow" size="large" url="http://www.vbits.com.hk/web-design/" text="詳情.." color_override=""][/vc_column_text][divider line_type="No Line"][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/3"][divider line_type="No Line"][vc_column_text]
<h2 style="text-align: center;">IT解決方案</h2>
<h5 style="text-align: center;"><span style="color: #00afcb;">超過十年的IT解決方案經驗</span></h5>
[/vc_column_text][image_with_animation image_url="6710" alignment="center" animation="Fade In" delay="150"][divider line_type="No Line"][vc_column_text][button open_new_tab="true" color="see-through-2" hover_text_color_override="#fff" image="default-arrow" size="large" url="http://www.vbits.com.hk/it-solutions/" text="詳情.." color_override=""][/vc_column_text][divider line_type="No Line"][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color="#00afcb" background_color_opacity="1" background_hover_color_opacity="1" width="1/3"][divider line_type="No Line"][vc_column_text]
<h2 style="text-align: center;">SEO 搜索引擎優化</h2>
<h5 style="text-align: center;"><span style="color: #ffffff;">提升銷售的最佳方法
</span></h5>
[/vc_column_text][image_with_animation image_url="6284" alignment="center" animation="Fade In" delay="150"][divider line_type="No Line"][vc_column_text][button open_new_tab="true" color="see-through-2" hover_text_color_override="#fff" image="default-arrow" size="large" url="http://www.vbits.com.hk/seo/" text="詳情.." color_override=""][/vc_column_text][divider line_type="No Line"][/vc_column][/vc_row][vc_row type="full_width_content" scene_position="center" text_color="dark" text_align="center" overlay_strength="0.3"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/3"][divider line_type="No Line"][vc_column_text]
<h2 style="text-align: center;">社交網絡行銷</h2>
<h5 style="text-align: center;"><span style="color: #00afcb;">想做網路營銷? 交給我們吧!</span></h5>
[/vc_column_text][image_with_animation image_url="6715" alignment="center" animation="Fade In" delay="150"][divider line_type="No Line"][vc_column_text][button open_new_tab="true" color="see-through-2" hover_text_color_override="#fff" image="default-arrow" size="large" url="http://www.vbits.com.hk/social-media-marketing/" text="詳情.." color_override=""][/vc_column_text][divider line_type="No Line"][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color="#00afcb" background_color_opacity="1" background_hover_color_opacity="1" width="1/3"][divider line_type="No Line"][vc_column_text]
<h2 style="text-align: center;">品牌設計</h2>
<h5 style="text-align: center;"><span style="color: #ffffff;">我們喜歡細節,即使是1px的修飾</span></h5>
[/vc_column_text][image_with_animation image_url="6716" alignment="center" animation="Fade In" delay="150"][divider line_type="No Line"][vc_column_text][button open_new_tab="true" color="see-through-2" hover_text_color_override="#fff" image="default-arrow" size="large" url="http://www.vbits.com.hk/brand-identity/" text="詳情.." color_override=""][/vc_column_text][divider line_type="No Line"][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/3"][divider line_type="No Line"][vc_column_text]
<h2>聯絡我們</h2>
<h5><span style="color: #00afcb;">Vbits, Your innovative partner
</span></h5>
[/vc_column_text][image_with_animation image_url="6718" alignment="center" animation="Fade In"][divider line_type="No Line"][vc_column_text][button open_new_tab="true" color="see-through-2" hover_text_color_override="#fff" image="default-arrow" size="large" url="http://www.vbits.com.hk/contact/" text="聯絡我們" color_override=""][/vc_column_text][divider line_type="No Line"][/vc_column][/vc_row]";s:10:"post_title";s:6:"主頁";s:12:"post_excerpt";s:0:"";s:11:"post_status";s:7:"publish";s:14:"comment_status";s:6:"closed";s:11:"ping_status";s:6:"closed";s:13:"post_password";s:0:"";s:9:"post_name";s:18:"%e4%b8%bb%e9%a0%81";s:7:"to_ping";s:0:"";s:6:"pinged";s:0:"";s:13:"post_modified";s:19:"2016-08-04 13:01:57";s:17:"post_modified_gmt";s:19:"2016-08-04 05:01:57";s:21:"post_content_filtered";s:0:"";s:11:"post_parent";s:1:"0";s:4:"guid";s:41:"http://web2.vbits.com.hk/zh/?page_id=6800";s:10:"menu_order";s:1:"0";s:9:"post_type";s:4:"page";s:14:"post_mime_type";s:0:"";s:13:"comment_count";s:1:"0";}}s:8:"col_info";a:23:{i:0;O:8:"stdClass":13:{s:4:"name";s:2:"ID";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:4;s:8:"not_null";i:1;s:11:"primary_key";i:1;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:1;s:4:"blob";i:0;s:4:"type";s:3:"int";s:8:"unsigned";i:1;s:8:"zerofill";i:0;}i:1;O:8:"stdClass":13:{s:4:"name";s:11:"post_author";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:1;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:1;s:10:"unique_key";i:0;s:7:"numeric";i:1;s:4:"blob";i:0;s:4:"type";s:3:"int";s:8:"unsigned";i:1;s:8:"zerofill";i:0;}i:2;O:8:"stdClass":13:{s:4:"name";s:9:"post_date";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:19;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:0;s:4:"type";s:8:"datetime";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:3;O:8:"stdClass":13:{s:4:"name";s:13:"post_date_gmt";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:19;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:0;s:4:"type";s:8:"datetime";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:4;O:8:"stdClass":13:{s:4:"name";s:12:"post_content";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:5793;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:1;s:4:"type";s:4:"blob";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:5;O:8:"stdClass":13:{s:4:"name";s:10:"post_title";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:6;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:1;s:4:"type";s:4:"blob";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:6;O:8:"stdClass":13:{s:4:"name";s:12:"post_excerpt";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:0;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:1;s:4:"type";s:4:"blob";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:7;O:8:"stdClass":13:{s:4:"name";s:11:"post_status";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:7;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:0;s:4:"type";s:6:"string";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:8;O:8:"stdClass":13:{s:4:"name";s:14:"comment_status";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:6;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:0;s:4:"type";s:6:"string";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:9;O:8:"stdClass":13:{s:4:"name";s:11:"ping_status";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:6;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:0;s:4:"type";s:6:"string";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:10;O:8:"stdClass":13:{s:4:"name";s:13:"post_password";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:0;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:0;s:4:"type";s:6:"string";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:11;O:8:"stdClass":13:{s:4:"name";s:9:"post_name";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:18;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:1;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:0;s:4:"type";s:6:"string";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:12;O:8:"stdClass":13:{s:4:"name";s:7:"to_ping";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:0;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:1;s:4:"type";s:4:"blob";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:13;O:8:"stdClass":13:{s:4:"name";s:6:"pinged";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:0;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:1;s:4:"type";s:4:"blob";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:14;O:8:"stdClass":13:{s:4:"name";s:13:"post_modified";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:19;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:0;s:4:"type";s:8:"datetime";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:15;O:8:"stdClass":13:{s:4:"name";s:17:"post_modified_gmt";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:19;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:0;s:4:"type";s:8:"datetime";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:16;O:8:"stdClass":13:{s:4:"name";s:21:"post_content_filtered";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:0;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:1;s:4:"type";s:4:"blob";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:17;O:8:"stdClass":13:{s:4:"name";s:11:"post_parent";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:1;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:1;s:10:"unique_key";i:0;s:7:"numeric";i:1;s:4:"blob";i:0;s:4:"type";s:3:"int";s:8:"unsigned";i:1;s:8:"zerofill";i:0;}i:18;O:8:"stdClass":13:{s:4:"name";s:4:"guid";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:41;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:0;s:4:"type";s:6:"string";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:19;O:8:"stdClass":13:{s:4:"name";s:10:"menu_order";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:1;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:1;s:4:"blob";i:0;s:4:"type";s:3:"int";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:20;O:8:"stdClass":13:{s:4:"name";s:9:"post_type";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:4;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:1;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:0;s:4:"type";s:6:"string";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:21;O:8:"stdClass":13:{s:4:"name";s:14:"post_mime_type";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:0;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:0;s:4:"type";s:6:"string";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:22;O:8:"stdClass":13:{s:4:"name";s:13:"comment_count";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:1;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:1;s:4:"blob";i:0;s:4:"type";s:3:"int";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}}s:8:"num_rows";i:1;s:10:"return_val";i:1;}