<h3>
    {{ strings.title }}
</h3>

<p>
    {{ strings.message }}
</p>
<input type="hidden" name="wpml_set_translation_editor_nonce" value="{{ nonces.enable }}">
<p class="js-done" style="display: none"><strong>{{ strings.enable_done }}</strong></p>
<p class="js-error" style="display: none"><strong>{{ strings.enable_error }}</strong></p>