<?php
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}
?>
<div class="vc_ui-panel-header-actions">
	<div class="vc_ui-search-box">
		<div class="vc_ui-search-box-input">
			<input type="search" id="vc_elements_name_filter"
			       placeholder="<?php echo __( 'Search element by name', 'js_composer' ) ?>">
			<label for="vc_elements_name_filter"></label>
		</div>
	</div>
</div>
