<a class="icl_tt_term_name " id="<%= trid + '-' + lang %>" title="<%= langs[ lang ].label %>: <%= labels.editTranslation %>">
	<i class="otgs-ico-edit"></i>
</a>
<div id="<%= trid + '-popup-' + lang %>"></div>
