<?php
function Baz() { };
function abstract() { };
function and() { };
function array() { };
function as() { };
function break() { };
function callable() { };
function case() { };
function catch() { };
function class() { };
function clone() { };
function const() { };
function continue() { };
function declare() { };
function default() { };
function do() { };
function else() { };
function elseif() { };
function enddeclare() { };
function endfor() { };
function endforeach() { };
function endif() { };
function endswitch() { };
function endwhile() { };
function extends() { };
function final() { };
function finally() { };
function for() { };
function foreach() { };
function function() { };
function global() { };
function goto() { };
function if() { };
function implements() { };
function interface() { };
function instanceof() { };
function insteadof() { };
function namespace() { };
function new() { };
function or() { };
function private() { };
function protected() { };
function public() { };
function static() { };
function switch() { };
function throw() { };
function trait() { };
function try() { };
function use() { };
function var() { };
function while() { };
function xor() { };
function __CLASS__() { };
function __DIR__() { };
function __FILE__() { };
function __FUNCTION__() { };
function __METHOD__() { };
function __NAMESPACE__() { };
