{% if not slot_settings.position_in_menu %}
    {% set menu_position = 'after' %}
{% else %}
    {% set menu_position = slot_settings.position_in_menu %}
{% endif %}

<h4><label>{{ strings.menus.position_label }}</label>  {% include 'tooltip.twig' with { "content": strings.tooltips.menu_position } %}</h4>
<ul>
    <li>
        <label>
            <input type="radio" name="{% if name_base %}{{ name_base }}[position_in_menu]{% else %}position_in_menu{% endif %}"
                   class=" js-wpml-ls-trigger-update"
                   value="before"{% if menu_position == 'before' %} checked="checked"{% endif %}>{{ strings.menus.position_first_item }}
        </label>
    </li>
    <li>
        <label>
            <input type="radio" name="{% if name_base %}{{ name_base }}[position_in_menu]{% else %}position_in_menu{% endif %}"
                   class=" js-wpml-ls-trigger-update"
                   value="after"{% if menu_position == 'after' %} checked="checked"{% endif %}>{{ strings.menus.position_last_item }}
        </label>
    </li>
</ul>