@import (reference) "../../popups/panel_edit_layout.less";

[data-vc-ui-element="panel-row-layout"] {
  width: 420px;
  z-index: 100001;
  top: 90px;
  left: 50%;
  .vc_row_layout {
    width: 288px;
  }
  .vc_layout-panel-switcher {
    .vc_layout-panel-switcher;
  }
  .vc_ui-panel-window-inner > .vc_ui-panel-content-container {
    overflow: hidden;
  }
}

.vc_general.vc_ui-button-update-layout {
  vertical-align: top;
}