æ˜ÔX<?php exit; ?>a:1:{s:7:"content";O:8:"stdClass":10:{s:7:"term_id";i:42;s:4:"name";s:17:"language switcher";s:4:"slug";s:17:"language-switcher";s:10:"term_group";i:0;s:16:"term_taxonomy_id";i:42;s:8:"taxonomy";s:8:"nav_menu";s:11:"description";s:0:"";s:6:"parent";i:0;s:5:"count";i:0;s:6:"filter";s:3:"raw";}}