// Just in Time Messaging - message prompts

.jp-jitm {
	border-radius: 2px;
	max-width: 100%;
	margin: 2em auto 1em auto;
	padding: .85em;
	background: #fcfcfc;
	border: 1px solid #dedede;
	text-align: center;

	// clear hack
	&:before, &:after {
		content: "";
		display: table;
	}
	&:after {
		clear: both;
	}

	#screen-meta-links + & {
	  margin: 3em 1.5385em 0 auto;
	}

	.activate {
		margin-top: .5em;
	} 
	.jp-emblem {
		width: 25px;
		height: 25px; // for ie svg
		margin: .40em 1em 0 auto;
	}

	svg {
		width: 100%;
		height: 100%;
	}

	path {
		fill: #8cc258;
	}

  	// WooCommerce jitm
  	&.woo-jitm path {
	  fill: #96588a;
	}

	.dismiss {
		margin: 0;
		text-decoration: none;
		float: right;
		&:before {
			color: #666;
			font: 400 15px/1 dashicons;
			content: '\f158';
		}
	}

	p {
		font-size: 1em;
		line-height: 165%;
	}

	.j-spinner {
		margin: 8px 0 0;
		height: 17px;
		width: 17px;
	}

	.hide {
		display: none;
	}

	form[name=post] > &:first-of-type {
		margin-top: 1em;
	}

	@media (min-width: 800px) {
		.jp-emblem, p {
			float: left;
			/* margin: .5em 1em 0 .5em;
			padding-top: 4px; */
		}
		.jp-emblem {
			width: 20px;
			height: 20px; // for ie svg
			margin-right: .5em;
		}
		p {
			margin: .40em 1em 0 0;
		}
		p + p {
			margin: 0;
			padding: 0;
		}
		.activate {
			margin-top: 0;
		}
	} // > 1100px

	@media (max-width: 1100px) {
		margin: 2.5em .75em .5em .5em;

		form[name=post] > &:first-of-type {
			margin-left: auto;
			margin-right: auto;
		}
	}

	@media (max-width: 800px) {
		.jp-emblem {
			margin: .40em auto 0 auto;
		}
	}

} // .jp-jitm

// update core page
.update-core-php .jp-jitm {
	@media (min-width: 1100px) { margin: 3em 2em 0 auto; }
}

// when jetpack is connected, we need to move up the upload prompt content so the photo JITM can fit properly.
.jetpack-connected .media-modal-content .uploader-inline-content {
	top: 20%;
}

.media-menu {

	@media only screen and (min-width: 800px) {

		.jp-jitm {
			margin: 10px 0;
			padding: 5px 5px 15px;
			border-width: 1px 0;

			.jp-emblem {
				margin: 20px 10px 0 15px;
			}

			.msg {
				width: 75%;
				text-align: left;
				margin: 0 0 10px;
			}

			.msg + p {
				text-align: center;
				width: 100%;
			}
		}
	}


	@media only screen and (max-width: 900px) {

		.jp-jitm {
			display: none;
			margin: .5em 3%;
			border-width: 1px;

			.msg {
				margin-top: 20px;
				width: 88%;
				margin-left: auto;
				margin-right: auto;
			}
		}

		&.visible .jp-jitm {
			display: block;
		}
	}

}