<?php
class Foobar { use BazTrait { oldfunction as Baz } }
class Foobar { use BazTrait { oldfunction as abstract } }
class Foobar { use BazTrait { oldfunction as and } }
class Foobar { use BazTrait { oldfunction as array } }
class Foobar { use BazTrait { oldfunction as as } }
class Foobar { use BazTrait { oldfunction as break } }
class Foobar { use BazTrait { oldfunction as callable } }
class Foobar { use BazTrait { oldfunction as case } }
class Foobar { use BazTrait { oldfunction as catch } }
class Foobar { use BazTrait { oldfunction as class } }
class Foobar { use BazTrait { oldfunction as clone } }
class Foobar { use BazTrait { oldfunction as const } }
class Foobar { use BazTrait { oldfunction as continue } }
class Foobar { use BazTrait { oldfunction as declare } }
class Foobar { use BazTrait { oldfunction as default } }
class Foobar { use BazTrait { oldfunction as do } }
class Foobar { use BazTrait { oldfunction as else } }
class Foobar { use BazTrait { oldfunction as elseif } }
class Foobar { use BazTrait { oldfunction as enddeclare } }
class Foobar { use BazTrait { oldfunction as endfor } }
class Foobar { use BazTrait { oldfunction as endforeach } }
class Foobar { use BazTrait { oldfunction as endif } }
class Foobar { use BazTrait { oldfunction as endswitch } }
class Foobar { use BazTrait { oldfunction as endwhile } }
class Foobar { use BazTrait { oldfunction as extends } }
class Foobar { use BazTrait { oldfunction as final } }
class Foobar { use BazTrait { oldfunction as finally } }
class Foobar { use BazTrait { oldfunction as for } }
class Foobar { use BazTrait { oldfunction as foreach } }
class Foobar { use BazTrait { oldfunction as function } }
class Foobar { use BazTrait { oldfunction as global } }
class Foobar { use BazTrait { oldfunction as goto } }
class Foobar { use BazTrait { oldfunction as if } }
class Foobar { use BazTrait { oldfunction as implements } }
class Foobar { use BazTrait { oldfunction as interface } }
class Foobar { use BazTrait { oldfunction as instanceof } }
class Foobar { use BazTrait { oldfunction as insteadof } }
class Foobar { use BazTrait { oldfunction as namespace } }
class Foobar { use BazTrait { oldfunction as new } }
class Foobar { use BazTrait { oldfunction as or } }
class Foobar { use BazTrait { oldfunction as static } }
class Foobar { use BazTrait { oldfunction as switch } }
class Foobar { use BazTrait { oldfunction as throw } }
class Foobar { use BazTrait { oldfunction as trait } }
class Foobar { use BazTrait { oldfunction as try } }
class Foobar { use BazTrait { oldfunction as use } }
class Foobar { use BazTrait { oldfunction as var } }
class Foobar { use BazTrait { oldfunction as while } }
class Foobar { use BazTrait { oldfunction as xor } }
class Foobar { use BazTrait { oldfunction as __CLASS__ } }
class Foobar { use BazTrait { oldfunction as __DIR__ } }
class Foobar { use BazTrait { oldfunction as __FILE__ } }
class Foobar { use BazTrait { oldfunction as __FUNCTION__ } }
class Foobar { use BazTrait { oldfunction as __METHOD__ } }
class Foobar { use BazTrait { oldfunction as __NAMESPACE__ } }
