<?php
namespace Baz;
namespace abstract;
namespace and;
namespace array;
namespace as;
namespace break;
namespace callable;
namespace case;
namespace catch;
namespace class;
namespace clone;
namespace const;
namespace continue;
namespace declare;
namespace default;
namespace do;
namespace else;
namespace elseif;
namespace enddeclare;
namespace endfor;
namespace endforeach;
namespace endif;
namespace endswitch;
namespace endwhile;
namespace extends;
namespace final;
namespace finally;
namespace for;
namespace foreach;
namespace function;
namespace global;
namespace goto;
namespace if;
namespace implements;
namespace interface;
namespace instanceof;
namespace insteadof;
namespace namespace;
namespace new;
namespace or;
namespace private;
namespace protected;
namespace public;
namespace static;
namespace switch;
namespace throw;
namespace trait;
namespace try;
namespace use;
namespace var;
namespace while;
namespace xor;
namespace __CLASS__;
namespace __DIR__;
namespace __FILE__;
namespace __FUNCTION__;
namespace __METHOD__;
namespace __NAMESPACE__;
