<?php
class Foobar extends Baz {}
class Foobar extends abstract {}
class Foobar extends and {}
class Foobar extends array {}
class Foobar extends as {}
class Foobar extends break {}
class Foobar extends callable {}
class Foobar extends case {}
class Foobar extends catch {}
class Foobar extends class {}
class Foobar extends clone {}
class Foobar extends const {}
class Foobar extends continue {}
class Foobar extends declare {}
class Foobar extends default {}
class Foobar extends do {}
class Foobar extends else {}
class Foobar extends elseif {}
class Foobar extends enddeclare {}
class Foobar extends endfor {}
class Foobar extends endforeach {}
class Foobar extends endif {}
class Foobar extends endswitch {}
class Foobar extends endwhile {}
class Foobar extends extends {}
class Foobar extends final {}
class Foobar extends finally {}
class Foobar extends for {}
class Foobar extends foreach {}
class Foobar extends function {}
class Foobar extends global {}
class Foobar extends goto {}
class Foobar extends if {}
class Foobar extends implements {}
class Foobar extends interface {}
class Foobar extends instanceof {}
class Foobar extends insteadof {}
class Foobar extends namespace {}
class Foobar extends new {}
class Foobar extends or {}
class Foobar extends private {}
class Foobar extends protected {}
class Foobar extends public {}
class Foobar extends static {}
class Foobar extends switch {}
class Foobar extends throw {}
class Foobar extends trait {}
class Foobar extends try {}
class Foobar extends use {}
class Foobar extends var {}
class Foobar extends while {}
class Foobar extends xor {}
class Foobar extends __CLASS__ {}
class Foobar extends __DIR__ {}
class Foobar extends __FILE__ {}
class Foobar extends __FUNCTION__ {}
class Foobar extends __METHOD__ {}
class Foobar extends __NAMESPACE__ {}
