.redux-container-spinner {
    .spinner-wrpr {
        position: relative;
        display: block;
        height: 30px;
        overflow: hidden;

        .spinner-input {
            position: relative !important;
            z-index: 1;
            width: 45px !important;
            height: 30px !important;
            background: #e7e7e7 !important;
            border: 1px solid #bfbfbf !important;
            border-right: 0 !important;
            border-left: 0 !important;
            -webkit-border-radius: 0 !important;
            -moz-border-radius: 0 !important;
            border-radius: 0 !important;
        }
    }

    .ui-spinner {
        position: static;
        display: inline;
    }


    .ui-spinner-buttons {
        position: absolute;
        padding: 0;
    }

    .ui-widget .ui-spinner-button {
        position: absolute;
        top: 0;
        padding: 0 0 30px;
        overflow: hidden;
        cursor: pointer;
        background: -moz-linear-gradient(#ffffff, #f3f3f3);
        background: -o-linear-gradient(#ffffff, #f3f3f3);
        background: -webkit-gradient(linear, left top, left bottom, from(#ffffff), to(#f3f3f3));
        background: linear-gradient(#ffffff, #f3f3f3);
        background-color: #ffffff;
        border: none;
        -webkit-box-shadow: none;
        -moz-box-shadow: none;
        box-shadow: none;
    }

    .ui-spinner-button:hover,
    .ui-state-hover {
        background: -moz-linear-gradient(#f3f3f3, #ffffff);
        background: -o-linear-gradient(#f3f3f3, #ffffff);
        background: -webkit-gradient(linear, left top, left bottom, from(#f3f3f3), to(#ffffff));
        background: linear-gradient(#f3f3f3, #ffffff);
        background-color: #f3f3f3;
    }

    .ui-corner-tr,
    .ui-spinner-button .ui-icon-triangle-1-n {
        -webkit-border-radius: 0 5px 5px 0;
        -moz-border-radius: 0 5px 5px 0;
        border-radius: 0 5px 5px 0;
    }

    .ui-corner-br,
    .ui-spinner-button .ui-icon-triangle-1-s {
        -webkit-border-radius: 5px 0 0 5px;
        -moz-border-radius: 5px 0 0 5px;
        border-radius: 5px 0 0 5px;
    }

    .ui-spinner-button {
        .ui-icon {
            top: 0;
            display: block;
            width: 28px;
            height: 28px;
            margin: 0;
            border: 1px solid #b7b7b7;
        }

        .ui-icon-triangle-1-n {
            background: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAYAAAAKCAYAAACXDi8zAAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAADxJREFUeNpsjwsKADAIQu3u3tsRY6M5gz7w0AqSQFLdZ3ZRgmf44JQ/EOZ9oYOsiDviVemP2oYoWCwBBgDpO6VXVo3RyQAAAABJRU5ErkJggg==) 10px 10px no-repeat!important;
        }

        .ui-icon-triangle-1-s {
            background: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAYAAAAKCAYAAACXDi8zAAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAADhJREFUeNpi+P//PwM6bmlpwS4IorEKokggC8Il0AVhEv9x6sAmiaz9P05XIUsygmVRAUiAESDAAFHcpVdWtdj/AAAAAElFTkSuQmCC) 10px 10px no-repeat!important;
        }
    }
}

@media screen and (max-width: 570px) {
    .redux-container-spinner {
        .spinner-wrpr {
            //text-align: center;
            // Need to center align this SOMEHOW
        }
    }
}