<?php

// autoload_files.php @generated by Composer

$vendorDir = dirname(dirname(__FILE__));
$baseDir = dirname($vendorDir);

return array(
    '995b589e693a50f54393aa31ee1c3763' => $vendorDir . '/yoast/whip/src/facades/wordpress.php',
);
