/*
 *
 * Do not edit the CSS in this file, it will be overwritten with updates.
 * Use the included custom.css file instead.
 *
 */

[class^="icon-"],[class*=" icon-"] {
	color: #333!important;
}


#redux-opts-heading {
	margin-bottom: 20px;
}

#redux-opts-form-wrapper {
	background-color: #F7F7F7; /* Old browsers */
	background-repeat: repeat-x; /* Repeat the gradient */
	background-image: -moz-linear-gradient(top, #f5f5f5 0%, #F7F7F7 100%); /* FF3.6+ */
	background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#f5f5f5), color-stop(100%,#F7F7F7)); /* Chrome,Safari4+ */
	background-image: -webkit-linear-gradient(top, #f5f5f5 0%,#F7F7F7 100%); /* Chrome 10+,Safari 5.1+ */
	background-image: -ms-linear-gradient(top, #f5f5f5 0%,#F7F7F7 100%); /* IE10+ */
	background-image: -o-linear-gradient(top, #f5f5f5 0%,#F7F7F7 100%); /* Opera 11.10+ */
	filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#f5f5f5', endColorstr='#F7F7F7',GradientType=0 ); /* IE6-9 */
	background-image: linear-gradient(top, #f5f5f5 0%,#F7F7F7 100%); /* W3C */
    border: 1px solid #e5e5e5;
	
	-moz-border-radius: 10px; /* Firefox */
	-webkit-border-radius: 10px; /* Safari, Chrome */
	border-radius: 10px;
	
	-moz-box-shadow: 0 1px 0 #FFFFFF inset, 0 1px 5px rgba(0, 0, 0, 0.1);
	-webkit-box-shadow: 0 1px 0 #FFFFFF inset, 0 1px 5px rgba(0, 0, 0, 0.1);
	box-shadow: 0 1px 0 #FFFFFF inset, 0 1px 5px rgba(0, 0, 0, 0.1);
	margin-top: 30px;
}

#redux-opts-form-wrapper .hr {
	height: 1px;
	width: 60%;
	border-bottom: 1px solid #DFDFDF;
	margin: 0 auto;
	margin-bottom: -20px;
}

.redux-opts-info-field {
	margin-bottom: -20px;
}

#redux-opts-header,
#redux-opts-footer {
	text-align: right;
	padding: 20px;	
}

#redux-opts-header {
	background-color: #332d39;
	border-radius: 10px 10px 0px 0px;
	border-bottom: 1px solid #DFDFDF;
}

#redux-opts-footer {
	border-top: 1px solid #DFDFDF;
}

#redux-opts-footer #redux-opts-share {
	float: left;
}

#redux-opts-footer #redux-opts-share a {
	margin-right: 10px;
}

#redux-opts-footer #redux-opts-share a img {
	margin-bottom: -3px;
}

#redux-opts-sub-footer {
    text-align: center;
    font-size: .8em;
}

#redux-opts-save {
	margin: 0px;
	border-bottom: 1px solid #DFDFDF;
    background-color: #DFF0D8;
    color: #468847;
    padding: 8px 35px 8px 14px;
    text-shadow: 0 1px 0 rgba(255, 255, 255, 0.5);
}

#redux-opts-imported {
	margin: 0px;
	border-bottom: 1px solid #BCE8F1;
    background-color: #D9EDF7;
    color: #3A87AD;
    padding: 8px 35px 8px 14px;
    text-shadow: 0 1px 0 rgba(255, 255, 255, 0.5);
}

#redux-opts-save-warn {
	margin: 0px;
	display: none;
	border-bottom: 1px solid #DFDFDF;
	background-color: #FCF8E3;
    color: #C09853;
    padding: 8px 35px 8px 14px;
    text-shadow: 0 1px 0 rgba(255, 255, 255, 0.5);
}

#redux-opts-field-warnings {
	margin: 0px;
	display: none;
	border-bottom: 1px solid #DFDFDF;
	background-color: #FCF8E3;
    color: #C09853;
    padding: 8px 35px 8px 14px;
    text-shadow: 0 1px 0 rgba(255, 255, 255, 0.5);	
}

#redux-opts-field-errors {
	margin: 0px;
	display: none;
	border-bottom: 1px solid #DFDFDF;
    background-color: #F2DEDE;
    color: #B94A48;
    padding: 8px 35px 8px 14px;
    text-shadow: 0 1px 0 rgba(255, 255, 255, 0.5);	
}

#redux-opts-sidebar,
#redux-opts-main {
	min-height: 300px;
}

#redux-opts-sidebar {
	width: 170px;
	float: left;
}

.redux-opts-menu-warning {
	background-color: #C09853;
    color: #FCF8E3;
	display: inline-block;
	float: right;
    padding: 6px 7px 4px 7px;
    margin-left: 4px;
	-moz-border-radius: 20px; /* Firefox */
	-webkit-border-radius: 20px; /* Safari, Chrome */
	border-radius: 20px;
	font-family: sans-serif;
    font-size: 9px;
    font-weight: bold;
    line-height: 9px;
}

.redux-opts-menu-error {
	background-color: #B94A48;
    color: #F2DEDE;
	display: inline-block;
	float: right;
    padding: 6px 7px 4px 7px;
    margin-left: 4px;
	-moz-border-radius: 20px; /* Firefox */
	-webkit-border-radius: 20px; /* Safari, Chrome */
	border-radius: 20px;
	font-family: sans-serif;
    font-size: 9px;
    font-weight: bold;
    line-height: 9px;
}

#redux-opts-main {
	background: #FFFFFF;
	margin-left: 171px;
	border-left: 1px solid #DFDFDF;
	padding: 10px 20px;
}

#redux-opts-sidebar #redux-opts-group-menu {
	margin-top: 0px;
}

#redux-opts-sidebar #redux-opts-group-menu li {
	margin: 0px;
}

#redux-opts-sidebar #redux-opts-group-menu li.divide {
	padding: 0px;
	border-width: 1px 0px 1px 0px;
	border-style: solid;
    border-bottom-color: #DFDFDF;
    border-top-color: #F9F9F9;
}

#redux-opts-sidebar #redux-opts-group-menu li a {
	display: block;
	padding: 14px 14px;
	background: #F7F7F7;
	border-width: 1px 0px 1px 0px;
	border-style: solid;
    border-bottom-color: #DFDFDF;
    border-top-color: #F9F9F9;
    color: #797979;
    font-weight: normal;
    text-decoration:none;
}

#redux-opts-sidebar #redux-opts-group-menu li a.custom-tab {
	background: #f6f6f6;
}

#redux-opts-sidebar #redux-opts-group-menu li a img {
	width: 16px;
	height: 16px;
	/*vertical-align:middle;*/
	margin-bottom:-3px;
}

#redux-opts-sidebar #redux-opts-group-menu li a:hover {
	background: #f2f2f2;
	width: 144px;
	margin-right: -2px;
}

#redux-opts-sidebar #redux-opts-group-menu li.active a {
	background: #ffffff;
	width: 144px;
	margin-right: -2px;
}

.redux-opts-group-tab {
	display: none;
}

.redux-opts-group-tab h3, .redux-opts-heading h3 {
	margin-top: 0px;
	font-size: 1.8em!important;
	line-height: 2em;
	font-style: normal;
	color: #222;
	border-bottom: 1px solid #DFDFDF;
}

.redux-opts-group-tab .redux-opts-section-desc {
	font-style: italic;
	font-size: 1.2em;
	color: #666666;
}

.redux-opts-group-tab .form-table {
	border-top: 1px solid #DFDFDF;
	clear: none;
	margin-top: 20px;
}

.redux-opts-group-tab .form-table.no-border {
	border-top: none;
}

.redux-opts-group-tab .form-table tr {
	border-bottom: 1px solid #DFDFDF;
}
.redux-opts-group-tab .form-table tr:last-child {
	border-bottom: none;
}
.redux-opts-group-tab .form-table tr th,
.redux-opts-group-tab .form-table tr td {
	padding: 20px 20px 40px 20px;
	color: #797979;
}

.redux-opts-group-tab .form-table tr th {
	font-weight: bold;
	font-size: 1.1em;
	width: 35%;
}

.redux-opts-group-tab .form-table.typography-table tr th {
	font-size: 13px;
}

.redux-opts-group-tab .form-table tr th span:first-child {
	font-weight: normal;
	display: block;
	color: #666666;
}

.redux-opts-group-tab .form-table tr td .redux-opts-th-warning {
	font-size: 1em;
    color: #C09853;
	font-weight: normal;
	display: block;
}

.redux-opts-group-tab .form-table tr td .redux-opts-field-warning {
	border-color: #C09853;
}

.redux-opts-group-tab .form-table tr td .redux-opts-th-error {
	font-size: 1em;
	color: #B94A48;
	font-weight: normal;
	display: block;
}

.redux-opts-group-tab .form-table tr td .redux-opts-field-error {
	border-color: #B94A48;
}

/* reset nested tables for mce */
.redux-opts-group-tab .form-table tr td table.mceLayout,
.redux-opts-group-tab .form-table tr td table.mceLayout tr,
.redux-opts-group-tab .form-table tr td table.mceLayout tr td {
	padding:0px;
	border-width:0px;
}

.redux-opts-group-tab .redux-opts-item-data {
	padding: 20px 0px;
	border-top: 1px solid #DFDFDF;
}

.redux-opts-group-tab .redux-opts-item-data.item-uri,
.redux-opts-group-tab .redux-opts-item-data.item-author,
.redux-opts-group-tab .redux-opts-item-data.item-version {
	padding:0px;
	border-width:0px;
}

.redux-opts-group-tab .redux-opts-item-data.item-description {
	padding: 10px 0px;
	border-width: 0px;
}

.redux-opts-group-tab fieldset span {
	font-size: 12px;	
}

[class^="icon-"], [class*=" icon-"] {
	color: #333333;
}

/*
 *
 * Redux_Options_radio_img
 *
 */
.redux-radio-img input[type='radio'] {
	display: none;
}

.redux-radio-img,
.redux-radio-img-selected {
	margin: 6px;
	display: inline-block;
	padding: 10px;
	border: 1px solid #FFF;
}

.redux-radio-img:hover {
	border: 1px solid #E1e1e1;
}

.redux-radio-img-selected {
	background-color: #f9f9f9;
	border: 1px solid #e1e1e1;
}

.redux-radio-img img,
.redux-radio-img-selected img {
	border-width: 4px;
	border-style: solid;
}

.redux-radio-img img {
	border-color: #fff;
}

.redux-radio-img-selected img {
		border-color: #e9e9e9;
}

/*
 *
 * Redux_Options_color
 *
 */
.iris-picker .iris-slider-offset {
   /* position: relative !important;
    top: 0 !important;
    bottom: 0 !important;*/
}

.iris-picker .ui-slider-vertical {
    width: auto;
    height: 100%;
    background: none;
}

.farb-popup-wrapper {
	position: relative;
	display: block;
}

.farb-popup {
	position: absolute;
	left: 40px;
	top: 40px;
	background-color: white;
	border: 1px solid #222;
	padding: 5px;
	z-index: 100;
}

#redux-opts-import-link-wrapper,
#redux-opts-import-code-wrapper {
	display: none;
}

#redux-opts-export-code,
#redux-opts-export-link-value {
	display: none;
}

#redux-opts-import-action span {
	color: #B94A48;
}

#import_divide {
	margin: 40px 0px;
	border-bottom: 1px solid #DFDFDF;
}

.redux-opts-screenshot {
	max-width: 300px;
	display: block;
}

@media screen and (max-width : 900px) {
	#redux-opts-sidebar {
		width: 42px;
	}

	#redux-opts-main {
		margin-left: 43px;
	}

	.redux-opts-group-tab-link-a {
		position: relative;
	}

	.redux-opts-group-tab-link-a span {
		display: none;
		position: absolute;
		top: 0;
		left: 44px;
		padding: 14px;
		width: 200px;
		background: #F7F7F7;
		border: 1px solid #DFDFDF;
		border-width: 1px 1px 1px 0px;
	}

	.redux-opts-group-tab-link-a:hover > span {
		display: block;
	}

	#redux-opts-sidebar #redux-opts-group-menu li a,
	#redux-opts-sidebar #redux-opts-group-menu li a:hover,
	#redux-opts-sidebar #redux-opts-group-menu li.active a,
	#redux-opts-sidebar #redux-opts-group-menu li.active a:hover {
		width: 15px;
	}
	
	table.form-table, .form-table > thead, .form-table > tbody, .form-table > tbody > tr > th, .form-table > tbody > tr > td, .form-table > tbody > tr {
		display: block !important;
		width: 100% !important;
		padding: 0px !important;
	}

	.form-table > tbody > tr > th, .form-table > tbody > tr > td {
		padding: 10px !important;
	}

	.form-table > tbody > tr > td span.description {
		display: block;
	}
}

/*
 This css and associated images borrow heavily from the fantastic 
 chosen select box plugin.
 
 Copyright (c) 2011 Harvest http://getharvest.com

 MIT License, https://github.com/harvesthq/chosen/blob/master/LICENSE.md
*/

.font-select {
  font-size: 16px;
  width: 210px;
  position: relative;
  display: inline-block;
  zoom: 1;
  *display: inline;
}

.font-select .fs-drop {
  background: #fff;
  border: 1px solid #aaa;
  border-top: 0;
  position: absolute;
  top: 29px;
  left: 0;
  -webkit-box-shadow: 0 4px 5px rgba(0,0,0,.15);
  -moz-box-shadow   : 0 4px 5px rgba(0,0,0,.15);
  -o-box-shadow     : 0 4px 5px rgba(0,0,0,.15);
  box-shadow        : 0 4px 5px rgba(0,0,0,.15);
  z-index: 999;
}

.font-select > a {
  background-color: #fff;
  background-image: -webkit-gradient(linear, left bottom, left top, color-stop(0, #eeeeee), color-stop(0.5, white));
  background-image: -webkit-linear-gradient(center bottom, #eeeeee 0%, white 50%);
  background-image: -moz-linear-gradient(center bottom, #eeeeee 0%, white 50%);
  background-image: -o-linear-gradient(top, #eeeeee 0%,#ffffff 50%);
  background-image: -ms-linear-gradient(top, #eeeeee 0%,#ffffff 50%);
  filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#eeeeee', endColorstr='#ffffff',GradientType=0 );
  background-image: linear-gradient(top, #eeeeee 0%,#ffffff 50%);
  -webkit-border-radius: 4px;
  -moz-border-radius   : 4px;
  border-radius        : 4px;
  -moz-background-clip   : padding;
  -webkit-background-clip: padding-box;
  background-clip        : padding-box;
  border: 1px solid #aaa;
  display: block;
  overflow: hidden;
  white-space: nowrap;
  position: relative;
  height: 26px;
  line-height: 26px;
  padding: 0 0 0 8px;
  color: #444;
  text-decoration: none;
}

.font-select > a span {
  margin-right: 26px;
  display: block;
  overflow: hidden;
  white-space: nowrap;
  line-height: 1.8;
  -o-text-overflow: ellipsis;
  -ms-text-overflow: ellipsis;
  text-overflow: ellipsis;
  cursor: pointer;
}

.font-select > a div {
  -webkit-border-radius: 0 4px 4px 0;
  -moz-border-radius   : 0 4px 4px 0;
  border-radius        : 0 4px 4px 0;
  -moz-background-clip   : padding;
  -webkit-background-clip: padding-box;
  background-clip        : padding-box;
  background: #ccc;
  background-image: -webkit-gradient(linear, left bottom, left top, color-stop(0, #ccc), color-stop(0.6, #eee));
  background-image: -webkit-linear-gradient(center bottom, #ccc 0%, #eee 60%);
  background-image: -moz-linear-gradient(center bottom, #ccc 0%, #eee 60%);
  background-image: -o-linear-gradient(bottom, #ccc 0%, #eee 60%);
  background-image: -ms-linear-gradient(top, #cccccc 0%,#eeeeee 60%);
  filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#cccccc', endColorstr='#eeeeee',GradientType=0 );
  background-image: linear-gradient(top, #cccccc 0%,#eeeeee 60%);
  border-left: 1px solid #aaa;
  position: absolute;
  right: 0;
  top: 0;
  display: block;
  height: 100%;
  width: 18px;
}

.font-select > a div b {
  background: url('../img/fs-sprite.png') no-repeat 0 1px;
  display: block;
  width: 100%;
  height: 100%;
  cursor: pointer;
}

.font-select .fs-drop {
  -webkit-border-radius: 0 0 4px 4px;
  -moz-border-radius   : 0 0 4px 4px;
  border-radius        : 0 0 4px 4px;
  -moz-background-clip   : padding;
  -webkit-background-clip: padding-box;
  background-clip        : padding-box;
}

.font-select .fs-results {
  margin: 0 4px 4px 0;
  max-height: 190px;
  width: 200px;
  padding: 0 0 0 4px;
  position: relative;
  overflow-x: hidden;
  overflow-y: auto;
}

.font-select .fs-results li {
  line-height: 80%;
  padding: 7px 7px 8px;
  margin: 0;
  list-style: none;
  font-size: 18px;
}

.font-select .fs-results li.active {
  background: #3875d7;
  color: #fff;
  cursor: pointer;
}
.font-select .fs-results li em {
  background: #feffde;
  font-style: normal;
}

.font-select .fs-results li.active em {
  background: transparent;
}

.font-select-active > a {
  -webkit-box-shadow: 0 0 5px rgba(0,0,0,.3);
  -moz-box-shadow   : 0 0 5px rgba(0,0,0,.3);
  -o-box-shadow     : 0 0 5px rgba(0,0,0,.3);
  box-shadow        : 0 0 5px rgba(0,0,0,.3);
  border: 1px solid #5897fb;
}

.font-select-active > a {
  border: 1px solid #aaa;
  -webkit-box-shadow: 0 1px 0 #fff inset;
  -moz-box-shadow   : 0 1px 0 #fff inset;
  -o-box-shadow     : 0 1px 0 #fff inset;
  box-shadow        : 0 1px 0 #fff inset;
  background-color: #eee;
  background-image: -webkit-gradient(linear, left bottom, left top, color-stop(0, white), color-stop(0.5, #eeeeee));
  background-image: -webkit-linear-gradient(center bottom, white 0%, #eeeeee 50%);
  background-image: -moz-linear-gradient(center bottom, white 0%, #eeeeee 50%);
  background-image: -o-linear-gradient(bottom, white 0%, #eeeeee 50%);
  background-image: -ms-linear-gradient(top, #ffffff 0%,#eeeeee 50%);
  filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#ffffff', endColorstr='#eeeeee',GradientType=0 );
  background-image: linear-gradient(top, #ffffff 0%,#eeeeee 50%);
  -webkit-border-bottom-left-radius : 0;
  -webkit-border-bottom-right-radius: 0;
  -moz-border-radius-bottomleft : 0;
  -moz-border-radius-bottomright: 0;
  border-bottom-left-radius : 0;
  border-bottom-right-radius: 0;
}

.font-select-active > a div {
  background: transparent;
  border-left: none;
}

.font-select-active > a div b {
  background-position: -18px 1px;
}

/* checkbox switch */
.switch_wrap input[type="checkbox"] {
  position:absolute;
  left:-9999px;
  opacity: 0;
}

.switch_wrap input[type="checkbox"]:checked + .switch {
  background-color: #6cbc43;
}

.switch_wrap input[type="checkbox"]:checked + .switch::before {
  display: block;
}

.switch_wrap input[type="checkbox"]:checked + .switch::after {
  display: none;
}

.switch_wrap input[type="checkbox"]:checked + .switch .bullet {
  left: 33px;
}

.switch_wrap .switch {
  position: relative;
  display: inline-block;
  width: 65px;
  height: 24px;
  line-height: 24px;
  margin-right: 1em;
  margin-top: -3px;
  vertical-align: middle;
  background-color: #c1272d;
  border-radius: 3px;
  border: 1px solid rgba(0, 0, 0, 0.2);
  -webkit-box-shadow: 0 0 3px rgba(0, 0, 0, 0.25) inset, 0 1px 0 rgb(255,255,255);
  box-shadow: 0 0 3px rgba(0, 0, 0, 0.25) inset, 0 1px 0 rgb(255,255,255);
}

.switch_wrap .switch::before,
.switch_wrap .switch::after {
  content: 'ON';
  display: none;
  width: 50%;
  position: absolute;
  top: 0;
  font-size: 11px;
  font-weight: bold;
  color: white;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
  text-align: center;
}

.switch_wrap .switch::after {
  content: 'OFF';
  display: block;
  right: 0;
}

.switch_wrap .switch .bullet {
  position: relative;
  display: block;
  width: 32px;
  height: 26px;
  top: -2px;
  left: -2px;
  background-color: #f0f0f0;
  background-image: -webkit-gradient(linear, left top, left bottom, from(#f0f0f0), to(#e6e6e6));
  background-image: -webkit-linear-gradient(top, #f0f0f0, #e6e6e6);
  background-image: -moz-linear-gradient(top, #f0f0f0, #e6e6e6);
  background-image: -ms-linear-gradient(top, #f0f0f0, #e6e6e6);
  background-image: -o-linear-gradient(top, #f0f0f0, #e6e6e6);
  background-image: linear-gradient(top, #f0f0f0, #e6e6e6);
  border: 1px solid rgba(0, 0, 0, 0.3);
  border-radius: 3px;
  -webkit-box-shadow: 0 1px 0 white inset, 0 1px 1px rgba(0, 0, 0, 0.25);
  box-shadow: 0 1px 0 white inset, 0 1px 1px rgba(0, 0, 0, 0.25);
  -webkit-transition: left 0.1s linear;
  -moz-transition: left 0.1s linear;
  -ms-transition: left 0.1s linear;
  -o-transition: left 0.1s linear;
  transition: left 0.1s linear;
}

.switch_wrap .switch .bullet::before,
.switch_wrap .switch .bullet::after {
  content: '';
  display: block;
  height: 15px;
  width: 3px;
  position: absolute;
  top: 5px;
  left: 50%;
  margin-left: -6px;
  border: 1px solid #cccccc;
  border-width: 0 1px;
  -webkit-box-shadow: 1px 0 0 white, 1px 0 0 white inset;
  box-shadow: 1px 0 0 white, 1px 0 0 white inset;
}

.switch_wrap .switch .bullet::after {
  margin-left: 2px;
}

/* Fix datepicker empty div at bottom of the page */
#ui-datepicker-div { 
	display: none;
}

/* TODO: remove pink */
.pink {
	background: pink;
}

#redux-opts-main .hide {
    display: none;
}

#redux-opts-main .ace_editor {
    border-radius: 3px;
    height: 350px;
}


/* RTL support */
.rtl #redux-opts-sidebar{float: right;}
.rtl #redux-opts-main{
	margin-left: 0;margin-right: 171px;
	border-right: 1px solid #DFDFDF;border-left:none;}
.rtl .switch_wrap input[type="checkbox"]{left: auto;right: -9999px;}
.rtl .switch_wrap .switch::after{left: 0;right:auto;}

@media screen and (max-width: 900px){
.rtl #redux-opts-main{    margin-right: 43px;}
}
