��X<?php exit; ?>a:1:{s:7:"content";O:8:"stdClass":24:{s:2:"ID";i:6802;s:11:"post_author";s:1:"1";s:9:"post_date";s:19:"2016-07-05 12:15:57";s:13:"post_date_gmt";s:19:"2016-07-05 04:15:57";s:12:"post_content";s:8260:"[vc_row type="full_width_background" scene_position="center" text_color="dark" text_align="center" bottom_padding="5%" color_overlay="#ffffff" overlay_strength="0.3"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/1"][vc_column_text]
<h2>符合不同設備的網頁設計</h2>
<h5><span style="color: #bbbbbb;">無論是桌上電腦，平板電腦還是手機，都看得舒適</span></h5>
[/vc_column_text][divider line_type="No Line"][image_with_animation image_url="6274" alignment="center" animation="Fade In" delay="150"][/vc_column][/vc_row][vc_row type="full_width_background" scene_position="center" text_color="dark" text_align="center" top_padding="5%" bottom_padding="5%" color_overlay="#00afcb" overlay_strength="0.3"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][split_line_heading]
<h2>對的網頁設計,是踏出成功的第一步</h2>
[/split_line_heading][vc_row_inner top_padding="15" bottom_padding="25"][vc_column_inner enable_animation="true" animation="fade-in-from-bottom" column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" width="1/1"][vc_column_text][icon enable_animation="true" color="Accent-Color" animation_speed="Medium" icon_size="128" animation_delay="400" image="basic_lightbulb.svg"]

作為香港網頁設計公司，我們有超過十年不同類型的網頁設計及網站製作經驗，對影像、視像、文字、表格、商業思維、網路平台及搜尋引擎的整合，給您十足信心。[/vc_column_text][/vc_column_inner][/vc_row_inner][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][image_with_animation image_url="6357" alignment="center" animation="Fade In" delay="150"][/vc_column][/vc_row][vc_row type="full_width_background" bg_color="#ffffff" scene_position="center" text_color="dark" text_align="left" top_padding="5%" bottom_padding="5%" color_overlay="#ededed" overlay_strength="0.3"][vc_column column_padding="padding-2-percent" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][split_line_heading]
<h2>設計符合不同要求及風格，讓我們為您辦妥</h2>
[/split_line_heading][image_with_animation image_url="6370" alignment="center" animation="Fade In" delay="150"][vc_row_inner][vc_column_inner enable_animation="true" animation="fade-in-from-bottom" column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" width="1/1"][vc_column_text]
<h6 style="color: #1e83ec;">需要其他服務嗎?</h6>
<span style="color: rgba(0,0,0,0.45);">IT解決方案 | 搜索引擎優化 | 社交網絡行銷 | 品牌設計</span>[/vc_column_text][/vc_column_inner][/vc_row_inner][/vc_column][vc_column column_padding="padding-2-percent" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" top_margin="5%" width="1/4"][vc_column_text css=".vc_custom_1467688975614{margin-bottom: 18px !important;}"]
<h5>不同型式的網頁設計</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #999999;">網頁設計</span></li>
 	<li><span style="color: #999999;">部落格設計</span></li>
 	<li><span style="color: #999999;">網上商店</span></li>
 	<li><span style="color: #999999;">活動介紹網頁</span></li>
 	<li><span style="color: #999999;">產品展示網頁</span></li>
</ul>
[/fancy-ul][vc_column_text css=".vc_custom_1467697234880{margin-bottom: 18px !important;}"]
<h5>商業分析 / 網站管理</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #999999;">網頁流量分析</span></li>
 	<li><span style="color: #999999;">搜尋引擎內容管理</span></li>
 	<li><span style="color: #999999;">網頁內容管理</span></li>
</ul>
[/fancy-ul][/vc_column][vc_column column_padding="padding-2-percent" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" top_margin="5%" width="1/4"][vc_column_text css=".vc_custom_1467689233559{margin-bottom: 18px !important;}"]
<h5>網頁特色</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #999999;">全面支援HTML5</span></li>
 	<li><span style="color: #999999;">自動符合頁面尺寸的設計</span></li>
 	<li><span style="color: #999999;">符合搜尋引擎的後台編程</span></li>
 	<li><span style="color: #999999;">Google服務嵌入</span></li>
 	<li><span style="color: #999999;">多國語言設計</span></li>
</ul>
[/fancy-ul][vc_column_text css=".vc_custom_1467697569338{margin-bottom: 18px !important;}"]
<h5>進階網站功能</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #999999;">網上支付系統</span></li>
 	<li><span style="color: #999999;">電郵訂閱系統</span></li>
 	<li><span style="color: #999999;">會員登入系統</span></li>
</ul>
[/fancy-ul][/vc_column][/vc_row][vc_row type="full_width_background" scene_position="center" text_color="dark" text_align="center" top_padding="5%" color_overlay="#00afcb" overlay_strength="0.3"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/1"][vc_column_text]
<h2>網頁設計參考</h2>
[/vc_column_text][/vc_column][/vc_row][vc_row type="full_width_background" scene_position="center" text_color="dark" text_align="left" top_padding="2%" color_overlay="#00afcb" overlay_strength="0.3"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/3"][fancy_box image_url="6330" link_new_tab="true" color="Accent-Color" link_url="http://energywatt.hk" link_text="energywatt.hk"]
<h3>Energywatt</h3>
Hong Kong famous sports Drink[/fancy_box][fancy_box image_url="6403" link_new_tab="true" color="Accent-Color" link_url="http://www.hangpotc.com" link_text="hangpotc.com"]
<h3>Hangpo</h3>
Hong Kong shuttle bus service[/fancy_box][fancy_box image_url="6410" link_new_tab="true" color="Accent-Color" link_url="http://www.kingsproduction.com.hk" link_text="kingsproduction.com.hk"]
<h3>Kings Production</h3>
Hong Kong Photographer[/fancy_box][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/3"][fancy_box image_url="6399" link_new_tab="true" color="Accent-Color" link_url="http://www.the-studio.com.hk" link_text="the-studio.com.hk"]
<h3>THE STUDIO</h3>
Hong Kong Photography Brand[/fancy_box][fancy_box image_url="6775" link_new_tab="true" color="Accent-Color" link_url="http://www.unisonpro.com.hk" link_text="unisonpro.com.hk"]
<h3>Unison Production</h3>
Hong Kong Live music brand[/fancy_box][fancy_box image_url="6412" link_new_tab="true" color="Accent-Color" link_url="http://www.faceshk.com" link_text="faceshk.com"]
<h3>Faces Blog</h3>
Hong Kong Makeup blog[/fancy_box][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/3"][fancy_box image_url="6401" link_new_tab="true" color="Accent-Color" link_url="http://www.cocoonbridal.com" link_text="cocoonbridal.com"]
<h3>Cocoon Bridal</h3>
Hong Kong Bridal company[/fancy_box][fancy_box image_url="6777" link_new_tab="true" color="Accent-Color" link_url="http://www.cherwish.hk" link_text="cherwish.hk"]
<h3>Cherwish</h3>
Hong Kong Online Fashion store[/fancy_box][fancy_box image_url="6779" link_new_tab="true" color="Accent-Color" link_url="http://www.odo.hk" link_text="odo.hk"]
<h3>ODO</h3>
Indian handmade fashion and accessories[/fancy_box][/vc_column][/vc_row]";s:10:"post_title";s:12:"網頁設計";s:12:"post_excerpt";s:0:"";s:11:"post_status";s:7:"publish";s:14:"comment_status";s:6:"closed";s:11:"ping_status";s:6:"closed";s:13:"post_password";s:0:"";s:9:"post_name";s:10:"web-design";s:7:"to_ping";s:0:"";s:6:"pinged";s:0:"";s:13:"post_modified";s:19:"2016-08-17 14:02:12";s:17:"post_modified_gmt";s:19:"2016-08-17 06:02:12";s:21:"post_content_filtered";s:0:"";s:11:"post_parent";i:0;s:4:"guid";s:41:"http://web2.vbits.com.hk/zh/?page_id=6802";s:10:"menu_order";i:0;s:9:"post_type";s:4:"page";s:14:"post_mime_type";s:0:"";s:13:"comment_count";s:1:"0";s:6:"filter";s:3:"raw";}}