<a class="icl_tt_label lowlight" id="<%= taxonomy %>_<%= lang %>" title="<%= langs[ lang ].label %>: <%= labels.addTranslation %>" >
	<i class="otgs-ico-add"></i>
</a>
<div id="popup-<%= lang %>"></div>
