{% set force           = data.templates[ template_slug ].force_settings %}
{% set is_hierarchical = slot_settings.slot_group == 'menus' and slot_settings.is_hierarchical %}

<h4>{{ strings.misc.title_what_to_include }} {% include 'tooltip.twig' with { "content": strings.tooltips.what_to_include } %}</h4>
<ul class="js-wpml-ls-to-include">
    <li>
        <label><input type="checkbox" class="js-wpml-ls-setting-display_flags js-wpml-ls-trigger-update"
                      name="{% if name_base %}{{ name_base }}[display_flags]{% else %}display_flags{% endif %}"
                      {% if force.display_flags is defined  %} disabled="disabled"{% endif %}
                      value="1"{% if slot_settings.display_flags %} checked="checked"{% endif %}> {{ strings.misc.label_include_flag }}</label>
    </li>
    <li>
        <label><input type="checkbox" class="js-wpml-ls-setting-display_names_in_native_lang js-wpml-ls-trigger-update"
                      name="{% if name_base %}{{ name_base }}[display_names_in_native_lang]{% else %}display_names_in_native_lang{% endif %}"
                      {% if force.display_names_in_native_lang is defined %} disabled="disabled"{% endif %}
                      value="1"{% if slot_settings.display_names_in_native_lang %} checked="checked"{% endif %}> {{ strings.misc.label_include_native_lang }}</label>
    </li>
    <li>
        <label><input type="checkbox" class="js-wpml-ls-setting-display_names_in_current_lang js-wpml-ls-trigger-update"
                      name="{% if name_base %}{{ name_base }}[display_names_in_current_lang]{% else %}display_names_in_current_lang{% endif %}"
                      {% if force.display_names_in_current_lang is defined %} disabled="disabled"{% endif %}
                      value="1"{% if slot_settings.display_names_in_current_lang|default(1) %} checked="checked"{% endif %}> {{ strings.misc.label_include_display_lang }}</label>
    </li>
    <li>
        <label><input type="checkbox" class="js-wpml-ls-setting-display_link_for_current_lang js-wpml-ls-trigger-update"
                      name="{% if name_base %}{{ name_base }}[display_link_for_current_lang]{% else %}display_link_for_current_lang{% endif %}"
                      {% if force.display_link_for_current_lang is defined or is_hierarchical %} disabled="disabled"{% endif %}
                      value="1"{% if slot_settings.display_link_for_current_lang|default(1) %} checked="checked"{% endif %}> {{ strings.misc.label_include_current_lang }}</label>
    </li>
</ul>