.switch_wrap input[type="checkbox"] {
  display: inline !important;
}

.switch_wrap .switch  {
  display: none !important;
  margin: 0 !important;
  height: 0 !important;
  padding: 0 !important;
  width: 0 !important;
}
