j˜ÔX<?php exit; ?>a:1:{s:7:"content";a:34:{s:8:"nickname";a:1:{i:0;s:3:"leo";}s:10:"first_name";a:1:{i:0;s:0:"";}s:9:"last_name";a:1:{i:0;s:0:"";}s:11:"description";a:1:{i:0;s:0:"";}s:12:"rich_editing";a:1:{i:0;s:4:"true";}s:17:"comment_shortcuts";a:1:{i:0;s:5:"false";}s:11:"admin_color";a:1:{i:0;s:5:"fresh";}s:7:"use_ssl";a:1:{i:0;s:1:"0";}s:20:"show_admin_bar_front";a:1:{i:0;s:4:"true";}s:15:"wp_capabilities";a:1:{i:0;s:31:"a:1:{s:13:"administrator";b:1;}";}s:13:"wp_user_level";a:1:{i:0;s:2:"10";}s:21:"dismissed_wp_pointers";a:1:{i:0;s:26:"vc_pointers_backend_editor";}s:18:"show_welcome_panel";a:1:{i:0;s:1:"0";}s:37:"wp_dashboard_quick_press_last_post_id";a:1:{i:0;s:4:"7012";}s:28:"managenav-menuscolumnshidden";a:1:{i:0;s:116:"a:5:{i:0;s:11:"link-target";i:1;s:11:"css-classes";i:2;s:3:"xfn";i:3;s:11:"description";i:4;s:15:"title-attribute";}";}s:23:"metaboxhidden_nav-menus";a:1:{i:0;s:191:"a:6:{i:0;s:25:"add-post-type-home_slider";i:1;s:23:"add-post-type-portfolio";i:2;s:12:"add-post_tag";i:3;s:15:"add-post_format";i:4;s:16:"add-project-type";i:5;s:22:"add-project-attributes";}";}s:12:"wp_r_tru_u_x";a:1:{i:0;s:46:"a:2:{s:2:"id";i:0;s:7:"expires";i:1465187064;}";}s:27:"wp_nav_menu_recently_edited";a:1:{i:0;s:2:"40";}s:16:"wp_user-settings";a:1:{i:0;s:130:"editor=html&edit_element_vcUIPanelWidth=650&edit_element_vcUIPanelLeft=507px&edit_element_vcUIPanelTop=106px&libraryContent=browse";}s:21:"wp_user-settings-time";a:1:{i:0;s:10:"1471414396";}s:24:"nav_menu_recently_edited";a:1:{i:0;s:2:"42";}s:25:"closedpostboxes_dashboard";a:1:{i:0;s:37:"a:1:{i:0;s:19:"dashboard_right_now";}";}s:23:"metaboxhidden_dashboard";a:1:{i:0;s:6:"a:0:{}";}s:20:"closedpostboxes_page";a:1:{i:0;s:6:"a:0:{}";}s:18:"metaboxhidden_page";a:1:{i:0;s:216:"a:8:{i:0;s:32:"nectar-metabox-portfolio-display";i:1;s:19:"wpb_visual_composer";i:2;s:12:"revisionsdiv";i:3;s:10:"postcustom";i:4;s:16:"commentstatusdiv";i:5;s:11:"commentsdiv";i:6;s:7:"slugdiv";i:7;s:9:"authordiv";}";}s:27:"wpcf7_hide_welcome_panel_on";a:1:{i:0;s:36:"a:2:{i:0;s:5:"4.4.2";i:1;s:3:"4.5";}";}s:17:"wpseo_ignore_tour";a:1:{i:0;s:1:"1";}s:23:"jetpack_tracks_wpcom_id";a:1:{i:0;s:8:"99764142";}s:13:"wpcom_user_id";a:1:{i:0;s:8:"99764142";}s:15:"wpcom_user_data";a:1:{i:0;s:292:"O:8:"stdClass":10:{s:2:"ID";i:99764142;s:5:"login";s:8:"vbitsleo";s:5:"email";s:16:"leo@vbits.com.hk";s:3:"url";s:0:"";s:10:"first_name";s:3:"LEO";s:9:"last_name";s:4:"CHOW";s:12:"display_name";s:8:"vbitsleo";s:11:"description";s:0:"";s:16:"two_step_enabled";b:0;s:16:"external_user_id";i:1;}";}s:19:"wpseo-dismiss-about";a:1:{i:0;s:4:"seen";}s:35:"icl_admin_language_migrated_to_wp47";a:1:{i:0;s:1:"1";}s:22:"wp_yoast_notifications";a:1:{i:0;s:1051:"a:1:{i:0;a:2:{s:7:"message";s:724:"We've noticed you've been using Yoast SEO for some time now; we hope you love it! We'd be thrilled if you could <a href="https://yoa.st/rate-yoast-seo">give us a 5 stars rating on WordPress.org</a>!

If you are experiencing issues, <a href="https://yoa.st/bugreport">please file a bug report</a> and we'll do our best to help you out.

By the way, did you know we also have a <a href='https://yoa.st/premium-notification'>Premium plugin</a>? It offers advanced features, like a redirect manager and support for multiple keywords. It also comes with 24/7 personal support.

<a class="button" href="http://www.vbits.com.hk/wp-admin/?page=wpseo_dashboard&yoast_dismiss=upsell">Please don't show me this notification anymore</a>";s:7:"options";a:8:{s:4:"type";s:7:"warning";s:2:"id";s:19:"wpseo-upsell-notice";s:5:"nonce";N;s:8:"priority";d:0.8000000000000000444089209850062616169452667236328125;s:9:"data_json";a:0:{}s:13:"dismissal_key";N;s:12:"capabilities";s:14:"manage_options";s:16:"capability_check";s:3:"all";}}}";}s:14:"session_tokens";a:1:{i:0;s:297:"a:1:{s:64:"d5090807c1c5d6fbde3312eb8eca56c4e518fc09535d5ab28cbc4dad1152e3d9";a:4:{s:10:"expiration";i:1490500278;s:2:"ip";s:13:"59.148.229.86";s:2:"ua";s:109:"Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/56.0.2924.87 Safari/537.36";s:5:"login";i:1490327478;}}";}}}