<?php
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}
?>
<div class="vc_welcome-tab changelog">
	<div class="vc_feature-section-teaser">
		<div>
			<img class="vc-featured-img" src="<?php echo vc_asset_url( 'vc/vc-welcome/screenshot49.png' ); ?>"/>

			<h3><?php _e( 'Now Faster Than Ever', 'js_composer' ); ?></h3>

			<p><?php _e( 'Visual Composer 4.9 offers significant improvements in terms of performance. Detailed code refactor and smart loading of components results in fastest Visual Composer ever with more than 30% performance improvements. Now you can build your WordPress pages even faster and Visual Composer will assist you there.', 'js_composer' ); ?></p>
			<p><?php _e( 'The most amazing thing is that the more content you have and the more addons you use - the more improvements in performance you will experience.', 'js_composer' ); ?></p>
		</div>
	</div>

	<div class="vc_welcome-feature feature-section vc_row">
		<div class="vc_col-xs-4">
			<img class="vc-img-center"
			     src="<?php echo vc_asset_url( 'vc/vc-welcome/01_49.png' ); ?>"/>
			<h4><?php _e( 'Equal Height', 'js_composer' ); ?></h4>

			<p><?php _e( 'Control column height by setting all columns within row to be equal height. Create new modern layouts you have dreamed of.', 'js_composer' ); ?></p>
		</div>
		<div class="vc_col-xs-4">
			<img class="vc-img-center"
			     src="<?php echo vc_asset_url( 'vc/vc-welcome/02_49.png' ); ?>"/>
			<h4><?php _e( 'Column Gap', 'js_composer' ); ?></h4>

			<p><?php _e( 'Set gaps between columns or merge columns together by setting gap to 0. Use with familiar grid gap control mechanism.', 'js_composer' ); ?></p>
		</div>
		<div class="vc_col-xs-4">
			<img class="vc-img-center"
			     src="<?php echo vc_asset_url( 'vc/vc-welcome/03_49.png' ); ?>"/>
			<h4><?php _e( 'Column, Content Position', 'js_composer' ); ?></h4>

			<p><?php _e( 'Control vertical alignment of columns and content within columns by setting it to top, middle or bottom.', 'js_composer' ); ?></p>
		</div>
	</div>

	<p class="vc-thank-you">Thank you for choosing Visual Composer,<br/>Michael M, CEO at WPBakery</p>

</div>
