<?php
interface Foobar extends Baz {}
interface Foobar extends abstract {}
interface Foobar extends and {}
interface Foobar extends array {}
interface Foobar extends as {}
interface Foobar extends break {}
interface Foobar extends callable {}
interface Foobar extends case {}
interface Foobar extends catch {}
interface Foobar extends class {}
interface Foobar extends clone {}
interface Foobar extends const {}
interface Foobar extends continue {}
interface Foobar extends declare {}
interface Foobar extends default {}
interface Foobar extends do {}
interface Foobar extends else {}
interface Foobar extends elseif {}
interface Foobar extends enddeclare {}
interface Foobar extends endfor {}
interface Foobar extends endforeach {}
interface Foobar extends endif {}
interface Foobar extends endswitch {}
interface Foobar extends endwhile {}
interface Foobar extends extends {}
interface Foobar extends final {}
interface Foobar extends finally {}
interface Foobar extends for {}
interface Foobar extends foreach {}
interface Foobar extends function {}
interface Foobar extends global {}
interface Foobar extends goto {}
interface Foobar extends if {}
interface Foobar extends implements {}
interface Foobar extends interface {}
interface Foobar extends instanceof {}
interface Foobar extends insteadof {}
interface Foobar extends namespace {}
interface Foobar extends new {}
interface Foobar extends or {}
interface Foobar extends private {}
interface Foobar extends protected {}
interface Foobar extends public {}
interface Foobar extends static {}
interface Foobar extends switch {}
interface Foobar extends throw {}
interface Foobar extends trait {}
interface Foobar extends try {}
interface Foobar extends use {}
interface Foobar extends var {}
interface Foobar extends while {}
interface Foobar extends xor {}
interface Foobar extends __CLASS__ {}
interface Foobar extends __DIR__ {}
interface Foobar extends __FILE__ {}
interface Foobar extends __FUNCTION__ {}
interface Foobar extends __METHOD__ {}
interface Foobar extends __NAMESPACE__ {}
