<?php
/* THIS IS A GENERATED FILE. DO NOT EDIT DIRECTLY. */
$generated_i18n_strings = array(
	// Reference: yoast-components/composites/OnboardingWizard/OnboardingWizard.js:286
	__( 'Next step', 'wordpress-seo' ),

	// Reference: yoast-components/composites/OnboardingWizard/OnboardingWizard.js:285
	__( 'Next', 'wordpress-seo' ),

	// Reference: yoast-components/composites/OnboardingWizard/OnboardingWizard.js:276
	__( 'Previous step', 'wordpress-seo' ),

	// Reference: yoast-components/composites/OnboardingWizard/OnboardingWizard.js:275
	__( 'Previous', 'wordpress-seo' ),

	// Reference: yoast-components/composites/OnboardingWizard/OnboardingWizard.js:245
	__( 'Close the Wizard', 'wordpress-seo' ),

	// Reference: yoast-components/composites/OnboardingWizard/OnboardingWizard.js:244
	__( 'Close', 'wordpress-seo' ),

	// Reference: yoast-components/composites/OnboardingWizard/OnboardingWizard.js:170
	__( 'A problem occurred when saving the current step, {{link}}please file a bug report{{/link}} describing what step you are on and which changes you want to make (if any).', 'wordpress-seo' ),

	// Reference: yoast-components/composites/OnboardingWizard/StepIndicator.js:48
	__( 'Step %1$d: %2$s', 'wordpress-seo' ),

	// Reference: yoast-components/composites/SearchResultForm/SearchResultForm.js:67
	__( 'Close search result form', 'wordpress-seo' ),

	// Reference: yoast-components/composites/SearchResultForm/SearchResultForm.js:46
	__( 'Please provide a meta description by editing it here.', 'wordpress-seo' ),

	// Reference: yoast-components/composites/SearchResultForm/SearchResultForm.js:45
	// Reference: yoast-components/composites/SearchResultPreview/SearchResultPreview.js:44
	__( 'Meta description preview: ', 'wordpress-seo' ),

	// Reference: yoast-components/composites/SearchResultForm/SearchResultForm.js:44
	__( 'Slug preview: ', 'wordpress-seo' ),

	// Reference: yoast-components/composites/SearchResultForm/SearchResultForm.js:43
	// Reference: yoast-components/composites/SearchResultPreview/SearchResultPreview.js:42
	__( 'This is an example title - edit by clicking here', 'wordpress-seo' ),

	// Reference: yoast-components/composites/SearchResultForm/SearchResultForm.js:42
	// Reference: yoast-components/composites/SearchResultPreview/SearchResultPreview.js:41
	__( 'SEO title preview: ', 'wordpress-seo' ),

	// Reference: yoast-components/composites/SearchResultForm/SearchResultForm.js:41
	// Reference: yoast-components/composites/SearchResultPreview/SearchResultPreview.js:40
	__( 'You can click on each element in the preview to jump to the Snippet Editor.', 'wordpress-seo' ),

	// Reference: yoast-components/composites/SearchResultForm/SearchResultForm.js:40
	__( 'Search Result Form', 'wordpress-seo' ),

	// Reference: yoast-components/composites/SearchResultPreview/SearchResultPreview.js:72
	__( 'Edit snippet', 'wordpress-seo' ),

	// Reference: yoast-components/composites/SearchResultPreview/SearchResultPreview.js:45
	__( 'Please provide a meta description by editing the snippet below.', 'wordpress-seo' ),

	// Reference: yoast-components/composites/SearchResultPreview/SearchResultPreview.js:43
	__( 'URL preview: ', 'wordpress-seo' ),

	// Reference: yoast-components/composites/SearchResultPreview/SearchResultPreview.js:39
	__( 'Search Result Preview', 'wordpress-seo' ),

	// Reference: js/src/components/ConnectGoogleSearchConsole.js:357
	__( 'Get Google Authorization Code', 'wordpress-seo' ),

	// Reference: js/src/components/ConnectGoogleSearchConsole.js:350
	__( 'To allow %s to fetch your Google Search Console information, please enter your Google Authorization Code. Clicking the button below will open a new window.', 'wordpress-seo' ),

	// Reference: js/src/components/ConnectGoogleSearchConsole.js:339
	__( 'Reauthenticate with Google', 'wordpress-seo' ),

	// Reference: js/src/components/ConnectGoogleSearchConsole.js:314
	__( 'Authenticate', 'wordpress-seo' ),

	// Reference: js/src/components/ConnectGoogleSearchConsole.js:310
	__( 'Enter authorization code here...', 'wordpress-seo' ),

	// Reference: js/src/components/ConnectGoogleSearchConsole.js:299
	__( 'Enter your Google Authorization Code and press the Authenticate button.', 'wordpress-seo' ),

	// Reference: js/src/components/ConnectGoogleSearchConsole.js:274
	__( 'Choose a profile', 'wordpress-seo' ),

	// Reference: js/src/components/ConnectGoogleSearchConsole.js:268
	__( 'Select profile', 'wordpress-seo' ),

	// Reference: js/src/components/ConnectGoogleSearchConsole.js:256
	__( 'There were no profiles found', 'wordpress-seo' ),

	// Reference: js/src/components/ConnectGoogleSearchConsole.js:110
	__( 'There is an error with the request.', 'wordpress-seo' ),

	// Reference: js/src/components/MailchimpSignup.js:228
	__( 'Email', 'wordpress-seo' ),

	// Reference: js/src/components/MailchimpSignup.js:214
	__( 'Name', 'wordpress-seo' ),

	// Reference: js/src/components/MailchimpSignup.js:196
	__( 'Sign Up!', 'wordpress-seo' ),

	// Reference: js/src/components/MailchimpSignup.js:111
	__( 'MailChimp signup failed:', 'wordpress-seo' ),

	// Reference: js/src/components/MediaUpload.js:106
	__( 'Choose image', 'wordpress-seo' ),

	// Reference: js/src/components/MediaUpload.js:96
	__( 'company logo image preview', 'wordpress-seo' ),

	// Reference: js/src/components/MediaUpload.js:89
	__( 'Remove the image', 'wordpress-seo' ),

	// Reference: js/src/components/MediaUpload.js:19
	// Reference: js/src/components/MediaUpload.js:18
	__( 'Choose an image', 'wordpress-seo' )
);
/* THIS IS THE END OF THE GENERATED FILE */
