<a href="#" class="js-wpml-ls-tooltip-open wpml-ls-tooltip-open otgs-ico-help" data-content="{{ content.text|e('html_attr') }}" data-link-text="{{ content.link.text|e('html_attr') }}" data-link-url="{{ content.link.url|e('html_attr') }}" data-link-target="{{ content.link.target|e('html_attr') }}"></a>