<div class="alignleft">
	<label for="status-select"><%=labels.Show%></label>
	<select id="status-select" name="status">
		<option value="0"><%=labels.all + ' ' + taxonomy.label%></option>
		<option value="1"><%=labels.untranslated + ' ' + taxonomy.label%></option>
	</select>
</div>
