/***************** Orbit ******************/
#featured article {
	position: fixed;
    background-position: center;
    background-repeat: no-repeat;
    height: 650px; 
    width: 100%;
    z-index: 1;
    background-color: #000; 
} 

#featured article[data-background-cover="1"] {
	background-size: cover;
}

div.slider-nav span {
	display: block;
    width: 56px;
    height: 56px;
    top: 380px;
    text-indent: -9999px!important;
    margin-top: -35px;
    cursor: pointer; 
    background-repeat: no-repeat;
}

body .orbit-wrapper div.slider-nav > span.left i {
	padding-right: 1px;
}

body .orbit-wrapper div.slider-nav > span.right i {
	padding-left: 1px;
}

div.slider-nav span i { 
	color: #a0a0a0!important;
	position: absolute;
	top: 0px;
	left: 0px;
	font-size: 18px;
	line-height: 25px;
	background-color: transparent;
	z-index: 1000;
}

div.slider-nav > span {
	 margin-top: 0px;
	 -webkit-transition: none!important;
    -moz-transition: none!important;
    -o-transition: none!important;
    transition: none!important;
}

div.slider-nav span.right, div.slider-nav span.left,  div.slider-nav span.right span,  div.slider-nav span.left span {
	-webkit-transition: all 0.2s linear;
    -moz-transition: all 0.2s linear;
    -o-transition: all 0.2s linear;
    transition: all 0.2s linear;
    border-radius: 1px 1px 1px 1px;
    -moz-border-radius: 1px 1px 1px 1px;
    -webkit-border-radius: 1px 1px 1px 1px;
    -o-border-radius: 1px 1px 1px 1px;
}

.orbit-wrapper div.slider-nav span.right {
	background-color: #27CFC3;
    background-image: url(../img/icons/slider-arrows.png);
    right: 0px; 
    background-position: right top;
}

body[data-smooth-scrolling="1"] .orbit-wrapper div.slider-nav span.right {
	right: 15px; 
}

.orbit-wrapper div.slider-nav span.left {
	background-color: #27CFC3;
    background-image: url(../img/icons/slider-arrows.png);
    left: 0px; 
    background-position: left top;
}

div.slider-nav span.right span.white {
	opacity: 0;
	top: 35px;
    right: 0px; 
    position: absolute;
    background: url(../img/icons/slider-arrows.png);
    background-position: right bottom;
}

div.slider-nav span.left span.white {
	opacity: 0;
	top: 35px;
    right: 0px; 
    position: absolute;
    background: url(../img/icons/slider-arrows.png);
    background-position: left bottom;
}


@media only screen and (-moz-min-device-pixel-ratio: 1.5),
only screen and (-o-min-device-pixel-ratio: 3/2),
only screen and (-webkit-min-device-pixel-ratio: 1.5),
only screen and (min-device-pixel-ratio: 1.5),
only screen and (min-resolution: 144dpi) {
   .orbit-wrapper div.slider-nav span.left, .orbit-wrapper div.slider-nav span.right, div.slider-nav span.right span.white, div.slider-nav span.left span.white {
   		background-size: 140px 133px!important;
   		-webkit-background-size: 140px 133px!important;
   		-moz-background-size: 140px 133px!important;
      	background-image: url(../img/icons/slider-arrows@2x.png)!important;
   }
}


div.slider-nav span.right:hover span.white, div.slider-nav span.left:hover span.white {
	opacity: 1;
}

div.slider-nav span span.shadow {
	display: block;
	top: 91px;
    right: 0px;
    height: 7px;
    position: absolute;
    width: 56px;
    background: url(../img/icons/slider-arrows-shadows.png);
}

div.slider-nav span.left span.shadow { background-position: left bottom; }

div.slider-nav span.right span.shadow { background-position: right bottom; }


/* transparent header fix */
@media only screen and (min-width: 1000px)  {
    .orbit-wrapper.transparent-header div.slider-nav > span, .orbit-wrapper.transparent-header article {
        margin-top: -75px!important;
    }
}


#featured .orbit-slide article .container {
	position: absolute;
	width: 100%;
	max-width: none!important;
	top: 295px;
	margin: 0 auto;
}

#featured .orbit-slide article .container .span_12 {
	margin: 0 auto!important;
	width: 1100px!important;	
	float: none;
}

#featured article .post-title h2 {
	max-width: 460px;
	min-width: 460px;
	margin-bottom: 7px;
	opacity: 0;
	padding: 0px 10px;
	left: -10px;
	position: relative;
	margin-top: 20px;
    font-weight: 300;
}

#featured article .post-title h2 span {
	padding: 4px 0px;
	background: none repeat scroll 0 0 rgba(0, 0, 0, 0.5);
	box-shadow: 10px 0 0 rgba(0, 0, 0, 0.5), -10px 0 0 rgba(0, 0, 0, 0.5);
	-moz-box-shadow: 10px 0 0 rgba(0, 0, 0, 0.5), -10px 0 0 rgba(0, 0, 0, 0.5);
	-webkit-box-shadow: 10px 0 0 rgba(0, 0, 0, 0.5), -10px 0 0 rgba(0, 0, 0, 0.5);
	-o-box-shadow: 10px 0 0 rgba(0, 0, 0, 0.5), -10px 0 0 rgba(0, 0, 0, 0.5);
	color: #fff;
	font-size: 32px;
	line-height: 54px!important;
	margin-bottom: 1px;
	background-position: right -53px;
    margin-bottom: 15px;
    /*display: none;*/
    margin-top: 20px;
    -webkit-box-decoration-break: clone;
    -o-box-decoration-break: clone;
    box-decoration-break: clone;
}

#featured article .post-title > a {
	opacity: 0;
	color: #fff;
	left: -10px;
	top: 10px;
	letter-spacing: 1.5px;
	position: relative;
	display: inline-block;
	padding: 14px 18px;
	border: 2px solid rgba(255,255,255,0.3);
	-webkit-transition: border-color 0.3s linear, background-color 0.3s linear;
    -moz-transition: border-color 0.3s linear, background-color 0.3s linear;
    -o-transition: border-color 0.3s linear, background-color 0.3s linear;
    transition: border-color 0.3s linear, background-color 0.3s linear;
}

#featured article .post-title a:hover {
	border-color: #27CFC3;
}


/* alignment */

#featured .orbit-slide.centered article .container .span_12 {
    margin: 0 auto !important;
    text-align: center;
    width: 100%; 
}

#featured .orbit-slide.centered article .post-title h2 {
    margin: 0 auto 7px auto;
    left: -10px;
    max-width: 560px;
    min-width: 560px;
}




#featured .orbit-slide.right article .container .span_12 {
    margin: 0 auto !important;
    text-align: right;
    width: 100%;
}

#featured .orbit-slide.right article .post-title h2 {
    margin: 0 auto;
    right: 10px;
    float: right;
    left: auto;
}

#featured .orbit-slide.right article .post-title > a {
	right: -10px;
	float: right;
	clear: both;
}


#featured .orbit-slide.has-video h2 {
	float: right;
    max-width: 400px;
    min-width: 400px;
} 

#featured .orbit-slide.has-video .post-title > a {
	left: 12px;
}

#featured .video {
	float: left; 
	width: 678px!important;
	left: -8px; 
	margin-bottom: 100px;
	position: relative;
	z-index: 1;
	opacity: 0;
}


#featured .more-info, #featured .btv {
	display: none;
}

#featured .video video {
	display: none;
}

 #featured .video {
	display: none;
}

#featured .video .mejs-mediaelement {
	visibility: hidden;	
}

#featured .video .mejs-mediaelement video {
	display: block;
}


#featured .video .mejs-container {
	background-color: #111!important;
	background-image: none!important;
}
 
#featured .jp-video-container {
	margin-bottom: 0px!important;
}

#featured .fluid-placeholder {
	display: none!important;
}



















 
 
 
/* PUT IN YOUR SLIDER ID AND SIZE TO MAKE LOAD BEAUTIFULLY
   ================================================== */
#featured { 
	width: 100%!important;
	margin-top: -70px;
	position: relative;
	z-index: 1;
	height: 650px!important;
	background: #000 url('../img/icons/loading.gif') no-repeat center center;
	overflow: hidden; }
#featured>img,  
#featured>div,
#featured>a { display: none; }


html:not(.js) #featured {
	display: none;
}

/* CONTAINER
   ================================================== */


div.orbit-wrapper {
    width: 100%!important;
    height: 1px;
    top: 0px;
    z-index: 1;
    position: relative; }

div.orbit {
    width: 1px;
    position: relative;
    overflow: hidden }

div.orbit>img {
    position: absolute;
    top: 0;
    left: 0;
    display: none; }

div.orbit > a {
    border: none;
    position: absolute;
    top: 0;
    left: 0;
    line-height: 0; 
    display: none; }

.orbit > div {
    position: fixed;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%; }
    


/* Note: If your slider only uses content or anchors, you're going to want to put the width and height declarations on the ".orbit>div" and "div.orbit>a" tags in addition to just the .orbit-wrapper */



/* TIMER
   ================================================== */

div.timer {
    width: 40px;
    height: 40px;
    overflow: hidden;
    position: absolute;
    top: 40px;
    display: none;
    right: 10px;
    opacity: .6;
    cursor: pointer;
    z-index: 1001; }

span.rotator {
    display: block;
    width: 40px;
    height: 40px;
    position: absolute;
    top: 0;
    left: -20px;
    background: url(../img/orbit/rotator-black.png) no-repeat;
    z-index: 3; }

span.mask {
    display: block;
    width: 20px;
    height: 40px;
    position: absolute;
    top: 0;
    right: 0;
    z-index: 2;
    overflow: hidden; }

span.rotator.move {
    left: 0 }

span.mask.move {
    width: 40px;
    left: 0;
    background: url(../img/orbit/timer-black.png) repeat 0 0; }

span.pause {
    display: block;
    width: 40px;
    height: 40px;
    position: absolute;
    top: 0;
    left: 0;
    background: url(../img/orbit/pause-black.png) no-repeat;
    z-index: 4;
    opacity: 0; }

span.pause.active {
    background: url(../img/orbit/pause-black.png) no-repeat 0 -40px }

div.timer:hover span.pause,
span.pause.active {
    opacity: 1 }


/* CAPTIONS
   ================================================== */

.orbit-caption {
    display: none;
    font-family: "HelveticaNeue", "Helvetica-Neue", Helvetica, Arial, sans-serif; }

.orbit-wrapper .orbit-caption {
    background: #000;
    background: rgba(0,0,0,.6);
    z-index: 1000;
    color: #fff;
	text-align: center;
	padding: 7px 0;
    font-size: 13px;
    position: fixed;
    right: 0;
    bottom: 0;
    width: 100%; }


/* DIRECTIONAL NAV
   ================================================== */

div.slider-nav {
    display: block }

div.slider-nav span {
    position: fixed;
    z-index: 1000;
    text-indent: -9999px;
    cursor: pointer; 
 }



