<p class="wpml-ls-form-line js-wpml-ls-option">
    <label for="wpml-ls-show-in-post-translations">
        <input type="checkbox" id="wpml-ls-show-in-post-translations" name="statics[post_translations][show]" value="1"
               class="js-wpml-ls-toggle-slot js-wpml-ls-trigger-save" data-target=".js-wpml-ls-post-translations-toggle-target"
               {% if settings.statics.post_translations.show %}checked="checked"{% endif %}/>
        {{ strings.post_translations.show }}
    </label>

    {% include 'save-notification.twig' %}
</p>

<div class="js-wpml-ls-post-translations-toggle-target alignleft{% if settings.statics.post_translations.show != 1 %} hidden{% endif %}">

    {% set slot_settings = [] %}
    {% set slot_settings = slot_settings|merge({'post_translations': settings.statics.post_translations}) %}

    {% include 'table-slots.twig'
        with {
            "slot_type": "statics",
            "slots_settings": slot_settings,
		    "slug"     : 'post_translations',
        }
    %}

</div>