<?php

// autoload_52.php generated by xrstf/composer-php52

require_once dirname(__FILE__) . '/composer'.'/autoload_real_52.php';

return ComposerAutoloaderInit385fde8bf789e867a8b8648de97c96cc::getLoader();
