<?php
class Foobar { use BazTrait { oldfunction as public Baz } }
class Foobar { use BazTrait { oldfunction as public abstract } }
class Foobar { use BazTrait { oldfunction as public and } }
class Foobar { use BazTrait { oldfunction as public array } }
class Foobar { use BazTrait { oldfunction as public as } }
class Foobar { use BazTrait { oldfunction as public break } }
class Foobar { use BazTrait { oldfunction as public callable } }
class Foobar { use BazTrait { oldfunction as public case } }
class Foobar { use BazTrait { oldfunction as public catch } }
class Foobar { use BazTrait { oldfunction as public class } }
class Foobar { use BazTrait { oldfunction as public clone } }
class Foobar { use BazTrait { oldfunction as public const } }
class Foobar { use BazTrait { oldfunction as public continue } }
class Foobar { use BazTrait { oldfunction as public declare } }
class Foobar { use BazTrait { oldfunction as public default } }
class Foobar { use BazTrait { oldfunction as public do } }
class Foobar { use BazTrait { oldfunction as public else } }
class Foobar { use BazTrait { oldfunction as public elseif } }
class Foobar { use BazTrait { oldfunction as public enddeclare } }
class Foobar { use BazTrait { oldfunction as public endfor } }
class Foobar { use BazTrait { oldfunction as public endforeach } }
class Foobar { use BazTrait { oldfunction as public endif } }
class Foobar { use BazTrait { oldfunction as public endswitch } }
class Foobar { use BazTrait { oldfunction as public endwhile } }
class Foobar { use BazTrait { oldfunction as public extends } }
class Foobar { use BazTrait { oldfunction as public final } }
class Foobar { use BazTrait { oldfunction as public finally } }
class Foobar { use BazTrait { oldfunction as public for } }
class Foobar { use BazTrait { oldfunction as public foreach } }
class Foobar { use BazTrait { oldfunction as public function } }
class Foobar { use BazTrait { oldfunction as public global } }
class Foobar { use BazTrait { oldfunction as public goto } }
class Foobar { use BazTrait { oldfunction as public if } }
class Foobar { use BazTrait { oldfunction as public implements } }
class Foobar { use BazTrait { oldfunction as public interface } }
class Foobar { use BazTrait { oldfunction as public instanceof } }
class Foobar { use BazTrait { oldfunction as public insteadof } }
class Foobar { use BazTrait { oldfunction as public namespace } }
class Foobar { use BazTrait { oldfunction as public new } }
class Foobar { use BazTrait { oldfunction as public or } }
class Foobar { use BazTrait { oldfunction as public private } }
class Foobar { use BazTrait { oldfunction as public protected } }
class Foobar { use BazTrait { oldfunction as public public } }
class Foobar { use BazTrait { oldfunction as public static } }
class Foobar { use BazTrait { oldfunction as public switch } }
class Foobar { use BazTrait { oldfunction as public throw } }
class Foobar { use BazTrait { oldfunction as public trait } }
class Foobar { use BazTrait { oldfunction as public try } }
class Foobar { use BazTrait { oldfunction as public use } }
class Foobar { use BazTrait { oldfunction as public var } }
class Foobar { use BazTrait { oldfunction as public while } }
class Foobar { use BazTrait { oldfunction as public xor } }
class Foobar { use BazTrait { oldfunction as public __CLASS__ } }
class Foobar { use BazTrait { oldfunction as public __DIR__ } }
class Foobar { use BazTrait { oldfunction as public __FILE__ } }
class Foobar { use BazTrait { oldfunction as public __FUNCTION__ } }
class Foobar { use BazTrait { oldfunction as public __METHOD__ } }
class Foobar { use BazTrait { oldfunction as public __NAMESPACE__ } }
