<div id="wpml-ls-dialog" style="display:none;" >
    <div class="js-wpml-ls-dialog-inner">

    </div>
    <div class="wpml-dialog-footer ">
        <span class="errors icl_error_text"></span>
        <input class="js-wpml-ls-dialog-close cancel wpml-dialog-close-button alignleft" value="{{ strings.misc.button_cancel }}" type="button">
        <input class="js-wpml-ls-dialog-save button-primary term-save alignright" value="{{ strings.misc.button_save }}" type="submit">
        <span class="spinner alignright"></span>
    </div>
</div>