/* 'Pages' is a temporary location for these styles, until we can break them up into their proper atmoic locations */

// ==========================================================================
// Jetpack Protect Config Page
//==========================================================================


.configure-module p {
	font-size: 14px;

	&.success, &.error {
		color: $white;
		padding: 10px;
	}

	&.success {
		background-color: $green;
	}

	&.error {
		background-color: $red;
	}
}

.protect-status {

	p {
		font-size: 16px;
	}

	strong {
		display: inline-block;
		margin-top: 10px;
		background: #fff;
		padding: 10px;
		border: 1px #ddd solid;
		font-size: 16px;
		color: #000;
		max-width: 100%;
	}

	&.attn {
		color: $red;
	}

	&.working {
		color: $green;
	}
} // .protect-status

.protect-whitelist {

	textarea {
		width: 100%;
		min-height: 150px;
	}
}

/* btns + inputs */

.configure-module {

	input[disabled] {
		opacity: .5;
	}

	input.button-primary {
		font-weight: bold;
	}
}

/* whitelist table */

@media only screen and (min-width : 1100px) {

	.protect-whitelist {
		width: 65%;
		float: left;
	}

} /* end > 1065px */

@media only screen and (max-width : 400px) {

	.protect-status strong {
		font-size: 12px;
		overflow: auto;
	}

} /* end < 400px */
