.icl-st-inline{border:1px solid #ddd;padding:1px;clear:both;display:none}.icl-st-table{width:100%}.icl-st-table textarea{font-size:10px;padding:1px;margin:0;line-height:normal}.wpml-st-col-string{width:70%}.wpml-st-col-string .icl-st-original{word-break:break-all}.colthree{width:48%;float:left;padding-right:8px}.colthree h4{margin-bottom:0}.meta_comment{font-style:italic;color:#777}p.sub{color:#444;font-family:Verdana;font-size:12px;margin:0 0 5px}div.postbox div.inside{margin:10px;position:relative}#icl_show_source_top{position:fixed;margin-left:-10px}.icl_string_track_source pre{height:100%;font-family:Arial;background-color:#fefefe;border:1px solid #eee}.icl_string_track_source ol{line-height:10px}.icl_string_track_source ol li{font-size:10px;margin:0;list-style-position:inside;padding:0;line-height:5px}.icl_string_track_source.icl_string_track_filename{position:fixed;font-size:10px;margin:-25px 0 0 -5px;color:#fff;background-color:#222}.icl_string_track_url{font-size:10px;height:16px;overflow:hidden;white-space:nowrap}#colorPickerDiv{background-color:#000;color:#fff;border:1px solid #000}#icl_st_option_writes ul.icl_st_option_writes{margin-left:20px}.icl_st_admin_string{padding:2px;float:left;margin-bottom:5px}.icl_st_numeric{background-color:#d5e8f9;border:1px solid #9bc8f0}.icl_st_string{background-color:#f3ece2;border:1px solid #c4a26f}span.icl_st_numeric,span.icl_st_string{padding:2px;border-radius:4px}.icl_stow_head{float:left}#icl_st_options_write_success{padding:4px}a.icl_stow_toggler{text-decoration:none}#icl_st_ow_export_close,#icl_st_ow_export_out{display:none}#icl_st_ow_export_out textarea{width:100%;height:200px;font-size:10px}tr.st_requires_update td{background-color:#fef7f1}tr.st_requires_update>td:first-child{border-left:4px solid #d54e21}tr.st_requires_update .update-message{font-size:13px;font-weight:400;padding:6px 12px;margin:0 31px 8px 10px;background-color:rgba(247,247,247,.03)}tr.st_requires_update .update-message:before{color:#d54e21;display:inline-block;font:400 20px/1 dashicons;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;vertical-align:top;content:'\f463';margin:0 -2px 0 8px}@media aural{tr.st_requires_update .update-message:before{speak:none}}.wpml-st-col-domain,.wpml-st-col-name{width:20%;word-break:break-all}.wpml-cdl-summary{margin-top:30px}.wpml-cdl-table{margin-bottom:40px}.wpml-cdl-table .num{text-align:right}.wpml-cdl-info,.wpml-cdl-table{width:90%;max-width:500px;margin-left:5%}label[for=wpml-cdl-set-default]{display:block;margin-top:5px}.wpml-st-exclude-contexts .wpml-st-excluded-info{font-weight:700}.wpml-st-exclude-contexts-box .contexts p{float:left;width:50%}.wpml-st-exclude-contexts-box .wpml-st-filter-and-select-all-box{border-bottom:1px solid #e5e5e5}.wpml-st-cancel-button{margin-right:20px}.wpml_plugin_table_filters>li{display:inline-block}