<?php
trait Baz {}
trait abstract {}
trait and {}
trait array {}
trait as {}
trait break {}
trait callable {}
trait case {}
trait catch {}
trait class {}
trait clone {}
trait const {}
trait continue {}
trait declare {}
trait default {}
trait do {}
trait else {}
trait elseif {}
trait enddeclare {}
trait endfor {}
trait endforeach {}
trait endif {}
trait endswitch {}
trait endwhile {}
trait extends {}
trait final {}
trait finally {}
trait for {}
trait foreach {}
trait function {}
trait global {}
trait goto {}
trait if {}
trait implements {}
trait interface {}
trait instanceof {}
trait insteadof {}
trait namespace {}
trait new {}
trait or {}
trait private {}
trait protected {}
trait public {}
trait static {}
trait switch {}
trait throw {}
trait trait {}
trait try {}
trait use {}
trait var {}
trait while {}
trait xor {}
trait __CLASS__ {}
trait __DIR__ {}
trait __FILE__ {}
trait __FUNCTION__ {}
trait __METHOD__ {}
trait __NAMESPACE__ {}
