.wpml-ls-statics-post_translations{clear:both}.wpml-ls-statics-post_translations .wpml-ls-item{padding:0;margin:0;display:inline-block}.wpml-ls-statics-post_translations .wpml-ls-item:not(:last-child):after{content:', '}.wpml-ls-statics-post_translations a{line-height:1;text-decoration:none;display:inline-block}.wpml-ls-statics-post_translations .wpml-ls-flag{display:inline;vertical-align:baseline;width:18px;height:12px}.wpml-ls-statics-post_translations .wpml-ls-flag+span{margin-left:.3em}.rtl .wpml-ls-statics-post_translations .wpml-ls-flag+span{margin-left:0;margin-right:.3em}
