<?php

// autoload_classmap.php @generated by Composer

$vendorDir = dirname(dirname(__FILE__));
$baseDir = dirname($vendorDir);

return array(
    'IWPML_PB_Strategy' => $baseDir . '/classes/page-builders/strategy/interface-iwpml-pb-strategy.php',
    'IWPML_ST_Page_Translations_Persist' => $baseDir . '/classes/filters/db-cache/persist/interface-iwpml-st-page-translations-persist.php',
    'IWPML_St_Upgrade_Command' => $baseDir . '/classes/upgrade/interface-iwpml_st_upgrade_command.php',
    'WPML_Admin_Notifier' => $baseDir . '/classes/class-wpml-admin-notifier.php',
    'WPML_Admin_Text_Configuration' => $baseDir . '/inc/admin-texts/wpml-admin-text-configuration.php',
    'WPML_Admin_Text_Functionality' => $baseDir . '/inc/admin-texts/wpml-admin-text-functionality.class.php',
    'WPML_Admin_Text_Import' => $baseDir . '/inc/admin-texts/wpml-admin-text-import.class.php',
    'WPML_Admin_Texts' => $baseDir . '/inc/admin-texts/wpml-admin-texts.class.php',
    'WPML_Autoregister_Context_Exclude' => $baseDir . '/classes/filters/autoregister/class-wpml-autoregister-context-exclude.php',
    'WPML_Autoregister_Save_Strings' => $baseDir . '/classes/filters/autoregister/class-wpml-autoregister-save-strings.php',
    'WPML_Cache_Directory' => $vendorDir . '/wpml-shared/wpml-lib-cache/src/cache/class-wpml-cache-directory.php',
    'WPML_Change_String_Domain_Language_Dialog' => $baseDir . '/classes/string-translation-ui/class-wpml-change-string-domain-language-dialog.php',
    'WPML_Change_String_Language_Dialog' => $baseDir . '/classes/string-translation-ui/class-wpml-change-string-language-dialog.php',
    'WPML_Custom_Post_Slug_UI' => $baseDir . '/classes/slug-translation/class-wpml-custom-post-slug-ui.php',
    'WPML_Dependencies' => $vendorDir . '/wpml-shared/wpml-lib-dependencies/src/dependencies/class-wpml-dependencies.php',
    'WPML_Displayed_String_Filter' => $baseDir . '/classes/filters/class-wpml-displayed-string-filter.php',
    'WPML_File_Name_Converter' => $baseDir . '/classes/strings-scanning/class-wpml-file-name-converter.php',
    'WPML_Language_Of_Domain' => $baseDir . '/classes/class-wpml-language-of-domain.php',
    'WPML_Localization' => $baseDir . '/inc/wpml-localization.class.php',
    'WPML_PB_API_Hooks_Strategy' => $baseDir . '/classes/page-builders/strategy/api-hooks/class-wpml-pb-api-hooks-strategy.php',
    'WPML_PB_Config_Import_Shortcode' => $baseDir . '/classes/page-builders/strategy/shortcode/class-wpml-pb-config-import-shortcode.php',
    'WPML_PB_Factory' => $baseDir . '/classes/page-builders/class-wpml-pb-factory.php',
    'WPML_PB_Integration' => $baseDir . '/classes/page-builders/class-wpml-pb-integration.php',
    'WPML_PB_Integration_Rescan' => $baseDir . '/classes/page-builders/class-wpml-pb-rescan.php',
    'WPML_PB_Loader' => $baseDir . '/classes/page-builders/class-wpml-pb-loader.php',
    'WPML_PB_Register_Shortcodes' => $baseDir . '/classes/page-builders/strategy/shortcode/class-wpml-pb-register-shortcodes.php',
    'WPML_PB_Reuse_Translations' => $baseDir . '/classes/page-builders/class-wpml-pb-reuse-translations.php',
    'WPML_PB_Shortcode_Encoding' => $baseDir . '/classes/page-builders/strategy/shortcode/class-wpml-pb-shortcode-encoding.php',
    'WPML_PB_Shortcode_Strategy' => $baseDir . '/classes/page-builders/strategy/shortcode/class-wpml-pb-shortcode-strategy.php',
    'WPML_PB_Shortcodes' => $baseDir . '/classes/page-builders/strategy/shortcode/class-wpml-pb-shortcodes.php',
    'WPML_PB_String' => $baseDir . '/classes/page-builders/class-wpml-pb-string.php',
    'WPML_PB_String_Registration' => $baseDir . '/classes/page-builders/class-wpml-pb-string-registration.php',
    'WPML_PB_String_Translation' => $baseDir . '/classes/page-builders/class-wpml-pb-string-translation.php',
    'WPML_PB_Update_API_Hooks_In_Content' => $baseDir . '/classes/page-builders/strategy/api-hooks/class-wpml-pb-update-api-hooks-in-content.php',
    'WPML_PB_Update_Post' => $baseDir . '/classes/page-builders/class-wpml-pb-update-post.php',
    'WPML_PB_Update_Shortcodes_In_Content' => $baseDir . '/classes/page-builders/strategy/shortcode/class-wpml-pb-update-shortcodes-in-content.php',
    'WPML_PO_Import' => $baseDir . '/inc/gettext/wpml-po-import.class.php',
    'WPML_PO_Import_Strings' => $baseDir . '/classes/po-import/class-wpml-po-import-strings.php',
    'WPML_PO_Import_Strings_Scripts' => $baseDir . '/classes/po-import/class-wpml-po-import-strings-scripts.php',
    'WPML_PO_Parser' => $baseDir . '/inc/gettext/wpml-po-parser.class.php',
    'WPML_Package' => $baseDir . '/inc/package-translation/inc/wpml-package.class.php',
    'WPML_Package_Admin_Lang_Switcher' => $baseDir . '/inc/package-translation/inc/wpml-package-admin-lang-switcher.class.php',
    'WPML_Package_Exception' => $baseDir . '/inc/package-translation/inc/wpml-package-translation-exception.class.php',
    'WPML_Package_Helper' => $baseDir . '/inc/package-translation/inc/wpml-package-translation-helper.class.php',
    'WPML_Package_ST' => $baseDir . '/inc/package-translation/inc/wpml-package-translation-st.class.php',
    'WPML_Package_TM' => $baseDir . '/inc/package-translation/inc/wpml-package-translation-tm.class.php',
    'WPML_Package_TM_Jobs' => $baseDir . '/inc/package-translation/inc/wpml-package-translation-tm-jobs.class.php',
    'WPML_Package_Translation' => $baseDir . '/inc/package-translation/inc/wpml-package-translation.class.php',
    'WPML_Package_Translation_HTML_Packages' => $baseDir . '/inc/package-translation/inc/wpml-package-translation-html-packages.class.php',
    'WPML_Package_Translation_Metabox' => $baseDir . '/inc/package-translation/inc/wpml-package-translation-metabox.class.php',
    'WPML_Package_Translation_Schema' => $baseDir . '/inc/package-translation/inc/wpml-package-translation-schema.class.php',
    'WPML_Package_Translation_UI' => $baseDir . '/inc/package-translation/inc/wpml-package-translation-ui.class.php',
    'WPML_Plugin_String_Scanner' => $baseDir . '/inc/gettext/wpml-plugin-string-scanner.class.php',
    'WPML_Register_String_Filter' => $baseDir . '/classes/filters/class-wpml-register-string-filter.php',
    'WPML_Rewrite_Rule_Filter' => $baseDir . '/classes/slug-translation/class-wpml-rewrite-rule-filter.php',
    'WPML_ST_Admin_Blog_Option' => $baseDir . '/classes/admin-texts/class-wpml-st-admin-blog-option.php',
    'WPML_ST_Admin_Option_Translation' => $baseDir . '/classes/admin-texts/class-wpml-st-admin-option-translation.php',
    'WPML_ST_Admin_String' => $baseDir . '/classes/class-wpml-st-admin-string.php',
    'WPML_ST_Blog_Name_And_Description_Hooks' => $baseDir . '/classes/filters/class-wpml-st-blog-name-and-description-hooks.php',
    'WPML_ST_DB_Cache' => $baseDir . '/classes/filters/db-cache/class-wpml-st-db-cache.php',
    'WPML_ST_DB_Cache_Factory' => $baseDir . '/classes/filters/db-cache/class-wpml-st-db-cache-factory.php',
    'WPML_ST_DB_Chunk_Retrieve' => $baseDir . '/classes/filters/db-cache/class-wpml-st-db-chunk-retrieve.php',
    'WPML_ST_DB_Mappers_String_Positions' => $baseDir . '/classes/db-mappers/class-wpml-st-db-mappers-string-positions.php',
    'WPML_ST_DB_Mappers_Strings' => $baseDir . '/classes/db-mappers/class-wpml-st-db-mappers-strings.php',
    'WPML_ST_DB_Translation_Retrieve' => $baseDir . '/classes/filters/db-cache/class-wpml-st-db-translation-retrieve.php',
    'WPML_ST_DB_Troubleshooting' => $baseDir . '/classes/menus/class-wpml-st-db-troubleshooting.php',
    'WPML_ST_Diff' => $baseDir . '/classes/utilities/class-wpml-st-diff.php',
    'WPML_ST_Domain_Fallback' => $baseDir . '/classes/filters/db-cache/class-wpml-st-domain-fallback.php',
    'WPML_ST_ICL_String_Translations' => $baseDir . '/classes/records/class-wpml-st-icl-string-translations.php',
    'WPML_ST_ICL_Strings' => $baseDir . '/classes/records/class-wpml-st-icl-strings.php',
    'WPML_ST_Label_Translation' => $baseDir . '/classes/filters/class-wpml-st-label-translation.php',
    'WPML_ST_MO_Downloader' => $baseDir . '/inc/auto-download-locales.php',
    'WPML_ST_Package_Cleanup' => $baseDir . '/classes/package-translation/class-wpml-st-package-cleanup.php',
    'WPML_ST_Package_Factory' => $baseDir . '/inc/package-translation/inc/wpml-package-factory.class.php',
    'WPML_ST_Page_Translation' => $baseDir . '/classes/filters/db-cache/class-wpml-st-page-translation.php',
    'WPML_ST_Page_Translations' => $baseDir . '/classes/filters/db-cache/class-wpml-st-page-translations.php',
    'WPML_ST_Page_Translations_Cached_Persist' => $baseDir . '/classes/filters/db-cache/persist/class-wpml-st-page-translations-cached-persist.php',
    'WPML_ST_Page_Translations_Persist' => $baseDir . '/classes/filters/db-cache/persist/class-wpml-st-page-translations-persist.php',
    'WPML_ST_Page_URL_Preprocessor' => $baseDir . '/classes/filters/db-cache/class-wpml-st-page-url-preprocessor.php',
    'WPML_ST_Records' => $baseDir . '/classes/records/class-wpml-st-records.php',
    'WPML_ST_Relative_Translation_Status' => $baseDir . '/classes/string-translation-status/class-wpml-st-relative-translation-status.php',
    'WPML_ST_Reset' => $baseDir . '/classes/class-wpml-st-reset.php',
    'WPML_ST_Settings' => $baseDir . '/classes/class-wpml-st-settings.php',
    'WPML_ST_String' => $baseDir . '/classes/class-wpml-st-string.php',
    'WPML_ST_String_Factory' => $baseDir . '/classes/class-wpml-st-string-factory.php',
    'WPML_ST_String_Positions' => $baseDir . '/classes/string-tracking/class-wpml-st-string-positions.php',
    'WPML_ST_String_Positions_In_Source' => $baseDir . '/classes/string-tracking/class-wpml-st-string-positions-in-source.php',
    'WPML_ST_String_Statuses' => $baseDir . '/classes/class-wpml-st-string-statuses.php',
    'WPML_ST_String_Update' => $baseDir . '/inc/wpml-st-string-update.class.php',
    'WPML_ST_Strings' => $baseDir . '/classes/class-wpml-st-strings.php',
    'WPML_ST_TM_Jobs' => $baseDir . '/classes/wpml-tm/class-wpml-st-tm-jobs.php',
    'WPML_ST_Theme_Localization_Type' => $baseDir . '/classes/class-wpml-st-theme-localization-type.php',
    'WPML_ST_Themes_And_Plugins_Settings' => $baseDir . '/classes/strings-scanning/class-wpml-themes-and-plugins-settings.php',
    'WPML_ST_Themes_And_Plugins_Updates' => $baseDir . '/classes/strings-scanning/class-wpml-themes-and-plugins-updates.php',
    'WPML_ST_Upgrade' => $baseDir . '/classes/upgrade/class-wpml-st-upgrade.php',
    'WPML_ST_Upgrade_Command_Factory' => $baseDir . '/classes/upgrade/class-wpml-st-upgrade-command-factory.php',
    'WPML_ST_Upgrade_Command_Not_Found_Exception' => $baseDir . '/classes/upgrade/class-wpml-st-upgrade-command-not-found-exception.php',
    'WPML_ST_Upgrade_DB_String_Location' => $baseDir . '/classes/upgrade/class-wpml-st-upgrade-db-string-location.php',
    'WPML_ST_Upgrade_DB_String_Packages' => $baseDir . '/classes/upgrade/class-wpml-st-upgrade-db-string-packages.php',
    'WPML_ST_Upgrade_Db_Cache_Command' => $baseDir . '/classes/upgrade/class-wpml-st-upgrade-db-cache-command.php',
    'WPML_ST_Upgrade_Display_Strings_Scan_Notices' => $baseDir . '/classes/upgrade/class-wpml-st-upgrade-display-strings-scan-notices.php',
    'WPML_ST_Upgrade_Migrate_Originals' => $baseDir . '/classes/upgrade/class-wpml-st-upgrade-migrate-originals.php',
    'WPML_ST_User_Fields' => $baseDir . '/classes/class-wpml-st-user-fields.php',
    'WPML_ST_Verify_Dependencies' => $baseDir . '/classes/class-wpml-st-verify-dependencies.php',
    'WPML_ST_WP_Loaded_Action' => $baseDir . '/classes/actions/class-wpml-st-wp-loaded-action.php',
    'WPML_ST_WP_Wrapper' => $baseDir . '/classes/filters/db-cache/class-wpml-st-wp-wrapper.php',
    'WPML_Slug_Translation' => $baseDir . '/inc/slug-translation.php',
    'WPML_String_Scanner' => $baseDir . '/inc/gettext/wpml-string-scanner.class.php',
    'WPML_String_Translation' => $baseDir . '/inc/wpml-string-translation.class.php',
    'WPML_String_Translation_MO_Import' => $baseDir . '/inc/gettext/wpml-string-translation-mo-import.class.php',
    'WPML_String_Translation_Table' => $baseDir . '/classes/string-translation-ui/class-wpml-string-translation-table.php',
    'WPML_TM_Filters' => $baseDir . '/classes/filters/class-wpml-tm-filters.php',
    'WPML_TM_Widget_Filter' => $baseDir . '/classes/filters/class-wpml-tm-widget-filter.php',
    'WPML_Theme_String_Scanner' => $baseDir . '/inc/gettext/wpml-theme-string-scanner.class.php',
    'WPML_post_slug_translation_settings' => $baseDir . '/classes/slug-translation/class-wpml-post-slug-translation-settings.php',
    'WP_Widget_Text_Icl' => $baseDir . '/classes/widgets/wp-widget-text-icl.php',
    'xrstf\\Composer52\\AutoloadGenerator' => $vendorDir . '/xrstf/composer-php52/lib/xrstf/Composer52/AutoloadGenerator.php',
    'xrstf\\Composer52\\Generator' => $vendorDir . '/xrstf/composer-php52/lib/xrstf/Composer52/Generator.php',
);
