.redux-container-sorter {
    margin-right: -20px;

    ul {
        background: #F9F9F9;
        border: 1px solid #E3E3E3;
        min-height: 40px;
        padding: 10px 10px 0;
        width: 145px;
        float: left;
        margin: 0 15px 0 0;

        &.filled {
            opacity: .7;
            filter: alpha(opacity=70); /* For IE8 and earlier */
            background: #efecec;
        }

        li {
            border: 1px solid #DFDFDF;
            cursor: move;
            font-weight: bold;
            margin-bottom: 10px !important;
            padding: 0 10px;
            height: 40px;
            line-height: 40px !important;
            background-color: #F1F1F1;
            background-image: -ms-linear-gradient(top, #f9f9f9, #ececec);
            background-image: -moz-linear-gradient(top, #f9f9f9, #ececec);
            background-image: -o-linear-gradient(top, #f9f9f9, #ececec);
            background-image: -webkit-gradient(linear, left top, left bottom, from(#f9f9f9), to(#ececec));
            background-image: -webkit-linear-gradient(top, #f9f9f9, #ececec);
            background-image: linear-gradient(top, #f9f9f9, #ececec);
            overflow: hidden;
            -webkit-border-radius: 3px;
            -moz-border-radius: 3px;
            border-radius: 3px;
            -moz-box-shadow: inset 0 1px 0 #fff;
            -webkit-box-shadow: inset 0 1px 0 #fff;
            box-shadow: inset 0 1px 0 #fff;
            text-align: center;

            h3 {
                margin: 0 0 10px;
                text-align: center;
                color: #777;
                text-transform: capitalize;
                word-wrap: break-word;
            }

            &.placeholder {
                height: 40px;
            }
        }
    }
}

.wp-customizer {
    .redux-container-sorter ul {
        width: 85%;
        margin: 0 0 5px 0;
    }
}