��X<?php exit; ?>a:1:{s:7:"content";O:8:"stdClass":24:{s:2:"ID";i:6866;s:11:"post_author";s:1:"1";s:9:"post_date";s:19:"2016-07-12 14:46:53";s:13:"post_date_gmt";s:19:"2016-07-12 06:46:53";s:12:"post_content";s:3723:"[vc_row type="full_width_background" scene_position="center" text_color="dark" text_align="center" bottom_padding="3%" overlay_strength="0.95"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/1"][vc_column_text]
<h2>細訴您的大計，其餘的事給我們</h2>
[/vc_column_text][/vc_column][/vc_row][vc_row type="full_width_background" scene_position="center" text_color="dark" text_align="left" bottom_padding="3%" overlay_strength="0.95"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][image_with_animation image_url="6292" alignment="right" animation="Fade In" delay="150"][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][vc_column_text]
<h5>品牌設計類別</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color"]
<ul>
 	<li>品牌形象設計</li>
 	<li>小冊子和產品目錄</li>
 	<li>標誌設計</li>
 	<li>咭片設計</li>
 	<li>單張及明信片設計</li>
 	<li>企業形象指南</li>
 	<li>包裝設計</li>
 	<li>插圖繪畫</li>
 	<li>其他平面設計</li>
</ul>
[/fancy-ul][/vc_column][/vc_row][vc_row type="full_width_background" scene_position="center" text_color="dark" text_align="center" top_padding="3%" bottom_padding="3%" color_overlay="#00afcb" overlay_strength="0.3"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/1"][split_line_heading]
<h2>作品參考</h2>
[/split_line_heading][divider line_type="No Line"][clients columns="4" fade_in_animation="true" carousel="true"][client image="6632" title="Client" tab_id="1467099424346-4" name="Energywatt - Tag" id="1467100705963-9"] Click the edit button to add your testimonial. [/client][client image="6638" title="Client" tab_id="1467099424500-1" name="Energywatt" id="1467100967717-3"] Click the edit button to add your testimonial. [/client][client image="6658" title="Client" tab_id="1467101016768-5" name="i Water - Productshot" id="1467128724605-7"][/client][client image="6644" title="Client" tab_id="1467101964602-1" name="element water - Booth" id="1467103000257-3"][/client][client image="6646" title="Client" tab_id="1467102957922-0" name="Energywatt" id="1467103055326-10"][/client][client image="6655" title="Client" tab_id="1467103724630-0" name="Energywatt" id="1467103781766-7"][/client][client image="6660" title="Client" tab_id="1467104284174-6" name="Energywatt" id="1468305766214-4"][/client][client image="6662" title="Client" tab_id="1467128731598-0" name="Energywatt" id="1468306020498-7"][/client][/clients][clients columns="4" fade_in_animation="true" carousel="true"][client image="6930" title="Client" tab_id="1467099424346-4" name="Energywatt" id="1468561513918-5"] Click the edit button to add your testimonial. [/client][client image="6931" title="Client" tab_id="1467099424500-1" name="Energywatt" id="1468561513938-1"] Click the edit button to add your testimonial. [/client][client image="6932" title="Client" tab_id="1467101016768-5" name="Energywatt" id="1468561513949-0"][/client][client image="6933" title="Client" tab_id="1467101964602-1" name="Energywatt" id="1468561513970-0"][/client][client image="6934" title="Client" tab_id="1467102957922-0" name="Energywatt" id="1468561513996-9"][/client][client image="6938" title="Client" tab_id="1467103724630-0" name="Energywatt" id="1468563119807-9"][/client][/clients][/vc_column][/vc_row]";s:10:"post_title";s:12:"品牌設計";s:12:"post_excerpt";s:0:"";s:11:"post_status";s:7:"publish";s:14:"comment_status";s:6:"closed";s:11:"ping_status";s:6:"closed";s:13:"post_password";s:0:"";s:9:"post_name";s:14:"brand-identity";s:7:"to_ping";s:0:"";s:6:"pinged";s:0:"";s:13:"post_modified";s:19:"2016-08-04 13:04:10";s:17:"post_modified_gmt";s:19:"2016-08-04 05:04:10";s:21:"post_content_filtered";s:0:"";s:11:"post_parent";i:0;s:4:"guid";s:41:"http://web2.vbits.com.hk/zh/?page_id=6866";s:10:"menu_order";i:0;s:9:"post_type";s:4:"page";s:14:"post_mime_type";s:0:"";s:13:"comment_count";s:1:"0";s:6:"filter";s:3:"raw";}}