<?php

// autoload_52.php generated by xrstf/composer-php52

require_once dirname(__FILE__) . '/composer'.'/autoload_real_52.php';

return ComposerAutoloaderInit425a40276f6d6243a4ea50b2b4c25c5e::getLoader();
