
.manage__icon {
	width: 155px;
	height: 155px;
	margin: 20px auto;
}

.manage-page {
	.manage__description {
		max-width: 600px;
		text-align: center;
		font-size: 22px;
		color: #999;
		margin: 20px auto;
	}
	.manage__button {
		font-size:16px;
		padding: 0 20px;
		height:40px;
		line-height:40px;
	}
}
.manage__title .genericon {
	font-size: 38px;
	color: #81A944;
}

.manage__link {
	font-size: 16px;
	padding: 0 20px;
	height: 40px;
	line-height: 40px;
	font-weight: normal;

	 .genericon{
		font-size: 28px;
		vertical-align: middle;
		margin-top: -6px;
	}
}
