X˜ÔX<?php exit; ?>a:6:{s:10:"last_error";s:0:"";s:10:"last_query";s:547:"
					SELECT DISTINCT 
						s.id,
						s.name,
						s.context,
						st.status,
						s.gettext_context, 
						st.value AS tra,
						s.value AS orig
					FROM wp_icl_string_pages sp
					INNER JOIN wp_icl_string_urls su
						ON su.id = sp.url_id
					INNER JOIN wp_icl_strings s
						ON s.id = sp.string_id
					LEFT JOIN wp_icl_string_translations st
						ON s.id=st.string_id
							AND st.language=su.language
							AND s.language!=su.language
					WHERE (su.language='zh' and su.url='/') or (su.language='zh' and su.url IS NULL)
					";s:11:"last_result";a:55:{i:0;O:8:"stdClass":7:{s:2:"id";s:2:"50";s:4:"name";s:30:"[wpseo_social]og_default_image";s:7:"context";s:24:"admin_texts_wpseo_social";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:0:"";}i:1;O:8:"stdClass":7:{s:2:"id";s:2:"51";s:4:"name";s:32:"[wpseo_social]og_frontpage_title";s:7:"context";s:24:"admin_texts_wpseo_social";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:0:"";}i:2;O:8:"stdClass":7:{s:2:"id";s:2:"52";s:4:"name";s:31:"[wpseo_social]og_frontpage_desc";s:7:"context";s:24:"admin_texts_wpseo_social";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:0:"";}i:3;O:8:"stdClass":7:{s:2:"id";s:2:"53";s:4:"name";s:32:"[wpseo_social]og_frontpage_image";s:7:"context";s:24:"admin_texts_wpseo_social";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:0:"";}i:4;O:8:"stdClass":7:{s:2:"id";s:1:"2";s:4:"name";s:30:"[wpseo_titles]title-home-wpseo";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:42:"%%sitename%% %%page%% %%sep%% %%sitedesc%%";}i:5;O:8:"stdClass":7:{s:2:"id";s:1:"3";s:4:"name";s:32:"[wpseo_titles]title-author-wpseo";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:41:"%%name%%, Author at %%sitename%% %%page%%";}i:6;O:8:"stdClass":7:{s:2:"id";s:1:"4";s:4:"name";s:33:"[wpseo_titles]title-archive-wpseo";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:38:"%%date%% %%page%% %%sep%% %%sitename%%";}i:7;O:8:"stdClass":7:{s:2:"id";s:1:"5";s:4:"name";s:32:"[wpseo_titles]title-search-wpseo";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:63:"You searched for %%searchphrase%% %%page%% %%sep%% %%sitename%%";}i:8;O:8:"stdClass":7:{s:2:"id";s:1:"6";s:4:"name";s:29:"[wpseo_titles]title-404-wpseo";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:35:"Page not found %%sep%% %%sitename%%";}i:9;O:8:"stdClass":7:{s:2:"id";s:1:"7";s:4:"name";s:33:"[wpseo_titles]metadesc-home-wpseo";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:0:"";}i:10;O:8:"stdClass":7:{s:2:"id";s:1:"8";s:4:"name";s:35:"[wpseo_titles]metadesc-author-wpseo";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:0:"";}i:11;O:8:"stdClass":7:{s:2:"id";s:1:"9";s:4:"name";s:36:"[wpseo_titles]metadesc-archive-wpseo";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:0:"";}i:12;O:8:"stdClass":7:{s:2:"id";s:2:"10";s:4:"name";s:32:"[wpseo_titles]metakey-home-wpseo";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:0:"";}i:13;O:8:"stdClass":7:{s:2:"id";s:2:"11";s:4:"name";s:34:"[wpseo_titles]metakey-author-wpseo";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:0:"";}i:14;O:8:"stdClass":7:{s:2:"id";s:2:"12";s:4:"name";s:24:"[wpseo_titles]title-post";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:39:"%%title%% %%page%% %%sep%% %%sitename%%";}i:15;O:8:"stdClass":7:{s:2:"id";s:2:"13";s:4:"name";s:27:"[wpseo_titles]metadesc-post";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:0:"";}i:16;O:8:"stdClass":7:{s:2:"id";s:2:"14";s:4:"name";s:26:"[wpseo_titles]metakey-post";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:0:"";}i:17;O:8:"stdClass":7:{s:2:"id";s:2:"15";s:4:"name";s:24:"[wpseo_titles]title-page";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:39:"%%title%% %%page%% %%sep%% %%sitename%%";}i:18;O:8:"stdClass":7:{s:2:"id";s:2:"16";s:4:"name";s:27:"[wpseo_titles]metadesc-page";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:0:"";}i:19;O:8:"stdClass":7:{s:2:"id";s:2:"17";s:4:"name";s:26:"[wpseo_titles]metakey-page";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:0:"";}i:20;O:8:"stdClass":7:{s:2:"id";s:2:"18";s:4:"name";s:30:"[wpseo_titles]title-attachment";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:39:"%%title%% %%page%% %%sep%% %%sitename%%";}i:21;O:8:"stdClass":7:{s:2:"id";s:2:"19";s:4:"name";s:33:"[wpseo_titles]metadesc-attachment";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:0:"";}i:22;O:8:"stdClass":7:{s:2:"id";s:2:"20";s:4:"name";s:32:"[wpseo_titles]metakey-attachment";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:0:"";}i:23;O:8:"stdClass":7:{s:2:"id";s:2:"21";s:4:"name";s:32:"[wpseo_titles]title-tax-category";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:53:"%%term_title%% Archives %%page%% %%sep%% %%sitename%%";}i:24;O:8:"stdClass":7:{s:2:"id";s:2:"22";s:4:"name";s:35:"[wpseo_titles]metadesc-tax-category";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:0:"";}i:25;O:8:"stdClass":7:{s:2:"id";s:2:"23";s:4:"name";s:34:"[wpseo_titles]metakey-tax-category";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:0:"";}i:26;O:8:"stdClass":7:{s:2:"id";s:2:"24";s:4:"name";s:32:"[wpseo_titles]title-tax-post_tag";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:53:"%%term_title%% Archives %%page%% %%sep%% %%sitename%%";}i:27;O:8:"stdClass":7:{s:2:"id";s:2:"25";s:4:"name";s:35:"[wpseo_titles]metadesc-tax-post_tag";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:0:"";}i:28;O:8:"stdClass":7:{s:2:"id";s:2:"26";s:4:"name";s:34:"[wpseo_titles]metakey-tax-post_tag";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:0:"";}i:29;O:8:"stdClass":7:{s:2:"id";s:2:"27";s:4:"name";s:35:"[wpseo_titles]title-tax-post_format";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:53:"%%term_title%% Archives %%page%% %%sep%% %%sitename%%";}i:30;O:8:"stdClass":7:{s:2:"id";s:2:"28";s:4:"name";s:38:"[wpseo_titles]metadesc-tax-post_format";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:0:"";}i:31;O:8:"stdClass":7:{s:2:"id";s:2:"29";s:4:"name";s:37:"[wpseo_titles]metakey-tax-post_format";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:0:"";}i:32;O:8:"stdClass":7:{s:2:"id";s:2:"30";s:4:"name";s:31:"[wpseo_titles]title-home_slider";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:39:"%%title%% %%page%% %%sep%% %%sitename%%";}i:33;O:8:"stdClass":7:{s:2:"id";s:2:"31";s:4:"name";s:34:"[wpseo_titles]metadesc-home_slider";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:0:"";}i:34;O:8:"stdClass":7:{s:2:"id";s:2:"32";s:4:"name";s:33:"[wpseo_titles]metakey-home_slider";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:0:"";}i:35;O:8:"stdClass":7:{s:2:"id";s:2:"33";s:4:"name";s:29:"[wpseo_titles]title-portfolio";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:39:"%%title%% %%page%% %%sep%% %%sitename%%";}i:36;O:8:"stdClass":7:{s:2:"id";s:2:"34";s:4:"name";s:32:"[wpseo_titles]metadesc-portfolio";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:0:"";}i:37;O:8:"stdClass":7:{s:2:"id";s:2:"35";s:4:"name";s:31:"[wpseo_titles]metakey-portfolio";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:0:"";}i:38;O:8:"stdClass":7:{s:2:"id";s:2:"36";s:4:"name";s:36:"[wpseo_titles]title-tax-project-type";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:53:"%%term_title%% Archives %%page%% %%sep%% %%sitename%%";}i:39;O:8:"stdClass":7:{s:2:"id";s:2:"37";s:4:"name";s:39:"[wpseo_titles]metadesc-tax-project-type";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:0:"";}i:40;O:8:"stdClass":7:{s:2:"id";s:2:"38";s:4:"name";s:38:"[wpseo_titles]metakey-tax-project-type";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:0:"";}i:41;O:8:"stdClass":7:{s:2:"id";s:2:"39";s:4:"name";s:42:"[wpseo_titles]title-tax-project-attributes";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:53:"%%term_title%% Archives %%page%% %%sep%% %%sitename%%";}i:42;O:8:"stdClass":7:{s:2:"id";s:2:"40";s:4:"name";s:45:"[wpseo_titles]metadesc-tax-project-attributes";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:0:"";}i:43;O:8:"stdClass":7:{s:2:"id";s:2:"41";s:4:"name";s:44:"[wpseo_titles]metakey-tax-project-attributes";s:7:"context";s:24:"admin_texts_wpseo_titles";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:0:"";}i:44;O:8:"stdClass":7:{s:2:"id";s:2:"48";s:4:"name";s:20:"[wpseo_rss]rssbefore";s:7:"context";s:21:"admin_texts_wpseo_rss";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:0:"";}i:45;O:8:"stdClass":7:{s:2:"id";s:2:"49";s:4:"name";s:19:"[wpseo_rss]rssafter";s:7:"context";s:21:"admin_texts_wpseo_rss";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:53:"The post %%POSTLINK%% appeared first on %%BLOGLINK%%.";}i:46;O:8:"stdClass":7:{s:2:"id";s:2:"42";s:4:"name";s:41:"[wpseo_internallinks]breadcrumbs-404crumb";s:7:"context";s:31:"admin_texts_wpseo_internallinks";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:25:"Error 404: Page not found";}i:47;O:8:"stdClass":7:{s:2:"id";s:2:"43";s:4:"name";s:46:"[wpseo_internallinks]breadcrumbs-archiveprefix";s:7:"context";s:31:"admin_texts_wpseo_internallinks";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:12:"Archives for";}i:48;O:8:"stdClass":7:{s:2:"id";s:2:"44";s:4:"name";s:37:"[wpseo_internallinks]breadcrumbs-home";s:7:"context";s:31:"admin_texts_wpseo_internallinks";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:4:"Home";}i:49;O:8:"stdClass":7:{s:2:"id";s:2:"45";s:4:"name";s:39:"[wpseo_internallinks]breadcrumbs-prefix";s:7:"context";s:31:"admin_texts_wpseo_internallinks";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:0:"";}i:50;O:8:"stdClass":7:{s:2:"id";s:2:"46";s:4:"name";s:45:"[wpseo_internallinks]breadcrumbs-searchprefix";s:7:"context";s:31:"admin_texts_wpseo_internallinks";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:16:"You searched for";}i:51;O:8:"stdClass":7:{s:2:"id";s:2:"47";s:4:"name";s:36:"[wpseo_internallinks]breadcrumbs-sep";s:7:"context";s:31:"admin_texts_wpseo_internallinks";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:7:"&raquo;";}i:52;O:8:"stdClass":7:{s:2:"id";s:2:"66";s:4:"name";s:40:"Text for alternative languages for posts";s:7:"context";s:4:"WPML";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:34:"This post is also available in: %s";}i:53;O:8:"stdClass":7:{s:2:"id";s:2:"54";s:4:"name";s:10:"Blog Title";s:7:"context";s:2:"WP";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:5:"Vbits";}i:54;O:8:"stdClass":7:{s:2:"id";s:1:"1";s:4:"name";s:38:"[sharing-options][global]sharing_label";s:7:"context";s:27:"admin_texts_sharing-options";s:6:"status";N;s:15:"gettext_context";s:0:"";s:3:"tra";N;s:4:"orig";s:11:"Share this:";}}s:8:"col_info";a:7:{i:0;O:8:"stdClass":13:{s:4:"name";s:2:"id";s:5:"table";s:1:"s";s:3:"def";s:0:"";s:10:"max_length";i:2;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:1;s:4:"blob";i:0;s:4:"type";s:3:"int";s:8:"unsigned";i:1;s:8:"zerofill";i:0;}i:1;O:8:"stdClass":13:{s:4:"name";s:4:"name";s:5:"table";s:1:"s";s:3:"def";s:0:"";s:10:"max_length";i:46;s:8:"not_null";i:0;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:0;s:4:"type";s:6:"string";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:2;O:8:"stdClass":13:{s:4:"name";s:7:"context";s:5:"table";s:1:"s";s:3:"def";s:0:"";s:10:"max_length";i:31;s:8:"not_null";i:0;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:0;s:4:"type";s:6:"string";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:3;O:8:"stdClass":13:{s:4:"name";s:6:"status";s:5:"table";s:2:"st";s:3:"def";s:0:"";s:10:"max_length";i:0;s:8:"not_null";i:0;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:1;s:4:"blob";i:0;s:4:"type";s:3:"int";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:4;O:8:"stdClass":13:{s:4:"name";s:15:"gettext_context";s:5:"table";s:1:"s";s:3:"def";s:0:"";s:10:"max_length";i:0;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:1;s:4:"type";s:4:"blob";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:5;O:8:"stdClass":13:{s:4:"name";s:3:"tra";s:5:"table";s:2:"st";s:3:"def";s:0:"";s:10:"max_length";i:0;s:8:"not_null";i:0;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:1;s:4:"type";s:4:"blob";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:6;O:8:"stdClass":13:{s:4:"name";s:4:"orig";s:5:"table";s:1:"s";s:3:"def";s:0:"";s:10:"max_length";i:63;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:1;s:4:"type";s:4:"blob";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}}s:8:"num_rows";i:55;s:10:"return_val";i:55;}