@media only screen and (min-width: 1300px) {
  .container,  
  body[data-ext-responsive="false"] #boxed #header-outer[data-full-width="true"] header > .container,  
  body[data-ext-responsive="false"] #boxed #header-secondary-outer[data-full-width="true"] > .container {
    max-width: 1100px;  
  } 

}

@media only screen and (min-width: 1000px) and (max-width: 1300px) {
	
	.col.vc_span3 h5, .col.vc_span4 h5, .col.vc_col-sm-3 h5, .col.vc_col-sm-4 h5 {
		font-size: 16px!important;
	}
	
	h2 .nectar-button {
		top: -2px;
	}

	body .container .portfolio-items:not(.carousel) .col {
		margin-bottom: 20px;
	}

	body #featured .orbit-slide article .container .span_12 {
		width: 900px!important;
	}
	
	#author-bio #author-info {
	  	width: 544px!important;
	}
	
	.portfolio-items:not(.carousel) .col.span_3 .work-item .work-info a {
		padding: 5px 6px!important;
		font-size: 11px!important;
		margin: 1px!important;
	}
	
	.portfolio-items:not(.carousel) .col.span_3 .work-meta, .portfolio-items:not(.carousel) .col.span_4 .work-meta {
		width: 74%!important;
	}
	
    .portfolio-items:not(.carousel) .col.span_3 .nectar-love-wrap, .portfolio-items:not(.carousel) .col.span_4 .nectar-love-wrap  {
		width: 52px;
	}
	
	body.single-portfolio #sidebar.fixed-sidebar, body.single-portfolio #sidebar {
		width: 27.5%;
	}
	body.single-portfolio #post-area {
		width: 72.5%;
	}
	.single-portfolio #boxed #post-area {
		width: 72.49%;
	}
	
	body.single-portfolio #sidebar div ul li.facebook-share, body.single-portfolio #sidebar div ul li.twitter-share, body.single-portfolio #sidebar div ul li.pinterest-share {
		margin: 0 11px 0 0!important;
		padding: 2px 11px 3px 0 !important;
	}
	
	#project-meta ul li .nectar-love-wrap.fadein {
		margin-right: 11px;
		padding-right: 11px;
	}
	
	body #featured .video {
		float: left;
		width: 540px!important;
		left: 1px;
		position: relative;
		z-index: 1;
	}

	body.single.single-post .section-title h1 {
		max-width: 620px;
	}
	
	body.single-portfolio .row .title-wrap .col.section-title {
		text-align: center;
	}

	body.single-portfolio .row .col.section-title h1 {
		max-width: 725px;
		margin: 0 auto;
	}
	
	#featured article .post-title > a {
		left: 0px;
	}
	
	#featured .orbit-slide.has-video h2 {
	    max-width: 330px!important;
	    min-width: 330px!important;
	}
	
	#featured .orbit-slide.has-video .post-title > a {
	    left: 20px!important;
	}
	
	#featured article .post-title h2 {
		left: 0px;	
	}
	
	#featured .has-video h2 {
		left: -10px!important;
	}
	
	#post-area.masonry {
		width: 895px;
	}

	#post-area.masonry.span_9 {
		width: 660px;
		margin-right: 10px;
	}

	.masonry-blog-item .jp-jplayer-video {
		height: 139px!important;
	}
	
	#post-area.span_9 .masonry-blog-item .jp-jplayer-video {
		height: 154px!important;
	}
	
	.single #post-area.span_12 #author-info {
		width: 773px!important;
	}

	#post-area.masonry.span_9 .masonry-blog-item {
		width: 46.5%;
	}

	#page-header-bg .span_6 span.subheader {
		font-size: 24px;
	}
	
	#boxed {
		width: 980px;
	}
	#boxed #header-outer, #boxed #header-secondary-outer, #boxed #page-header-bg, #boxed #featured, #boxed .orbit > div, #boxed #featured article {
		min-width: 980px;
	}
	
	.nectar-milestone .number {
		font-size: 50px;
		line-height: 50px;
	}
	
	.nectar-slider-wrap[data-full-width="false"] .swiper-slide .content h2, #boxed .nectar-slider-wrap[data-full-width="false"] .swiper-slide .content h2  {
		font-size: 32px!important;
		line-height: 50px!important;
	}

	body .swiper-slide .content p {
		font-size: 20px!important;
		line-height: 34px!important;
		padding-bottom: 22px;
	}
	
	.nectar-slider-wrap[data-full-width="false"] .swiper-slide .content p {
		font-size: 14px!important;
		line-height: 24px!important;
	}
		
	.main-content .col.span_4 .col.span_2 img, .main-content .col.span_3 .col.span_2 img, .main-content .col.span_2 .col.span_2 img, .main-content .col.span_6 .col.span_2 img {
		padding-right: 5px;
		top: -3px;
	}
	
	.carousel-next {
		right: 0px;
		padding-left: 1px;
	}
	
	.carousel-prev {
		right: 25px;
		padding-right: 1px;
	}
	
	.portfolio-items:not(.carousel) .col .work-item.style-2 i {
		line-height: 32px!important;
		height: 32px!important;
		width: 32px!Important;
		font-size: 14px!important;
	}
	
	header#top nav > ul > li > a {
		padding-left: 8px;
	}
	
	.sf-menu .sf-with-ul a {
		padding-right: 14px!important;
	}
	
	.sf-sub-indicator {
		left: 6px;
	}
	
	body .swiper-slide .content p.transparent-bg span {
		line-height: 38px!important;
	}
	
	body .carousel-wrap[data-full-width="true"] .carousel-heading h2 {
	    max-width: 720px;
	}
	
	body .vc_pie_chart .vc_pie_chart_value {
		font-size: 32px;
	}
}


@media only screen and (min-width: 1000px) and (max-width: 1080px) {
	
	body #featured .orbit-slide article .container .span_12 {
		width: 820px!important;
	}
	
	body #featured .video {
		float: left;
		width: 460px!important;
		left: 1px;
		position: relative;
		z-index: 1;
	}
	
	.cart-outer { display: none; }
	#header-outer[data-full-width="true"] .cart-outer { display: block; }



	/*html .ascend[data-slide-out-widget-area="true"] #header-outer[data-full-width="true"][data-cart="true"] header#top nav > ul {
		padding-right: 55px!important;
	}*/
	.ascend[data-slide-out-widget-area="true"] #header-outer[data-full-width="true"] header > .container, .ascend[data-slide-out-widget-area="true"] #header-secondary-outer[data-full-width="true"] > .container {
		padding: 0 28px!important;
	}
	/*.ascend[data-slide-out-widget-area="true"] #header-outer[data-full-width="true"] header#top nav ul .slide-out-widget-area-toggle {
		margin-left: 0!important;
	}*/
	

	#featured .orbit-slide.has-video h2 {
	    max-width: 330px!important;
	    min-width: 330px!important;
	}
	
	#featured .orbit-slide.has-video .post-title > a {
	    left: 20px!important;
	}
	
	body #sidebar.fixed-sidebar, body.single-portfolio #sidebar {
		top: 0px!important;
		margin-left: 0px!important;
		position: relative!important;
	}
}

@media only screen and (max-width: 1020px) {
	#to-top:not(.mobile-enabled) {
		display: none!important;
	}
}


/* iPad fixes */
@media only screen and (min-device-width: 481px) and (max-device-width: 1025px) {
	body[data-smooth-scrolling="1"] .nectar-slider-wrap[data-full-width="true"] .swiper-container a.slider-next {
		right: 0px!important;
	}
}

/* iPad landscape fixes */
@media only screen and (min-device-width: 481px) and (max-device-width: 1025px) and (orientation:landscape) {
	
	
	body[data-smooth-scrolling="1"], body[data-smooth-scrolling="1"] #header-outer {
		padding-right: 0px!important;
	}
	
	body[data-smooth-scrolling="1"] .orbit-wrapper div.slider-nav span.right {
		right: 0px!important;
	}
	
	#to-top {
	 	display: none!important;	
	}
	
	.swiper-slide .content p, .swiper-slide .content h2, .swiper-slide .content .buttons {
		opacity: 1!important;
		padding: 0!important;
	}

	.full-width-section.parallax_section, .full-width-content.parallax_section  {
		background-attachment: scroll!important;
		background-position: center!important;
	}

    .wpb_row .row-bg, .full-width-section .row-bg {
    	margin-top: 0!important;
    	height: 100%!important;
    	transform: none!important;
    	-webkit-transform: none!important;
    	background-attachment: scroll!important;
	}
	
	.orbit > div {
		position: absolute !important;
		top: 0px!Important;
	}
	
	#featured.orbit > div.has-video .container {
		top: 70px!Important;	
	}
	
	#featured article {
		top: 0px!Important;
		background-position: center!important;
	}
	
	#featured .orbit-slide article .container {
		top: 145px!important;
		position: absolute!important;
	}
	
	.orbit-wrapper div.slider-nav span.left, .orbit-wrapper div.slider-nav span.right {
		position: absolute!important;
		top: 230px!important;
	}
	
	.orbit-wrapper, .orbit-wrapper #featured, .orbit-wrapper #featured article  {
  		height: 450px!important;	
  		margin-bottom: 0;
  	}
  	
  	#featured article {
  		position: relative!important;
		background-size: cover!important;
		-moz-background-size: cover!important;
		-o-background-size: cover!important;
		-webkit-background-size: cover!important;
		background-attachment: scroll!important;
	}
	
	body .fixed-sidebar, .single-portfolio #sidebar {
		top: 0px!important;
		width: 23.5%!important;
		margin-left: 0px!important;
		position: relative!important;
	}
	
	#page-header-bg[data-parallax="1"] .span_6, #page-header-bg[data-parallax="1"] {
		position: relative!important;
	}
	
	#page-header-bg[data-parallax="1"] {
		top: 0px!important;
	}
	
	#page-header-bg .span_6 {
		display: block!important;
		opacity: 1!important;
	}
	
	.swiper-container .slider-right {
		right: 0px!important;
	}
	
	.video-texture, #style-selection {
		display: none!important;
	}
	
	.parallax_slider_outer.first-section .nectar-slider-wrap, #full_width_portfolio .project-title.parallax-effect {
		transform: translate(0px, 0px)!important;
		-webkit-transform: translate(0px, 0px)!important;
	}
	
	.parallax_slider_outer.first-section .swiper-slide .content {
		opacity: 1!important;
		transform: translate(0px, 0px)!important;
		-webkit-transform: translate(0px, 0px)!important;
	}
	
	#full_width_portfolio .project-title.parallax-effect {
		padding-top: 5em!important;
		position: relative!important;
		margin-top: -32px!important;
		top: 0px!important;
	}

	.parallax_slider_outer.first-section .nectar-slider-wrap {
		position: relative!important;
		max-width: 100%;
		overflow-x: hidden;
	}
	
	img.img-with-animation[data-animation="fade-in-from-right"] {
		padding-left: 0px!important;
		right: 0!important;
	}
	
	img.img-with-animation[data-animation="fade-in-from-left"] {
		padding-right: 0px!important;
		left: 0!important;
	}

	.col.has-animation[data-animation="fade-in-from-left"], .wpb_column.has-animation[data-animation="fade-in-from-left"] {
		left: 0!important;
	}
	
	img.img-with-animation[data-animation="fade-in-from-bottom"] {
		bottom: 0px!important;
	}
	
	.clients.fade-in-animation > div, img.img-with-animation, .col.has-animation, .wpb_column.has-animation {
		opacity: 1!important;
	}
	
	.col.has-animation[data-animation="fade-in-from-bottom"], .wpb_column.has-animation[data-animation="fade-in-from-bottom"] {
		bottom: 0px!important;
		transform: translateY(0)!important;
		-webkit-transform: translateY(0)!important;
		-moz-transform: translateY(0)!important;
	}
	
	img.img-with-animation[data-animation="grow-in"], .col.has-animation[data-animation="grow-in"], .wpb_column.has-animation[data-animation="grow-in"] {
		 transform: scale(1, 1)!important;
		 -webkit-transform: scale(1, 1)!Important;
	}

	img.img-with-animation[data-animation="flip-in"], .col.has-animation[data-animation="flip-in"], .wpb_column.has-animation[data-animation="flip-in"] {
		opacity: 1!important;
	    transform: perspective(1000px) rotateY(0deg)!important;
	    -webkit-transform: perspective(1000px) rotateY(0deg)!important;
	    -o-webkit-transform: perspective(1000px) rotateY(0deg)!important;
	    -moz-webkit-transform: perspective(1000px) rotateY(0deg)!important;
	}
	
	.parallax_slider_outer.first-section .nectar-slider-wrap, #full_width_portfolio .project-title.parallax-effect {
		transform: translate(0px, 0px)!Important;
		-webkit-transform: translate(0px, 0px)!Important;
	}
	
	.portfolio-items .col .work-item .work-info a {
		display: block;
		position: absolute;
		top: 0px;
		left: 0px;
		margin: 0px;
		width: 100%;
		height: 100%;
		text-indent: -9999px;
	}

	.portfolio-items .col .work-item .work-info .custom-content a.nectar-button {
		width: auto;
	}

	.portfolio-items[data-ps="6"] .work-item .parallaxImg-layers > div .bg-img:after {
	    opacity: 1;
	}

	.portfolio-items[data-ps="6"] .work-item .work-meta .inner, .portfolio-items[data-ps="6"] .wide_tall .work-item .work-meta .inner {
	    opacity: 1;
	    transform: scale(1);
	    -webkit-transform: scale(1);
	}
	
	.portfolio-items .col .work-item:not(.style-2):not(.style-3):not(.style-3-alt):not(.style-4) .work-info .vert-center {
	    height: 100%;
	    top: 0 !important;
	    transform: none !important;
	    -webkit-transform: none !important;
	}
	
}


/*higher res tablets*/
@media only screen and (min-device-width: 481px) and (max-device-width: 2600px)  {
	
	.using-mobile-browser img.img-with-animation[data-animation="fade-in-from-right"] {
		padding-left: 0px!important;
		right: 0!important;
	}
	
	.using-mobile-browser img.img-with-animation[data-animation="fade-in-from-left"] {
		padding-right: 0px!important;
		left: 0!important;
	}

	.using-mobile-browser .col.has-animation[data-animation="fade-in-from-left"], .using-mobile-browser .wpb_column.has-animation[data-animation="fade-in-from-left"] {
		left: 0!important;
	}
	
	.using-mobile-browser img.img-with-animation[data-animation="fade-in-from-bottom"] {
		bottom: 0px!important;
	}
	
	.using-mobile-browser .clients.fade-in-animation > div, .using-mobile-browser img.img-with-animation, .using-mobile-browser .col.has-animation, .using-mobile-browser .wpb_column.has-animation {
		opacity: 1!important;
	}
	
	.using-mobile-browser .col.has-animation[data-animation="fade-in-from-bottom"], .using-mobile-browser .wpb_column.has-animation[data-animation="fade-in-from-bottom"] {
		bottom: 0px!important;
		transform: translateY(0)!important;
		-webkit-transform: translateY(0)!important;
		-moz-transform: translateY(0)!important;
	}
	
	.using-mobile-browser img.img-with-animation[data-animation="grow-in"], .using-mobile-browser .col.has-animation[data-animation="grow-in"], .using-mobile-browser .wpb_column.has-animation[data-animation="grow-in"] {
		 transform: scale(1, 1)!important;
		 -webkit-transform: scale(1, 1)!Important;
	}

	.using-mobile-browser img.img-with-animation[data-animation="flip-in"], .using-mobile-browser .col.has-animation[data-animation="flip-in"], .using-mobile-browser .wpb_column.has-animation[data-animation="flip-in"] {
		opacity: 1!important;
	    transform: perspective(1000px) rotateY(0deg)!important;
	    -webkit-transform: perspective(1000px) rotateY(0deg)!important;
	    -o-webkit-transform: perspective(1000px) rotateY(0deg)!important;
	    -moz-webkit-transform: perspective(1000px) rotateY(0deg)!important;
	}

	.ascend.using-mobile-browser #search {
		height: 100%;
	}
	.ascend.using-mobile-browser #search #search-box {
		top: 20px!important;
	}

	.using-mobile-browser .nectar-split-heading .heading-line > span {
	    transform: none;
	    -webkit-transform: none;
	}

}


@media only screen and (min-device-width: 1px) and (max-device-width: 1025px) {
	.wpb_row .nectar-parallax-scene div {
		top: -40px!important;
	}

	.blurred-wrap.blurred {
	  -webkit-filter: blur(0px);
	  -moz-filter: blur(0px);
	  -o-filter: blur(0px);
	  -ms-filter: blur(0px);
	  filter: blur(0px);
	}
}

	
@media only screen and (min-width : 690px) and (max-width : 1000px) {
		
	body[data-smooth-scrolling="1"] #header-outer {
		padding-right: 0px!important;	
	}
	
	.span_1, .span_2, .span_3, .span_4, .span_5, .span_6, .span_7, .span_8, .span_9, .span_10, .span_11, .span_12 { width: 100%; margin-left: 0px; }
	
	.col, body .vc_row-fluid .wpb_column {
		margin-bottom: 25px;	
	}
	
	body .vc_row-fluid .wpb_column,
	body .vc_row-fluid .vc_col-sm-2[class*="vc_col-sm-"],
	body .vc_row-fluid .vc_col-sm-3[class*="vc_col-sm-"],
	body .vc_row-fluid .vc_col-sm-4[class*="vc_col-sm-"],
	body .vc_row-fluid .vc_col-sm-6[class*="vc_col-sm-"],
	body .vc_row-fluid .vc_col-sm-8[class*="vc_col-sm-"],
	body .vc_row-fluid .vc_col-sm-9[class*="vc_col-sm-"],
	body .vc_row-fluid .vc_col-sm-10[class*="vc_col-sm-"],
	body .vc_row-fluid .vc_col-sm-11[class*="vc_col-sm-"] {
		width: 100%;
		margin-right: 0px!important;
		margin-left: 0px;
	}
	
	body .vc_row-fluid .vc_col-sm-2[class*="vc_col-sm-"] {
		width: 31.2%;
		margin-left: 3.1%;
	}
	.vc_row-fluid .vc_col-sm-2[class*="vc_col-sm-"]:first-child:not([class*="offset"]),
	.vc_row-fluid .vc_col-sm-2[class*="vc_col-sm-"]:nth-child(3n+4):not([class*="offset"]) {
	  margin-left: 0;
	}

	.container {
    	max-width: 600px; 
  	} 
  	
  	body[data-ext-responsive="true"] .vc_span12 .nectar-slider-wrap[data-full-width="boxed-full-width"], body[data-ext-responsive="true"] .vc_col-sm-12 .nectar-slider-wrap[data-full-width="boxed-full-width"] {
		margin: 0 -7%!important;
	}
  	
  	#header-secondary-outer nav > ul > li:last-child {
	    border-right: 1px solid #DDDDDD!important;
	}

  	.orbit-wrapper, .orbit-wrapper #featured, .orbit-wrapper #featured article  {
  		height: 450px!important;	
  		position: relative!important;
  		margin-bottom: 0em;
  	}
  	
  	
	body #featured .orbit-slide article .container { 
	    top: -25px!important;
	    opacity: 1!important;
	    position: relative!important;
	}
	
	body #featured .orbit-slide article .container .span_12 {
		width: 600px!important;
	}
	
	.one-fourths.span_3, .one-fourths.vc_span3, .one-fourths.vc_col-sm-3  { width: 48%!important; margin-bottom: 2%; margin-right: 15px; margin-left: 0px!important; padding: 15px; float: left; }
	
	.full-width-content.vc_row-fluid  .one-fourths.vc_span3,
	.full-width-content.vc_row-fluid  .one-fourths.vc_span4,
	.full-width-content.vc_row-fluid  .one-fourths.vc_col-sm-3,
	.full-width-content.vc_row-fluid  .one-fourths.vc_col-sm-4 {
		width: 50%!important;
	}
  	
  	.one-fourths.span_3.clear-both, .one-fourths.vc_span3.clear-both, .one-fourths.vc_col-sm-3.clear-both { clear: both; }
  	.one-fourths.span_3.right-edge, .one-fourths.vc_span3.right-edge, .one-fourths.vc_col-sm-3.right-edge { margin-right: 0px; }

  	.portfolio-items .col {
  		width: 100%;
  		margin-left: 0px;
  		margin-bottom: 8px;
  	}

  	.portfolio-items:not(.carousel) div:nth-child(2n+2), .portfolio-items:not(.carousel) div:nth-child(2n+2) {
  		clear: both;
  	}

  	body .portfolio-items:not(.carousel)[data-col-num="cols-3"], body .portfolio-items:not(.carousel)[data-col-num="cols-4"] {
		margin: 0 -2% 0 -2%;
	}

  	.portfolio-items:not(.carousel) .col.span_4, .portfolio-items:not(.carousel) .col.span_3 {
  		width: 45.8%!important;
  		margin: 2%!important;
  	}
  	
  	.portfolio-items[data-ps="6"] .col {
  		padding: 2%;
  	}

  	.portfolio-items[data-ps="6"] .work-item .parallaxImg-layers > div .bg-img:after {
	    opacity: 1;
	}

	.portfolio-items[data-ps="6"] .work-item .work-meta .inner, .portfolio-items[data-ps="6"] .wide_tall .work-item .work-meta .inner {
	    opacity: 1;
	    transform: scale(1);
	    -webkit-transform: scale(1);
	}

  	.col.boxed:hover {
  		margin-top: 0px!important;
  		-o-box-shadow: 0 1px 2px rgba(0,0,0,0.2)!important;
		-moz-box-shadow: 0 1px 2px rgba(0,0,0,0.2)!important;
		-webkit-box-shadow: 0 1px 2px rgba(0,0,0,0.2)!important;
    	box-shadow: 0 1px 2px rgba(0,0,0,0.2)!important;
  	}

  	.pricing-table[data-style="flat-alternative"].two-cols > div,
  	.pricing-table[data-style="flat-alternative"].three-cols > div,
  	.pricing-table[data-style="flat-alternative"].four-cols > div,
  	.pricing-table[data-style="flat-alternative"].five-cols > div {
  		width: 48%!important;
  	}
  	
  	body #featured article .post-title h2 span {
  		font-size: 24px!important;
  		line-height: 43px!important;
  	}
  	
  	
	#featured article .post-title h2 {
		max-width: 325px!important;
    	min-width: 325px!important;
	}
	
	#featured .orbit-slide.centered article .post-title h2 {
		max-width: 415px!important;
    	min-width: 415px!important;
	}
	
	#call-to-action .container a {
		margin-top: 20px;
		margin-left: 0px!important;
	}
	
	#post-area {
		padding-right: 0px!important;
	}
	
	body.single-portfolio .row .col.section-title h1 {
		width: 450px;
		margin: 0 auto;
	}

	.contact-info {
		padding-left: 0px!important;
	}
	
	.nectar-google-map {
  		max-height: 425px;
  	}
  	
	#sidebar #flickr > div {
		width: 16%!important;
	}
	
	#footer-outer #copyright .col {
		width: 49%;
		margin-bottom: 0px;
	}
	
	#footer-widgets .container .col {
		margin-left: 15px;
		width: 48%;
	}
	
	#footer-widgets .one-fourths .span_3:nth-child(2n+1) {
		margin-left: 0px;
	}
	
	body #sidebar #flickr div {
		float: left;
	}
	
	#sidebar .recent_projects_widget div a, body #sidebar #flickr div a  {
		width: 90px!important;
	}
	
	body #sidebar .recent_projects_widget div a:last-child, body #sidebar #flickr div {
		margin-right: 0px!important;
	}
	
	#sidebar .recent_projects_widget div a:nth-child(3n+3), body #sidebar #flickr div:nth-child(3n+3) a {
		margin: 2% 2% 0 0!important;
	}
	

	#author-bio #author-info {
	  	width: 494px!important;
	}
	
	#page-header-bg .span_6 h1 {
  		font-size: 32px!important;
  		line-height: 38px!important;
  	}
  	#page-header-bg .span_6 span.subheader {
  		font-size: 22px!important;
  	}
	
	#page-header-bg .span_6 {
		top: auto!important;
		float: none!important;
	}
	
	.portfolio-filters {
		position: relative!important;
		display: inline-block!important;
		clear: both!important;
		margin-top: 10px!important;
		float: none;
		top: auto!important;
	}
	
	.page-header-no-bg .portfolio-filters {
		margin-top: 15px!important;
		float: none!important;
		clear: both;
		height: auto!important;
	}
	
	#page-header-bg[data-parallax="1"] .project-title .span_6 {
		padding-right: 70px!important;
	}

	.page-header-no-bg  .portfolio-filters ul {
		position: absolute;
		width: 100%;
	}
	
	html.js #page-header-bg[data-parallax="0"].not-loaded {
		height: 250px!important;
		background-color: #F5F5F5;
	}
	
	.pricing-table > div { 
  		width: 50%!important; 
  		margin-bottom: 25px!important;
  	}
  	
  	.pricing-column.highlight .nectar-button {
  		margin-bottom: 10px!important;
  		margin-top: 0px!important;
  	}
  	
  	.pricing-column.highlight {
  		margin-top: 0px!important;
  	}
  	
  	.pricing-column h3 {
  		font-size: 20px!important;
  	}
  	
  	.pricing-column.highlight h3 {
  		padding: 5px 0px!important;
  	}

  	
  	body .clients.no-carousel > div { 
  		width: 24.2%!important;
  		margin-right: 1%!important;
  	}
  	
  	body .clients.no-carousel.six-cols > div { 
  		width:15.8% !important;
  		margin-right: 1%!important;
  	}
  	
  	body .clients.no-carousel.five-cols  > div { 
  		width: 19.2%!important;
  		margin-right: 1%!important;
  	}
  	
  	body .clients.no-carousel > div:nth-child(4n+4){
  		margin-right: 0px!important;
  	}
  	
  	body .clients.carousel > div {
		margin: 0px 5px!important;
	}
	
	#call-to-action .container span {
		display: block!important;
	}

	.masonry-blog-item {
		width: 47.7%;
	}
	
	#post-area.masonry, #post-area.masonry.span_9,  body[data-ext-responsive="true"] #post-area.masonry.span_9 {
		width: 610px;
	}

	#post-area.masonry.span_9 {
		margin-bottom: 90px;
	}

	#post-area.masonry.span_9 .masonry-blog-item {
		width: 47.5%;
	}

	body #post-area.masonry.classic_enhanced.span_9 .masonry-blog-item.large_featured {
		width: 99%;
	}

	#post-area.masonry #pagination {
		bottom: -90px;
	}

	.masonry-blog-item .jp-jplayer-video {
		height: 139px!important;
	}
	
	#post-area.span_9 .masonry-blog-item .jp-jplayer-video {
		height: 139px!important;
	}
	
	body.woocommerce .container div.product div.images div.thumbnails a, body.woocommerce .container #content div.product div.images div.thumbnails a, body.woocommerce-page .container div.product div.images div.thumbnails a, body.woocommerce-page .container #content div.product div.images div.thumbnails a {
		width: 16.9%!important;
		margin-right: 3.8%!important;
	}
	
	.woocommerce .container div.product div.images div.thumbnails a:nth-child(5n+5) {
		margin-right: 0px!important;
	}
	
	.main-content .col.span_4 .col.span_2, .main-content .col.span_3 .col.span_2, .main-content .col.span_2 .col.span_2, .main-content .col.span_6 .col.span_2  {
	  	 width: 7%!important;	
	}
	
	.main-content .col.span_4 .span_10, .main-content .col.span_3 .col.span_10, .main-content .col.span_2 .col.span_10, .main-content .col.span_6 .col.span_10  {
	    width: 91%!important;
	}
	

	.nectar-social.full-width.items_6 i, .nectar-social.full-width.items_5 i {
		font-size: 25px!important;
		margin-top: -20px;
	}
	
	.nectar-social.full-width.items_4 i {
		font-size: 30px!important;
		margin-top: -15px;
	}
	
	.nectar-social.full-width.items_2 i {
		font-size: 35px!important;
		margin-top: -18px;
	}
	
	.nectar-social.full-width.items_1 > * {
		padding: 8% 5%!important;
	}

	
	body #boxed {
		width: 679px;
	}
	body  #boxed #header-outer, body  #boxed #header-secondary-outer, body  #boxed #page-header-bg, body  #boxed #featured, body  #boxed .orbit > div, body  #boxed #featured article, body  #boxed #slide-out-widget-area-bg.fullscreen {
		min-width: 679px;
	}
	
	body  #boxed #footer-outer #footer-widgets, body  #boxed #footer-outer #copyright {
		padding-left: 30px!important;
		padding-right: 30px!important;
	}
	
	.swiper-container .slider-prev {
		left: 0px!important;
	}
	
	body .swiper-slide .content h2 {
		font-size: 33px!important;
		line-height: 57px!important;
		margin-bottom: 8px;
	}
	
	body .swiper-slide .content p, body .swiper-slide .content p.transparent-bg span {
		font-size: 13px!important;
		line-height: 26px!important;
	}
	
	body .swiper-slide .content p {
		padding-bottom: 17px;
	}

	
	.nectar-slider-wrap[data-full-width="false"] .swiper-slide .content h2, #boxed .swiper-slide .content h2 {
		font-size: 22px;
		line-height: 40px;
	}
	
	
	.nectar-slider-wrap[data-full-width="false"] .swiper-slide .content p, #boxed .swiper-slide .content h2 p  {
		font-size: 10px!important;
		padding-bottom: 10px!important;
		line-height: 20px!important;
	}
	
	.nectar-slider-wrap[data-full-width="false"] .swiper-slide .button a, #boxed .swiper-slide .content a {
		padding: 5px 10px!important;
		font-size: 9px!important;
	}
	
	body .vc_span3 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content p,
	body .vc_span4 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content p,
	body .vc_span6 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content p,
	body .vc_span8 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content p,
	body .vc_span9 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content p,
	body .vc_col-sm-3 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content p,
	body .vc_col-sm-4 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content p,
	body .vc_col-sm-6 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content p,
	body .vc_col-sm-8 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content p,
	body .vc_col-sm-9 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content p {
		font-size: 17px !important;
   		line-height: 28px !important;
	}
	
	body .vc_span3 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content a,
	body .vc_span4 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content a,
	body .vc_span6 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content a,
	body .vc_span8 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content a,
	body .vc_span9 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content a,
	body .vc_col-sm-3 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content a,
	body .vc_col-sm-4 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content a,
	body .vc_col-sm-9 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content a,
	body .vc_col-sm-8 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content a,
	body .vc_col-sm-9 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content a{
		letter-spacing: 1px !important;
		font-size: 9px !important;
  	    padding: 8px 13px;
	}
	

	.nectar-slider-wrap[data-overall_style="directional"] .swiper-container .slider-prev i, .nectar-slider-wrap[data-overall_style="directional"] .swiper-container .slider-next i {
		width: 50px!important;
		font-size: 46px!important;
	}

	.nectar-slider-wrap[data-overall_style="directional"] .swiper-container .slider-prev, .nectar-slider-wrap[data-overall_style="directional"] .swiper-container .slider-next {
		width: 50px!important;
	}
	
	.swiper-slide .button a, div[data-button-sizing="large"] .swiper-slide .button a {
		 padding: 8px 13px;
		 letter-spacing: 1px!important;
	}
	
	.swiper-slide .button.transparent a, .swiper-slide .button.transparent_2 a,
	div[data-button-sizing="large"] .swiper-slide .button.transparent a, div[data-button-sizing="large"] .swiper-slide .button.transparent_2 a {
		padding: 6px 13px!important;
		letter-spacing: 1px!important;
	}
	
	.nectar-slider-wrap[data-full-width="false"] .swiper-slide .content {
		padding: 0 80px;
	}
	
	.nectar-slider-wrap[data-full-width="boxed-full-width"] {
		margin: 0px -42px;
	}

	.nectar-slider-wrap[data-full-width="boxed-full-width"] .swiper-slide .content {
	 	padding: 0px 50px;
	}
	
	.swiper-slide .content h2 {
		letter-spacing: -1px;
	}
	
	.span_12 .col.span_6.empty-second {
		width: 49%!important;
	}
	
	.swiper-slide .button a {
		font-size: 9px!important;
	}
	
	.single-portfolio #full_width_portfolio .row .col.section-title h1 {
		max-width: 430px;
		margin: 0 auto;
		letter-spacing: -1px;
		font-size: 22px;
	}
	
	body .swiper-slide .content p i {
		width: 18px!Important;
		font-size: 16px!Important;
	}
	
	.carousel-next {
		right: 1px;
		padding-left: 1px;
	}
	
	.carousel-prev {
		right: 25px;
		padding-right: 1px;
	}

	
	.nectar-slider-wrap[data-full-width="boxed-full-width"] {
		margin: 0px -40px!Important;
	}
	
	body .swiper-slide .content p.transparent-bg span {
		line-height: 29px!important;
	}
	
	#footer-widgets .container .col.span_6, #footer-widgets .container .col.span_4 {
		margin-left: 0px;
		margin-right: 15px;
		padding: 15px;
		margin-bottom: 0px;
	}
	
	#footer-widgets .container .col.span_4 {
		margin-bottom: 40px;
	}
	
	#footer-widgets .container .row > div:last-child, #footer-widgets .container .row > div.col_last {
		margin-right: 0px;
	}
	
	#footer-widgets .container .row > div:nth-child(2).span_4 {
		margin-right: 0px!Important;
	}
	
	.team-member[data-style="meta_overlaid"] .team-member-image {
		height: 500px!important;
	}
	
	.one-fourths .team-member[data-style="meta_overlaid"] .team-member-image {
		height: 350px!important;
	}
	
	.wpb_row:not(.full-width-content) .vc_span3.one-fourths  .team-member[data-style="meta_overlaid"] .team-member-image,
	.wpb_row:not(.full-width-content) .vc_col-sm-3.one-fourths  .team-member[data-style="meta_overlaid"] .team-member-image {
		height: 250px!important;
	}

	.iosSlider.product-thumbnails .thumb {
		width: 112px!important;
	}
	
}

@media only screen and (max-width : 1130px) and (min-width : 1000px) {

	body.single.single-post .section-title h1 {
		max-width: 510px;
	}

}

@media only screen and (max-width : 690px) {
	
	body[data-smooth-scrolling="1"] #header-outer {
		padding-right: 0px!important;	
	}
	
	.vc_row-fluid [class*="vc_span"] {
		width: 100%!important;
	}
	.vc_row-fluid [class*="vc_col-"] {
		width: 100%;
	}
	
	body .vc_row-fluid .wpb_column {
		width: 100%;
		margin-right: 0px!important;
		margin-left: 0px;
		margin-bottom: 25px;
	}

	body .vc_row-fluid .vc_col-sm-2[class*="vc_col-sm-"] {
		width: 48%;
		margin-left: 4%;
	}
	.vc_row-fluid .vc_col-sm-2[class*="vc_col-sm-"]:first-child:not([class*="offset"]),
	.vc_row-fluid .vc_col-sm-2[class*="vc_col-sm-"]:nth-child(2n+3):not([class*="offset"]) {
	  margin-left: 0;
	}
	
	.container, div.slider-nav {
    	max-width: 300px!important; 
  	} 
  	
  	body #header-outer[data-full-width="true"] header > .container, body #header-secondary-outer[data-full-width="true"] > .container {
  		max-width: 100%!important;
  		padding: 0 18px !important;
  	}

  	.col {
		margin-bottom: 25px;
	}
	
	#post-area {
		margin-bottom: 0px;
	}
	
	.col.boxed:hover {
  		margin-top: 0px!important;
  		-o-box-shadow: 0 1px 2px rgba(0,0,0,0.2)!important;
		-moz-box-shadow: 0 1px 2px rgba(0,0,0,0.2)!important;
		-webkit-box-shadow: 0 1px 2px rgba(0,0,0,0.2)!important;
    	box-shadow: 0 1px 2px rgba(0,0,0,0.2)!important;
  	}
  
	#header-outer .col {
  		margin-bottom: 0px;
  	}
  	
  	.orbit-wrapper #featured article .post-title h2 span {
		font-size: 18px;
	}
	
	.orbit-wrapper, .orbit-wrapper #featured {
  		height: 325px!important;	
  		margin-bottom: 0em;
  		margin-top: 0px;
  	}
  	
  	.orbit-wrapper #featured article {
  		height: 325px!important;	
  		margin-bottom: 3em;
  		position: relative!Important;
  	}
	
	.orbit-wrapper #featured article .post-title h2 span {
		line-height: 35px !important;
	}
	
	body .orbit-wrapper #featured article .post-title h2 {
		max-width: 240px!important;
		min-width: 240px!important;
	}
	
	#featured .orbit-slide.centered article .post-title h2 {
		max-width: 265px!important;
    	min-width: 265px!important;
	}
	
	body #featured .orbit-slide article .container { 
	    top: -20px!important;
	    opacity: 1!important;
	    position: relative!important;
	}
	
	body #featured .orbit-slide article .container .span_12 {
		width: 300px!important;
		position: relative;
	}
	
	.container article.post .post-meta {
		display: none;
	}
	
	.container article.post .post-content {
		padding-left: 0px!important;
	}
	
	.container article.post .post-header h2  {
		font-size: 18px;
	}	
	
	.container .post-header {
	    font-size: 10px;
	}
	
	.container .comment-list li.comment > div {
		padding: 25px 25px 70px 25px;
	}
	
	.container .comment-list li.comment > div img.avatar {
		display: none;
	}
	
	.container #respond h3 {
		font-size: 13px;
	}
	
	.container .comment-list .reply {
    	right: 29px;
    	top: auto;
    	bottom: 29px;
	}	 
	
	body h1.jumbo, body h2.jumbo, body h3.jumbo, body h4.jumbo, body h5.jumbo, body h6.jumbo, p.jumbo {
		font-size: 60px!important;
		line-height: 70px!important;
	}

	.container .contact-info {
		padding-left: 0px;
	}
	
	.row .col.section-title span:not(.share-count-total), html .single #single-below-header span:not(.share-count-total) {
		display: none;
	}
	
	#page-header-bg h1 {
		font-size: 34px!important;
	}
	
	#page-header-bg .subheader {
		font-size: 22px!important;
	}
	
	html.js #page-header-bg[data-parallax="0"].not-loaded {
		height: 180px!important;
		background-color: #F5F5F5;
	}
	
	#page-header-bg .portfolio-filters ul {
		position: absolute!important;
		width: 100%;
	}
	
	#page-header-bg .span_6 {
		margin-bottom: 15px!important;
	}
	
	
	body #footer-outer #copyright .col ul {
		float: left;
	}
	
	body #footer-outer #copyright .col ul li:first-child {
		margin-left: 0px;
	}
	
	body .orbit-wrapper #featured article .post-title {
  		top: 120px!important;
  	}

  	.flickity-page-dots .dot { width: 12px; margin: 0 3px; }
  	.flickity-page-dots .dot:before {
  		height: 2px;
  	}

  	#header-outer[data-full-width="true"] header > .container, #header-secondary-outer[data-full-width="true"] > .container {
		padding-left: 0!important;
		padding-right: 0!important;
	}
  	
  	
	.orbit-wrapper #featured article .post-title h2 {
		max-width: 260px;
		min-width: 260px;
	}
	
	#call-to-action .container a {
		display: block!important;
		margin-top: 20px;
		margin-left: 0px!important;
	}
	
	
	#call-to-action {
		font-size: 18px!important;
	}
	
	h2 .nectar-button, h3 .nectar-button, h4 .nectar-button { display: block!important; }
	
	#footer-widgets .container .col:nth-child(3) {
		margin-bottom: 40px!important;
	}
	
	
	#footer-outer #flickr img, #sidebar #flickr img {
		width: 95px;
	}
	
	#post-area #pagination {
		padding-left: 0px!important;	
	}
	
	body #featured .orbit-slide article .container {
		top: -35px!important;	
	}
	
	body #featured article .post-title > a {
  		padding: 6px 9px!important;
  		font-size: 10px;
  		top: 10px;
  	}
  	
  	body #featured .more-info {
  		display: block;
  		top: 240px!important;
  	}
  	
  	body #featured .has-video article div.post-title {
  		top: 80px!Important;
  	}
  	
  	body.single-portfolio .row .col.section-title h1 {
		width: 280px;
		margin: 0 auto;
		line-height: 16px !important;
	}

	.portfolio-items:not(.carousel) .col.span_4, .portfolio-items:not(.carousel) .col.span_3 {
  		width: 100%!important;
  		margin-right: 0px!important;
  		margin-left: 0px!important;
  	}
  	
	.portfolio-items[data-ps="6"] .work-item .parallaxImg-layers > div .bg-img:after {
	    opacity: 1;
	}

	.portfolio-items[data-ps="6"] .work-item .work-meta .inner, .portfolio-items[data-ps="6"] .wide_tall .work-item .work-meta .inner {
	    opacity: 1;
	    transform: scale(1);
	    -webkit-transform: scale(1);
	}


  	body #portfolio {
		margin: 3px 0 0;
	}

	#search-results .result, .masonry-blog-item  {
  		width: 100%!important;
  		margin-right: 0px!important;
  		margin-bottom: 15px!important;
  		margin-left: 0px!important;
  	}
  	
  	.gallery .gallery-item {
  		width: 100%!important;
  	}
  	
  	#author-bio img {
  		margin-right: 0px!important;
  		width: 60px;
		height: 60px;
  	}

  	.single-post #single-below-header.fullscreen-header > span {
  		width: 100%;
  		height: 80px!important;
    	line-height: 80px!important;
  		border-bottom: 1px solid #dddddd;
  	}

  	.section-down-arrow i.icon-default-style[class^="icon-"] {
  		font-size: 16px!important;
  	}

  	.section-down-arrow {
  		bottom: 10px;
  		right: 20px;
  	}

  	#page-header-bg.fullscreen-header .author-section {
  		bottom: 20px;
  	}

  	#page-header-bg.fullscreen-header .author-section .meta-date {
  		margin-top: -4px;
  		display: block;
  	}

  	.single-post #single-below-header.fullscreen-header {
  		border: none!important;
  	}

  	#author-bio #author-info {
   	    padding-left: 85px!important;
	}
  	

  	#contact-map {
  		height: 270px!important;
  	}
  	
  	.nectar-google-map {
  		max-height: 270px;
  	}
  	
  	div.pp_pic_holder {
  		left: 9px!important;
  		width: 96%!important;
  	}
  	
  	.pp_content {
  		width: 100%!important;
  		height: 290px!important;
  	}
  	
  	.pp_content iframe {
  		width: 100%!important;
  	}
  	
  	.pp_content .pp_inline iframe {
  		height: 250px!important;
  	}
  	
  	.pp_content #pp_full_res img { 
  		width: 100%!important;
  		height: auto!important;
  	}
  	
  	#page-header-bg .span_6 h1, .single.single-post .section-title h1 {
  		font-size: 24px!important;
  		line-height: 30px!important;
  		margin-bottom: 4px!important;
  	}
  	#page-header-bg .span_6 span.subheader {
  		font-size: 15px!important;
  	}
  	
  	#page-header-bg .span_6 {
		top: auto!important;
		display: block!important;
		opacity: 1!important;
		float: none!important;
	}

	#page-header-bg .author-section .meta-author .avatar {
  		display: none;
  	}
  	#page-header-bg.fullscreen-header .author-section .avatar-post-info {
  		margin: 10px 0 0 0!important;
  	}
	
	.ascend #single-below-header.fullscreen-header  {
		border-top: 1px solid #dddddd!important;
	}

	.portfolio-filters {
		width: 100%!important;
		position: relative!important;
		display: block!important;
		clear: both!important;
		top: auto!important;
	}
	
	.page-template-template-portfolio-php .portfolio-filters {
		margin-bottom: 0px;
	}
	
	.page-header-no-bg .portfolio-filters {
		margin-top: 20px!important;
		height: auto!important;
	}
	
	.portfolio-filters > ul {
		position: relative!important;
	}
	
	.nectar-social.full-width.items_6 > * {
		width: 33.3%!important;
		border-bottom-width: 1px;
		border-bottom-style: solid;
		padding: 10% 5%!important;
	}
	
	body[data-button-style="default"]  .nectar-social.full-width.items_6 > *:nth-child(1n+4) {
		border-bottom: none!important;
	}
	body[data-button-style="default"] .nectar-social.full-width.items_6 > *:nth-child(3) {
		border-right: none!important;
	}
	
	.nectar-social.full-width.items_6 i {
		font-size: 20px!important;
		margin-top: -20px!important;
	}
	
	.nectar-social.full-width.items_5 i {
		font-size: 16px!important;
		margin-top: -20px!important;
		padding: 0!important;
	}
	
	.nectar-social.full-width.items_4 > * {
		width: 50%!important;
		border-bottom-width: 1px;
		border-bottom-style: solid;
		padding: 10% 5%!important;
	}
	
	.nectar-social.full-width.items_4 i {
		font-size: 20px!important;
		margin-top: -20px!important;
	}
	
	body[data-button-style="default"] .nectar-social.full-width.items_4 > *:nth-child(1n+3) {
		border-bottom: none!important;
	}
	
	body[data-button-style="default"] .nectar-social.full-width.items_4 > *:nth-child(2) {
		border-right: none!important;
	}
	
	.nectar-social.full-width.items_3 i {
		font-size: 16px!important;
		margin-top: -20px!important;
		padding: 0!important;
	}
	
	.nectar-social.full-width.items_2 i {
		font-size: 30px!important;
		margin-top: -20px!important;
		padding: 0!important;
	}
	
	.nectar-social.full-width.items_2 > *, .nectar-social.full-width.items_1 > * {
		padding: 10% 5%!important;
	}
	
	.nectar-social.full-width.items_1 i {
		font-size: 50px!important;
		margin-top: -20px!important;
		padding: 0!important;
	}
	
	.nectar-social.full-width a.nectar-love i { margin-top: -15px!important;}
	
	.nectar-social.full-width.items_5 a span { display: none!important; }
  	
  	.pricing-table > div { 
  		width: 100%!important; 
  		margin: 0px 0px 25px 0px!important;
  	}
  	
 
  	body .clients.no-carousel > div { 
  		margin-right: 1%!important;
  		width: 49.4%!important;
  	}
  
    body .clients.no-carousel > div:nth-child(2n+2){
  		margin-right: 0px!important;
  	}
	
	body .clients.carousel > div {
		margin: 0px 5px!important;
		width: 150px;
	}
	
	body .clients.carousel.phone > div { 
		width: 150px;
	}
	
	body .row #error-404 h1 {
		 font-size: 150px !important;
   		 line-height: 150px !important;
	}
	
	body .row #error-404 h2 {
		 font-size: 40px;
	}
	
	body .row #error-404 {
		margin-bottom: 0px;
	}
	
	.woocommerce div.product .woocommerce-tabs ul.tabs li {
		float: none;
		border-right: 0px;
		width: 100%;
	}
	.tabbed[data-style="minimal"] > ul li:not(.cta-button) a, .tabbed[data-style="minimal"] > ul li:not(.cta-button) a.active-tab {
		    padding: 20px 15px 5px 15px;
	}

	.tabbed[data-style="minimal"] .wpb_tabs_nav {
		border-bottom: none;
	}
	.tabbed > ul li {
		float: none;
		display: inline-block;
		border-right: 0px;
	}
	
	.tabbed > ul {
		float: none!important;
	}
	
	.tabbed > ul li a {
		border-right: 0px!important;
	}
	
	#portfolio-nav {
		margin: 10px 0px 0px;
		position: relative!important;
	}
	.bottom_controls #portfolio-nav {
		margin-top: 0;
	}

	.bottom_controls #portfolio-nav ul.controls {
		position: absolute!important;
	}

	.bottom_controls #portfolio-nav ul.controls span {
		display: none;
	}
	
	body .project-title #portfolio-nav {
		top: 10px!important;
		height: 33px!important;
	}
	
	#portfolio-nav ul {
		position: relative!important;
		margin-left: 0px;
	}
	
	#portfolio-nav ul:first-child {
		z-index: 103;
	}
	
	#portfolio-nav .controls:after {
		content: ""; 
		display: block; 
		height: 0; 
		clear: both; 
		visibility: hidden;
	}

	body .container .portfolio-filters-inline.full-width-content .container {
		padding-left: 0!important;
		padding-right: 0!important;
	}
	
	body #full_width_portfolio .project-title.parallax-effect .container, body #page-header-bg .project-title .container {
	    padding-bottom: 30px!important;
	}
	

	#page-header-bg .project-title {
		top: 0px!important;
		padding-top: 30px!important;
	}

	.single-portfolio #page-header-bg[data-alignment-v="middle"]:not(.fullscreen-header) .span_6 {
		transform: none!important;
		-webkit-transform: none!important;
		-o-transform: none!important;
	}

	body[data-permanent-transparent="1"] #page-header-bg .project-title {
		padding-top: 50px!important;
	}
	
	body #page-header-bg .section-title, .project-title .section-title  {
		padding: 0!important;
	}
	
	.single-portfolio #page-header-bg {
		height: auto!important;
	}
	
	.single #page-header-bg .span_6 {
		margin-bottom: 0!important;
	}
	
	.row .col.section-title.project-title {
		padding-bottom: 30px;
		margin-bottom: 30px!important;
	}
	
	body #featured .slide .post-title .video img {
		height: 169px!important;
	}
	
	body #featured .orbit-slide.has-video .span_12 .post-title h2 {
		margin-top: 190px!important;
	}

	body #featured .slide .mejs-container {
		margin-bottom: 210px!important;
		height: 167px!important;
	}


	.testimonial_slider[data-style="multiple_visible"] blockquote p:before {
		display: none;
	}

	.testimonial_slider[data-style="multiple_visible"] blockquote p {
		padding: 30px;
	}

	.testimonial_slider[data-style="multiple_visible"] blockquote {
		margin-bottom: 0;
	}

	/*#post-area .video-wrap .mejs-container, #post-area .video .mejs-container {
		height: 167px!important;
	}*/
	
	#footer-outer #social li {	
	   margin-right: 10px;
	   margin-left: 0px!important;
	}

	#post-area.masonry, #post-area.masonry.span_9,  body[data-ext-responsive="true"] #post-area.masonry.span_9  {
		width: 299px;
	}

	#post-area.masonry.span_9 {
		margin-bottom: 90px;
	}

	#post-area.masonry #pagination {
		bottom: -95px;
	}

	.masonry-blog-item .jp-jplayer-video {
		height: 139px!important;
	}
	
	#post-area.span_9 .masonry-blog-item .jp-jplayer-video {
		height: 139px!important;
	}

	.ascend.single .container-wrap #author-bio #author-info {
		width: 100%!important;
	}

	.ascend .container-wrap #author-bio #author-info p {
		max-width: 100%!important;
	}

	.ascend .comment-list .reply {
		top: 0!important;
	}

	.single.ascend .comment-list li.comment > div, .single.ascend  .comment-list li.pingback > div {
		padding-left: 0!important;
	}
	
	#customer_details > div {
		width: 100%;
		float: none!important;
	}
	
	body #header-secondary-outer nav > ul > li, body #header-secondary-outer nav > ul > li a {
		border: none!important;
	}
	
	#header-secondary-outer nav ul.sf-menu {
		padding-top: 10px;
		padding-bottom: 10px;
	}
	
	body #header-secondary-outer ul#social {
		padding: 10px 0px;
	}
	
	.woocommerce .shop_table .product-thumbnail {
		display: none;
	}
	
	.woocommerce .shop_table .coupon {
		margin-bottom: 10px;
		margin-top: 5px;
	}
	
	.woocommerce #customer_login.col2-set .col-1, .woocommerce-page #customer_login.col2-set .col-1, .woocommerce #customer_login.col2-set .col-2, .woocommerce-page #customer_login.col2-set .col-2 {
      width: 100%!important;
   }
	
	.woocommerce .shop_table .actions > input {
		float: left!important;
	}
	
	.woocommerce form.login .form-row-first, .woocommerce-page form.login .form-row-first, .woocommerce form.login .form-row-last, .woocommerce-page form.login .form-row-last {
		width: 100%!important;
	}
	
	.woocommerce .cart.shop_table .quantity input.plus, .woocommerce .cart.shop_table .quantity input.minus {
		display: block;	
	}

	html .woocommerce-page div[data-project-style="text_on_hover"] button.single_add_to_cart_button[type="submit"] {
		padding: 20px 35px!important;
	}

	.iosSlider.product-thumbnails .thumb {
		width: 93px!important;
	}
	
	.main-content .col.span_4 .col.span_2, .main-content .col.span_3 .col.span_2, .main-content .col.span_2 .col.span_2, .main-content .col.span_6 .col.span_2  {
	  	width: 15%!important;	
	}
	
	.main-content .col.span_4 .span_10, .main-content .col.span_3 .col.span_10, .main-content .col.span_2 .col.span_10, .main-content .col.span_6 .col.span_10  {
	    width: 83%!important;
	}
	
	
	#boxed {
		width: 100%;
	}
	#boxed #header-outer, #boxed #header-secondary-outer, #boxed #page-header-bg, #boxed #featured, #boxed .orbit > div, #boxed #featured article, #boxed #slide-out-widget-area-bg.fullscreen {
		width: 100%;
		min-width: 100%;
	}

	#boxed #page-header-bg {
		min-width: 100%;
	}
	
	#boxed .container, #boxed #post-area.masonry.span_9 {
		max-width: 85%!important;
	}
	body[data-ext-responsive="true"] .vc_span12 .nectar-slider-wrap[data-full-width="boxed-full-width"], body[data-ext-responsive="true"] .vc_col-sm-12 .nectar-slider-wrap[data-full-width="boxed-full-width"] {
		margin: 0 -9%!important;
	}

	#boxed #post-area.masonry.meta_overlaid {
		max-width: none!important;
	}
	#boxed #footer-outer #footer-widgets, #boxed #footer-outer #copyright {
		padding-left: 20px!important;
		padding-right: 20px!important;
	}
	
	.swiper-container .slider-next, .swiper-container .slider-prev {
		display: none;
	}
	

	
	/*body .nectar-slider-wrap[data-fullscreen="false"]  .swiper-slide .content h2 {
		font-size: 16px!important;
		line-height: 32px!important;
		margin-bottom: 6px;
		letter-spacing: -0.5px;
	}
	*/
	body .nectar-slider-wrap[data-fullscreen="false"] .swiper-slide .content p {
		padding-bottom: 7px;
	}
	
	.nectar-slider-wrap[data-fullscreen="false"] .swiper-slide .button a {
		 font-size: 8px!important;
		 padding: 4px 7px;
		 line-height: 18px;
		 letter-spacing: 0.5px!important;
	}
	
	body .nectar-slider-wrap[data-fullscreen="false"] .swiper-slide .button.transparent a,  body .nectar-slider-wrap[data-fullscreen="false"] .swiper-slide .button.transparent_2 a {
		padding: 3px 7px!important;
		letter-spacing: 0.5px!important;
		border-width: 1px;
	}
	
	.slider-pagination {
		bottom: 10px;
	}
	
	.slider-pagination .swiper-pagination-switch {
		height: 8px;
		width: 8px;
	}
	
	
	
	body .nectar-slider-wrap[data-fullscreen="true"]  .swiper-slide .content h2, 
	body .vc_span3 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content h2,
	body .vc_span4 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content h2,
	body .vc_span6 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content h2,
	body .vc_span8 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content h2,
	body .vc_span9 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content h2,
	body .vc_col-sm-3 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content h2,
	body .vc_col-sm-4 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content h2,
	body .vc_col-sm-6 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content h2,
	body .vc_col-sm-8 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content h2,
	body .vc_col-sm-9 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content h2  {
		font-size: 33px !important;
    	line-height: 57px !important;
		margin-bottom: 8px;
		letter-spacing: -0.5px;
	}
	
	body .nectar-slider-wrap[data-fullscreen="true"] .swiper-slide .content p,
	body .vc_span3 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content p,
	body .vc_span4 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content p,
	body .vc_span6 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content p,
	body .vc_span8 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content p,
	body .vc_span9 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content p,
	body .vc_col-sm-3 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content p,
	body .vc_col-sm-4 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content p,
	body .vc_col-sm-6 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content p,
	body .vc_col-sm-8 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content p,
	body .vc_col-sm-9 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .content p {
		font-size: 13px !important;
    	line-height: 26px !important;
		padding-bottom: 7px;
	}
	
	.nectar-slider-wrap[data-fullscreen="true"] .swiper-slide .button a,
	body .vc_span3 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .button a,
	body .vc_span4 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .button a,
	body .vc_span6 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .button a,
	body .vc_span8 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .button a,
	body .vc_span9 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .button a,
	body .vc_col-sm-3 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .button a,
	body .vc_col-sm-4 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .button a,
	body .vc_col-sm-6 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .button a,
	body .vc_col-sm-8 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .button a,
	body .vc_col-sm-9 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .button a {
		 font-size: 9px!important;
		 padding: 8px 13px;
		 letter-spacing: 0.5px!important;
	}
	
	body .nectar-slider-wrap[data-fullscreen="true"] .swiper-slide .button.transparent a, body .nectar-slider-wrap[data-fullscreen="true"] .swiper-slide .button.transparent_2 a {
		 font-size: 9px!important;
		 padding: 6px 13px!important;
		 letter-spacing: 0.5px!important;
	}

	body .vc_span3 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .button.transparent a,
	body .vc_span4 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .button.transparent a,
	body .vc_span6 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .button.transparent a,
	body .vc_span8 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .button.transparent a,
	body .vc_span9 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .button.transparent a,
	body .vc_col-sm-3 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .button.transparent a,
	body .vc_col-sm-4 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .button.transparent a,
	body .vc_col-sm-6 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .button.transparent a,
	body .vc_col-sm-8 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .button.transparent a,
	body .vc_col-sm-9 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide .button.transparent a  {
		padding: 0px 13px!important;
		letter-spacing: 0.5px!important;
	}
	
	body .nectar-slider-wrap[data-fullscreen="true"] .swiper-slide .content p.transparent-bg span,
	body .vc_span3 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide p.transparent-bg span,
	body .vc_span4 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide p.transparent-bg span,
	body .vc_span6 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide p.transparent-bg span,
	body .vc_span8 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide p.transparent-bg span,
	body .vc_span9 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide p.transparent-bg span,
	body .vc_col-sm-3 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide p.transparent-bg span,
	body .vc_col-sm-4 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide p.transparent-bg span,
	body .vc_col-sm-6 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide p.transparent-bg span,
	body .vc_col-sm-8 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide p.transparent-bg span,
	body .vc_col-sm-9 .nectar-slider-wrap[data-flexible-height="true"]  .swiper-slide p.transparent-bg span {
	    font-size: 13px !important;
    	line-height: 29px !important;
	}
	
	
	
	.nectar-slider-wrap[data-full-width="false"] .swiper-slide .content h2, #boxed .swiper-slide .content h2 {
		font-size: 16px!important;
		line-height: 30px!important;
	}
	
	
	.nectar-slider-wrap[data-full-width="false"] .swiper-slide .content p, #boxed .swiper-slide .content p {
		font-size: 6px!important;
		padding-bottom: 4px!important;
		line-height: 11px!important;
	}
	
	.nectar-slider-wrap[data-full-width="false"] .swiper-slide .button a, #boxed .swiper-slide .content a {
		padding: 1px 7px!important;
		font-size: 6px!important;
	}
	
	
	
	.nectar-slider-wrap[data-full-width="false"] .swiper-slide .content {
		padding: 0px 15px!important;
	}
	
	.nectar-slider-wrap[data-full-width="boxed-full-width"] {
		margin: 0px -22px;
	}

	.nectar-slider-wrap[data-full-width="boxed-full-width"] .swiper-slide .content {
	 	padding: 0px 5px;
	}
	
	.swiper-slide .buttons > div {
		padding-left: 0px!important;
	}
	
	.swiper-slide .content h2 {
	    margin-bottom: 3px;
	}
	
	.nectar-slider-wrap[data-overall_style="directional"] .swiper-container .slider-prev,
	.nectar-slider-wrap[data-overall_style="directional"] .swiper-container .slider-next {
		display: block!important;
	}

	.nectar-slider-wrap[data-overall_style="directional"] .swiper-container .slider-prev i, .nectar-slider-wrap[data-overall_style="directional"] .swiper-container .slider-next i {
		width: 24px!important;
		font-size: 24px!important;
	}

	.nectar-slider-wrap[data-overall_style="directional"] .swiper-container .slider-next i, .nectar-slider-wrap[data-overall_style="directional"] .swiper-container .slider-next:hover i  {
		right: 15px!important;
	}

	.nectar-slider-wrap[data-overall_style="directional"] .swiper-container .slider-prev i, .nectar-slider-wrap[data-overall_style="directional"] .swiper-container .slider-prev:hover i  {
		left: 15px!important;
	}

	.nectar-slider-wrap[data-overall_style="directional"] .swiper-container .slider-prev, .nectar-slider-wrap[data-overall_style="directional"] .swiper-container .slider-next {
		width: 30px!important;
	}
	
	.project-title .controls {
		margin: 0 auto!important;
		float: none!important;
		display: block;
		width: 120px;
	}
	
	.project-title .controls #prev-link {
		float: left!important;
	}
	
	.project-title .controls #next-link {
		float: right!important;
	}
	
	.project-title #all-items {
		left: 134px!important;
		float: none!important;
		position: absolute;
	}
	
	#boxed .project-title #all-items {
		left: 124px!important;
	}
	
	body .swiper-slide .content p i {
		width: 14px!Important;
		font-size: 12px!Important;
	}
	
	.main-content .col.span_4 .col.span_2 img, .main-content .col.span_3 .col.span_2 img, .main-content .col.span_2 .col.span_2 img, .main-content .col.span_6 .col.span_2 img {
		padding-right: 13px;
		top: -3px;
	}
	

	.carousel-next {
		right: 1px;
		padding-left: 1px;
	}
	
	.carousel-prev {
		right: 25px;
		padding-right: 1px;
	}
	
	.woocommerce .woocommerce-result-count {
		padding-bottom: 0px!important;	
	}
	
	.woocommerce .woocommerce-ordering {
		position: relative!important;
		right: 0px;
		top: 0px!important;
		float: none!important;
		margin-bottom: 45px!important;
	}

	.woocommerce .product-subtotal {
	    display: none;
	} 
	
	.nectar-slider-wrap[data-full-width="boxed-full-width"] {
		margin: -16px -19px 0px -19px!Important;
	}
	
	body .swiper-slide .content p.transparent-bg span {
		line-height: 20px!important;
		top: -5px;
		left: 4px;
		box-shadow: 4px 0 0 rgba(0, 0, 0, 0.5), -4px 0 0 rgba(0, 0, 0, 0.5);
		-moz-box-shadow: 4px 0 0 rgba(0, 0, 0, 0.5), -4px 0 0 rgba(0, 0, 0, 0.5);
		-webkit-box-shadow: 4px 0 0 rgba(0, 0, 0, 0.5), -4px 0 0 rgba(0, 0, 0, 0.5);
		-o-box-shadow: 4px 0 0 rgba(0, 0, 0, 0.5), -4px 0 0 rgba(0, 0, 0, 0.5);
	}
	
	#buddypress .register-section {
		width: 100%!important;
		margin-bottom: 15px;
	}
	
	.full-width-content.blog-fullwidth-wrap:not(.meta-overlaid) {
		padding: 0px 10%!important;	
	}
	
	#header-outer[data-full-width="true"] header > .container {
		padding: 0;
	}
	
}

@media only screen and (max-width: 480px) {
	.single .blog-title #single-meta ul {
		float: left!important;
	}


	.single .blog-title #single-meta ul li.meta-share-count {
		float: none!important;
		clear: both;
	}

	.blog-title ul li.meta-share-count > a {
		display: none!important;
	}
	.blog-title ul li.meta-share-count .nectar-social {
		display: block!important;
		opacity: 1!important;
		left: 0!important;
		position: relative!important;
	}
	.blog-title ul li.meta-share-count .nectar-social a {
		opacity: 1!important;
		left: 0!important;
	}
	.single .blog-title #single-meta ul li a {
		display: inline-block;
		margin-bottom: 5px;
	}
	.single .blog-title #single-meta ul li:not(.meta-share-count) > a,
	.single .blog-title #single-meta ul li .n-shortcode a {
		opacity: 1!important;
	}
}


@media only screen and (min-width: 480px) and (max-width: 690px) {
	
 	body .container, body div.slider-nav {
    	max-width: 420px!important; 
  	} 

  	#header-outer[data-full-width="true"] header > .container, #header-secondary-outer[data-full-width="true"] > .container {
  		max-width: 100%!important;
  		padding: 0 28px !important;
  	}
  	
  	.project-title #all-items {
	    left: 194px !important;
	}
	
	#boxed .project-title #all-items {
	    left: 159px !important;
	}
	
	#boxed {
	    width: 100%;
	}
	
	#boxed #featured, #boxed .orbit > div, #boxed #featured article,
	#boxed #header-outer, #boxed #header-secondary-outer, #boxed #page-header-bg, #boxed #slide-out-widget-area-bg.fullscreen, #boxed #page-header-bg {
		min-width: 100%!important;
	}
	
	.nectar-slider-wrap[data-full-width="boxed-full-width"] {
		margin-left: -30px!important;
		margin-right: -30px!important;
	}
	
	#boxed .container, #boxed #post-area.masonry.span_9 {
	    max-width: 85% !important;
	}

	body[data-ext-responsive="true"] .vc_span12 .nectar-slider-wrap[data-full-width="boxed-full-width"], body[data-ext-responsive="true"] .vc_col-sm-12 .nectar-slider-wrap[data-full-width="boxed-full-width"] {
		margin: 0 -9%!important;
	}
	
	#post-area.masonry, #post-area.masonry.span_9,  body[data-ext-responsive="true"] #post-area.masonry.span_9 {
		width: 420px;
	}

	.iosSlider.product-thumbnails .thumb {
		width: 98px!important;
	}
}


@media only screen and (-webkit-min-device-pixel-ratio: 1.5) and (max-width : 1000px), only screen and (min-device-pixel-ratio: 1.5) and (max-width : 1000px), only screen and (min-resolution: 144dpi) and (max-width : 1000px) {
	#header-outer.transparent.directional-nav-effect header#top #logo span.original img.default-logo {
		display: block!important;
	}
}

@media only screen and (min-width : 1px) and (max-width : 1000px) {
	
	body[data-smooth-scrolling="1"], body[data-smooth-scrolling="1"] #header-outer, body[data-smooth-scrolling="1"] #page-header-bg[data-parallax="1"],
	#page-header-bg[data-parallax="1"] .span_6, #page-header-bg[data-parallax="1"] {
		padding-right: 0px!important;
		transform: translate(0px)!important;
		visibility: visible!important;
	}
	
	.video-texture {
		display: none!important;
	}

	
	.full-width-section.parallax_section, .full-width-content.parallax_section   {
		background-attachment: scroll!important;
		background-position: center!important;
	}

	.wpb_row .row-bg, .full-width-section .row-bg {
    	margin-top: 0!important;
    	height: 100%!important;
    	transform: none!important;
    	-webkit-transform: none!important;
    	background-attachment: scroll!important;
    	background-position: 50%!important;
	}

	.midnightHeader .stnd:not(.dark-version) {
		display: none!important;
	}
	
	img.img-with-animation[data-animation="fade-in-from-right"] {
		padding-left: 0px!important;
	}
	
	img.img-with-animation[data-animation="fade-in-from-left"] {
		padding-right: 0px!important;
	}
	
	img.img-with-animation[data-animation="fade-in-from-bottom"] {
		bottom: 0px!important;
		transform: none!important;
		-webkit-transform: none!important;
	}

	.full-width-section > .col.span_12 {
		margin-bottom: 0px;
	}
	
	.full-width-section {
		margin-top: 0px!important;
	}

	div[data-bg-mobile-hidden="true"] .row-bg.using-image {
		background-image: none!important;
	}
	
	/*body[data-bg-header="false"] .full-width-section.first-section, body[data-bg-header="false"] .full-width-content.first-section {
		margin-top: -40px!important;
	}*/
	
	body[data-bg-header="true"] .full-width-section.first-section, body[data-bg-header="true"] .full-width-content.first-section,
	body[data-header-resize="0"] .container-wrap .portfolio-filters-inline.first-section {
		margin-top: 0px!important;
	}

	.single-portfolio .row #post-area {
		margin-top: 0;
	}
	
	.full-width-section.under-page-header {
		margin-top: -2.1em!important;
	}
	
	.home-wrap .full-width-section.first-section {
		margin-top: -37px!important;
	}
	
	header#top #logo  {
		margin-top: 7px!important;	
	}
	
	body #header-outer[data-format="centered-menu-under-logo"] header#top #logo img {
		margin: 0;
	}

	#header-outer[data-has-menu="false"][data-format="default"] header#top .span_3,
	#header-outer[data-has-menu="true"][data-mobile-fixed="1"] header#top .span_3,
	#header-outer[data-has-menu="true"][data-ptnm="1"] header#top .span_3  {
		text-align: left;
	}

	#header-outer[data-permanent-transparent="1"] .midnightHeader header#top #logo *, #header-outer[data-permanent-transparent="1"] .midnightHeader header#top ul.sf-menu > li > a,
	#header-outer[data-permanent-transparent="1"] .midnightHeader header#top .span_9 > .slide-out-widget-area-toggle,
	#header-outer[data-permanent-transparent="1"] .midnightHeader header#top #toggle-nav,
	#header-outer[data-permanent-transparent="1"] .midnightHeader header#top #mobile-cart-link {
		margin-top: 10px!important;

	}

	#header-outer[data-permanent-transparent="1"] .midnightHeader header#top #mobile-cart-link i {
		line-height: 34px!important;
	}

	#header-outer[data-transparent-header="true"].no-pointer-events.side-widget-open {
		pointer-events: auto;
	}

	#header-outer[data-mobile-fixed="1"],
	#header-outer[data-permanent-transparent="1"][data-mobile-fixed="1"],
	#mobile-menu[data-mobile-fixed="1"] {
		position: fixed!important;
	}

	html body #header-outer[data-transparent-header="true"][data-remove-border="true"] {
		border: none!important;
	}

	#mobile-menu[data-mobile-fixed="1"] {
		width:100%;
		top: 58px;
		left: 0;
	}

	.container-wrap {
		z-index: 11;
	}

	.page-submenu .mobile-menu-link {
		display: inline-block;
	}
	.page-submenu ul {
		position: absolute;
		top: 48px;
		left: 0;
		width: 101%;
		display: none;
		z-index: 1000;
	}
	.page-submenu ul li {
		display: block;
		margin: 0!important;
	}
	.page-submenu .full-width-content {
		position: relative;
	}
	.page-submenu ul li a {
		border-top: 1px solid rgba(255,255,255,0.2);
		padding: 10px 20px!important;
	}
	.page-submenu[data-bg-color="#ffffff"] ul li a {
		border-top: 1px solid rgba(0,0,0,0.08);
	}
	.orbit > div {
	  position: absolute!important;	
	}
	
	.work-item:not([data-custom-content="on"]) .work-info-bg { 
		display: none;
	}
	
	.style-3 .work-info-bg {
		display: block;
	}
	
	.portfolio-items .work-item.style-3 p {
		display: block;
		margin-top: 0!important;
		opacity: 1!important;
		position: relative!important;
	}
	
	.portfolio-items .work-item.style-3 .vert-center {
		padding-top: 15px;
	}
	
	.carousel-wrap[data-full-width="true"] {
		padding: 0px!important;
	}
	
	.recent-work-carousel[data-full-width="true"] .portfolio-items .work-info-bg, .portfolio-items .col .work-item.style-2 .work-info-bg {
		display: block!important;
	}

	.blog-recent[data-style="title_only"] .post-header { transform: none!important; -webkit-transform: none!important; top: 0; }
	
	body header#top #logo img, #header-outer[data-permanent-transparent="false"] #logo .dark-version {
		height: 24px!important;
		margin-top: -3px!important;
		top: 3px; 
		position: relative;
	}

	#header-outer[data-permanent-transparent="1"][data-mobile-fixed="1"] #logo .dark-version {
		top: 6px; 
	}
	/*#header-outer[data-transparent-header="true"] .midnightHeader.dark #logo .dark-version {
		position: relative;
	}*/

	#header-outer[data-format="centered-menu-under-logo"] header#top .span_9 {
		position: static!important;
	}
	
	html .admin-bar #header-outer, html .logged-in.buddypress #header-outer {
		top: 0px;	
	}
	
	#header-outer {
  		position: relative!important;	
  		/*height: 52px!important;*/
  		padding-top: 10px!important;
  		margin-bottom: 0px;
  	}

  	#header-outer[data-permanent-transparent="1"] {
  		position: absolute!important;
  	}

  	#header-outer[data-permanent-transparent="1"].transparent header#top .span_9 > .slide-out-widget-area-toggle i,
  	#header-outer[data-transparent-header="true"].transparent.side-widget-open .midnightHeader.dark header#top .span_9 > .slide-out-widget-area-toggle i,
  	#header-outer[data-transparent-header="true"].transparent.side-widget-open .midnightHeader.default header#top .span_9 > .slide-out-widget-area-toggle i,
  	#header-outer[data-permanent-transparent="1"].transparent .midnightHeader.light header#top #mobile-cart-link i {
  		color: #fff!important;
  	}
  	#header-outer[data-permanent-transparent="1"] .midnightHeader.dark header#top .span_9 > .slide-out-widget-area-toggle i,
  	#header-outer[data-permanent-transparent="1"].transparent .midnightHeader.default header#top .span_9 > .slide-out-widget-area-toggle i,
  	#header-outer[data-permanent-transparent="1"].transparent .midnightHeader.default header#top #mobile-cart-link i,
  	#header-outer[data-permanent-transparent="1"].transparent .midnightHeader.dark header#top #mobile-cart-link i {
  		color: #000!important;
  	}

  	#header-outer[data-transparent-header="true"][data-permanent-transparent="1"].transparent #logo .starting-logo {
  		opacity: 1;
  		position: relative;
  	}

  	#header-outer[data-transparent-header="true"][data-permanent-transparent="1"].transparent .midnightHeader.dark #logo .starting-logo.dark {
  		opacity: 1;
  		position: relative;
  	}

  	#header-outer.transparent.side-widget-open[data-permanent-transparent="1"] .midnightHeader.dark #logo .dark-version,
  	#header-outer[data-transparent-header="true"][data-permanent-transparent="1"].transparent .midnightHeader.dark #logo .starting-logo.dark,
  	#header-outer[data-transparent-header="true"][data-permanent-transparent="1"].transparent .midnightHeader.dark #logo .starting-logo:not(.dark),
  	#header-outer[data-transparent-header="true"][data-permanent-transparent="1"].transparent .midnightHeader.default #logo .starting-logo {
  		opacity: 0;
  		position: absolute;
  	}

  	#header-outer[data-transparent-header="true"][data-permanent-transparent="1"].transparent #logo img.dark-version {
  		opacity: 0!important;
  	}
  	
  	body #slide-out-widget-area a.slide_out_area_close {
		position: absolute;
		right: 22px;
		top: 22px;
		z-index: 100;
	}

	#slide-out-widget-area.fullscreen .off-canvas-social-links,
	.admin-bar #slide-out-widget-area.fullscreen .off-canvas-social-links {
	  position: relative;
	  bottom: 0!important;
	  right: 0;
	  margin-top: 70px;
	}

	#slide-out-widget-area.fullscreen .off-canvas-social-links:after {
	  display: block;
	  height: 1px;
	  width: 0px;
	  background-color: rgba(255,255,255,0.6);
	  content: ' ';
	  margin: 0 auto;
	  position: absolute;
	  top: -40px;
	  left: 50%;
	  transform: translateX(-50%);
	  -webkit-transform: translateX(-50%);
	  -moz-transform: translateX(-50%);
	  transition: all 0.5s cubic-bezier(0.215, 0.61, 0.355, 1);
	  -webkit-transition: all 0.5s cubic-bezier(0.215, 0.61, 0.355, 1);
	  -moz-transition: all 0.5s cubic-bezier(0.215, 0.61, 0.355, 1);
	}

	#slide-out-widget-area .mobile-only {
		display: block;
	}

	#slide-out-widget-area.fullscreen .off-canvas-social-links.line-shown:after {
		width: 100px;
	}

	#slide-out-widget-area.fullscreen .bottom-text,
	.admin-bar #slide-out-widget-area.fullscreen .bottom-text {
	  position: relative;
	  bottom: 0!important;
	  left: 0;
	  margin-bottom: 30px;
	  margin-top: 15px;
	}

	#slide-out-widget-area {
		top: 0!important;
	}
	#slide-out-widget-area.overflow-state {
		padding-top: 110px!important;
	}

	#slide-out-widget-area.fullscreen .inner.overflow-state {
		margin-top: 0px;
		margin-bottom: 130px;
	}

  	#header-outer #logo { top: 6px!important; left: 6px!important; }
  	#header-space, #search-outer { display: none!important; }
  	#header-space[data-header-mobile-fixed="1"] { display: block!important; }

	header#top #toggle-nav, header#top #mobile-cart-link, header#top .span_9 > .slide-out-widget-area-toggle { display: block!important; }
	
	header#top .col.span_3 {
		position: absolute;
		left: 0px;
		top: 0px;
		z-index: 1000;
  		width: 85%!important;
  	}
  	
  	header#top .col.span_9 {
  		margin-left: 0px;
  		min-height: 48px;
  		margin-bottom: 0px;
  		width: 100%!important;
  		float: none;
  		z-index: 100;
		position: relative;
  	}

  	/*body[data-slide-out-widget-area="true"] #header-outer {
  		z-index: 1000!important;
  	}*/

  	body[data-slide-out-widget-area="true"] header#top #logo {
  		transform: none!important;
  		-webkit-transform: none!important;
  	}
  	
  	body[data-slide-out-widget-area="true"] header#top #toggle-nav {
		left: 0!important;
		right: auto!important;
		text-align: left;
		z-index: 10000;
	}

	body[data-slide-out-widget-area="true"] header#top .span_3 {
		text-align: center;
	}
	body[data-slide-out-widget-area="true"] header#top #logo, #header-outer[data-mobile-fixed="1"] header#top #logo {
		display: inline-block;
	}
	body[data-slide-out-widget-area="true"] header#top .col.span_3 {
		width: 100%!important;
	}

	body #slide-out-widget-area .slide_out_area_close {
		display: block;
	}

	#slide-out-widget-area .widget_nav_menu{
		overflow-y: hidden;
		overflow-x: hidden;
	}

	#header-outer header#top nav > ul {
		width: 100%;
		padding: 15px 0px 25px 0px!important;
		margin: 0px auto 0px auto!important;
		float: none!important;
		z-index: 100000;
		position: relative;
	}
	
	
	#header-outer header#top nav {
		background-color: #1F1F1F;
		margin-left: -250px!important;	
		margin-right: -250px!important;	
		padding: 0px 250px 0px 250px;
		top: 48px;
		margin-bottom: 75px;
		display: none!important;
		position: relative;
		z-index: 100000;
	}
	
	header#top nav > ul li {
		display: block;
		width: 100%;
		float: none!important;
		margin-left: 0px!important;
	}
	
	#header-outer header#top nav > ul {
		overflow: hidden!important;
	}
	
	header#top nav > ul ul {
		position: relative;
		width: 100%;
		top:0px!important;
		left: 0px!important;
		padding: 0px;
		visibility: visible!important;
		box-shadow: 0px 0px 0px #fff!important;
		-moz-box-shadow: 0px 0px 0px #fff!important;
		-webkit-box-shadow: 0px 0px 0px #fff!important;
		background-color: transparent!important;
		float: none!important;
	}
	
	header#top nav > ul ul li {
		padding-left: 20px;
	}
	
	header#top .sf-menu a {
		color: rgba(255,255,255,0.6)!important;
		font-size: 12px;
		border-bottom: 1px dotted rgba(255, 255, 255, 0.3);
		padding: 16px 0px 16px 0px!important;
		background-color: transparent!important;	
	}
	
	header#top nav .sf-menu li.sfHover > a {
		color: #FFBAAF;
	}
	
	#header-outer #top nav ul li a:hover, #header-outer header#top nav .sf-menu li.sfHover > a, #header-outer header#top nav .sf-menu li.current_page_ancestor > a, #header-outer header#top nav .sf-menu li.current-menu-ancestor > a, #header-outer header#top nav .sf-menu li.current_page_item > a {
		color: #27CFC3;
	}
	
	a > .sf-sub-indicator { 
		right: 0px!important;
		position: absolute;
		padding: 16px;
		left: auto!important;
  	    top: 0px!important; 
		height: auto;
		width: auto;
  	}
	
	header#top .sf-menu li ul li a:hover,
    header#top nav ul li a:hover, 
    header#top nav .sf-menu li.sfHover > a, 
    header#top nav .sf-menu li.current_page_ancestor > a, 
    header#top nav .sf-menu li.current-menu-ancestor > a, 
    header#top nav .sf-menu li.current_page_item > a {
		color: #FFF!Important;
	}
	
	header#top .sf-menu > li:hover  ul, header#top .sf-menu > li.sfHover  ul {
		height: 0px;
		position: absolute;
		visibility: hidden!important;
		overflow: hidden;
    }

    
    header#top .sf-menu li ul.mobile-open {
    	height: auto!important;
    	display: block!important;
    	position: relative;
    	visibility: visible!important;
    }
	
	header#top nav > ul > li > a {
		padding:16px 0px!important;
		border-bottom: 1px solid #ddd;
	}
	
	header#top, #header-outer:not([data-permanent-transparent="1"]) {
		height: auto!important;
	}
	
	header#top li#search-btn {
		display: none;
	}
	

	#header-outer.transparent.directional-nav-effect header#top #logo span.dark,
	#header-outer.transparent.directional-nav-effect header#top #logo span.light {
		display: none!important;
	}
	#header-outer.transparent.directional-nav-effect header#top #logo span.original {
		display: block!important;
		opacity: 1!important;
	}

	#header-outer.transparent.directional-nav-effect header#top #logo span.dark
	.orbit-wrapper #featured .slide article .post-title, .orbit-wrapper .slider-nav > span {
		opacity: 1!important;
		margin-top: 0px!important;
	}
	
	#featured article {
		top: 0px!important;
		background-size: cover!important;
		-moz-background-size: cover!important;
		-o-background-size: cover!important;
		-webkit-background-size: cover!important;
		background-attachment: scroll!important;
		background-position: center 60%!important;
	}
	
	#featured .no-caption article {
		top: -7px!important;
	}
	
	.orbit-wrapper, .orbit-wrapper #featured {
  		margin-top: 0px;
  	}
  	

	body #featured .mejs-container {
		position: relative;
		top: 20px!important;
		margin-bottom: 140px!important;
	}
	
	.swiper-slide .mejs-controls {
		display: none!important;
		visibility: hidden!important;
	}
	.mejs-controls {
		display: block!important;
		visibility: visible!important;
	}
	
	#post-area {
		padding-right: 0px!important;
		margin-bottom: 0px;
	}
	
	div.slider-nav {
		position: relative;
		max-width: 600px; 
		margin: -40px auto 0px auto;
	}
	
	body div.slider-nav > span {
		height: 25px!important;
		width: 25px!important;
	}
	
	body .orbit-wrapper div.slider-nav > span.left, body .orbit-wrapper div.slider-nav > span.right {
		background-color: #fff!important;
	}
	
	body div.slider-nav > span.left {
		left: 0px!important; 
	}
	
	body div.slider-nav > span.right {
		left: 30px!important;
	}
	
	
	div.slider-nav span span {
		display: none!important;
	}
	
		
  	.portfolio-items .col {
  		margin-bottom: 15px!important;
  	}
  	
  	.orbit-wrapper #featured article .post-title{
  		position: relative;
  	}
  	
  	.orbit-wrapper div.slider-nav span {
  		position: absolute;
  	}
  	
  	.orbit-wrapper div.slider-nav span.right, .orbit-wrapper div.slider-nav span.left {
  		text-indent: 0px!Important;
  	}
  	
  	.orbit-wrapper #featured article .post-title {
  		top: 170px!important;
  		left: 0px;
  	}
  	
  	#featured .orbit-slide.centered article .post-title > a, #featured .orbit-slide.centered article .post-title h2 { 
  		left: 0px!Important;	
  	}
  	
  	.orbit-wrapper div.slider-nav span {
  		top: 0px!important;
  	}
  	
  	#footer-widgets .container .col {
  		margin-bottom: 40px;
  	}
  	
  	#footer-widgets .container .col:nth-child(3), #footer-widgets .container .col:nth-child(4) {
  		margin-bottom: 0px;
  	}
  	
  	#pagination {
		margin-bottom: 40px!important;
	}
	
    body #featured article .post-title > a {
  		padding: 10px 12px;
  		background-color: #27CFC3;
  		border-color: #27CFC3;
  		color: #fff;
  		top: 20px;
  	}
  	
  	body #featured article .post-title > a:hover {
  		border-color: #27CFC3;
  		box-shadow: 0px 1px 2px rgba(0,0,0,0.3);
  		-moz-box-shadow: 0px 1px 2px rgba(0,0,0,0.3);
  		-webkit-box-shadow: 0px 1px 2px rgba(0,0,0,0.3);
  		-o-box-shadow: 0px 1px 2px rgba(0,0,0,0.3);
  	}
  	
  	#featured article .post-title > a {
  		left: 0px!important;
  	}
  	
  	.portfolio-items:not(.carousel) .col.span_3 .work-item .work-info a {
		padding: 9px 15px!important;
		font-size: 12px!important;
		margin: 5px!important;
	}
	
	.portfolio-items .col .work-item .work-info a {
		display: block;
		position: absolute;
		top: 0px;
		left: 0px;
		margin: 0px;
		width: 100%;
		height: 100%;
		opacity: 0!important;
		text-indent: -9999px;
	}
	.portfolio-items .col .work-item .work-info .custom-content a.nectar-button {
		width: auto;
	}

	.portfolio-items .col .work-item:not(.style-2):not(.style-3):not(.style-3-alt):not(.style-4):not([data-custom-content="on"]) .work-info .vert-center {
		transform: none!important;
		-webkit-transform: none!important;
		top: 0!important;
		height: 100%;
	}
		
  	.wp-caption {
  		width: 100%!important;
  	}

  	.pricing-table[data-style="flat-alternative"] .pricing-column.highlight {
  		margin-top: 30px!important;
  	}

  	.pricing-table[data-style="flat-alternative"].two-cols > div:nth-child(2),
  	.pricing-table[data-style="flat-alternative"].three-cols > div:nth-child(2),
  	.pricing-table[data-style="flat-alternative"].four-cols > div:nth-child(2n+2),
  	.pricing-table[data-style="flat-alternative"].five-cols > div:nth-child(2n+2) {
  		margin-right: 0!important;
  	}

  	
  	body.single-portfolio #sidebar.fixed-sidebar, body.single-portfolio #sidebar  {
		top: 0px!important;
		width: 100%!important;
		margin-left: 0px!important;
		margin-top: 10px;
		position: relative!important;
		float: none!important;
	}

	body.single-portfolio #sidebar {
		margin-top: 30px;
	}
	
	body.search .row .col.section-title h1 {
		font-size: 18px!Important;	
	}
	
	body.search .row .col.section-title span {
		display: inline-block;
		margin-top: 10px;
		font-size: 14px;
	}
	
	body.search .divider {
		display: none;	
	}
	
	.main-content > div {
		padding-bottom: 0px;
	}
	
	#single-meta {
		display: block;
		position: relative!important;
		clear: both;
		margin-bottom: 10px;
	}

	body.single-post #page-header-bg:not(.fullscreen-header) {
		min-height: 250px!important;
	}
	body.single-post #page-header-bg:not(.fullscreen-header) .row {
		top: 0!important;
	}

	.single #single-meta ul li.meta-share-count .nectar-social {
		left: 0!important;
		right: auto!important;
		text-align: left;
	}

	.single #single-meta ul {
		float: left;
	}
	.single .blog-title #single-meta ul li {
		float: right;
	}
	body.single-post .blog-title #single-meta ul li:last-child {
		margin: 5px!important;
	}
	
	html .single-post #single-meta {
		margin-top: 20px!important;
	}
	
	#single-meta ul {
		margin-left: 0px;
	}
	
	.page-template-template-portfolio-php .portfolio-filters {
		margin-bottom: 0px;
	}
	
	body #featured .post-title h2, body #featured .post-title > a, body #featured .post-title > span, body #featured .post-title div.video {
		margin-top: 0px!important;
	}
	
	body #featured .has-video .post-title {
		top: 48px!important;
	}
	
	body #featured .has-video h2 {
		text-align: center!important;
		left: auto!Important;	
		float: none!important;
		margin: 0 auto;
	}
	
	body #featured .orbit-slide.has-video .post-title h2 {
		margin-top: 80px!important;
	}
	
	body #featured .post-title .video {
		float: none;
		margin: 0 auto;
		width: 100%!important;
		left: auto;
		position: relative;
		z-index: 1;
	}

	body #featured .post-title .video img {
		height: 338px!important;
	}
	
	body #featured article .post-title > a {
		left: 0px;
	}
	
	body #featured .orbit-slide.has-video h2 {
	    max-width: 330px!important;
	    min-width: 330px!important;
	    margin-top: 60px!important;
	}
	
	body #featured .orbit-slide.has-video .post-title {
	    text-align: center!Important;
	}
	
	body #featured .more-info {
		display: block;
		position: absolute;
		z-index: 10000;
		left: 80px !important;
		top: 387px;
	}
	
	body #featured a.more-info {
		display: block;
		color: #6d6d6d;
		border-radius: 1px 1px 1px 1px;
    	background-color: #FFFFFF !important;
		padding: 2px 7px;
	}

	.swiper-slide .content p, .swiper-slide .content h2, .swiper-slide .content .buttons {
		opacity: 1!important;
		padding: 0!important;
	}
	
	#footer-outer #social li {	
	   width: 33px;
	   margin-top: 9px;
	   margin-bottom: 9px;
	}

	.nectar-recent-posts-slider .recent-post-container {
		max-width: none!important;
	}
	.nectar-recent-posts-slider .recent-post-container,
	.nectar-recent-posts-slider .flickity-page-dots {
		padding: 0 40px;
	}


	.full-width-content .nectar-recent-posts-slider .recent-post-container .inner-wrap {
		max-width: 100%;
	}

	body[data-footer-reveal="1"] #footer-outer {
		position: relative;
	}

	body[data-footer-reveal="1"][data-footer-reveal-shadow="large"] .container-wrap {
	    box-shadow: none!important;
	    -webkit-box-shadow: none!important;
	}

	body[data-footer-reveal="1"] .container-wrap {
		margin-bottom: 0!important;
	}


	.carousel-heading h2 {
		max-width: 83%;
		font-size: 11px;
	}
	
	.carousel-wrap[data-full-width="false"] .carousel-heading h2 {
		font-size: 11px!important;
	}
	
	.span_9 .carousel-heading {
		padding-right: 0px!important;
	}
	
	body.woocommerce ul.products li.product, body.woocommerce-page ul.products li.product, .woocommerce .related ul.products li.product, .woocommerce .related ul li.product, .woocommerce .upsells.products ul.products li.product, .woocommerce .upsells.products ul li.product, .woocommerce-page .related ul.products li.product, .woocommerce-page .related ul li.product, .woocommerce-page .upsells.products ul.products li.product, .woocommerce-page .upsells.products ul li.product, 
	body.woocommerce .span_9 ul.products li.product, body.woocommerce-page .span_9 ul.products li.product, body .woocommerce ul.products li.product, body .woocommerce-page ul.products li.product,
	html .woocommerce .products.related .product, html .woocommerce .products.upsells .product, html .woocommerce-page.columns-3 ul.products li.product, 
	html .woocommerce.columns-3 ul.products li.product {
		width: 48%;
		margin: 0px 4% 25px 0px;
	}

	html .woocommerce .products.related .product, html .woocommerce .products.upsells .product {
		width: 48%!important;
	}
	 
	.woocommerce .span_9 ul.products li.product:nth-child(2n+2), .woocommerce-page .span_9 ul.products li.product:nth-child(2n+2), 
	body .woocommerce ul.products li.product:nth-child(2n+2),  body .woocommerce-page ul.products li.product:nth-child(2n+2),
	body.woocommerce ul.products li:nth-child(2n+2) {
		margin-right: 0px;
	}

	.woocommerce .related ul.products li:nth-child(2n+2), .woocommerce .upsells.products ul li.product:nth-child(2n+2) {
		margin-right: 0px!important;
	}
	
	body.woocommerce .span_9 ul.products li.product, body.woocommerce-page .span_9 ul.products li.product {
		clear: none;
	}
	
	.single-product .product_title {
		padding-right: 0!important;
	}
	
	.woocommerce .span_9 .woocommerce-ordering {
		right: 0px;
	}
	
	.cart-outer { display: none; }
	
	#header-secondary-outer {
		position: relative!important;	
		top: 0px!important;
		height: auto!important;
	}

	#header-secondary-outer[data-permanent-transparent="1"] {
		margin-top: 33px;
	}
	
	#header-secondary-outer nav > ul {
		float: none!important;
		width: 100%;
		text-align: center;
		height: auto!important;
	}
	
	#header-secondary-outer nav > ul > li > a .sf-sub-indicator {
		display: none!important;
	}
	
	#header-secondary-outer nav > ul > li {
		display: inline-block!important;
		float: none!important;
	}
	
	#header-secondary-outer ul ul {
		z-index: 100000;
	}
	
	#header-secondary-outer ul li:hover {
		z-index: 1000;
	}
	
	#header-secondary-outer nav > ul > li ul li {
		text-align: left!important;
	}

	#header-secondary-outer #social li > a {
		height: 15px!important;
	}
	
	#header-secondary-outer nav ul.sf-menu {
		border-top: 1px solid #DDDDDD;
	}
	
	/*
	body[data-header-color="custom"] #header-secondary-outer ul#social {
		border-bottom: 1px solid rgba(0,0,0,0.1);
	}
	
	body[data-header-color="dark"] #header-secondary-outer ul#social {
		border-bottom: 1px solid #333333;
	}*/
	
	#page-header-wrap {
		margin-top: 0px;
		overflow: visible;
		height: auto!important;	
	}
	
	#page-header-bg[data-parallax="1"] .span_6, #page-header-bg[data-parallax="1"] {
		position: relative!important;
		top: 0px!important;
	}
	
	#page-header-bg .span_6 {
		display: block!important;
		opacity: 1!important;
	}

	#page-header-bg[data-alignment-v="middle"]:not(.fullscreen-header) .span_6 {
		top: 50%!important;
		transform: translateY(-50%)!important;
		-webkit-transform: translateY(-50%)!important;
		-moz-transform: translateY(-50%)!important;
	}

	/*.single-portfolio #page-header-bg[data-alignment-v="middle"]:not(.fullscreen-header) .span_6 {
		transform: none!important;
		-webkit-transform: none!important;
		-o-transform: none!important;
	} */

	body #header-outer[data-using-secondary="1"], body.admin-bar #header-outer[data-using-secondary="1"] {
	    top: 0;
	}
	
	h1 .nectar-button, h2 .nectar-button, h3 .nectar-button, h4 .nectar-button {
		display: inline-block;
		margin-top: 20px;
	}
	
	body .clients.no-carousel > div {
		opacity: 1;
	}
	
	img.img-with-animation[data-animation="fade-in-from-left"], .col.has-animation[data-animation="fade-in-from-left"], .wpb_column.has-animation[data-animation="fade-in-from-left"] {
		left: 0px!important;	
	}
	
	img.img-with-animation[data-animation="fade-in-from-right"], .col.has-animation[data-animation="fade-in-from-right"], .wpb_column.has-animation[data-animation="fade-in-from-right"] {
		right: 0px!important;
	}
	
	.clients.fade-in-animation > div, img.img-with-animation, .col.has-animation, .wpb_column.has-animation {
		opacity: 1!important;
	}
	
	.col.has-animation[data-animation="fade-in-from-bottom"], .wpb_column.has-animation[data-animation="fade-in-from-bottom"] {
		bottom: 0px!important;
		transform: translateY(0)!important;
		-webkit-transform: translateY(0)!important;
		-moz-transform: translateY(0)!important;
	}
	
	img.img-with-animation[data-animation="grow-in"], .col.has-animation[data-animation="grow-in"], .wpb_column.has-animation[data-animation="grow-in"] {
		 transform: scale(1, 1)!important;
		 -webkit-transform: scale(1, 1)!Important;
	}
	
	img.img-with-animation[data-animation="flip-in"], .col.has-animation[data-animation="flip-in"], .wpb_column.has-animation[data-animation="flip-in"] {
		opacity: 1!important;
	    transform: perspective(1000px) rotateY(0deg)!important;
	    -webkit-transform: perspective(1000px) rotateY(0deg)!important;
	    -o-webkit-transform: perspective(1000px) rotateY(0deg)!important;
	    -moz-webkit-transform: perspective(1000px) rotateY(0deg)!important;
	}

	.portfolio-items:not(.carousel) .col .inner-wrap[data-animation="fade_in"],
	.portfolio-items:not(.carousel) .col .inner-wrap[data-animation="fade_in_from_bottom"], 
	.posts-container[data-load-animation="fade_in_from_bottom"] .inner-wrap, 
	.posts-container[data-load-animation="fade_in"] article .inner-wrap {
	    opacity: 1!important;
	    transform: translateY(0)!important;
	    -webkit-transform: translateY(0)!important;
	    -moz-transform: translateY(0)!important;
	}

	
	.main-content .vc_span2 .iwithtext .iwt-icon i { font-size: 34px!important; line-height: 34px!important; width: 34px!important; height: 34px!important;}
	.main-content .vc_span2 .iwithtext .iwt-icon img { width: 35px; }
    .main-content .vc_span2  .iwithtext .iwt-text { padding-left: 55px; }
	.main-content .vc_span2 .iwithtext .iwt-icon { top: -4px; }
	
	.parallax_slider_outer.first-section .swiper-container .slider-prev, .parallax_slider_outer.first-section .swiper-container .slider-next {
		margin-top: -30px;
	}
	
	#post-area.col_last {
		padding-left: 0px!important;	
	}
	
	body.single-portfolio #post-area {
		width: 100%!important;
		float: none!important;
	}
	
	.ascend #author-bio img {
		margin: 0 auto!important;
	}

	.woocommerce #post-area .woocommerce-ordering {
		float: none!important;
		display: block;
	}
	
	/*.col h2 {
		font-size: 18px;
	}
	
	.col h3 {
		font-size: 16px;
	}
	
	.col h4 {
		font-size: 16px;
	}*/
	
	.col.centered-text ul, .wpb_column.centered-text ul, .col.centered-text ul li, .wpb_column.centered-text ul li {
		text-align: left;
		margin-left: 0!important;
	}
	
	.col.centered-text ul, .wpb_column.centered-text ul {
		margin: 0!important;
		display: block!important;
	}
	
	.col[data-padding-pos="right"] {
		padding-right: 0!important;
	}
	.col[data-padding-pos="left"] {
		padding-left: 0!important;
	}

	.vc_text_separator {
 		height: auto!important;
	}
	
	.nectar-fancy-ul[data-animation="true"] ul li {
		opacity: 1!important;
		left: 0!important;
	}

	.testimonial_slider .controls ul {
		text-align: center!important;
	}
	
	#page-header-bg[data-parallax="0"] {
		margin-top: -1px;
	}
	
	
	.nectar-milestone {
		margin-bottom: 15px;
	}

	.nectar-milestone.motion_blur .number span:not(.in-sight) {
		transform: none;
		-webkit-transform: none;
		-moz-transform: none;
		opacity: 1;
	}
	
	#page-header-wrap, #page-header-bg {
		transition: none!important;
		-moz-transition: none!important;
		-webkit-transition: none!important;
		-o-transition: none!important;
	}
	
	#featured article .post-title h2 {
		left: 0px!important;	
	}
	
/*	.container-wrap {
		overflow-x: hidden!important;
	}*/
	
	.nectar-slider-wrap {
		margin-top: 0!important;
		margin-left: -1px;
	}
	
	.nectar-slider-loading {
		background-position: center!important;
		top: 0!important;
	}

	.nectar-slider-loading .loading-icon {
		height: 100%!important;
	}
	
	.swiper-wrapper .slider-down-arrow { display: none; }
	.nectar-slider-wrap[data-fullscreen="true"] .swiper-wrapper .slider-down-arrow { 
		display: block; 	
		bottom: 0px;
		margin-left: -30px!important;
	}
	.nectar-slider-wrap[data-fullscreen="true"] .swiper-wrapper .slider-down-arrow i { 
		font-size: 14px!Important;
		opacity: 1!important;
		transform: none!important;
		-webkit-transform: none!important;
		-o-transform: none!important;
	}
	
	.parallax_slider_outer.first-section .slider-pagination, .nectar-slider-wrap.first-section .slider-pagination {
		padding: 0!important;
	}
	
	/*#boxed .container-wrap .row > .wpb_row:first-child .nectar-slider-wrap[data-full-width="boxed-full-width"][data-parallax="false"] {
		margin-top: -30px!important;
	}*/
	
	#boxed .container-wrap .row > .nectar-slider-wrap.first-section[data-full-width="boxed-full-width"][data-parallax="false"] {
		margin-top: -40px!important;
	}
	
	.parallax_slider_outer.first-section .nectar-slider-wrap {
		position: relative!important;
		max-width: 100%;
		overflow-x: hidden;
	}
	.parallax_slider_outer.first-section .nectar-slider-wrap, #full_width_portfolio .project-title.parallax-effect {
		transform: translate(0px, 0px)!Important;
		-webkit-transform: translate(0px, 0px)!Important;
	}
	
	.single-portfolio #full_width_portfolio .row .col.section-title h1,
	.single-portfolio .row .col.section-title h1 {
		letter-spacing: 0px;
		font-size: 20px;
	}
	
	.parallax_slider_outer.first-section, body .parallax-disabled, .parallax-disabled .nectar-slider-wrap {
		margin-top: 0px!important;	
	}
	
	.admin-bar.single-portfolio .project-title.parallax-effect {
		margin-top: 0px!important;	
	}
	
	#full_width_portfolio .project-title.parallax-effect {
		position: relative!important;
		top: 0px!important;
	} 
	
	.project-title {
		padding-top: 2.2em!important;
		margin-top: 0px!important;
	}
	
	.admin-bar .project-title.parallax-effect {
		margin-top: -28px!Important;
	} 
	
	.parallax_slider_outer.first-section .swiper-slide .content {
		opacity: 1!important;
		transform: translate(0px, 0px)!Important;
		-webkit-transform: translate(0px, 0px)!Important;
	}
	
	.parallax_slider_outer.first-section .nectar-slider-wrap {
		left: 1px!important; 
	}
	
	.swiper-slide {
		top: -1px;
	}
	
	.swiper-slide .mejs-overlay {
		z-index: 1000!important;
	}
	
	.swiper-slide .mejs-poster {
		opacity: 1!Important;
	}
	
	.swiper-slide .content p img {
		max-width: 100%;
	}
	
	.wpb_tabs_nav li.cta-button {
		top: 0;
		transform: translateY(-100%);
		left: 0;
		right: auto;
	}
	.tabbed[data-alignment="right"] .wpb_tabs_nav li.cta-button {
		top: 0;
		transform: translateY(-100%);
		left: auto;
		right: 0;
	}
	.tabbed[data-alignment="center"] .wpb_tabs_nav li.cta-button {
		top: 0;
		transform: translateY(-100%) translateX(-50%);
		left: 50%;
		right: auto;
	}
	/*.swiper-slide .content br {
		display: none;
	}*/
	
	body[data-smooth-scrolling="1"] #full_width_portfolio .project-title.parallax-effect {
		padding-right: 0px!important;
	}
	
	body.single-portfolio #full_width_portfolio .container-wrap {
		padding-top: 2.1em;	
	}
	
	.parallax_slider_outer.first-section .swiper-slide .content, .nectar-slider-wrap.first-section .swiper-slide .content {
		margin-top: 3px!important;	
		margin-left: 2px!Important;
	}
	
	.parallax_slider_outer.first-section .slider-pagination, .nectar-slider-wrap.first-section .slider-pagination {
		padding-left: 2px;
	}
	
	.carousel-wrap[data-full-width="true"] {
		padding: 0px 9px;
	}
	
	#footer-widgets .container .row > div:last-child {
		margin-bottom: 0px!important;
	}
	
	body .carousel-wrap[data-full-width="true"] .carousel-heading h2 {
		font-size: 16px;	
		top: 3px;
	}
	
	body .carousel-wrap[data-full-width="true"] .controls {
		display: block;
		height: 30px;
		position: relative;
		margin-top: 25px!important;
		margin-bottom: 10px;
		width: 130px;
		margin: 0 auto;
	}
	
	body .carousel-wrap[data-full-width="true"] .carousel-heading a.portfolio-page-link, 
	body .carousel-wrap[data-full-width="true"] .carousel-heading a.carousel-prev, 
	body .carousel-wrap[data-full-width="true"] .carousel-heading a.carousel-next {
		top: 0px!important;
	}
	
	body .carousel-wrap[data-full-width="true"] .carousel-heading a.portfolio-page-link {
		margin: 0 auto;
		position: relative;
	}
	body .carousel-wrap[data-full-width="true"] .carousel-heading a.carousel-prev {
		left: 0px!important;
		margin-left: 0px;
		text-align: left!important;
	}
	body .carousel-wrap[data-full-width="true"] .carousel-heading a.carousel-next {
		right: 0px!Important;
	}
	
	div[data-full-width="false"] .carousel-heading h2 {
		font-size: 12px!important;
	}
	
	div.portfolio-items[data-col-num="elastic"] {
		padding-left: 0px!important;
	}
	
	.portfolio-filters-inline #current-category {
		display: none!important;
	}
	
	.portfolio-filters-inline .container > ul {
		float: none!important;
		text-align: center;
	}
	
	.portfolio-filters-inline #sort-label {
		display: none!important;
	}

	.blog-fullwidth-wrap #post-area.masonry {
	    margin-bottom: 83px !important;
	}
	.blog-fullwidth-wrap.meta-overlaid #post-area.masonry {
		margin-bottom: 0!important;
	}
	
	body .portfolio-filters-inline ul li, body .portfolio-filters-inline ul ul {
		float: none!important;
		display: inline;
	}
	
	body .container-wrap .portfolio-filters-inline.first-section {
		padding-top: 19px !important;
	}
	
	body .container-wrap.portfolio-filters-inline.first-section.non-fw  {
		padding-top: 33px !important;
	}
	
	body .portfolio-filters-inline .container > ul {
		max-width: 100%!important;
		margin-right: 0px!important;
	}
	
	body .pp_gallery, .woocommerce .pp_gallery {
		display: none!important;
	}
	
	#post-area.masonry:not(.meta_overlaid) {
		opacity: 1!important;
	}
	
	/* full width content column sizing  */
	.full-width-content.vc_row-fluid .vc_span2,
	.full-width-content.vc_row-fluid .vc_span3,
	.full-width-content.vc_row-fluid .vc_span4,
	.full-width-content.vc_row-fluid .vc_span5,
	.full-width-content.vc_row-fluid .vc_span6,
	.full-width-content.vc_row-fluid .vc_span7,
	.full-width-content.vc_row-fluid .vc_span8,
	.full-width-content.vc_row-fluid .vc_span9,
	.full-width-content.vc_row-fluid .vc_span10,
	.full-width-content.vc_row-fluid .vc_span11, 
	.full-width-content.vc_row-fluid .vc_span12,
	.full-width-content.vc_row-fluid .vc_col-sm-2,
	.full-width-content.vc_row-fluid .vc_col-sm-3,
	.full-width-content.vc_row-fluid .vc_col-sm-4,
	.full-width-content.vc_row-fluid .vc_col-sm-5,
	.full-width-content.vc_row-fluid .vc_col-sm-6,
	.full-width-content.vc_row-fluid .vc_col-sm-7,
	.full-width-content.vc_row-fluid .vc_col-sm-8,
	.full-width-content.vc_row-fluid .vc_col-sm-9,
	.full-width-content.vc_row-fluid .vc_col-sm-10,
	.full-width-content.vc_row-fluid .vc_col-sm-11, 
	.full-width-content.vc_row-fluid .vc_col-sm-12 { width: 100%!important; height: auto!important; margin-left: 0; }
	

	.full-width-content .col[data-using-bg="true"], .full-width-content .col .wpb_row, .full-width-content .col {
		margin-bottom: 0!important;	
	}
	
	.full-width-content.wpb_row .span_12 > .col .wpb_wrapper {
		margin-top: 0!important;
		margin-bottom: 0!important;
	}
	
	.wpb_row .span_12 > .col.padding-1-percent,
	.wpb_row .span_12 > .col.padding-2-percent,
	.column-inner.padding-1-percent,
	.column-inner.padding-2-percent { padding: 3%!important; }
	
	.wpb_row .span_12 > .col.padding-3-percent,
	.wpb_row .span_12 > .col.padding-4-percent,
	.wpb_row .span_12 > .col.padding-5-percent,
	.column-inner.padding-3-percent,
	.column-inner.padding-4-percent,
	.column-inner.padding-5-percent { padding: 6%!important; }
	
	.full-width-content .one-fourths.span_3, .full-width-content .one-fourths.vc_span3, .full-width-content .one-fourths.vc_col-sm-3 { padding: 0;}
}


/* full width carousels*/


@media only screen and (min-width: 470px) and (max-width: 600px) {
	
	body .carousel-wrap[data-full-width="true"] .portfolio-items .work-meta {
		width: 66%;
	}
	body .carousel-wrap[data-full-width="true"] .portfolio-items .work-meta {
		font-size: 10px;
	}
	body .portfolio-items .work-meta h4 { 
		font-size: 15px!important;
		line-height: 18px!important;
	}
	body .portfolio-items[data-ps="6"] .work-meta p { 
		font-size: 12px!important;
		margin-top: 5px;
		line-height: 14px!important;
	}
}


body #post-area.masonry.meta_overlaid .masonry-blog-item.large_featured {
	width: 100%!important;
}


@media screen and (max-width: 782px) {
	html .admin-bar #header-outer[data-permanent-transparent="1"][data-mobile-fixed="1"], html .logged-in.buddypress #header-outer[data-permanent-transparent="1"][data-mobile-fixed="1"],
	html .admin-bar #header-outer[data-permanent-transparent="false"][data-mobile-fixed="1"], html .logged-in.buddypress #header-outer[data-permanent-transparent="false"][data-mobile-fixed="1"] {
		top: 47px;
	}

	#header-secondary-outer[data-permanent-transparent="1"] {
		margin-top: 0px;
	}

	body {
		position: static;
	}


}

/* full width portfolio/blog/fwc rows*/
@media only screen and (min-width: 1600px) {
	body:after {
		content: 'five';
		display: none;
	}
	
	
	/*boxed*/
	#boxed .portfolio-items .elastic-portfolio-item {
		width: 25%;
	}
	
	body #boxed .portfolio-items .col.elastic-portfolio-item.tall, body #boxed .portfolio-items .col.elastic-portfolio-item.regular {
		width: 20%;
	}
	
	body #boxed .portfolio-items .col.elastic-portfolio-item.wide {
		width: 50%;
	}
	
	body #boxed .portfolio-items .col.elastic-portfolio-item.wide_tall {
		width: 50%;
	}
	
	
	body #boxed .default-style .portfolio-items .col.elastic-portfolio-item {
		width: 21.72%!important;
	}
	
	#post-area.full-width-content .masonry-blog-item, .full-width-content #post-area .masonry-blog-item {
		width: 18%;
	}
	#post-area.full-width-content.classic_enhanced .masonry-blog-item, .full-width-content #post-area.classic_enhanced .masonry-blog-item {
		width: 18.5%;
	}
	
	#boxed #post-area.full-width-content .masonry-blog-item, #boxed .full-width-content #post-area .masonry-blog-item {
	    width: 30.8%;
	}
	#boxed #post-area.full-width-content.classic_enhanced .masonry-blog-item, #boxed .full-width-content #post-area.classic_enhanced .masonry-blog-item {
	    width: 31.8%;
	}

	/*constrained masonry*/
	body .portfolio-items.constrain-max-cols .col.elastic-portfolio-item.wide,
	body #post-area.masonry.meta_overlaid .masonry-blog-item.wide_tall,
	body #post-area.masonry.meta_overlaid.span_9 .masonry-blog-item.regular.format-quote,
	body #post-area.masonry.meta_overlaid.span_9 .masonry-blog-item.regular.format-link {
		width: 50%;
	}
	
	body .portfolio-items.constrain-max-cols .col.elastic-portfolio-item.wide_tall {
		width: 50%;
	}

	body .portfolio-items.constrain-max-cols .col.elastic-portfolio-item.tall, body .portfolio-items.constrain-max-cols.masonry-items .col.elastic-portfolio-item.regular,
	body #post-area.masonry.meta_overlaid .masonry-blog-item.regular,
	#boxed #post-area.full-width-content.meta_overlaid .masonry-blog-item.regular, #boxed .full-width-content #post-area.meta_overlaid .masonry-blog-item.regular {
		width: 25%;
	}

	/*classic blog enhanced*/
	body #post-area.masonry.classic_enhanced .masonry-blog-item.large_featured {
		width: 63.66%;
	}

	body .blog-fullwidth-wrap #post-area.masonry.classic_enhanced .masonry-blog-item.large_featured{
		width: 58.5%;
	}

	body #post-area.masonry.classic_enhanced.span_9 .masonry-blog-item.large_featured {
		width: 97.5%;
	}

	#boxed .full-width-content #post-area.classic_enhanced .masonry-blog-item.large_featured {
		width: 65%;
	}
	

}

@media only screen and (min-width: 1300px) and (max-width: 1600px) {
	body:after {
		content: 'four';
		display: none;
	}
	
	.portfolio-items .elastic-portfolio-item,
	body #post-area.masonry.meta_overlaid .masonry-blog-item.regular {
		width: 25%;
	}
	
	

	body .portfolio-items .col.elastic-portfolio-item.tall, body .portfolio-items .col.elastic-portfolio-item.regular {
		width: 20%;
	}
	
	body .portfolio-items .col.elastic-portfolio-item.wide {
		width: 50%;
	}
	
	body .portfolio-items .col.elastic-portfolio-item.wide_tall,
	body #post-area.masonry.meta_overlaid .masonry-blog-item.wide_tall,
	body #post-area.masonry.meta_overlaid.span_9 .masonry-blog-item.regular.format-quote,
	body #post-area.masonry.meta_overlaid.span_9 .masonry-blog-item.regular.format-link {
		width: 50%;
	}

	body #post-area.masonry.meta_overlaid .masonry-blog-item.regular h2.title {
		font-size: 16px!important;
		line-height: 22px!important;
	}
	body .masonry.meta_overlaid article.post .post-header .meta-author a { font-size: 11px!important; }
	body .masonry.meta_overlaid article.post .post-header .meta-author span { font-size: 13px!important; }
	
	html body .default-style .portfolio-items .col.elastic-portfolio-item {
		width: 22.43%!important;
	}
	
	html body #boxed .default-style .portfolio-items .col.elastic-portfolio-item {
		width: 21.72%!important;
	}
	
	
	#post-area.full-width-content .masonry-blog-item, .full-width-content #post-area .masonry-blog-item {
		width: 23%;
	}
	
		
	.full-width-content.blog-fullwidth-wrap:not(.meta-overlaid) {
		padding-left: 2.8%!important;
	}
	
	#boxed #post-area.full-width-content .masonry-blog-item, #boxed .full-width-content #post-area .masonry-blog-item {
	    width: 32%;
	}
	
	.full-width-content .vc_span2 .nectar-milestone .number, .full-width-content .vc_col-sm-2 .nectar-milestone .number{
		font-size: 50px;
		line-height: 50px;
	}
	
	.full-width-content .vc_span8 .clients.five-cols.carousel > div, .full-width-content .vc_col-sm-8 .clients.five-cols.carousel > div {
		width: 33%;
	}
	
	.full-width-content .vc_span3 .team-member[data-style="meta_overlaid"] .team-member-image, .full-width-content .vc_col-sm-3 .team-member[data-style="meta_overlaid"] .team-member-image{
		height: 320px;
	}
	
	.full-width-content .vc_span4 .team-member[data-style="meta_overlaid"] .team-member-image, .full-width-content .vc_col-sm-4 .team-member[data-style="meta_overlaid"] .team-member-image {
		height: 370px;
	}

	/*classic blog enhanced*/
	body #post-area.masonry.classic_enhanced .masonry-blog-item.large_featured {
		width: 64.1%;
	}

	body .blog-fullwidth-wrap #post-area.masonry.classic_enhanced .masonry-blog-item.large_featured,
	#boxed .full-width-content #post-area .masonry-blog-item.large_featured {
		width: 73%;
	}

	body #post-area.masonry.classic_enhanced.span_9 .masonry-blog-item.large_featured {
		width: 97.5%;
	}
	
	#boxed #post-area.full-width-content.classic_enhanced .masonry-blog-item, #boxed .full-width-content #post-area.classic_enhanced .masonry-blog-item {
	    width: 31.3%;
	}

	#boxed .full-width-content #post-area.classic_enhanced .masonry-blog-item.large_featured {
		width: 64.7%;
	}

}


@media only screen and (min-width: 990px) and (max-width: 1300px) {
    body:after {
        content: 'three';
        display: none;
    }

    .portfolio-items .elastic-portfolio-item {
        width: 33.3%;
    }

    .portfolio-items[data-ps="6"] .col {
		padding: 1.5%;
	}

    body .portfolio-items .col.elastic-portfolio-item.wide_tall, body .portfolio-items .col.elastic-portfolio-item.wide  {
        width: 66.6%;
    }

    html body .default-style .portfolio-items .col.elastic-portfolio-item {
        width: 30.6%!important;
    }
    
    html body #boxed .default-style .portfolio-items .col.elastic-portfolio-item {
        width: 29.7%!important;
    }
    
    
	/* constrained cols */
	body .portfolio-items.constrain-max-cols.no-masonry .col.elastic-portfolio-item,
	body #post-area.masonry.meta_overlaid .masonry-blog-item.regular {
		width: 25%;
	}
	
	/* constrained cols */
	body .portfolio-items.constrain-max-cols.no-masonry .col.elastic-portfolio-item h3, .team-member[data-style="meta_overlaid"] .team-meta h3,
	body .portfolio-items.constrain-max-cols.no-masonry .col.elastic-portfolio-item .style-5 h4 {
		font-size: 14px;
		line-height: 20px;
	}
	body .portfolio-items.constrain-max-cols.masonry-items .col.elastic-portfolio-item h3,
	body .portfolio-items.constrain-max-cols.masonry-items .col.elastic-portfolio-item h4 {
		font-size: 18px;
		line-height: 25px;
	}
	body .masonry.meta_overlaid article.post .post-header .meta-author a { font-size: 11px!important; }
	body .masonry.meta_overlaid article.post .post-header .meta-author span { font-size: 13px!important; }
	
	.portfolio-items.constrain-max-cols .work-item.style-4 .bottom-meta {
	    padding: 13px 13px 10px;
	}
	
	.portfolio-items.constrain-max-cols .work-item.style-4 .bottom-meta p,
	.portfolio-items.constrain-max-cols .work-item.style-5 p {
	    font-size: 12px;
	    line-height: 18px;
	}


	/*constrained masonry*/
	body .portfolio-items.constrain-max-cols .col.elastic-portfolio-item.wide {
		width: 25%;
	}
	
	body .portfolio-items.constrain-max-cols .col.elastic-portfolio-item.wide_tall,
	body #post-area.masonry.meta_overlaid .masonry-blog-item.wide_tall,
	body #post-area.masonry.meta_overlaid.span_9 .masonry-blog-item.regular.format-quote,
	body #post-area.masonry.meta_overlaid.span_9 .masonry-blog-item.regular.format-link {
		width: 25%;
	}

	body .portfolio-items.constrain-max-cols .col.elastic-portfolio-item.tall, body .portfolio-items.constrain-max-cols.masonry-items .col.elastic-portfolio-item.regular {
		width: 25%;
	}

	body #post-area.masonry.meta_overlaid .masonry-blog-item.regular h2.title {
		font-size: 14px!important;
		line-height: 20px!important;
	}

	
	.team-member[data-style="meta_overlaid"] .team-meta { bottom: 30px; }
	
	
	/*fw content column early content shrinking*/
	.full-width-content .vc_span8 .clients.six-cols > div, .full-width-content .vc_col-sm-8 .clients.six-cols > div {
	    width: 32.3%;
	}
	
	.full-width-content .vc_span8 .clients.no-carousel.six-cols > div:nth-child(3n+3), .full-width-content .vc_col-sm-8 .clients.no-carousel.six-cols > div:nth-child(3n+3) {
	    margin-right: 0;
	}
	
	.full-width-content .vc_span8 .clients.five-cols.carousel > div, .full-width-content .vc_col-sm-8 .clients.five-cols.carousel > div {
		width: 40%;
	}
	
	.full-width-content .vc_span4 .testimonial_slider blockquote, .full-width-content .vc_col-sm-4 .testimonial_slider blockquote {
	    font-size: 16px;
	    line-height: 33px;
	}
	
	.full-width-content .vc_span3 .team-member[data-style="meta_overlaid"] .team-member-image, .full-width-content .vc_col-sm-3 .team-member[data-style="meta_overlaid"] .team-member-image {
		height: 270px;
	}
	
	.full-width-content .vc_span4 .team-member[data-style="meta_overlaid"] .team-member-image, .full-width-content .vc_col-sm-4 .team-member[data-style="meta_overlaid"] .team-member-image {
		height: 320px;
	}
	
	.wpb_row:not(.full-width-content) .vc_span3 .team-member[data-style="meta_overlaid"] .team-member-image, .wpb_row:not(.full-width-content) .vc_col-sm-3 .team-member[data-style="meta_overlaid"] .team-member-image {
		height: 250px;
	}

	.full-width-content .wpb_column .wpb_row .wpb_column,
	.full-width-content .wpb_column .wpb_row .wpb_column p {
		font-size: 12px;
		line-height: 23px;
	}

	/*classic blog enhanced*/
	body #post-area.masonry.classic_enhanced .masonry-blog-item.large_featured {
		width: 100%;
	}

	body .blog-fullwidth-wrap #post-area.masonry.classic_enhanced .masonry-blog-item.large_featured {
		width: 97.2%;
	}
	body #post-area.masonry.classic_enhanced.span_9 .masonry-blog-item.large_featured {
		width: 97.5%;
	}

	#boxed #post-area.full-width-content.classic_enhanced .masonry-blog-item, #boxed .full-width-content #post-area.classic_enhanced .masonry-blog-item {
	    width: 31.4%;
	}
	#boxed .full-width-content #post-area.classic_enhanced .masonry-blog-item.large_featured {
		width: 98%;
	}
	
}


@media only screen and (min-width: 470px) and (max-width: 990px) {
	body:after {
		content: 'two';
		display: none;
	}
	
	.portfolio-items .elastic-portfolio-item,
	body #post-area.masonry.meta_overlaid .masonry-blog-item.regular {
		width: 50%;
	}
	
	body .portfolio-items .col.elastic-portfolio-item.wide_tall, body .portfolio-items .col.elastic-portfolio-item.wide,
	body #post-area.masonry.meta_overlaid .masonry-blog-item.wide_tall,
	body #post-area.masonry.meta_overlaid.span_9 .masonry-blog-item.regular.format-quote,
	body #post-area.masonry.meta_overlaid.span_9 .masonry-blog-item.regular.format-link {
		width: 100%;
	}

	body .portfolio-wrap.default-style { padding: 0px!Important; margin-top: 30px; }
	body .portfolio-wrap.default-style .portfolio-items { margin: 0px!important; width: 100%!important; padding: 0px!important; transform: none!important;}
	html body .default-style .portfolio-items .col.elastic-portfolio-item {
		width: 100%!important;
		margin: 0px!important;
		padding-bottom: 25px;
	}
	
	
	/*boxed*/
	#boxed .portfolio-items .elastic-portfolio-item {
		width: 100%;
	}
	
	#boxed .portfolio-items .elastic-portfolio-item img {
		height: auto!important;
	}
	
	
	body #boxed .default-style { padding: 0px!Important; margin-top: 30px; }
	body #boxed .default-style .portfolio-items { margin: 0px!important; width: 100%!important; padding: 0px!important;}
	body #boxed .default-style .portfolio-items .col.elastic-portfolio-item {
		width: 100%!important;
		margin: 0px!important;
		padding-bottom: 25px;
	}

	body #post-area.masonry.meta_overlaid .masonry-blog-item.regular h2.title {
		font-size: 16px!important;
		line-height: 20px!important;
	}
	
	/*classic blog enhanced*/
	body #post-area.masonry.classic_enhanced .masonry-blog-item.large_featured {
		width: 97%;
	}

	body .blog-fullwidth-wrap #post-area.masonry.classic_enhanced .masonry-blog-item.large_featured {
		width: 97%;
	}

	#boxed #post-area.full-width-content.classic_enhanced .masonry-blog-item, #boxed .full-width-content #post-area.classic_enhanced .masonry-blog-item {
	    width: 48%;
	}

	#boxed .full-width-content #post-area.classic_enhanced .masonry-blog-item.large_featured {
		width: 98%;
	}

}

@media only screen and (max-width: 690px) and (min-width: 470px) {
	body #post-area.masonry.meta_overlaid .masonry-blog-item.format-quote.regular,
	body #post-area.masonry.meta_overlaid .masonry-blog-item.format-link.regular,
	body #post-area.masonry.meta_overlaid .masonry-blog-item.format-quote.regular_2x,
	body #post-area.masonry.meta_overlaid .masonry-blog-item.format-link.regular_2x {
		width: 100%;
	}
	article.post.quote .post-content .quote-inner, article.post.link .post-content .link-inner, article.format-status .post-content .status-inner, article.post.format-aside .aside-inner {
		padding: 50px 10%;
	}
	body .portfolio-items.constrain-max-cols.masonry-items .col.elastic-portfolio-item h3 {
		font-size: 18px;
		line-height: 25px;
	}

	.portfolio-items[data-ps="6"] .col, .portfolio-items[data-ps="6"][data-col-num="elastic"] {
		padding: 10px!important;
	}


}

@media only screen and (max-width: 690px)  {

	/*classic blog enhanced*/
	#post-area.masonry.classic_enhanced article.post.large_featured .content-inner {
		width: 100%;
		height: auto;
		position: static;
	}
	.masonry.classic_enhanced .masonry-blog-item.post.large_featured .article-content-wrap {
		position: relative;
		transform: none;
		top: auto;
		padding: 27px!important;
	}
	#post-area.masonry.classic_enhanced article.post.large_featured .post-meta {
		position: relative!important;
		width: 100%!important;
	}
	#post-area.masonry.classic_enhanced article.post.large_featured .meta-category a {
		color: #fff;
		border: 2px solid rgba(255,255,255,0.5);
	}
	#post-area.masonry.classic_enhanced article.post.large_featured .img-link {
		position: relative;
		width: 100%;
		height: 280px;
	}
	#post-area.masonry.classic_enhanced article.post.large_featured,
	#post-area.masonry.classic_enhanced article.post.regular .article-content-wrap,
	#post-area.masonry.classic_enhanced article.post.regular.format-standard.has-post-thumbnail,
	#post-area.masonry.classic_enhanced article.post.regular.format-video.has-post-thumbnail,
	#post-area.masonry.classic_enhanced article.post.regular.format-audio.has-post-thumbnail {
		height: auto!important;
	}


	.nectar-recent-posts-slider .inner-wrap {
		max-width: 80%;
	}

	.arhchive #page-header-wrap #page-header-bg .subheader {
		display: none;
	}

}

@media only screen and (max-width: 470px) {
	body:after {
		content: 'one';
		display: none;
	}
	
	.portfolio-items .elastic-portfolio-item,
	body #post-area.masonry.meta_overlaid .masonry-blog-item.wide_tall,
	body #post-area.masonry.meta_overlaid .masonry-blog-item.format-quote.regular,
	body #post-area.masonry.meta_overlaid .masonry-blog-item.format-link.regular,
	body #post-area.masonry.meta_overlaid .masonry-blog-item.format-quote.regular_2x,
	body #post-area.masonry.meta_overlaid .masonry-blog-item.format-link.regular_2x {
		width: 100%;
	}

	body #post-area.masonry.meta_overlaid .masonry-blog-item.regular {
		width: 50%;
	}
	
	.portfolio-items .elastic-portfolio-item img,
	.masonry.meta_overlaid article.post.wide_tall .content-inner .post-featured-img img {
		height: auto!important;
	}
	
	.portfolio-items[data-ps="6"] .col, .portfolio-items[data-ps="6"][data-col-num="elastic"] {
		padding: 10px!important;
	}
	
	body .default-style { padding: 0px!Important; margin-top: 30px; }
	body .default-style .portfolio-items:not(.carousel) { margin: 0px!important; width: 100%!important; padding: 0px!important; transform: none!important;}
	html body .default-style .portfolio-items .col.elastic-portfolio-item {
		width: 100%!important;
		margin: 0px!important;
		padding-bottom: 25px;
	}

	body .masonry.meta_overlaid .link-inner .link-wrap, body .masonry.meta_overlaid .quote-inner .quote-wrap {
	    transform: none!important;
	    -webkit-transform: none!important;
	    -moz-transform: none!important;
	    top: 0!important;
	}

	article.post.quote .post-content .quote-inner, article.post.link .post-content .link-inner, article.format-status .post-content .status-inner, article.post.format-aside .aside-inner {
		padding: 50px 10%;
	}
	
	.full-width-content.blog-fullwidth-wrap:not(.meta-overlaid) {
		padding: 0px 10%!important;	
	}

	body #post-area.masonry.meta_overlaid .masonry-blog-item.regular h2.title {
		font-size: 12px!important;
		line-height: 18px!important;
	}

	body .masonry.meta_overlaid .masonry-blog-item.wide_tall h2.title, body .masonry.meta_overlaid .masonry-blog-item.large_featured h2.title {
		font-size: 19px!important;
	}
	body #post-area.masonry.meta_overlaid article.masonry-blog-item.wide_tall .post-meta .date, body #post-area.masonry.meta_overlaid article.masonry-blog-item.large_featured .post-meta .date {
		font-size: 13px!important;
	}
	#post-area.masonry.meta_overlaid article.post.wide_tall .post-meta, #post-area.masonry.meta_overlaid article.post.large_featured .post-meta {
		margin: -1px 0!important;
	}


	body #post-area.masonry.meta_overlaid .masonry-blog-item .post-meta .date {
		font-size: 9px!important;
	}

	body .masonry.meta_overlaid .masonry-blog-item .article-content-wrap {
		padding-bottom: 0!important;
	}

	body .masonry.meta_overlaid article.post .post-header .meta-author a { font-size: 11px!important; }
	body .masonry.meta_overlaid article.post .post-header .meta-author span { font-size: 11px!important; }

	.portfolio-items .col.wide .work-item.style-3-alt[data-text-align="left"] .vert-center,
	.portfolio-items .col.wide .work-item.style-3-alt[data-text-align="right"] .vert-center,
	.portfolio-items .col.wide .work-item.style-3[data-text-align="left"] .vert-center,
	.portfolio-items .col.wide .work-item.style-3[data-text-align="right"] .vert-center {
		left: 50%!important;
		right: auto!important;
		margin-left: 0;
	}

	.portfolio-items .work-item.style-4 .bottom-meta {
		bottom: 0!important;
	}
}



/* vc mobile */

@media (max-width: 767px) {
  body .vc_row-fluid [class*="vc_col-xs-"] {
    margin-left: 2.1%;
  }
  body .vc_row-fluid [class*="vc_col-xs-12"] {
    margin-left: 0;
  }
}
@media (min-width: 768px) and (max-width: 991px) {
  body .vc_row-fluid [class*="vc_col-sm-"] {
    margin-left: 2.1%;
  }
  body .vc_row-fluid [class*="vc_col-sm-12"] {
    margin-left: 0;
  }
}
@media (min-width: 992px) and (max-width: 1199px) {
  body .vc_row-fluid [class*="vc_col-md-"] {
    margin-left: 2.1%;
  }
  body .vc_row-fluid [class*="vc_col-md-12"] {
    margin-left: 0;
  }
}
