<?php
/* THIS IS A GENERATED FILE. DO NOT EDIT DIRECTLY. */
$jetpack_strings = array(
_x( "Sharing", "Navigation item.", "jetpack" ), // _inc/client/admin.js:70
_x( "Writing", "Navigation item.", "jetpack" ), // _inc/client/admin.js:69
_x( "Traffic", "Navigation item.", "jetpack" ), // _inc/client/admin.js:68
_x( "Security", "Navigation item.", "jetpack" ), // _inc/client/admin.js:67
_x( "Discussion", "Navigation item.", "jetpack" ), // _inc/client/admin.js:66
_x( "Settings", "Navigation item.", "jetpack" ), // _inc/client/admin.js:65
_x( "Plans", "Navigation item.", "jetpack" ), // _inc/client/admin.js:64
__( "At A Glance", "jetpack" ), // _inc/client/admin.js:63
_x( "At A Glance", "Navigation item.", "jetpack" ), // _inc/client/admin.js:61
__( "Error unlinking from WordPress.com. %(error)s", "jetpack" ), // _inc/client/state/connection/actions.js:128
__( "Unlinked from WordPress.com.", "jetpack" ), // _inc/client/state/connection/actions.js:119
__( "Unlinking from WordPress.com", "jetpack" ), // _inc/client/state/connection/actions.js:112
__( "There was an error disconnecting Jetpack. Error: %(error)s", "jetpack" ), // _inc/client/state/connection/actions.js:96
__( "Disconnecting Jetpack", "jetpack" ), // _inc/client/state/connection/actions.js:81
__( "Options failed to reset.", "jetpack" ), // _inc/client/state/dev-version/actions.js:40
__( "Options reset.", "jetpack" ), // _inc/client/state/dev-version/actions.js:33
__( "Resetting Jetpack options…", "jetpack" ), // _inc/client/state/dev-version/actions.js:27
__( "Recommended features failed to activate. %(error)s", "jetpack" ), // _inc/client/state/jumpstart/actions.js:47
__( "Recommended features active.", "jetpack" ), // _inc/client/state/jumpstart/actions.js:37
__( "Activating recommended features…", "jetpack" ), // _inc/client/state/jumpstart/actions.js:29
__( "Error regenerating %(slug)s address. %(error)s", "jetpack" ), // _inc/client/state/modules/actions.js:299
__( "Regenerated %(slug)s address .", "jetpack" ), // _inc/client/state/modules/actions.js:281
__( "Updating %(slug)s address…", "jetpack" ), // _inc/client/state/modules/actions.js:261
__( "Error updating %(slug)s settings. %(error)s", "jetpack" ), // _inc/client/state/modules/actions.js:234
__( "Updated %(slug)s settings.", "jetpack" ), // _inc/client/state/modules/actions.js:216
__( "Updating %(slug)s settings…", "jetpack" ), // _inc/client/state/modules/actions.js:198
__( "%(slug)s failed to deactivate. %(error)s", "jetpack" ), // _inc/client/state/modules/actions.js:174
__( "%(slug)s has been deactivated.", "jetpack" ), // _inc/client/state/modules/actions.js:154
__( "Deactivating %(slug)s…", "jetpack" ), // _inc/client/state/modules/actions.js:138
__( "%(slug)s failed to activate. %(error)s", "jetpack" ), // _inc/client/state/modules/actions.js:117
__( "%(slug)s has been activated.", "jetpack" ), // _inc/client/state/modules/actions.js:97
__( "Activating %(slug)s…", "jetpack" ), // _inc/client/state/modules/actions.js:81
__( "Updated settings. Refreshing page…", "jetpack" ), // _inc/client/state/settings/actions.js:115
__( "Error regenerating Post by Email address. %(error)s", "jetpack" ), // _inc/client/state/settings/actions.js:99
__( "Regenerated Post by Email address.", "jetpack" ), // _inc/client/state/settings/actions.js:98
__( "Updating Post by Email address…", "jetpack" ), // _inc/client/state/settings/actions.js:97
__( "Error updating settings. %(error)s", "jetpack" ), // _inc/client/state/settings/actions.js:90
__( "Updated settings.", "jetpack" ), // _inc/client/state/settings/actions.js:89
__( "Updating settings…", "jetpack" ), // _inc/client/state/settings/actions.js:88
__( "There are unsaved settings in this tab that will be lost if you leave it. Proceed?", "jetpack" ), // _inc/client/main.jsx:79
__( "There are unsaved settings in this tab that will be lost if you leave it. Proceed?", "jetpack" ), // _inc/client/main.jsx:64
_x( "Spam comments blocked.", "Example: \"412 Spam comments blocked\"", "jetpack" ), // _inc/client/at-a-glance/akismet.jsx:127
__( "Whoops! Your Akismet key is missing or invalid. {{akismetSettings}}Go to Akismet settings to fix{{/akismetSettings}}.", "jetpack" ), // _inc/client/at-a-glance/akismet.jsx:106
__( "Invalid key", "jetpack" ), // _inc/client/at-a-glance/akismet.jsx:101
__( "For state-of-the-art spam defense, please {{a}}activate Akismet{{/a}}.", "jetpack" ), // _inc/client/at-a-glance/akismet.jsx:83
__( "For state-of-the-art spam defense, please {{a}}install Akismet{{/a}}.", "jetpack" ), // _inc/client/at-a-glance/akismet.jsx:61
__( "Loading…", "jetpack" ), // _inc/client/at-a-glance/akismet.jsx:44
__( "Spam Protection", "jetpack" ), // _inc/client/at-a-glance/akismet.jsx:33
__( "Unavailable in Dev Mode.", "jetpack" ), // _inc/client/at-a-glance/backups.jsx:95
__( "To automatically back up your entire site, please {{a}}upgrade your account{{/a}}.", "jetpack" ), // _inc/client/at-a-glance/backups.jsx:77
__( "To automatically back up your entire site, please {{a}}install and activate{{/a}} VaultPress.", "jetpack" ), // _inc/client/at-a-glance/backups.jsx:69
__( "{{a}}View backup details{{/a}}.", "jetpack" ), // _inc/client/at-a-glance/backups.jsx:55
__( "Loading…", "jetpack" ), // _inc/client/at-a-glance/backups.jsx:37
__( "Backups", "jetpack" ), // _inc/client/at-a-glance/backups.jsx:27
_x( "Account connection", "Dashboard widget header", "jetpack" ), // _inc/client/at-a-glance/connections.jsx:185
_x( "Site connection", "Dashboard widget header", "jetpack" ), // _inc/client/at-a-glance/connections.jsx:175
__( "Link your account to WordPress.com to get the most out of Jetpack.", "jetpack" ), // _inc/client/at-a-glance/connections.jsx:151
/* translators: %(username) is the WordPress user login name. */
__( "Connected as {{span}}%(username)s{{/span}}", "jetpack" ), // _inc/client/at-a-glance/connections.jsx:124
__( "The site is in Development Mode, so you can not connect to WordPress.com.", "jetpack" ), // _inc/client/at-a-glance/connections.jsx:110
__( "You are the Jetpack owner.", "jetpack" ), // _inc/client/at-a-glance/connections.jsx:71
__( "Your site is connected to WordPress.com.", "jetpack" ), // _inc/client/at-a-glance/connections.jsx:67
__( "Your site is in Development Mode, so it can not be connected to WordPress.com.", "jetpack" ), // _inc/client/at-a-glance/connections.jsx:51
__( "Performance", "jetpack" ), // _inc/client/at-a-glance/index.jsx:98
__( "Connections", "jetpack" ), // _inc/client/at-a-glance/index.jsx:54
__( "Manage security on WordPress.com", "jetpack" ), // _inc/client/at-a-glance/index.jsx:44
__( "Security", "jetpack" ), // _inc/client/at-a-glance/index.jsx:39
__( "{{a}}Activate Monitor{{/a}} to receive notifications if your site goes down.", "jetpack" ), // _inc/client/at-a-glance/monitor.jsx:58
__( "Unavailable in Dev Mode.", "jetpack" ), // _inc/client/at-a-glance/monitor.jsx:57
__( "Jetpack is monitoring your site. If we think your site is down, you will receive an email.", "jetpack" ), // _inc/client/at-a-glance/monitor.jsx:44
__( "Downtime Monitoring", "jetpack" ), // _inc/client/at-a-glance/monitor.jsx:35
__( "{{a}}Activate Photon{{/a}} to enhance the performance and speed of your images.", "jetpack" ), // _inc/client/at-a-glance/photon.jsx:43
__( "Unavailable in Dev Mode", "jetpack" ), // _inc/client/at-a-glance/photon.jsx:42
__( "Jetpack is improving and optimizing your image speed.", "jetpack" ), // _inc/client/at-a-glance/photon.jsx:30
__( "Image Performance %(photon)s", "jetpack" ), // _inc/client/at-a-glance/photon.jsx:22
__( "{{a}}Activate Manage{{/a}} to turn on auto updates and manage your plugins from WordPress.com.", "jetpack" ), // _inc/client/at-a-glance/plugins.jsx:97
__( "All plugins are up-to-date. Awesome work!", "jetpack" ), // _inc/client/at-a-glance/plugins.jsx:96
_n( "Needs updating. ", "Need updating. ", 1, "jetpack" ), // _inc/client/at-a-glance/plugins.jsx:73
_n( "%(number)s plugin", "%(number)s plugins", 1, "jetpack" ), // _inc/client/at-a-glance/plugins.jsx:63
__( "{{a}}Activate Manage and turn on auto updates{{/a}}", "jetpack" ), // _inc/client/at-a-glance/plugins.jsx:54
__( "{{a}}Turn on plugin auto updates{{/a}}", "jetpack" ), // _inc/client/at-a-glance/plugins.jsx:53
__( "Loading…", "jetpack" ), // _inc/client/at-a-glance/plugins.jsx:46
__( "Plugin Updates", "jetpack" ), // _inc/client/at-a-glance/plugins.jsx:32
__( "{{a}}Activate Protect{{/a}} to keep your site protected from malicious sign in attempts.", "jetpack" ), // _inc/client/at-a-glance/protect.jsx:65
__( "Unavailable in Dev Mode", "jetpack" ), // _inc/client/at-a-glance/protect.jsx:64
__( "Total malicious attacks blocked on your site.", "jetpack" ), // _inc/client/at-a-glance/protect.jsx:52
__( "Jetpack is actively blocking malicious login attempts. Data will display here soon!", "jetpack" ), // _inc/client/at-a-glance/protect.jsx:40
__( "Unavailable in Dev Mode.", "jetpack" ), // _inc/client/at-a-glance/scan.jsx:132
__( "For automated, comprehensive scanning of security threats, please {{a}}upgrade your account{{/a}}.", "jetpack" ), // _inc/client/at-a-glance/scan.jsx:114
__( "For automated, comprehensive scanning of security threats, please {{a}}install and activate{{/a}} VaultPress.", "jetpack" ), // _inc/client/at-a-glance/scan.jsx:106
__( "Loading…", "jetpack" ), // _inc/client/at-a-glance/scan.jsx:101
__( "No threats found, you're good to go!", "jetpack" ), // _inc/client/at-a-glance/scan.jsx:91
__( "{{a}}Contact Support{{/a}}", "jetpack" ), // _inc/client/at-a-glance/scan.jsx:76
__( "{{a}}View details at VaultPress.com{{/a}}", "jetpack" ), // _inc/client/at-a-glance/scan.jsx:74
_n( "Uh oh, %(number)s threat found.", "Uh oh, %(number)s threats found.", 1, "jetpack" ), // _inc/client/at-a-glance/scan.jsx:64
__( "Loading…", "jetpack" ), // _inc/client/at-a-glance/scan.jsx:48
__( "Security Scanning", "jetpack" ), // _inc/client/at-a-glance/scan.jsx:31
__( "{{a}}Activate Site Verification{{/a}} to verify your site and increase ranking with Google, Bing, and Pinterest.", "jetpack" ), // _inc/client/at-a-glance/site-verification.jsx:43
__( "Site Verification Tools are active. Ensure your site is verified with Google, Bing, and Pinterest for more accurate indexing and ranking. {{a}}Verify now{{/a}}", "jetpack" ), // _inc/client/at-a-glance/site-verification.jsx:27
__( "Site Verification Tools", "jetpack" ), // _inc/client/at-a-glance/site-verification.jsx:21
__( "Learn more", "jetpack" ), // _inc/client/discussion/comments.jsx:138
__( "Enable Markdown use for comments.", "jetpack" ), // _inc/client/discussion/comments.jsx:136
__( "Learn more", "jetpack" ), // _inc/client/discussion/comments.jsx:118
__( "Color scheme", "jetpack" ), // _inc/client/discussion/comments.jsx:88
__( "A few catchy words to motivate your readers to comment.", "jetpack" ), // _inc/client/discussion/comments.jsx:86
__( "Comments headline", "jetpack" ), // _inc/client/discussion/comments.jsx:79
__( "Comments", "jetpack" ), // _inc/client/discussion/comments.jsx:56
__( "Show a \"follow comments\" option in the comment form", "jetpack" ), // _inc/client/discussion/subscriptions.jsx:103
__( "Show a \"follow blog\" option in the comment form", "jetpack" ), // _inc/client/discussion/subscriptions.jsx:93
__( "Connect your user account to WordPress.com to view your email followers", "jetpack" ), // _inc/client/discussion/subscriptions.jsx:64
__( "View your Email Followers", "jetpack" ), // _inc/client/discussion/subscriptions.jsx:63
__( "Compare Plans", "jetpack" ), // _inc/client/plans/plan-body.jsx:346
__( "We support all Jetpack users, regardless of plan. But customers on a paid subscription enjoy priority support so that security issues are identified and fixed for you as soon as possible. ", "jetpack" ), // _inc/client/plans/plan-body.jsx:339
__( "Enjoy priority support", "jetpack" ), // _inc/client/plans/plan-body.jsx:338
__( "The Jetpack Premium plan now offers you the ability to generate income from your site by showing high-quality paid ads to your visitors. Professional plan customers also benefit from SEO tools to help optimize search engine traffic.", "jetpack" ), // _inc/client/plans/plan-body.jsx:334
__( "Premium traffic and monetization tools", "jetpack" ), // _inc/client/plans/plan-body.jsx:333
__( "Bulletproof spam filtering protects your brand, your readers, and improves SEO. Malware scanning helps maintain peace of mind and keeps your backend safe from intruders.", "jetpack" ), // _inc/client/plans/plan-body.jsx:330
__( "Real-time backup with unlimited space, one-click restores, bulletproof spam monitoring, malware defense, and brute-force login protection - all in one place and optimized for WordPress.", "jetpack" ), // _inc/client/plans/plan-body.jsx:329
__( "Maximum grade security", "jetpack" ), // _inc/client/plans/plan-body.jsx:328
__( "Compare Plans", "jetpack" ), // _inc/client/plans/plan-body.jsx:313
__( "Income generation from ads", "jetpack" ), // _inc/client/plans/plan-body.jsx:310
__( "Advanced SEO tools", "jetpack" ), // _inc/client/plans/plan-body.jsx:309
__( "One-click threat resolution", "jetpack" ), // _inc/client/plans/plan-body.jsx:308
__( "Real-time backups", "jetpack" ), // _inc/client/plans/plan-body.jsx:307
__( "On-demand security scanning", "jetpack" ), // _inc/client/plans/plan-body.jsx:306
__( "If your site is important to you, consider protecting and improving it with some of our advanced features: ", "jetpack" ), // _inc/client/plans/plan-body.jsx:305
__( "Need more? Running a business site?", "jetpack" ), // _inc/client/plans/plan-body.jsx:304
__( "Compare Plans", "jetpack" ), // _inc/client/plans/plan-body.jsx:294
__( "Income generation from ads", "jetpack" ), // _inc/client/plans/plan-body.jsx:291
__( "Advanced SEO tools", "jetpack" ), // _inc/client/plans/plan-body.jsx:290
__( "Unlimited and ad-free video hosting", "jetpack" ), // _inc/client/plans/plan-body.jsx:289
__( "Real-time backups and one-click threat resolution", "jetpack" ), // _inc/client/plans/plan-body.jsx:288
__( "Daily and on-demand security scanning", "jetpack" ), // _inc/client/plans/plan-body.jsx:287
__( "If your site is important to you, consider protecting and improving it with some of our advanced features: ", "jetpack" ), // _inc/client/plans/plan-body.jsx:286
__( "Need more? Running a business site?", "jetpack" ), // _inc/client/plans/plan-body.jsx:285
__( "Activate Google Analytics", "jetpack" ), // _inc/client/plans/plan-body.jsx:274
__( "Configure Google Analytics", "jetpack" ), // _inc/client/plans/plan-body.jsx:265
__( "Track website statistics with Google Analytics for a deeper understanding of your website visitors and customers.", "jetpack" ), // _inc/client/plans/plan-body.jsx:261
__( "Google Analytics", "jetpack" ), // _inc/client/plans/plan-body.jsx:260
__( "Activate SEO Tools", "jetpack" ), // _inc/client/plans/plan-body.jsx:249
__( "Configure Site SEO", "jetpack" ), // _inc/client/plans/plan-body.jsx:240
__( "Advanced SEO tools to help your site get found when people search for relevant content.", "jetpack" ), // _inc/client/plans/plan-body.jsx:236
__( "SEO Tools", "jetpack" ), // _inc/client/plans/plan-body.jsx:235
__( "Activate VideoPress", "jetpack" ), // _inc/client/plans/plan-body.jsx:224
__( "Upload Videos Now", "jetpack" ), // _inc/client/plans/plan-body.jsx:215
__( "Fast, optimized, ad-free, and unlimited video hosting for your site (powered by VideoPress).", "jetpack" ), // _inc/client/plans/plan-body.jsx:211
__( "Video Hosting", "jetpack" ), // _inc/client/plans/plan-body.jsx:210
__( "Activate VideoPress", "jetpack" ), // _inc/client/plans/plan-body.jsx:199
__( "Upload Videos Now", "jetpack" ), // _inc/client/plans/plan-body.jsx:190
__( "13Gb of fast, optimized, and ad-free video hosting for your site (powered by VideoPress).", "jetpack" ), // _inc/client/plans/plan-body.jsx:186
__( "Video Hosting", "jetpack" ), // _inc/client/plans/plan-body.jsx:185
__( "Activate Ads", "jetpack" ), // _inc/client/plans/plan-body.jsx:174
__( "View your earnings", "jetpack" ), // _inc/client/plans/plan-body.jsx:165
__( "Earn income by allowing Jetpack to display high quality ads (powered by WordAds).", "jetpack" ), // _inc/client/plans/plan-body.jsx:161
__( "Ads", "jetpack" ), // _inc/client/plans/plan-body.jsx:160
__( "Configure VaultPress", "jetpack" ), // _inc/client/plans/plan-body.jsx:149
__( "View your security dashboard", "jetpack" ), // _inc/client/plans/plan-body.jsx:144
__( "Real-time backup of all your site data with unlimited space, one-click restores, automated security scanning, one-click threat resolution, and priority support (powered by VaultPress).", "jetpack" ), // _inc/client/plans/plan-body.jsx:140
__( "Backups & Security Scanning", "jetpack" ), // _inc/client/plans/plan-body.jsx:139
__( "Configure VaultPress", "jetpack" ), // _inc/client/plans/plan-body.jsx:128
__( "View your security dashboard", "jetpack" ), // _inc/client/plans/plan-body.jsx:123
__( "Daily backup of all your site data with unlimited space, one-click restores, automated security scanning, and priority support (powered by VaultPress).", "jetpack" ), // _inc/client/plans/plan-body.jsx:119
__( "Backups & Security Scanning", "jetpack" ), // _inc/client/plans/plan-body.jsx:118
__( "Configure VaultPress", "jetpack" ), // _inc/client/plans/plan-body.jsx:107
__( "View your security dashboard", "jetpack" ), // _inc/client/plans/plan-body.jsx:102
__( "Daily backup of all your site data with unlimited space and one-click restores (powered by VaultPress).", "jetpack" ), // _inc/client/plans/plan-body.jsx:98
__( "Backups", "jetpack" ), // _inc/client/plans/plan-body.jsx:97
__( "Configure Akismet", "jetpack" ), // _inc/client/plans/plan-body.jsx:88
__( "View your spam stats", "jetpack" ), // _inc/client/plans/plan-body.jsx:83
__( "State-of-the-art spam defense powered by Akismet.", "jetpack" ), // _inc/client/plans/plan-body.jsx:79
__( "Spam Protection", "jetpack" ), // _inc/client/plans/plan-body.jsx:78
__( "Once you connect, you can upgrade to a paid plan in order to unlock world-class security, spam protection tools, and priority support.", "jetpack" ), // _inc/client/plans/plan-header.jsx:126
__( "Your site is on Development Mode", "jetpack" ), // _inc/client/plans/plan-header.jsx:125
__( "You get spam-protection, real-time backups (unlimited archive), unlimited backup storage, security scanning, unlimited ad-free video hosting, income generation from ads, SEO tools, and priority support.", "jetpack" ), // _inc/client/plans/plan-header.jsx:112
__( "Your site is on the Jetpack Professional plan", "jetpack" ), // _inc/client/plans/plan-header.jsx:111
__( "With this plan you are provided with spam-protection, daily backups (up to 30 days), unlimited backup storage, security scanning, 13Gb of ad-free video hosting, income generation from ads, and priority support.", "jetpack" ), // _inc/client/plans/plan-header.jsx:98
__( "Your site is on the Jetpack Premium plan", "jetpack" ), // _inc/client/plans/plan-header.jsx:97
__( "With this plan you are provided with spam-protection, daily backups (up to 30 days), and unlimited storage.", "jetpack" ), // _inc/client/plans/plan-header.jsx:84
__( "Your site is on the Jetpack Personal plan", "jetpack" ), // _inc/client/plans/plan-header.jsx:83
__( "Upgrade to a paid plan to unlock world-class security, spam protection tools, priority support, SEO and monetization tools.", "jetpack" ), // _inc/client/plans/plan-header.jsx:70
__( "Your site is on the Free Jetpack Plan", "jetpack" ), // _inc/client/plans/plan-header.jsx:69
__( "Image of WordPress login screen protected by Jetpack", "jetpack" ), // _inc/client/plans/plan-header.jsx:55
__( "Learn more", "jetpack" ), // _inc/client/plans/plan-header.jsx:50
__( "Hackers, botnets and spammers attack websites indiscriminately. Their goal is to attack everywhere and often. Our goal is to help you prepare by blocking these threats, and in worst-case-scenarios we'll be here to help you restore your site to its former glory.", "jetpack" ), // _inc/client/plans/plan-header.jsx:46
__( "For less than the price of a coffee a month you can rest easy knowing your hard work (or livelihood) is backed up.", "jetpack" ), // _inc/client/plans/plan-header.jsx:44
__( "How much is your website worth?", "jetpack" ), // _inc/client/plans/plan-header.jsx:42
__( "The Personal Plan keeps your data, site, and hard work safe.", "jetpack" ), // _inc/client/plans/plan-header.jsx:38
__( "Introducing our most affordable backups and security plan yet", "jetpack" ), // _inc/client/plans/plan-header.jsx:35
_x( "Set up", "Caption for a button to set up a feature.", "jetpack" ), // _inc/client/pro-status/index.jsx:131
__( "ACTIVE", "jetpack" ), // _inc/client/pro-status/index.jsx:98
_x( "Invalid key", "Short warning message about an invalid key being used for Akismet.", "jetpack" ), // _inc/client/pro-status/index.jsx:94
_x( "Secure", "Short message informing user that the site is secure.", "jetpack" ), // _inc/client/pro-status/index.jsx:90
_x( "Upgrade", "Caption for a button to purchase a paid feature.", "jetpack" ), // _inc/client/pro-status/index.jsx:85
_x( "No scanning", "Short warning message about site having no security scan.", "jetpack" ), // _inc/client/pro-status/index.jsx:83
_x( "FIX", "A caption for a small button to fix security issues.", "jetpack" ), // _inc/client/pro-status/index.jsx:74
_x( "Threats found!", "Short warning message about new threats found.", "jetpack" ), // _inc/client/pro-status/index.jsx:73
_x( "Threats", "A caption for a small button to fix security issues.", "jetpack" ), // _inc/client/pro-status/index.jsx:71
__( "If you don't already have an API key, then {{a}}get your API key here{{/a}}, and you'll be guided through the process of getting one.", "jetpack" ), // _inc/client/security/antispam.jsx:150
__( "Your API key", "jetpack" ), // _inc/client/security/antispam.jsx:138
_x( "Spam filtering", "Settings header", "jetpack" ), // _inc/client/security/antispam.jsx:127
__( "Checking key…", "jetpack" ), // _inc/client/security/antispam.jsx:118
__( "Your site is protected from spam.", "jetpack" ), // _inc/client/security/antispam.jsx:112
__( "Your Antispam key is valid.", "jetpack" ), // _inc/client/security/antispam.jsx:110
__( "Your site is not protected from spam.", "jetpack" ), // _inc/client/security/antispam.jsx:108
__( "There's a problem with your Antispam API key. {{a}}Learn more{{/a}}.", "jetpack" ), // _inc/client/security/antispam.jsx:102
__( "Your site needs an Antispam key.", "jetpack" ), // _inc/client/security/antispam.jsx:98
__( "Fetching key…", "jetpack" ), // _inc/client/security/antispam.jsx:93
__( "Checking your spam protection…", "jetpack" ), // _inc/client/security/antispam.jsx:89
__( "Configure your Security Scans", "jetpack" ), // _inc/client/security/backups-scan.jsx:73
_x( "Backups and security scanning", "Settings header", "jetpack" ), // _inc/client/security/backups-scan.jsx:63
__( "Checking site status…", "jetpack" ), // _inc/client/security/backups-scan.jsx:56
__( "Click \"Set Up\" to finish installation.", "jetpack" ), // _inc/client/security/backups-scan.jsx:53
__( "You have paid for backups and security scanning but they’re not yet active.", "jetpack" ), // _inc/client/security/backups-scan.jsx:51
__( "You have paid for backups but they're not yet active.", "jetpack" ), // _inc/client/security/backups-scan.jsx:49
__( "Your site is backed up and threat-free.", "jetpack" ), // _inc/client/security/backups-scan.jsx:46
__( "Unavailable in Dev Mode.", "jetpack" ), // _inc/client/security/backups-scan.jsx:43
__( "You may whitelist an IP address or series of addresses preventing them from ever being blocked by Jetpack. IPv4 and IPv6 are acceptable. To specify a range, enter the low value and high value separated by a dash. Example: 12.12.12.1-12.12.12.100", "jetpack" ), // _inc/client/security/protect.jsx:138
__( "Whitelisted IP addresses", "jetpack" ), // _inc/client/security/protect.jsx:128
__( "Add to whitelist", "jetpack" ), // _inc/client/security/protect.jsx:122
__( "Your current IP: %(ip)s", "jetpack" ), // _inc/client/security/protect.jsx:115
_x( "Brute force attack protection", "Settings header", "jetpack" ), // _inc/client/security/protect.jsx:100
__( "Require accounts to use WordPress.com Two-Step Authentication", "jetpack" ), // _inc/client/security/sso.jsx:86
__( "Match accounts using email addresses", "jetpack" ), // _inc/client/security/sso.jsx:76
_x( "WordPress.com log in", "Settings header", "jetpack" ), // _inc/client/security/sso.jsx:54
__( "Enter a search term to find settings or close search.", "jetpack" ), // _inc/client/settings/index.jsx:37
__( "No search results found for %(term)s", "jetpack" ), // _inc/client/settings/index.jsx:29
__( "Allow readers to show their appreciation of your posts by adding a like button to your content", "jetpack" ), // _inc/client/sharing/likes.jsx:34
_x( "Like buttons", "Settings header", "jetpack" ), // _inc/client/sharing/likes.jsx:24
__( "Automatically share your posts to social networks", "jetpack" ), // _inc/client/sharing/publicize.jsx:72
_x( "Publicize connections", "Settings header", "jetpack" ), // _inc/client/sharing/publicize.jsx:61
__( "Connect your user account to WordPress.com to use this feature", "jetpack" ), // _inc/client/sharing/publicize.jsx:53
__( "Connect your social media accounts", "jetpack" ), // _inc/client/sharing/publicize.jsx:45
__( "Add sharing buttons to your posts", "jetpack" ), // _inc/client/sharing/share-buttons.jsx:59
_x( "Sharing buttons", "Settings header", "jetpack" ), // _inc/client/sharing/share-buttons.jsx:49
__( "Connect your user account to WordPress.com to use this feature", "jetpack" ), // _inc/client/sharing/share-buttons.jsx:43
__( "Configure your sharing buttons", "jetpack" ), // _inc/client/sharing/share-buttons.jsx:40
__( "Configure your sharing buttons", "jetpack" ), // _inc/client/sharing/share-buttons.jsx:36
__( "View your earnings", "jetpack" ), // _inc/client/traffic/ads.jsx:101
__( "Display an additional ad at the top of each page", "jetpack" ), // _inc/client/traffic/ads.jsx:94
__( "Enable ads and display an ad below each post", "jetpack" ), // _inc/client/traffic/ads.jsx:85
__( "By activating ads, you agree to the Automattic Ads {{link}}Terms of Service{{/link}}.", "jetpack" ), // _inc/client/traffic/ads.jsx:70
__( "Show ads on the first article on your home page or at the end of every page and post. Place additional ads at the top of your site and to any widget area to increase your earnings.", "jetpack" ), // _inc/client/traffic/ads.jsx:67
_x( "Ads", "Ads header", "jetpack" ), // _inc/client/traffic/ads.jsx:58
__( "Configure your Google Analytics settings", "jetpack" ), // _inc/client/traffic/google-analytics.jsx:44
__( "Google Analytics is a free service that complements our {{a}}built-in stats{{/a}} with different insights into your traffic. WordPress.com stats and Google Analytics use different methods to identify and track activity on your site, so they will normally show slightly different totals for your visits, views, etc.", "jetpack" ), // _inc/client/traffic/google-analytics.jsx:31
_x( "Google Analytics", "Settings header", "jetpack" ), // _inc/client/traffic/google-analytics.jsx:27
/* translators: It refers to the category where a post was found. Used in an example preview. */
__( "In \"Upgrade\"", "jetpack" ), // _inc/client/traffic/related-posts.jsx:132
__( "Upgrade Focus: VideoPress For Weddings", "jetpack" ), // _inc/client/traffic/related-posts.jsx:131
/* translators: It refers to the category where a post was found. Used in an example preview. */
__( "In \"Mobile\"", "jetpack" ), // _inc/client/traffic/related-posts.jsx:125
__( "The WordPress for Android App Gets a Big Facelift", "jetpack" ), // _inc/client/traffic/related-posts.jsx:124
/* translators: It refers to the category where a post was found. Used in an example preview. */
__( "In \"Mobile\"", "jetpack" ), // _inc/client/traffic/related-posts.jsx:118
__( "Big iPhone/iPad Update Now Available", "jetpack" ), // _inc/client/traffic/related-posts.jsx:117
__( "Related", "jetpack" ), // _inc/client/traffic/related-posts.jsx:110
_x( "Preview", "A header for a preview area in the configuration screen.", "jetpack" ), // _inc/client/traffic/related-posts.jsx:105
__( "{{span}}You can now also configure related posts in the Customizer. {{ExternalLink}}Try it out!{{/ExternalLink}}{{/span}}", "jetpack" ), // _inc/client/traffic/related-posts.jsx:95
__( "Use a large and visually striking layout", "jetpack" ), // _inc/client/traffic/related-posts.jsx:90
__( "Show a \"Related\" header to more clearly separate the related section from posts", "jetpack" ), // _inc/client/traffic/related-posts.jsx:80
__( "Show related content after posts", "jetpack" ), // _inc/client/traffic/related-posts.jsx:69
__( "Configure your SEO settings", "jetpack" ), // _inc/client/traffic/seo.jsx:45
__( "You can tweak these settings if you'd like more advanced control. Read more about what you can do to {{a}}optimize your site's SEO{{/a}}.", "jetpack" ), // _inc/client/traffic/seo.jsx:33
_x( "Search engine optimization", "Settings header", "jetpack" ), // _inc/client/traffic/seo.jsx:27
__( "Allow stats reports to be viewed by", "jetpack" ), // _inc/client/traffic/site-stats.jsx:221
__( "Count logged in page views from", "jetpack" ), // _inc/client/traffic/site-stats.jsx:205
__( "The image helps collect stats, but should work when hidden.", "jetpack" ), // _inc/client/traffic/site-stats.jsx:199
__( "Hide the stats smiley face image", "jetpack" ), // _inc/client/traffic/site-stats.jsx:194
__( "Put a chart showing 48 hours of views in the admin bar", "jetpack" ), // _inc/client/traffic/site-stats.jsx:181
__( "Collecting valuable traffic stats and insights", "jetpack" ), // _inc/client/traffic/site-stats.jsx:165
_x( "Site stats", "Settings header", "jetpack" ), // _inc/client/traffic/site-stats.jsx:160
__( "Activate Site Stats", "jetpack" ), // _inc/client/traffic/site-stats.jsx:147
__( "{{a}}Activate Site Stats{{/a}} to see detailed stats, likes, followers, subscribers, and more! {{a1}}Learn More{{/a1}}", "jetpack" ), // _inc/client/traffic/site-stats.jsx:132
__( "Unavailable in Dev Mode", "jetpack" ), // _inc/client/traffic/site-stats.jsx:131
__( "Jetpack Stats Icon", "jetpack" ), // _inc/client/traffic/site-stats.jsx:126
__( "Your site is not currently accessible to search engines. You might have \"Search Engine Visibility\" disabled in your {{a}}Reading Settings{{/a}}.", "jetpack" ), // _inc/client/traffic/sitemaps.jsx:69
__( "Your sitemap is automatically sent to all major search engines for indexing.", "jetpack" ), // _inc/client/traffic/sitemaps.jsx:57
__( "Generate XML sitemaps", "jetpack" ), // _inc/client/traffic/sitemaps.jsx:51
__( "Yandex", "jetpack" ), // _inc/client/traffic/verification-services.jsx:90
__( "Pinterest", "jetpack" ), // _inc/client/traffic/verification-services.jsx:85
__( "Bing", "jetpack" ), // _inc/client/traffic/verification-services.jsx:80
__( "Google", "jetpack" ), // _inc/client/traffic/verification-services.jsx:75
__( "Note that {{b}}verifying your site with these services is not necessary{{/b}} in order for your site to be indexed by search engines. To use these advanced search engine tools and verify your site with a service, paste the HTML Tag code below. Read the {{support}}full instructions{{/support}} if you are having trouble. Supported verification services: {{google}}Google Search Console{{/google}}, {{bing}}Bing Webmaster Center{{/bing}}, {{pinterest}}Pinterest Site Verification{{/pinterest}}, and {{yandex}}Yandex.Webmaster{{/yandex}}.", "jetpack" ), // _inc/client/traffic/verification-services.jsx:32
_x( "Composing", "Settings header", "jetpack" ), // _inc/client/writing/composing.jsx:242
__( "Add a phrase", "jetpack" ), // _inc/client/writing/composing.jsx:149
__( "Ignored Phrases", "jetpack" ), // _inc/client/writing/composing.jsx:144
__( "Redundant Phrases", "jetpack" ), // _inc/client/writing/composing.jsx:140
__( "Phrases to Avoid", "jetpack" ), // _inc/client/writing/composing.jsx:139
__( "Passive Voice", "jetpack" ), // _inc/client/writing/composing.jsx:138
__( "Jargon", "jetpack" ), // _inc/client/writing/composing.jsx:137
__( "Hidden Verbs", "jetpack" ), // _inc/client/writing/composing.jsx:136
__( "Double Negatives", "jetpack" ), // _inc/client/writing/composing.jsx:135
__( "Diacritical Marks", "jetpack" ), // _inc/client/writing/composing.jsx:134
__( "Complex Phrases", "jetpack" ), // _inc/client/writing/composing.jsx:133
__( "Clichés", "jetpack" ), // _inc/client/writing/composing.jsx:132
__( "Bias Language", "jetpack" ), // _inc/client/writing/composing.jsx:131
__( "Enable proofreading for the following grammar and style rules: ", "jetpack" ), // _inc/client/writing/composing.jsx:129
__( "English Options", "jetpack" ), // _inc/client/writing/composing.jsx:127
__( "Use automatically detected language to proofread posts and pages", "jetpack" ), // _inc/client/writing/composing.jsx:122
__( "The proofreader supports English, French, German, Portuguese and Spanish.", "jetpack" ), // _inc/client/writing/composing.jsx:117
__( "Automatic Language Detection", "jetpack" ), // _inc/client/writing/composing.jsx:114
__( "A post or page is updated", "jetpack" ), // _inc/client/writing/composing.jsx:111
__( "A post or page is first published", "jetpack" ), // _inc/client/writing/composing.jsx:110
__( "Automatically proofread content when: ", "jetpack" ), // _inc/client/writing/composing.jsx:108
__( "Proofreading", "jetpack" ), // _inc/client/writing/composing.jsx:106
__( "Add, organize, and display {{portfolioLink}}portfolios{{/portfolioLink}}. If your theme doesn’t support portfolios yet, you can display them using the shortcode ( [portfolios] )", "jetpack" ), // _inc/client/writing/custom-content-types.jsx:95
__( "Portfolios", "jetpack" ), // _inc/client/writing/custom-content-types.jsx:88
__( "Add, organize, and display {{testimonialLink}}testimonials{{/testimonialLink}}. If your theme doesn’t support testimonials yet, you can display them using the shortcode	( [testimonials] ).", "jetpack" ), // _inc/client/writing/custom-content-types.jsx:72
__( "Testimonials", "jetpack" ), // _inc/client/writing/custom-content-types.jsx:65
__( "Writing tools available to you will be shown here when an administrator enables them.", "jetpack" ), // _inc/client/writing/index.jsx:97
__( "Connect your user account to WordPress.com to use this feature", "jetpack" ), // _inc/client/writing/masterbar.jsx:54
__( "The WordPress.com toolbar replaces the default admin bar and offers quick links to the Reader, all your sites, your WordPress.com profile, and notifications. Centralize your WordPress experience with a single global toolbar.", "jetpack" ), // _inc/client/writing/masterbar.jsx:39
__( "Enable the WordPress.com toolbar", "jetpack" ), // _inc/client/writing/masterbar.jsx:36
_x( "WordPress.com toolbar", "Settings header", "jetpack" ), // _inc/client/writing/masterbar.jsx:26
__( "Media", "jetpack" ), // _inc/client/writing/media.jsx:179
__( "Color scheme", "jetpack" ), // _inc/client/writing/media.jsx:142
__( "Show photo metadata (Exif) in carousel, when available", "jetpack" ), // _inc/client/writing/media.jsx:136
__( "Must be enabled to use tiled galleries.", "jetpack" ), // _inc/client/writing/media.jsx:108
__( "Connect your user account to WordPress.com to use this feature", "jetpack" ), // _inc/client/writing/post-by-email.jsx:113
__( "Create address", "jetpack" ), // _inc/client/writing/post-by-email.jsx:100
__( "Regenerate address", "jetpack" ), // _inc/client/writing/post-by-email.jsx:99
__( "Highlight and copy the following text to your clipboard:", "jetpack" ), // _inc/client/writing/post-by-email.jsx:91
__( "Copied!", "jetpack" ), // _inc/client/writing/post-by-email.jsx:90
_x( "Copy", "verb", "jetpack" ), // _inc/client/writing/post-by-email.jsx:89
__( "Email Address", "jetpack" ), // _inc/client/writing/post-by-email.jsx:85
__( "Show an ad for the WordPress mobile apps in the footer of the mobile theme", "jetpack" ), // _inc/client/writing/theme-enhancements.jsx:208
__( "Show featured images", "jetpack" ), // _inc/client/writing/theme-enhancements.jsx:204
__( "Use excerpts instead of full posts on front page and archive pages", "jetpack" ), // _inc/client/writing/theme-enhancements.jsx:200
__( "Learn more", "jetpack" ), // _inc/client/writing/theme-enhancements.jsx:182
__( "Learn more about adding support for Infinite Scroll to your theme.", "jetpack" ), // _inc/client/writing/theme-enhancements.jsx:180
__( "Theme support required.", "jetpack" ), // _inc/client/writing/theme-enhancements.jsx:178
__( "Load more posts as the reader scrolls down", "jetpack" ), // _inc/client/writing/theme-enhancements.jsx:139
__( "Load more posts in page with a button", "jetpack" ), // _inc/client/writing/theme-enhancements.jsx:135
__( "Load more posts using the default theme behavior", "jetpack" ), // _inc/client/writing/theme-enhancements.jsx:131
__( "Theme enhancements", "jetpack" ), // _inc/client/writing/theme-enhancements.jsx:121
__( "Connect your account to WordPress.com to view more stats", "jetpack" ), // _inc/client/at-a-glance/stats/dash-stats-bottom.jsx:146
__( "{{button}}View more stats on WordPress.com {{/button}}", "jetpack" ), // _inc/client/at-a-glance/stats/dash-stats-bottom.jsx:124
__( "{{button}}View detailed stats{{/button}}", "jetpack" ), // _inc/client/at-a-glance/stats/dash-stats-bottom.jsx:113
/* translators: Referring to a number of comments */
__( "All-time comments", "jetpack" ), // _inc/client/at-a-glance/stats/dash-stats-bottom.jsx:100
/* translators: Referring to a number of page views */
__( "All-time views", "jetpack" ), // _inc/client/at-a-glance/stats/dash-stats-bottom.jsx:92
_n( "%(number)s View", "%(number)s Views", 1, "jetpack" ), // _inc/client/at-a-glance/stats/dash-stats-bottom.jsx:74
/* translators: Referring to a number of page views */
__( "Best overall day", "jetpack" ), // _inc/client/at-a-glance/stats/dash-stats-bottom.jsx:69
/* translators: Referring to a number of page views */
__( "Views today", "jetpack" ), // _inc/client/at-a-glance/stats/dash-stats-bottom.jsx:65
__( "Site Stats", "jetpack" ), // _inc/client/at-a-glance/stats/index.jsx:225
__( "Months", "jetpack" ), // _inc/client/at-a-glance/stats/index.jsx:193
__( "Weeks", "jetpack" ), // _inc/client/at-a-glance/stats/index.jsx:188
__( "Days", "jetpack" ), // _inc/client/at-a-glance/stats/index.jsx:183
__( "Activate Site Stats", "jetpack" ), // _inc/client/at-a-glance/stats/index.jsx:166
__( "{{a}}Activate Site Stats{{/a}} to see detailed stats, likes, followers, subscribers, and more! {{a1}}Learn More{{/a1}}", "jetpack" ), // _inc/client/at-a-glance/stats/index.jsx:151
__( "Unavailable in Dev Mode", "jetpack" ), // _inc/client/at-a-glance/stats/index.jsx:150
__( "Jetpack Stats Icon", "jetpack" ), // _inc/client/at-a-glance/stats/index.jsx:146
__( "Something happened while loading stats. Please try again later or {{a}}view your stats now on WordPress.com{{/a}}", "jetpack" ), // _inc/client/at-a-glance/stats/index.jsx:112
__( "Click to view detailed stats.", "jetpack" ), // _inc/client/at-a-glance/stats/index.jsx:89
__( "Views: %(numberOfViews)s", "jetpack" ), // _inc/client/at-a-glance/stats/index.jsx:87
__( "Week of %(date)s", "jetpack" ), // _inc/client/at-a-glance/stats/index.jsx:71
__( "I already use this app.", "jetpack" ), // _inc/client/components/apps-card/index.jsx:78
__( "Download the free apps", "jetpack" ), // _inc/client/components/apps-card/index.jsx:72
__( "Manage all your sites from a single dashboard: publish content, track stats, moderate comments, and so much more from anywhere in the world.", "jetpack" ), // _inc/client/components/apps-card/index.jsx:65
__( "Get WordPress Apps for every device", "jetpack" ), // _inc/client/components/apps-card/index.jsx:61
__( "Connect Jetpack", "jetpack" ), // _inc/client/components/connect-button/index.jsx:129
__( "Manage site connection", "jetpack" ), // _inc/client/components/connect-button/index.jsx:114
__( "Link to WordPress.com", "jetpack" ), // _inc/client/components/connect-button/index.jsx:94
__( "Unlink me from WordPress.com", "jetpack" ), // _inc/client/components/connect-button/index.jsx:77
_x( "Paid", "Short label appearing near a paid feature configuration block.", "jetpack" ), // _inc/client/components/dash-item/index.jsx:132
__( "Settings", "jetpack" ), // _inc/client/components/dash-item/index.jsx:118
__( "Active", "jetpack" ), // _inc/client/components/dash-item/index.jsx:107
_x( "Updates needed", "Short warning message", "jetpack" ), // _inc/client/components/dash-item/index.jsx:101
_x( "Settings", "Noun. Displayed to screen readers.", "jetpack" ), // _inc/client/components/dash-section-header/index.jsx:52
_x( "Privacy", "Shorthand for Privacy Policy.", "jetpack" ), // _inc/client/components/footer/index.jsx:174
__( "Automattic's Privacy Policy", "jetpack" ), // _inc/client/components/footer/index.jsx:172
_x( "Terms", "Shorthand for Terms of Service.", "jetpack" ), // _inc/client/components/footer/index.jsx:163
__( "WordPress.com Terms of Service", "jetpack" ), // _inc/client/components/footer/index.jsx:161
__( "An Automattic Airline", "jetpack" ), // _inc/client/components/footer/index.jsx:135
_x( "Dev Tools", "Navigation item.", "jetpack" ), // _inc/client/components/footer/index.jsx:116
_x( "Debug", "Navigation item. Noun. Links to a debugger tool for Jetpack.", "jetpack" ), // _inc/client/components/footer/index.jsx:99
__( "Test your site’s compatibility with Jetpack.", "jetpack" ), // _inc/client/components/footer/index.jsx:97
_x( "Reset Options (dev only)", "Navigation item.", "jetpack" ), // _inc/client/components/footer/index.jsx:82
__( "This will reset all Jetpack options, are you sure?", "jetpack" ), // _inc/client/components/footer/index.jsx:32
__( "Save Settings", "jetpack" ), // _inc/client/components/forms/index.jsx:143
__( "Saving…", "jetpack" ), // _inc/client/components/forms/index.jsx:143
__( "No account? Create one for free…", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:222
__( "Join the millions of users who rely on Jetpack to enhance and secure their sites. We're passionate about WordPress and here to make your life easier.", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:214
__( "Jetpack is supported by some of the most technical and passionate people in the community. They're located around the globe and ready to help you.", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:199
__( "Did we mention free, professional support?", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:196
__( "Jetpack utilizes the state-of-the-art WordPress.com content delivery network to load your gorgeous imagery super fast. Optimized for any device, and its completely free.", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:180
__( "Lightning fast, optimized images", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:177
__( "Never fall behind on a security release or waste time updating multiple sites.", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:167
__( "Automatic site updates.", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:164
_x( "Manage", "Header. Noun: Manage is a module of Jetpack.", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:160
__( "Stress less. Monitor will send you real-time alerts if your site ever goes down.", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:154
__( "Live site monitoring.", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:151
_x( "Monitor", "Header. Noun: Monitor is a module of Jetpack.", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:147
__( "Gain peace of mind with Protect, the tool that has blocked billions of login attacks across millions of sites.", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:138
__( "Block site attacks.", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:135
_x( "Protect", "Header. Noun: Protect is a module of Jetpack.", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:131
__( "Jetpack blocks malicious log in attempts, lets you know if your site goes down, and can automatically update your plugins, so you don’t have to worry.", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:120
__( "Site security and peace of mind", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:117
__( "Jetpack harnesses the power of WordPress.com to show you detailed insights about your visitors, what they’re reading, and where they’re coming from.", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:102
__( "Track your growth", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:99
__( "Keep visitors engaged by giving them more to share and read with Related Posts.", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:92
__( "Increase page views.", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:89
_x( "Related Posts", "Header. Noun: Related posts is a module of Jetpack.", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:85
__( "Give visitors the tools to share and subscribe to your content.", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:79
__( "Build a community.", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:76
__( "Sharing & Like Buttons", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:72
__( "Use Publicize to automatically share your posts with friends, followers, and the world.", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:66
__( "Automated social marketing.", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:63
_x( "Publicize", "Header. Noun: Publicize is a module of Jetpack", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:59
__( "Jetpack has many traffic and engagement tools to help you get more viewers to your site and keep them there.", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:47
__( "Drive more traffic to your site", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:44
__( "No account? Create one for free…", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:35
__( "Please connect to or create a WordPress.com account to start using Jetpack. This will enable powerful security, traffic, and customization services.", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:30
__( "Welcome to Jetpack", "jetpack" ), // _inc/client/components/jetpack-connect/index.jsx:25
__( "Read more about Jetpack benefits", "jetpack" ), // _inc/client/components/jetpack-disconnect-dialog/index.jsx:188
_x( "Disconnect", "A caption for a button to disconnect.", "jetpack" ), // _inc/client/components/jetpack-disconnect-dialog/index.jsx:181
_x( "Stay connected", "A caption for a button to cancel disconnection.", "jetpack" ), // _inc/client/components/jetpack-disconnect-dialog/index.jsx:173
__( "By disconnecting %(siteName)s from WordPress.com you will no longer have access to the following:", "jetpack" ), // _inc/client/components/jetpack-disconnect-dialog/index.jsx:151
__( "Disconnect Jetpack", "jetpack" ), // _inc/client/components/jetpack-disconnect-dialog/index.jsx:146
__( "Unlimited, high-speed image hosting", "jetpack" ), // _inc/client/components/jetpack-disconnect-dialog/index.jsx:112
__( "Brute force attack protection and uptime monitoring", "jetpack" ), // _inc/client/components/jetpack-disconnect-dialog/index.jsx:108
__( "Site stats, related content, and sharing tools", "jetpack" ), // _inc/client/components/jetpack-disconnect-dialog/index.jsx:104
__( "SEO preview tools", "jetpack" ), // _inc/client/components/jetpack-disconnect-dialog/index.jsx:97
__( "Unlimited high-speed video hosting", "jetpack" ), // _inc/client/components/jetpack-disconnect-dialog/index.jsx:93
__( "Priority support", "jetpack" ), // _inc/client/components/jetpack-disconnect-dialog/index.jsx:89
__( "Daily, automated malware scanning with automated resolution", "jetpack" ), // _inc/client/components/jetpack-disconnect-dialog/index.jsx:85
__( "Daily, automated backups (unlimited storage)", "jetpack" ), // _inc/client/components/jetpack-disconnect-dialog/index.jsx:81
__( "13Gb of high-speed video hosting", "jetpack" ), // _inc/client/components/jetpack-disconnect-dialog/index.jsx:73
__( "Priority support", "jetpack" ), // _inc/client/components/jetpack-disconnect-dialog/index.jsx:69
__( "Daily, automated malware scanning", "jetpack" ), // _inc/client/components/jetpack-disconnect-dialog/index.jsx:65
__( "Daily, automated backups (unlimited storage)", "jetpack" ), // _inc/client/components/jetpack-disconnect-dialog/index.jsx:61
__( "Spam filtering", "jetpack" ), // _inc/client/components/jetpack-disconnect-dialog/index.jsx:53
__( "Priority support", "jetpack" ), // _inc/client/components/jetpack-disconnect-dialog/index.jsx:49
__( "Daily, automated backups (unlimited storage)", "jetpack" ), // _inc/client/components/jetpack-disconnect-dialog/index.jsx:45
__( "Would you tell us why? Just {{a}}answering two simple questions{{/a}} would help us improve Jetpack.", "jetpack" ), // _inc/client/components/jetpack-notices/dismissable.jsx:40
__( "You have successfully disconnected Jetpack", "jetpack" ), // _inc/client/components/jetpack-notices/dismissable.jsx:37
__( "Let us know!", "jetpack" ), // _inc/client/components/jetpack-notices/feedback-dash-request.jsx:36
__( "What would you like to see on your Jetpack Dashboard?", "jetpack" ), // _inc/client/components/jetpack-notices/feedback-dash-request.jsx:31
__( "This site is not connected to WordPress.com. Please ask the site administrator to connect.", "jetpack" ), // _inc/client/components/jetpack-notices/index.jsx:223
__( "Link to WordPress.com", "jetpack" ), // _inc/client/components/jetpack-notices/index.jsx:180
__( "You, %(userName)s, are not connected to WordPress.com.", "jetpack" ), // _inc/client/components/jetpack-notices/index.jsx:165
__( "Learn More", "jetpack" ), // _inc/client/components/jetpack-notices/index.jsx:134
__( "Currently in {{a}}Development Mode{{/a}} (some features are disabled) because: {{reasons/}}", "jetpack" ), // _inc/client/components/jetpack-notices/index.jsx:119
__( "{{li}}Your site URL lacks a dot (e.g. http://localhost){{/li}}", "jetpack" ), // _inc/client/components/jetpack-notices/index.jsx:110
__( "{{li}}The JETPACK_DEV_DEBUG constant is defined{{/li}}", "jetpack" ), // _inc/client/components/jetpack-notices/index.jsx:101
__( "{{li}}The jetpack_development_mode filter is active{{/li}}", "jetpack" ), // _inc/client/components/jetpack-notices/index.jsx:92
__( "More Info", "jetpack" ), // _inc/client/components/jetpack-notices/index.jsx:67
__( "You are running Jetpack on a staging server.", "jetpack" ), // _inc/client/components/jetpack-notices/index.jsx:57
__( "Submit Beta feedback", "jetpack" ), // _inc/client/components/jetpack-notices/index.jsx:34
__( "You are currently running a development version of Jetpack.", "jetpack" ), // _inc/client/components/jetpack-notices/index.jsx:29
__( "Learn More", "jetpack" ), // _inc/client/components/jetpack-notices/state-notices.jsx:200
__( "Your server is misconfigured, which means that Jetpack Protect is unable to effectively protect your site.", "jetpack" ), // _inc/client/components/jetpack-notices/state-notices.jsx:194
__( "You're fueled up and ready to go.", "jetpack" ), // _inc/client/components/jetpack-notices/state-notices.jsx:190
__( "You're fueled up and ready to go, Jetpack is now active.", "jetpack" ), // _inc/client/components/jetpack-notices/state-notices.jsx:186
__( "Your Jetpack is already connected.", "jetpack" ), // _inc/client/components/jetpack-notices/state-notices.jsx:182
__( "Welcome to {{s}}Jetpack %(jetpack_version)s{{/s}}!", "jetpack" ), // _inc/client/components/jetpack-notices/state-notices.jsx:170
__( "{{s}}Your Jetpack has a glitch.{{/s}}  We're sorry for the inconvenience. Please try again later, if the issue continues please contact support with this message: %(error_key)s", "jetpack" ), // _inc/client/components/jetpack-notices/state-notices.jsx:129
__( "Jetpack could not contact WordPress.com: %(error_key)s.  This usually means something is incorrectly configured on your web host.", "jetpack" ), // _inc/client/components/jetpack-notices/state-notices.jsx:90
__( "WordPress.com is currently having problems and is unable to fuel up your Jetpack.  Please try again later.", "jetpack" ), // _inc/client/components/jetpack-notices/state-notices.jsx:86
__( "{{s}}Your Jetpack has a glitch.{{/s}} Connecting this site with WordPress.com is not possible. This usually means your site is not publicly accessible (localhost).", "jetpack" ), // _inc/client/components/jetpack-notices/state-notices.jsx:73
__( "Your website needs to be publicly accessible to use Jetpack: %(error_key)s", "jetpack" ), // _inc/client/components/jetpack-notices/state-notices.jsx:64
__( "There was an issue connecting your Jetpack. Please click \"Connect to WordPress.com\" again.", "jetpack" ), // _inc/client/components/jetpack-notices/state-notices.jsx:60
__( "We had an issue connecting Jetpack; deactivate then reactivate the Jetpack plugin, then connect again.", "jetpack" ), // _inc/client/components/jetpack-notices/state-notices.jsx:57
__( "You need to stay logged in to your WordPress blog while you authorize Jetpack.", "jetpack" ), // _inc/client/components/jetpack-notices/state-notices.jsx:54
__( "{{p}}Would you mind telling us why you did not complete the Jetpack connection in this {{a}}2 question survey{{/a}}?{{/p}}{{p}}A Jetpack connection is required for our free security and traffic features to work.{{/p}}", "jetpack" ), // _inc/client/components/jetpack-notices/state-notices.jsx:43
__( "Cheatin' uh?", "jetpack" ), // _inc/client/components/jetpack-notices/state-notices.jsx:40
__( "Skip this step", "jetpack" ), // _inc/client/components/jumpstart/index.jsx:87
__( "Skip the Jetpack Jumpstart process", "jetpack" ), // _inc/client/components/jumpstart/index.jsx:86
__( "Features can be activated or deactivated at any time.", "jetpack" ), // _inc/client/components/jumpstart/index.jsx:76
__( "Jetpack's recommended features include:", "jetpack" ), // _inc/client/components/jumpstart/index.jsx:68
__( "Activate Recommended Features", "jetpack" ), // _inc/client/components/jumpstart/index.jsx:58
__( "Quickly enhance your site by activating Jetpack's recommended features.", "jetpack" ), // _inc/client/components/jumpstart/index.jsx:55
__( "Jump Start your Site", "jetpack" ), // _inc/client/components/jumpstart/index.jsx:49
__( "Settings", "jetpack" ), // _inc/client/components/masthead/index.jsx:83
__( "Dashboard", "jetpack" ), // _inc/client/components/masthead/index.jsx:75
__( "Display an ad unit at the top of your site.", "jetpack" ), // _inc/client/components/module-settings/index.jsx:198
__( "By default ads are shown at the end of every page, post, or the first article on your front page. You can also add them to the top of your site and to any widget area to increase your earnings!", "jetpack" ), // _inc/client/components/module-settings/index.jsx:192
__( "{{link}}Configure your Monitor notification settings on WordPress.com{{/link}}", "jetpack" ), // _inc/client/components/module-settings/index.jsx:175
__( "{{a}}Manage Likes visibility from the Sharing Module Settings{{/a}}", "jetpack" ), // _inc/client/components/module-settings/index.jsx:155
__( "WordPress.com Likes are:", "jetpack" ), // _inc/client/components/module-settings/index.jsx:143
_x( "Preview", "Noun, a header for a preview block in a configuration screen.", "jetpack" ), // _inc/client/components/module-settings/index.jsx:121
__( "Use a large and visually striking layout", "jetpack" ), // _inc/client/components/module-settings/index.jsx:119
__( "Show a \"Related\" header to more clearly separate the related section from posts", "jetpack" ), // _inc/client/components/module-settings/index.jsx:115
__( "{{span}}You can now also configure related posts in the Customizer. {{ExternalLink}}Try it out!{{/ExternalLink}}{{/span}}", "jetpack" ), // _inc/client/components/module-settings/index.jsx:101
_x( "Related", "A header for a block of related posts.", "jetpack" ), // _inc/client/components/module-settings/index.jsx:80
__( "Upgrade Focus: VideoPress For Weddings", "jetpack" ), // _inc/client/components/module-settings/index.jsx:73
__( "The WordPress for Android App Gets a Big Facelift", "jetpack" ), // _inc/client/components/module-settings/index.jsx:70
__( "Big iPhone/iPad Update Now Available", "jetpack" ), // _inc/client/components/module-settings/index.jsx:67
__( "Subscriber", "jetpack" ), // _inc/client/components/module-settings/index.jsx:48
__( "To get started, click on Add Media in your post editor and upload a video; we’ll take care of the rest!", "jetpack" ), // _inc/client/components/module-settings/index.jsx:34
__( "The easiest way to upload ad-free and unbranded videos to your site. You get stats on video playback and shares and the player is lightweight and responsive.", "jetpack" ), // _inc/client/components/module-settings/index.jsx:31
__( "{{link}}Configure your %(module_slug)s Settings {{/link}}", "jetpack" ), // _inc/client/components/module-settings/modules-per-tab-page.jsx:152
__( "{{link}}Configure your %(module_slug)s Settings {{/link}}", "jetpack" ), // _inc/client/components/module-settings/modules-per-tab-page.jsx:130
__( "Real-time offsite backups with automated restores deliver peace-of-mind, so you can focus on writing great content and increasing traffic while we protect every aspect of your investment. Upgrade today.", "jetpack" ), // _inc/client/components/module-settings/modules-per-tab-page.jsx:123
__( "Let search engines and visitors know that you are serious about your websites integrity by upgrading Jetpack. Our anti-spam tools will eliminate comment spam, protect your SEO, and make it easier for visitors to stay in touch.", "jetpack" ), // _inc/client/components/module-settings/modules-per-tab-page.jsx:121
__( "This module has no configuration options", "jetpack" ), // _inc/client/components/module-settings/modules-per-tab-page.jsx:114
__( "Configure Google Analytics settings.", "jetpack" ), // _inc/client/components/module-settings/modules-per-tab-page.jsx:101
__( "Google Analytics is a free service that complements our {{a}}built-in stats{{/a}} with different insights into your traffic. WordPress.com stats and Google Analytics use different methods to identify and track activity on your site, so they will normally show slightly different totals for your visits, views, etc.", "jetpack" ), // _inc/client/components/module-settings/modules-per-tab-page.jsx:86
__( "Configure your SEO settings.", "jetpack" ), // _inc/client/components/module-settings/modules-per-tab-page.jsx:74
__( "Activate this module to use the advanced SEO tools.", "jetpack" ), // _inc/client/components/module-settings/modules-per-tab-page.jsx:68
__( "Make sure your site is easily found on search engines with SEO tools for your content and social posts.", "jetpack" ), // _inc/client/components/module-settings/modules-per-tab-page.jsx:60
__( "Configure your Security Scans", "jetpack" ), // _inc/client/components/module-settings/modules-per-tab-page.jsx:53
__( "You can see the information about security scanning in the \"At a Glance\" section.", "jetpack" ), // _inc/client/components/module-settings/modules-per-tab-page.jsx:50
__( "Upgrade Jetpack and our state-of-the-art security scanner will hunt out malicious files and report them immediately so that you're never unaware of what is happening on your website.", "jetpack" ), // _inc/client/components/module-settings/modules-per-tab-page.jsx:44
__( "Search your content.", "jetpack" ), // _inc/client/components/module-settings/modules-per-tab-page.jsx:34
_x( "At a Glance", "Navigation item.", "jetpack" ), // _inc/client/components/navigation/index.jsx:54
_x( "Plans", "Navigation item.", "jetpack" ), // _inc/client/components/navigation/index.jsx:44
_x( "At a Glance", "Navigation item.", "jetpack" ), // _inc/client/components/navigation/index.jsx:38
_x( "Writing", "Navigation item.", "jetpack" ), // _inc/client/components/navigation-settings/index.jsx:227
_x( "Sharing", "Navigation item.", "jetpack" ), // _inc/client/components/navigation-settings/index.jsx:212
_x( "Security", "Navigation item.", "jetpack" ), // _inc/client/components/navigation-settings/index.jsx:193
_x( "Traffic", "Navigation item.", "jetpack" ), // _inc/client/components/navigation-settings/index.jsx:179
_x( "Discussion", "Navigation item.", "jetpack" ), // _inc/client/components/navigation-settings/index.jsx:161
_x( "Sharing", "Navigation item.", "jetpack" ), // _inc/client/components/navigation-settings/index.jsx:146
_x( "Writing", "Navigation item.", "jetpack" ), // _inc/client/components/navigation-settings/index.jsx:132
__( "Search for a Jetpack feature.", "jetpack" ), // _inc/client/components/navigation-settings/index.jsx:67
_x( "Save settings", "Button caption", "jetpack" ), // _inc/client/components/settings-card/index.jsx:264
_x( "Saving…", "Button caption", "jetpack" ), // _inc/client/components/settings-card/index.jsx:263
__( "Protect your site from spam.", "jetpack" ), // _inc/client/components/settings-card/index.jsx:188
__( "Help your content get found and shared with SEO tools.", "jetpack" ), // _inc/client/components/settings-card/index.jsx:171
__( "Integrate easily with Google Analytics.", "jetpack" ), // _inc/client/components/settings-card/index.jsx:156
__( "Protect against data loss, malware, and malicious attacks.", "jetpack" ), // _inc/client/components/settings-card/index.jsx:141
__( "Real-time site backups and automatic threat resolution.", "jetpack" ), // _inc/client/components/settings-card/index.jsx:128
__( "Generate income with high-quality ads.", "jetpack" ), // _inc/client/components/settings-card/index.jsx:111
__( "Host fast, high-quality, ad-free video.", "jetpack" ), // _inc/client/components/settings-card/index.jsx:92
_x( "Upgrade", "A caption for a button to upgrade an existing paid feature to a higher tier.", "jetpack" ), // _inc/client/components/settings-card/index.jsx:79
__( "Upgrade", "jetpack" ), // _inc/client/components/support-card/index.jsx:111
__( "Get a faster resolution to your support questions.", "jetpack" ), // _inc/client/components/support-card/index.jsx:109
__( "Search our support site", "jetpack" ), // _inc/client/components/support-card/index.jsx:101
__( "Ask a question", "jetpack" ), // _inc/client/components/support-card/index.jsx:92
__( "Your paid plan gives you access to prioritized Jetpack support.", "jetpack" ), // _inc/client/components/support-card/index.jsx:81
__( "Jetpack comes with free, basic support for all users.", "jetpack" ), // _inc/client/components/support-card/index.jsx:80
__( "We're here to help", "jetpack" ), // _inc/client/components/support-card/index.jsx:75
__( "Learn more", "jetpack" ), // _inc/client/components/settings-group/index.jsx:77
__( "Learn more", "jetpack" ), // _inc/client/components/settings-group/index.jsx:70
);
/* THIS IS THE END OF THE GENERATED FILE */