<?php
class Foobar { use const Baz }
class Foobar { use const abstract }
class Foobar { use const and }
class Foobar { use const array }
class Foobar { use const as }
class Foobar { use const break }
class Foobar { use const callable }
class Foobar { use const case }
class Foobar { use const catch }
class Foobar { use const class }
class Foobar { use const clone }
class Foobar { use const const }
class Foobar { use const continue }
class Foobar { use const declare }
class Foobar { use const default }
class Foobar { use const do }
class Foobar { use const else }
class Foobar { use const elseif }
class Foobar { use const enddeclare }
class Foobar { use const endfor }
class Foobar { use const endforeach }
class Foobar { use const endif }
class Foobar { use const endswitch }
class Foobar { use const endwhile }
class Foobar { use const extends }
class Foobar { use const final }
class Foobar { use const finally }
class Foobar { use const for }
class Foobar { use const foreach }
class Foobar { use const function }
class Foobar { use const global }
class Foobar { use const goto }
class Foobar { use const if }
class Foobar { use const implements }
class Foobar { use const interface }
class Foobar { use const instanceof }
class Foobar { use const insteadof }
class Foobar { use const namespace }
class Foobar { use const new }
class Foobar { use const or }
class Foobar { use const private }
class Foobar { use const protected }
class Foobar { use const public }
class Foobar { use const static }
class Foobar { use const switch }
class Foobar { use const throw }
class Foobar { use const trait }
class Foobar { use const try }
class Foobar { use const use }
class Foobar { use const var }
class Foobar { use const while }
class Foobar { use const xor }
class Foobar { use const __CLASS__ }
class Foobar { use const __DIR__ }
class Foobar { use const __FILE__ }
class Foobar { use const __FUNCTION__ }
class Foobar { use const __METHOD__ }
class Foobar { use const __NAMESPACE__ }
