.mobile-video-image {
	display: block!important;
}


#featured article .post-title > a {
    border: 2px solid #fff;
}

#featured article .post-title h2 {
	padding: 10px;
	margin-left: -10px;
}

#featured article .post-title h2[data-has-caption="1"] {
	background-color: #000;
}

#featured {
	margin-top: -130px!important;
}

div.orbit-wrapper {
	z-index: -100;
	position: relative!important;
}

.single-portfolio #sidebar {
	position: relative!important;
	margin-left: 0px!important;
	top: 0px!Important;
	bottom: 0px!important;
}

body, #header-outer {
	padding-right: 0px!Important;
}

 body[data-smooth-scrolling="1"] .orbit-wrapper div.slider-nav span.right {
  right: 0px!important; 
}


#header-outer header#top nav {
	display: block!important;
}

.full-width-section.parallax_section {
	background-position: center center!important;
	background-attachment: scroll!important;
}

.container-wrap {
	margin-top: -100px;
}

#page-header-bg[data-parallax="0"] {
	margin-top: -70px;
}

.video-texture {
	display: none!important;
}


.swiper-slide .video-wrap object {
    display: block;
	margin: 0 auto!important;
    width: 1400px!important;
    height: 800px!important;	
}

.swiper-slide .mejs-container, .swiper-slide .video-wrap {
	position: static!important;
}

.swiper-slide .mejs-container .mejs-controls {
	visibility: visible!important;
	display: block!important;
}

.nectar-slider-loading {
  display: none!important;	
}


.swiper-container .slider-prev, .swiper-container .slider-next {
	background-image: url("../img/ie8-transparency.png");	
}

.slider-prev.dark-cs, .slider-next.dark-cs {
	background-image: url("../img/ie8-transparency-white.png");	
}

.swiper-container .slider-prev .slide-count span, .swiper-container .slider-next .slide-count span {
	-ms-filter: "alpha(opacity=0)";
} 

.swiper-container .slide-count i {
	display: block;
	-ms-filter: "alpha(opacity=0)";
}

.portfolio-loading {
   display: none;
}

.parallax_slider_outer.first-section {
	margin-top: -70px!important;
}

#full_width_portfolio .parallax_slider_outer.first-section  {
	margin-top: 0px!important;
}

.swiper-slide .button.transparent a, .col.light .nectar-button.see-through {
	border: 2px solid #fff!important;
}

.swiper-slide[data-color-scheme="dark"] .content .button.transparent a, .nectar-button.see-through {
    border: 2px solid #000!important;
}

.swiper-slide .content p, .swiper-slide .content h2, .swiper-slide .content .buttons {
	padding-top: 0px!important;
}


/* keep this in here to avoid the flash of everything on its own row while loading */
.span_1 { width: 6.5%; }
.span_2 { width: 15.0%; }
.span_3 { width: 23.5%; }
.span_4 { width: 32.0%; }
.span_5 { width: 40.5%; }
.span_6 { width: 49.0%; }
.span_7 { width: 57.5%; }
.span_8 { width: 66.0%; }
.span_9 { width: 74.5%; }
.span_10 { width: 83.0%; }
.span_11 { width: 91.5%; }
.span_12 { width: 100%; }
