.wpml-settings-container .spinner{float:none;margin-top:-1px}#icl_save_default_button,#icl_cancel_default_button,#icl_theme_localization{display:none}.icl_setup_wizard_step{float:left;width:25%;text-align:center;font-size:17px}[dir='rtl'] .icl_setup_wizard_step{float:right}#icl_setup_wizard_progress{margin:15px 0 3px 0;width:100%;height:10px;background-color:#ccc}#icl_setup_wizard_progress_bar{height:10px;background-color:#21759b}#colorPickerDiv{z-index:999}#colorPickerDiv a{padding:1px;border-bottom:0;text-decoration:none}#colorPickerDiv a:hover{padding:1px;border-bottom:0;text-decoration:none}#icl_edit_languages_table td{vertical-align:middle}#icl_edit_languages_table input{width:70px}#icl_edit_languages_table .radio,#icl_edit_languages_table .file{width:auto}#icl_edit_languages_info ul{padding:15px;list-style:square inside}.wpml-section-languages .selected{font-weight:bold}.wpml-section-languages .wpml-major,.wpml-section-languages .wpml-selected{font-weight:600}.wpml-section-languages .available-languages,.wpml-section-languages .enabled-languages{margin:0 0 20px 0}.wpml-section-languages .available-languages{overflow:hidden;-webkit-column-width:180px;-moz-column-width:180px;column-width:180px}.wpml-section-languages .available-languages li img{vertical-align:-1px;margin-right:4px}.wpml-section-languages .enabled-languages input[type="radio"]{display:none}.wpml-section-languages .inactive-content-table{width:auto}.wpml-section-languages .inactive-content-table td{text-align:right}.wpml-section-languages .inactive-content-table tfoot td{font-weight:bold}.branch-3-8 .enabled-languages input[type="radio"]{left:-22px;top:7px}.wpml-section-url-format ul table{margin:10px 0}
