<a class="icl_tt_term_name lowlight" id="<%= trid + '-' + lang %>" title="<%= langs[ lang ].label %>: <%= labels.addTranslation %>" >
	<i class="otgs-ico-add"></i>
</a>
<div id="<%= trid + '-popup-' + lang %>"></div>
