<?php

// autoload_namespaces.php @generated by Composer

$vendorDir = dirname(dirname(__FILE__));
$baseDir = dirname($vendorDir);

return array(
    'xrstf\\Composer52' => array($vendorDir . '/xrstf/composer-php52/lib'),
    'Composer\\Installers\\' => array($vendorDir . '/composer/installers/src'),
);
