/*!
* Do not modify this file directly.  It is compiled SASS code.
*/
.jp-jitm {
  border-radius: 2px;
  max-width: 100%;
  margin: 2em auto 1em auto;
  padding: .85em;
  background: #fcfcfc;
  border: 1px solid #dedede;
  text-align: center;
}

.jp-jitm:before, .jp-jitm:after {
  content: "";
  display: table;
}

.jp-jitm:after {
  clear: both;
}

#screen-meta-links + .jp-jitm {
  margin: 3em auto 0 1.5385em;
}

.jp-jitm .activate {
  margin-top: .5em;
}

.jp-jitm .jp-emblem {
  width: 25px;
  height: 25px;
  margin: .40em auto 0 1em;
}

.jp-jitm svg {
  width: 100%;
  height: 100%;
}

.jp-jitm path {
  fill: #8cc258;
}

.jp-jitm.woo-jitm path {
  fill: #96588a;
}

.jp-jitm .dismiss {
  margin: 0;
  text-decoration: none;
  float: left;
}

.jp-jitm .dismiss:before {
  color: #666;
  font: 400 15px/1 dashicons;
  content: '\f158';
}

.jp-jitm p {
  font-size: 1em;
  line-height: 165%;
}

.jp-jitm .j-spinner {
  margin: 8px 0 0;
  height: 17px;
  width: 17px;
}

.jp-jitm .hide {
  display: none;
}

form[name=post] > .jp-jitm:first-of-type {
  margin-top: 1em;
}

@media (min-width: 800px) {
  .jp-jitm .jp-emblem, .jp-jitm p {
    float: right;
    /* margin: .5em 1em 0 .5em;
			padding-top: 4px; */
  }
  .jp-jitm .jp-emblem {
    width: 20px;
    height: 20px;
    margin-left: .5em;
  }
  .jp-jitm p {
    margin: .40em 0 0 1em;
  }
  .jp-jitm p + p {
    margin: 0;
    padding: 0;
  }
  .jp-jitm .activate {
    margin-top: 0;
  }
}

@media (max-width: 1100px) {
  .jp-jitm {
    margin: 2.5em .5em .5em .75em;
  }
  form[name=post] > .jp-jitm:first-of-type {
    margin-right: auto;
    margin-left: auto;
  }
}

@media (max-width: 800px) {
  .jp-jitm .jp-emblem {
    margin: .40em auto 0 auto;
  }
}

@media (min-width: 1100px) {
  .update-core-php .jp-jitm {
    margin: 3em auto 0 2em;
  }
}

.jetpack-connected .media-modal-content .uploader-inline-content {
  top: 20%;
}

@media only screen and (min-width: 800px) {
  .media-menu .jp-jitm {
    margin: 10px 0;
    padding: 5px 5px 15px;
    border-width: 1px 0;
  }
  .media-menu .jp-jitm .jp-emblem {
    margin: 20px 15px 0 10px;
  }
  .media-menu .jp-jitm .msg {
    width: 75%;
    text-align: right;
    margin: 0 0 10px;
  }
  .media-menu .jp-jitm .msg + p {
    text-align: center;
    width: 100%;
  }
}

@media only screen and (max-width: 900px) {
  .media-menu .jp-jitm {
    display: none;
    margin: .5em 3%;
    border-width: 1px;
  }
  .media-menu .jp-jitm .msg {
    margin-top: 20px;
    width: 88%;
    margin-right: auto;
    margin-left: auto;
  }
  .media-menu.visible .jp-jitm {
    display: block;
  }
}

/*# sourceMappingURL=jetpack-admin-jitm-rtl.css.map */
