.otgs-notice{position:relative}.otgs-notice .otgs-notice-actions{margin-bottom:1em}.otgs-notice.message,.otgs-notice.info,.otgs-notice.warning,.otgs-notice.error{clear:both;background:#fff;border-left:4px solid #fff;box-shadow:0 1px 1px 0 rgba(0,0,0,0.1);margin:5px 15px 2px;padding:1px 12px}.wrap .otgs-notice.message,.wrap .otgs-notice.info,.wrap .otgs-notice.warning,.wrap .otgs-notice.error{margin:5px 0 15px}.otgs-notice.message p,.otgs-notice.info p,.otgs-notice.warning p,.otgs-notice.error p{margin:.5em 0;padding:2px}.otgs-notice.message ul,.otgs-notice.message ol,.otgs-notice.info ul,.otgs-notice.info ol,.otgs-notice.warning ul,.otgs-notice.warning ol,.otgs-notice.error ul,.otgs-notice.error ol{max-height:10em;overflow:auto;padding-left:2em !important}.otgs-notice.message ul,.otgs-notice.info ul,.otgs-notice.warning ul,.otgs-notice.error ul{list-style-type:disc}.otgs-notice.message.right>*,.otgs-notice.info.right>*,.otgs-notice.warning.right>*,.otgs-notice.error.right>*{text-align:right}.otgs-notice.message.center>*,.otgs-notice.info.center>*,.otgs-notice.warning.center>*,.otgs-notice.error.center>*{text-align:center}.otgs-notice.message.center>*>ul,.otgs-notice.message.center>*>ol,.otgs-notice.info.center>*>ul,.otgs-notice.info.center>*>ol,.otgs-notice.warning.center>*>ul,.otgs-notice.warning.center>*>ol,.otgs-notice.error.center>*>ul,.otgs-notice.error.center>*>ol{text-align:left;padding-left:1em !important;font-weight:normal}.otgs-notice.message.center>*>ul,.otgs-notice.info.center>*>ul,.otgs-notice.warning.center>*>ul,.otgs-notice.error.center>*>ul{list-style-type:disc}.otgs-notice.message{border-left:4px solid #9bc8f0}.otgs-notice.info{border-left:4px solid #d5e8f9}.otgs-notice.inline{border-left:4px solid #d5e8f9}.otgs-notice.warning,.otgs-notice.error{border-left:4px solid #fff366}.otgs-notice.error{border-color:#dd3d36;background-color:#FFE6E5}.otgs-notice.is-dismissible{position:relative;padding-right:38px}.otgs-notice.is-dismissible .notice-dismiss{text-decoration:none}.otgs-notice.is-dismissible p [class*="button-"]{margin:-5px 5px}.otgs-notice .otgs-notice-collapse-hide{position:absolute;top:0;right:1px;border:none;margin:0;padding:9px;background:0 0;color:#b4b9be;cursor:pointer}.otgs-notice .otgs-notice-collapse-hide:before{background:0 0;color:#b4b9be;content:"\f460";display:block;font:400 16px/20px dashicons;speak:none;height:20px;text-align:center;width:20px;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}.otgs-notice .otgs-notice-collapse-hide:hover:before{color:#d54e21}.otgs-notice .otgs-notice-collapsed-text .otgs-notice-collapse-show{color:#b4b9be;cursor:pointer}.otgs-notice .otgs-notice-collapsed-text .otgs-notice-collapse-show:before{background:0 0;color:#b4b9be;content:"\f132";display:block;font:400 16px/20px dashicons;speak:none;height:20px;width:20px;float:left;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}.otgs-notice .otgs-notice-collapsed-text .otgs-notice-collapse-show:hover:before{color:#d54e21}.otgs-notice .notice-collapse-header{display:none}.otgs-notice .notice-action-link{display:block;position:absolute;right:1em;bottom:1em}[dir="rtl"] .otgs-notice .notice-action-link{right:auto;left:1em}
