<?php

// autoload_52.php generated by xrstf/composer-php52

require_once dirname(__FILE__) . '/composer'.'/autoload_real_52.php';

return ComposerAutoloaderInitb475fed6016da8fa03e743e036b80517::getLoader();
