��X<?php exit; ?>a:1:{s:7:"content";O:8:"stdClass":24:{s:2:"ID";i:6873;s:11:"post_author";s:1:"1";s:9:"post_date";s:19:"2016-07-12 15:49:45";s:13:"post_date_gmt";s:19:"2016-07-12 07:49:45";s:12:"post_content";s:1726:"[vc_row type="full_width_background" scene_position="center" text_color="light" text_align="left" color_overlay="#00afcb" overlay_strength="0.95"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][divider line_type="No Line"][vc_column_text]
<h2>弘迅科技資訊有限公司</h2>
<h2>Vision Beta IT Solutions Ltd.</h2>
<h5>九龍官塘創業街36號華基中心1602室</h5>
[/vc_column_text][vc_column_text]<iframe style="border: 0;" src="https://www.google.com/maps/embed?pb=!1m18!1m12!1m3!1d3691.0403696915528!2d114.2169883153857!3d22.314312948024053!2m3!1f0!2f0!3f0!3m2!1i1024!2i768!4f13.1!3m3!1m2!1s0x34040148ef0a1209%3A0xe6b85b5693db5906!2sVbits+-+Vision+Beta+IT+Solutions+Ltd.!5e0!3m2!1sen!2shk!4v1468312710249" width="600" height="200" frameborder="0" allowfullscreen="allowfullscreen"></iframe>[/vc_column_text][divider line_type="No Line"][vc_column_text][icon color="Accent-Color" animation_speed="Slow" size="small" icon_size="" animation_delay="" image="fa-envelope-o"] 電郵 : cs@vbits.com.hk[/vc_column_text][divider line_type="No Line"][vc_column_text][icon color="Accent-Color" animation_speed="Slow" size="small" icon_size="" animation_delay="" image="fa-phone"] 電話 : 3622 5593[/vc_column_text][divider line_type="No Line"][vc_column_text][icon color="Accent-Color" animation_speed="Slow" size="small" icon_size="" animation_delay="" image="fa-fax"] 傳真 : 3753 5415[/vc_column_text][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][contact-form-7 id="6878"][/vc_column][/vc_row]";s:10:"post_title";s:12:"聯絡我們";s:12:"post_excerpt";s:0:"";s:11:"post_status";s:7:"publish";s:14:"comment_status";s:6:"closed";s:11:"ping_status";s:6:"closed";s:13:"post_password";s:0:"";s:9:"post_name";s:7:"contact";s:7:"to_ping";s:0:"";s:6:"pinged";s:0:"";s:13:"post_modified";s:19:"2016-08-04 13:05:55";s:17:"post_modified_gmt";s:19:"2016-08-04 05:05:55";s:21:"post_content_filtered";s:0:"";s:11:"post_parent";i:0;s:4:"guid";s:41:"http://web2.vbits.com.hk/zh/?page_id=6873";s:10:"menu_order";i:0;s:9:"post_type";s:4:"page";s:14:"post_mime_type";s:0:"";s:13:"comment_count";s:1:"0";s:6:"filter";s:3:"raw";}}