<?php
class Foobar { use BazTrait { oldfunction as private Baz } }
class Foobar { use BazTrait { oldfunction as private abstract } }
class Foobar { use BazTrait { oldfunction as private and } }
class Foobar { use BazTrait { oldfunction as private array } }
class Foobar { use BazTrait { oldfunction as private as } }
class Foobar { use BazTrait { oldfunction as private break } }
class Foobar { use BazTrait { oldfunction as private callable } }
class Foobar { use BazTrait { oldfunction as private case } }
class Foobar { use BazTrait { oldfunction as private catch } }
class Foobar { use BazTrait { oldfunction as private class } }
class Foobar { use BazTrait { oldfunction as private clone } }
class Foobar { use BazTrait { oldfunction as private const } }
class Foobar { use BazTrait { oldfunction as private continue } }
class Foobar { use BazTrait { oldfunction as private declare } }
class Foobar { use BazTrait { oldfunction as private default } }
class Foobar { use BazTrait { oldfunction as private do } }
class Foobar { use BazTrait { oldfunction as private else } }
class Foobar { use BazTrait { oldfunction as private elseif } }
class Foobar { use BazTrait { oldfunction as private enddeclare } }
class Foobar { use BazTrait { oldfunction as private endfor } }
class Foobar { use BazTrait { oldfunction as private endforeach } }
class Foobar { use BazTrait { oldfunction as private endif } }
class Foobar { use BazTrait { oldfunction as private endswitch } }
class Foobar { use BazTrait { oldfunction as private endwhile } }
class Foobar { use BazTrait { oldfunction as private extends } }
class Foobar { use BazTrait { oldfunction as private final } }
class Foobar { use BazTrait { oldfunction as private finally } }
class Foobar { use BazTrait { oldfunction as private for } }
class Foobar { use BazTrait { oldfunction as private foreach } }
class Foobar { use BazTrait { oldfunction as private function } }
class Foobar { use BazTrait { oldfunction as private global } }
class Foobar { use BazTrait { oldfunction as private goto } }
class Foobar { use BazTrait { oldfunction as private if } }
class Foobar { use BazTrait { oldfunction as private implements } }
class Foobar { use BazTrait { oldfunction as private interface } }
class Foobar { use BazTrait { oldfunction as private instanceof } }
class Foobar { use BazTrait { oldfunction as private insteadof } }
class Foobar { use BazTrait { oldfunction as private namespace } }
class Foobar { use BazTrait { oldfunction as private new } }
class Foobar { use BazTrait { oldfunction as private or } }
class Foobar { use BazTrait { oldfunction as private private } }
class Foobar { use BazTrait { oldfunction as private protected } }
class Foobar { use BazTrait { oldfunction as private public } }
class Foobar { use BazTrait { oldfunction as private static } }
class Foobar { use BazTrait { oldfunction as private switch } }
class Foobar { use BazTrait { oldfunction as private throw } }
class Foobar { use BazTrait { oldfunction as private trait } }
class Foobar { use BazTrait { oldfunction as private try } }
class Foobar { use BazTrait { oldfunction as private use } }
class Foobar { use BazTrait { oldfunction as private var } }
class Foobar { use BazTrait { oldfunction as private while } }
class Foobar { use BazTrait { oldfunction as private xor } }
class Foobar { use BazTrait { oldfunction as private __CLASS__ } }
class Foobar { use BazTrait { oldfunction as private __DIR__ } }
class Foobar { use BazTrait { oldfunction as private __FILE__ } }
class Foobar { use BazTrait { oldfunction as private __FUNCTION__ } }
class Foobar { use BazTrait { oldfunction as private __METHOD__ } }
class Foobar { use BazTrait { oldfunction as private __NAMESPACE__ } }
