<?php

// Array of Elusive Icons
// Contributed by @WhatJustHappened
// Last updated: 14 Sept. 2013
    function get_font_icons() {
        $elusiveIcons = array(
            'el el-address-book-alt',
            'el el-address-book',
            'el el-adjust-alt',
            'el el-adjust',
            'el el-adult',
            'el el-align-center',
            'el el-align-justify',
            'el el-align-left',
            'el el-align-right',
            'el el-arrow-down',
            'el el-arrow-left',
            'el el-arrow-right',
            'el el-arrow-up',
            'el el-asl',
            'el el-asterisk',
            'el el-backward',
            'el el-ban-circle',
            'el el-barcode',
            'el el-behance',
            'el el-bell',
            'el el-blind',
            'el el-blogger',
            'el el-bold',
            'el el-book',
            'el el-bookmark-empty',
            'el el-bookmark',
            'el el-braille',
            'el el-briefcase',
            'el el-broom',
            'el el-brush',
            'el el-bulb',
            'el el-bullhorn',
            'el el-calendar-sign',
            'el el-calendar',
            'el el-camera',
            'el el-car',
            'el el-caret-down',
            'el el-caret-left',
            'el el-caret-right',
            'el el-caret-up',
            'el el-cc',
            'el el-certificate',
            'el el-check-empty',
            'el el-check',
            'el el-chevron-down',
            'el el-chevron-left',
            'el el-chevron-right',
            'el el-chevron-up',
            'el el-child',
            'el el-circle-arrow-down',
            'el el-circle-arrow-left',
            'el el-circle-arrow-right',
            'el el-circle-arrow-up',
            'el el-cloud-alt',
            'el el-cloud',
            'el el-cog-alt',
            'el el-cog',
            'el el-cogs',
            'el el-comment-alt',
            'el el-comment',
            'el el-compass-alt',
            'el el-compass',
            'el el-credit-card',
            'el el-css',
            'el el-dashboard',
            'el el-delicious',
            'el el-deviantart',
            'el el-digg',
            'el el-download-alt',
            'el el-download',
            'el el-dribbble',
            'el el-edit',
            'el el-eject',
            'el el-envelope-alt',
            'el el-envelope',
            'el el-error-alt',
            'el el-error',
            'el el-eur',
            'el el-exclamation-sign',
            'el el-eye-close',
            'el el-eye-open',
            'el el-facebook',
            'el el-facetime-video',
            'el el-fast-backward',
            'el el-fast-forward',
            'el el-female',
            'el el-file-alt',
            'el el-file-edit-alt',
            'el el-file-edit',
            'el el-file-new-alt',
            'el el-file-new',
            'el el-file',
            'el el-film',
            'el el-filter',
            'el el-fire',
            'el el-flag-alt',
            'el el-flag',
            'el el-flickr',
            'el el-folder-close',
            'el el-folder-open',
            'el el-folder-sign',
            'el el-folder',
            'el el-font',
            'el el-fontsize',
            'el el-fork',
            'el el-forward-alt',
            'el el-forward',
            'el el-foursquare',
            'el el-friendfeed-rect',
            'el el-friendfeed',
            'el el-fullscreen',
            'el el-gbp',
            'el el-gift',
            'el el-github-text',
            'el el-github',
            'el el-glass',
            'el el-glasses',
            'el el-globe-alt',
            'el el-globe',
            'el el-googleplus',
            'el el-graph-alt',
            'el el-graph',
            'el el-group-alt',
            'el el-group',
            'el el-guidedog',
            'el el-hand-down',
            'el el-hand-left',
            'el el-hand-right',
            'el el-hand-up',
            'el el-hdd',
            'el el-headphones',
            'el el-hearing-impaired',
            'el el-heart-alt',
            'el el-heart-empty',
            'el el-heart',
            'el el-home-alt',
            'el el-home',
            'el el-hourglass',
            'el el-idea-alt',
            'el el-idea',
            'el el-inbox-alt',
            'el el-inbox-box',
            'el el-inbox',
            'el el-indent-left',
            'el el-indent-right',
            'el el-info-sign',
            'el el-instagram',
            'el el-iphone-home',
            'el el-italic',
            'el el-key',
            'el el-laptop-alt',
            'el el-laptop',
            'el el-lastfm',
            'el el-leaf',
            'el el-lines',
            'el el-link',
            'el el-linkedin',
            'el el-list-alt',
            'el el-list',
            'el el-livejournal',
            'el el-lock-alt',
            'el el-lock',
            'el el-magic',
            'el el-magnet',
            'el el-male',
            'el el-map-marker-alt',
            'el el-map-marker',
            'el el-mic-alt',
            'el el-mic',
            'el el-minus-sign',
            'el el-minus',
            'el el-move',
            'el el-music',
            'el el-myspace',
            'el el-network',
            'el el-off',
            'el el-ok-circle',
            'el el-ok-sign',
            'el el-ok',
            'el el-opensource',
            'el el-paper-clip-alt',
            'el el-paper-clip',
            'el el-path',
            'el el-pause-alt',
            'el el-pause',
            'el el-pencil-alt',
            'el el-pencil',
            'el el-person',
            'el el-phone-alt',
            'el el-phone',
            'el el-photo-alt',
            'el el-photo',
            'el el-picasa',
            'el el-picture',
            'el el-pinterest',
            'el el-plane',
            'el el-play-alt',
            'el el-play-circle',
            'el el-play',
            'el el-plus-sign',
            'el el-plus',
            'el el-podcast',
            'el el-print',
            'el el-puzzle',
            'el el-qrcode',
            'el el-question-sign',
            'el el-question',
            'el el-quotes-alt',
            'el el-quotes',
            'el el-random',
            'el el-record',
            'el el-reddit',
            'el el-refresh',
            'el el-remove-circle',
            'el el-remove-sign',
            'el el-remove',
            'el el-repeat-alt',
            'el el-repeat',
            'el el-resize-full',
            'el el-resize-horizontal',
            'el el-resize-small',
            'el el-resize-vertical',
            'el el-return-key',
            'el el-retweet',
            'el el-reverse-alt',
            'el el-road',
            'el el-rss',
            'el el-scissors',
            'el el-screen-alt',
            'el el-screen',
            'el el-screenshot',
            'el el-search-alt',
            'el el-search',
            'el el-share-alt',
            'el el-share',
            'el el-shopping-cart-sign',
            'el el-shopping-cart',
            'el el-signal',
            'el el-skype',
            'el el-slideshare',
            'el el-smiley-alt',
            'el el-smiley',
            'el el-soundcloud',
            'el el-speaker',
            'el el-spotify',
            'el el-stackoverflow',
            'el el-star-alt',
            'el el-star-empty',
            'el el-star',
            'el el-step-backward',
            'el el-step-forward',
            'el el-stop-alt',
            'el el-stop',
            'el el-stumbleupon',
            'el el-tag',
            'el el-tags',
            'el el-tasks',
            'el el-text-height',
            'el el-text-width',
            'el el-th-large',
            'el el-th-list',
            'el el-th',
            'el el-thumbs-down',
            'el el-thumbs-up',
            'el el-time-alt',
            'el el-time',
            'el el-tint',
            'el el-torso',
            'el el-trash-alt',
            'el el-trash',
            'el el-tumblr',
            'el el-twitter',
            'el el-universal-access',
            'el el-unlock-alt',
            'el el-unlock',
            'el el-upload',
            'el el-usd',
            'el el-user',
            'el el-viadeo',
            'el el-video-alt',
            'el el-video-chat',
            'el el-video',
            'el el-view-mode',
            'el el-vimeo',
            'el el-vkontakte',
            'el el-volume-down',
            'el el-volume-off',
            'el el-volume-up',
            'el el-w3c',
            'el el-warning-sign',
            'el el-website-alt',
            'el el-website',
            'el el-wheelchair',
            'el el-wordpress',
            'el el-wrench-alt',
            'el el-wrench',
            'el el-youtube',
            'el el-zoom-in',
            'el el-zoom-out'
        );

        return $elusiveIcons;
    }

    add_filter( 'redux/font-icons', 'get_font_icons' );
