<?php
define('Baz', 1);
define('abstract', 1);
define('and', 1);
define('array', 1);
define('as', 1);
define('break', 1);
define('callable', 1);
define('case', 1);
define('catch', 1);
define('class', 1);
define('clone', 1);
define('const', 1);
define('continue', 1);
define('declare', 1);
define('default', 1);
define('do', 1);
define('else', 1);
define('elseif', 1);
define('enddeclare', 1);
define('endfor', 1);
define('endforeach', 1);
define('endif', 1);
define('endswitch', 1);
define('endwhile', 1);
define('extends', 1);
define('final', 1);
define('finally', 1);
define('for', 1);
define('foreach', 1);
define('function', 1);
define('global', 1);
define('goto', 1);
define('if', 1);
define('implements', 1);
define('interface', 1);
define('instanceof', 1);
define('insteadof', 1);
define('namespace', 1);
define('new', 1);
define('or', 1);
define('private', 1);
define('protected', 1);
define('public', 1);
define('static', 1);
define('switch', 1);
define('throw', 1);
define('trait', 1);
define('try', 1);
define('use', 1);
define('var', 1);
define('while', 1);
define('xor', 1);
define('__CLASS__', 1);
define('__DIR__', 1);
define('__FILE__', 1);
define('__FUNCTION__', 1);
define('__METHOD__', 1);
define('__NAMESPACE__', 1);
