<?php
class Foobar { use Baz }
class Foobar { use abstract }
class Foobar { use and }
class Foobar { use array }
class Foobar { use as }
class Foobar { use break }
class Foobar { use callable }
class Foobar { use case }
class Foobar { use catch }
class Foobar { use class }
class Foobar { use clone }
class Foobar { use const }
class Foobar { use continue }
class Foobar { use declare }
class Foobar { use default }
class Foobar { use do }
class Foobar { use else }
class Foobar { use elseif }
class Foobar { use enddeclare }
class Foobar { use endfor }
class Foobar { use endforeach }
class Foobar { use endif }
class Foobar { use endswitch }
class Foobar { use endwhile }
class Foobar { use extends }
class Foobar { use final }
class Foobar { use finally }
class Foobar { use for }
class Foobar { use foreach }
class Foobar { use function }
class Foobar { use global }
class Foobar { use goto }
class Foobar { use if }
class Foobar { use implements }
class Foobar { use interface }
class Foobar { use instanceof }
class Foobar { use insteadof }
class Foobar { use namespace }
class Foobar { use new }
class Foobar { use or }
class Foobar { use private }
class Foobar { use protected }
class Foobar { use public }
class Foobar { use static }
class Foobar { use switch }
class Foobar { use throw }
class Foobar { use trait }
class Foobar { use try }
class Foobar { use use }
class Foobar { use var }
class Foobar { use while }
class Foobar { use xor }
class Foobar { use __CLASS__ }
class Foobar { use __DIR__ }
class Foobar { use __FILE__ }
class Foobar { use __FUNCTION__ }
class Foobar { use __METHOD__ }
class Foobar { use __NAMESPACE__ }
