<div class="js-wpml-ls-preview-wrapper wpml-ls-preview-wrapper{% if class %} {{ class }}{% endif %}">
    <strong class="wpml-ls-preview-label">{{ strings.misc.label_preview }}</strong>
    <span class="spinner"></span>
    <div class="js-wpml-ls-preview">{{ preview.html|raw }}</div>
</div>