��X<?php exit; ?>a:1:{s:7:"content";O:8:"stdClass":24:{s:2:"ID";i:6811;s:11:"post_author";s:1:"1";s:9:"post_date";s:19:"2016-07-05 14:04:13";s:13:"post_date_gmt";s:19:"2016-07-05 06:04:13";s:12:"post_content";s:21781:"[vc_row type="full_width_background" scene_position="center" text_color="light" text_align="left" color_overlay="#00afcb" overlay_strength="0.95"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/1"][page_submenu sticky="true"][page_link link_url="#it-outsourcing" title="IT外判" tab_id="1466414153530-3" id="1467700142480-2"] [/page_link][page_link link_url="#networking" title="網路工程" tab_id="1466414153918-10" id="1467704817061-10"] [/page_link][page_link title="伺服器部署" tab_id="1466498762904-5" link_url="#server-deployment" id="1467705126788-10"][/page_link][page_link title="新辦公室IT設置" tab_id="1466583163302-0" link_url="#new-office-setup" id="1467710986497-1"][/page_link][page_link title="電腦及週邊產品" tab_id="1466585451279-9" link_url="#it-product" id="1467861466157-8"][/page_link][page_link title="使用授權" tab_id="1466585560752-0" link_url="#licensing" id="1467862890725-0"][/page_link][/page_submenu][/vc_column][/vc_row][vc_row type="full_width_background" scene_position="center" text_color="light" text_align="left" top_padding="5%" id="it-outsourcing" color_overlay="#00afcb" overlay_strength="0.95"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][vc_column_text]
<h2>IT外判</h2>
[/vc_column_text][vc_column_text]透過我們的IT外判服務，你可以用一個合理的投資得到一個IT部門的支援。我們還會定時評估及更新貴公司的IT狀況，與不斷更新的IT資訊接軌。[/vc_column_text][image_with_animation image_url="6426" alignment="center" animation="Fade In" delay="150"][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1467699700362{margin-bottom: 18px !important;}"]
<h5>技術支援</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Extra-Color-3" enable_animation="true"]
<ul>
 	<li><span style="color: #a2d8e6;">定時上門檢查</span></li>
 	<li><span style="color: #a2d8e6;">遠端技術支援</span></li>
 	<li><span style="color: #a2d8e6;">防毒軟件更新</span></li>
 	<li><span style="color: #a2d8e6;">電腦維修排解</span></li>
 	<li><span style="color: #a2d8e6;">技術支援記錄</span></li>
</ul>
[/fancy-ul][vc_column_text css=".vc_custom_1467700166399{margin-bottom: 18px !important;}"]
<h5>網路安全</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Extra-Color-3" enable_animation="true"]
<ul>
 	<li><span style="color: #a2d8e6;">防火牆管理</span></li>
 	<li><span style="color: #a2d8e6;">網路流量管理</span></li>
 	<li><span style="color: #a2d8e6;">VPN 虛擬私人網路管理</span></li>
 	<li><span style="color: #a2d8e6;">網路流量控制</span></li>
 	<li><span style="color: #a2d8e6;">使用者網上行為管理</span></li>
</ul>
[/fancy-ul][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1467699980626{margin-bottom: 18px !important;}"]
<h5>伺服器保養</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Extra-Color-3" enable_animation="true"]
<ul>
 	<li><span style="color: #a2d8e6;">伺服器效能檢查</span></li>
 	<li><span style="color: #a2d8e6;">伺服器安全性檢查</span></li>
 	<li><span style="color: #a2d8e6;">伺服器備份方案</span></li>
 	<li><span style="color: #a2d8e6;">Windows伺服器部署</span></li>
 	<li><span style="color: #a2d8e6;">Linux伺服器部署</span></li>
</ul>
[/fancy-ul][vc_column_text css=".vc_custom_1467700460259{margin-bottom: 18px !important;}"]
<h5>主動式IT風險評估</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Extra-Color-3" enable_animation="true"]
<ul>
 	<li><span style="color: #a2d8e6;">軟件/系統更新</span></li>
 	<li><span style="color: #a2d8e6;">IT工作環境評估</span></li>
 	<li><span style="color: #a2d8e6;">硬件生命週期管理</span></li>
 	<li><span style="color: #a2d8e6;">軟件許可證管理</span></li>
 	<li><span style="color: #a2d8e6;">IT 培訓</span></li>
</ul>
[/fancy-ul][/vc_column][/vc_row][vc_row type="full_width_background" scene_position="center" text_color="dark" text_align="left" top_padding="5%" bottom_padding="5%" id="networking" overlay_strength="0.3"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][vc_column_text]
<h2>網路工程</h2>
[/vc_column_text][vc_column_text]我們有不同的網路架構的豐富經驗，如區域網路(LAN)、無線區域網路(WLAN)及閉路電視系統(CCTV)，無論是小型公司網路或全層的網路架構，我們都能順利解決。[/vc_column_text][image_with_animation image_url="6448" alignment="center" animation="Fade In" delay="150"][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1467702027365{margin-bottom: 18px !important;}"]
<h5>區域網路工程(LAN)</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">結構化佈線設計Cat5e/Cat6</span></li>
 	<li><span style="color: #00afcb;">網路面版安裝</span></li>
 	<li><span style="color: #00afcb;">網路佈線</span></li>
 	<li><span style="color: #00afcb;">階段式工程報告</span></li>
 	<li><span style="color: #00afcb;">網線測試</span></li>
</ul>
[/fancy-ul][vc_column_text css=".vc_custom_1467703317600{margin-bottom: 18px !important;}"]
<h5>閉路電視系統工程(CCTV)</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">鏡頭安裝</span></li>
 	<li><span style="color: #00afcb;">鏡頭設置</span></li>
 	<li><span style="color: #00afcb;">數碼視頻錄像(DVR)設置</span></li>
 	<li><span style="color: #00afcb;">網線喉管佈設及安裝</span></li>
 	<li><span style="color: #00afcb;">後備電源設備安裝</span></li>
</ul>
[/fancy-ul][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1467702062222{margin-bottom: 18px !important;}"]
<h5>無線區域網路工程(WLAN)</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">無線區域網路規劃</span></li>
 	<li><span style="color: #00afcb;">無線存取點安裝</span></li>
 	<li><span style="color: #00afcb;">無線區域網路管理</span></li>
 	<li><span style="color: #00afcb;">無線區域網路信號規劃</span></li>
 	<li><span style="color: #00afcb;">無線區域網路規劃測試</span></li>
</ul>
[/fancy-ul][vc_column_text css=".vc_custom_1467703851330{margin-bottom: 18px !important;}"]
<h5>網路設備設置</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">寬頻安裝及設定</span></li>
 	<li><span style="color: #00afcb;">防火牆/整合式威脅管理設定</span></li>
 	<li><span style="color: #00afcb;">網路交換器安裝</span></li>
 	<li><span style="color: #00afcb;">伺服器機櫃安裝</span></li>
 	<li><span style="color: #00afcb;">後備電源設備安裝</span></li>
</ul>
[/fancy-ul][/vc_column][/vc_row][vc_row type="full_width_background" scene_position="center" text_color="dark" text_align="left" top_padding="5%" bottom_padding="5%" id="server-deployment" color_overlay="#00afcb" overlay_strength="0.3"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][vc_column_text]
<h2>伺服器部署</h2>
[/vc_column_text][vc_column_text]我們對部署伺服器規劃擁有非常豐富的經驗，由小型的NAS部署到機房級別的伺服器架構，都能為你辦妥。[/vc_column_text][image_with_animation image_url="6462" alignment="center" animation="Fade In" delay="150"][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1467705508516{margin-bottom: 18px !important;}"]
<h5>微軟視窗伺服器</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">Windows Domain controller server</span></li>
 	<li><span style="color: #00afcb;">Windows File server</span></li>
 	<li><span style="color: #00afcb;">Windows Hyper-V server</span></li>
 	<li><span style="color: #00afcb;">Windows DNS server</span></li>
 	<li><span style="color: #00afcb;">Windows DHCP server</span></li>
 	<li><span style="color: #00afcb;">Windows FTP server</span></li>
 	<li><span style="color: #00afcb;">Windows Remote Terminal server</span></li>
 	<li><span style="color: #00afcb;">Windows System Center server</span></li>
 	<li><span style="color: #00afcb;">Windows Data Protection server</span></li>
 	<li><span style="color: #00afcb;">Windows Exchange server</span></li>
</ul>
[/fancy-ul][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1467705877445{margin-bottom: 18px !important;}"]
<h5>Linux 伺服器</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">Linux Apache server</span></li>
 	<li><span style="color: #00afcb;">LAMP server stack</span></li>
 	<li><span style="color: #00afcb;">BIND DNS server</span></li>
 	<li><span style="color: #00afcb;">Mail / POP3 server</span></li>
 	<li><span style="color: #00afcb;">Database server</span></li>
 	<li><span style="color: #00afcb;">Linux FTP server</span></li>
</ul>
[/fancy-ul][vc_column_text css=".vc_custom_1467706078230{margin-bottom: 18px !important;}"]
<h5>NAS 網路儲存裝置</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">NAS雲端文件伺服器設置</span></li>
 	<li><span style="color: #00afcb;">NAS雲端軟件市場</span></li>
 	<li><span style="color: #00afcb;">個人化NAS服務應用</span></li>
 	<li><span style="color: #00afcb;">NAS Apps部署</span></li>
 	<li><span style="color: #00afcb;">NAS設置</span></li>
</ul>
[/fancy-ul][/vc_column][/vc_row][vc_row type="full_width_background" scene_position="center" text_color="dark" text_align="left" top_padding="5%" bottom_padding="5%" id="new-office-setup" overlay_strength="0.3"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][vc_column_text]
<h2>新辦公室IT設置</h2>
[/vc_column_text][vc_column_text]我們能提供開新公司所需要的一站式的IT配套解決方案，讓您可以専注業務發展。IT的事項交給我們吧！我們不止辦得到，而且辦得妥。
一站式的IT配套解決方案包括IT顧問服務、品牌及平面設計、網站規劃、網路工程規劃、軟硬件採購、商業軟件配套等等。[/vc_column_text][image_with_animation image_url="6472" alignment="center" animation="Fade In" delay="150"][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1467710000974{margin-bottom: 18px !important;}"]
<h5>網頁設計</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">域名申請及註冊</span></li>
 	<li><span style="color: #00afcb;">網頁設計</span></li>
 	<li><span style="color: #00afcb;">部落格設計</span></li>
 	<li><span style="color: #00afcb;">網上商店設計</span></li>
 	<li><span style="color: #00afcb;">內容管理系統設計</span></li>
</ul>
[/fancy-ul][vc_column_text css=".vc_custom_1467710801113{margin-bottom: 18px !important;}"]
<h5>網路工程及設置</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">由路器/防火牆設置</span></li>
 	<li><span style="color: #00afcb;">區域網路規劃</span></li>
 	<li><span style="color: #00afcb;">無線區域網路規劃</span></li>
 	<li><span style="color: #00afcb;">防盜系統設置</span></li>
 	<li><span style="color: #00afcb;">伺服器/網路設備専櫃安裝</span></li>
</ul>
[/fancy-ul][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1467710531184{margin-bottom: 18px !important;}"]
<h5>電腦相關硬件/軟件</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">桌上電腦/手提電腦</span></li>
 	<li><span style="color: #00afcb;">伺服器</span></li>
 	<li><span style="color: #00afcb;">電腦軟件</span></li>
 	<li><span style="color: #00afcb;">公司軟件使用權証</span></li>
 	<li><span style="color: #00afcb;">其他電腦週邊設備</span></li>
</ul>
[/fancy-ul][vc_column_text css=".vc_custom_1467711009043{margin-bottom: 18px !important;}"]
<h5>商業軟件應用</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">企業資源計劃方案(ERP)</span></li>
 	<li><span style="color: #00afcb;">客戶關係管理方案(CRM)</span></li>
 	<li><span style="color: #00afcb;">銷售系統方案(POS)</span></li>
 	<li><span style="color: #00afcb;">電郵解決方案(Email)</span></li>
 	<li><span style="color: #00afcb;">協同合作解決方案(Collaboration)</span></li>
</ul>
[/fancy-ul][/vc_column][/vc_row][vc_row type="full_width_background" scene_position="center" text_color="light" text_align="left" top_padding="5%" bottom_padding="5%" id="it-product" color_overlay="#00afcb" overlay_strength="0.95"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][vc_column_text]
<h2>電腦及週邊產品</h2>
[/vc_column_text][vc_column_text]不用再自己找電腦商場購買電腦產品，安心専注您們的核心業務，我們為您安排！
搜羅全球品牌，擁有多年電腦及週邊產品的銷售經驗，我們會因應不同工作環境提供合適的產品。產品包括伺服器、桌上電腦、手提電腦、平板電腦、硬碟、記憶體、滑鼠，甚至只是一條網線都能為您效勞。[/vc_column_text][image_with_animation image_url="6489" alignment="center" animation="Fade In" delay="150"][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1467860001791{margin-bottom: 18px !important;}"]
<h5>電腦硬件</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Extra-Color-3" enable_animation="true"]
<ul>
 	<li><span style="color: #a2d8e6;">品牌電腦/手提電腦</span></li>
 	<li><span style="color: #a2d8e6;">蘋果電腦</span></li>
 	<li><span style="color: #a2d8e6;">平板電腦</span></li>
 	<li><span style="color: #a2d8e6;">掌上電腦設備</span></li>
 	<li><span style="color: #a2d8e6;">自組電腦</span></li>
</ul>
[/fancy-ul][vc_column_text css=".vc_custom_1467860286184{margin-bottom: 18px !important;}"]
<h5>電腦軟件</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Extra-Color-3" enable_animation="true"]
<ul>
 	<li><span style="color: #a2d8e6;">電腦操作系統</span></li>
 	<li><span style="color: #a2d8e6;">伺服器操作系統</span></li>
 	<li><span style="color: #a2d8e6;">繪圖軟件</span></li>
 	<li><span style="color: #a2d8e6;">文書處理軟件</span></li>
 	<li><span style="color: #a2d8e6;">防毒軟件</span></li>
</ul>
[/fancy-ul][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1467860155698{margin-bottom: 18px !important;}"]
<h5>網路相關設備</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Extra-Color-3" enable_animation="true"]
<ul>
 	<li><span style="color: #a2d8e6;">網路器材</span></li>
 	<li><span style="color: #a2d8e6;">網路機櫃</span></li>
 	<li><span style="color: #a2d8e6;">網路線材/線材週邊配件</span></li>
 	<li><span style="color: #a2d8e6;">網路攝錄器材</span></li>
 	<li><span style="color: #a2d8e6;">後備電線及配件</span></li>
</ul>
[/fancy-ul][vc_column_text css=".vc_custom_1467860455628{margin-bottom: 18px !important;}"]
<h5>電腦配件</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Extra-Color-3" enable_animation="true"]
<ul>
 	<li><span style="color: #a2d8e6;">儲存設備</span></li>
 	<li><span style="color: #a2d8e6;">打印機</span></li>
 	<li><span style="color: #a2d8e6;">顯示器</span></li>
 	<li><span style="color: #a2d8e6;">投影器</span></li>
 	<li><span style="color: #a2d8e6;">輸入裝置(滑鼠/鍵盤/手寫系統)</span></li>
</ul>
[/fancy-ul][/vc_column][/vc_row][vc_row type="full_width_background" scene_position="center" text_color="dark" text_align="left" top_padding="5%" id="licensing" overlay_strength="0.3"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][vc_column_text]
<h2>使用授權</h2>
[/vc_column_text][vc_column_text]有使用授權的煩惱？我們是不同知名品牌的經綃商，能夠幫您找到最理想的使用授權方案！[/vc_column_text][image_with_animation image_url="6508" alignment="center" animation="Fade In" delay="150"][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1467860990705{margin-bottom: 18px !important;}"]
<h5>軟件授權</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">Microsoft Open License</span></li>
 	<li><span style="color: #00afcb;">Microsoft Full Packaged Product (FPP) Software</span></li>
 	<li><span style="color: #00afcb;">Autodesk AutoCAD Product</span></li>
 	<li><span style="color: #00afcb;">CorelDRAW Graphic Suite</span></li>
 	<li><span style="color: #00afcb;">Symantec License</span></li>
 	<li><span style="color: #00afcb;">Kaspersky License</span></li>
 	<li><span style="color: #00afcb;">ESET NOD32 License</span></li>
</ul>
[/fancy-ul][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1467861104683{margin-bottom: 18px !important;}"]
<h5>網路軟件續期/授權</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">Sonicwall</span></li>
 	<li><span style="color: #00afcb;">FortiGate</span></li>
 	<li><span style="color: #00afcb;">Sophos</span></li>
 	<li><span style="color: #00afcb;">Netgear</span></li>
 	<li><span style="color: #00afcb;">Watchguard</span></li>
</ul>
[/fancy-ul][/vc_column][/vc_row][vc_row type="full_width_background" scene_position="center" text_color="dark" text_align="left" top_padding="40" bottom_padding="40" overlay_strength="1"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/1"][clients columns="6" carousel="true"][client image="6519" title="Client" tab_id="1451662966191-10" name="Dell" id="1466931216835-2"] Click the edit button to add your testimonial. [/client][client image="6522" title="Client" tab_id="1451663132415-1" name="APC" id="1466931413922-0"][/client][client image="6520" title="Client" tab_id="1451663143506-0" name="Adobe" id="1466931284237-6"][/client][client image="6527" title="Client" tab_id="1466931353621-0" name="Microsoft" id="1466931598150-0"][/client][client image="6528" title="Client" tab_id="1466931384037-3" name="Autodesk" id="1466931493068-0"][/client][client image="6530" title="Client" tab_id="1466931509584-3" name="Symantec" id="1466931598175-1"][/client][client image="6533" title="Client" tab_id="1466931571980-4" name="Trend Micro" id="1466931633164-10"][/client][client image="6535" title="Client" tab_id="1466931604541-2" name="Watchguard" id="1467000202494-0"][/client][/clients][/vc_column][/vc_row]";s:10:"post_title";s:14:"IT解決方案";s:12:"post_excerpt";s:0:"";s:11:"post_status";s:7:"publish";s:14:"comment_status";s:6:"closed";s:11:"ping_status";s:6:"closed";s:13:"post_password";s:0:"";s:9:"post_name";s:12:"it-solutions";s:7:"to_ping";s:0:"";s:6:"pinged";s:0:"";s:13:"post_modified";s:19:"2016-08-15 16:55:49";s:17:"post_modified_gmt";s:19:"2016-08-15 08:55:49";s:21:"post_content_filtered";s:0:"";s:11:"post_parent";i:0;s:4:"guid";s:41:"http://web2.vbits.com.hk/zh/?page_id=6811";s:10:"menu_order";i:0;s:9:"post_type";s:4:"page";s:14:"post_mime_type";s:0:"";s:13:"comment_count";s:1:"0";s:6:"filter";s:3:"raw";}}