// Functions
@import '_inc/client/scss/functions/rem';

// Variables
@import '_inc/client/scss/variables/colors';
@import '_inc/client/scss/variables/layout';

// Mixins
@import '_inc/client/scss/mixins/breakpoints';
@import '_inc/client/scss/mixins/clear-fix';
@import '_inc/client/scss/mixins/long-content-fade';

// Styles
@import "_inc/client/dashboard-widget/style";
