.wpb_vc_gitem_row {
  margin: 0 auto @vc_gitem_element_margin_bottom; // TODO: add to list
  .vc_controls-row {
    .vc_column-delete {
      float: right;
      display: block;
      background: #ffffff;
      // Hide in A/B
      .wpb_vc_gitem_zone_a &, .wpb_vc_gitem_zone_b & {
        display: none;
      }
    }
    .vc_row_layouts {
      background: #ffffff;
    }
    .vc_row_layouts {
      margin-left: 0;
      &:hover {
        left: 0;
        height: 24px;
      }
    }
  }
}

.wpb_row_container {
  > .wpb_vc_gitem_col {
    > .vc_controls, > .wpb_element_wrapper {
      background-color: #ffffff;
    }

  }
}

.wpb_vc_gitem_col {
  &.vc_col-sm-4 {
    .wpb_content_element {
      > .vc_controls {
        .vc_controls-cc {
          .vc_clearfix();
        }
        .vc_element-name {
          float: none;
          display: block;
          .vc_btn-content {
            overflow: hidden;
          }
        }
      }
    }
  }
}