<?php

// autoload_classmap.php @generated by Composer

$vendorDir = dirname(dirname(__FILE__));
$baseDir = dirname($vendorDir);

return array(
    'AbsoluteLinks' => $baseDir . '/inc/absolute-links/absolute-links.class.php',
    'Composer\\Installers\\AglInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/AglInstaller.php',
    'Composer\\Installers\\AimeosInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/AimeosInstaller.php',
    'Composer\\Installers\\AnnotateCmsInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/AnnotateCmsInstaller.php',
    'Composer\\Installers\\AsgardInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/AsgardInstaller.php',
    'Composer\\Installers\\AttogramInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/AttogramInstaller.php',
    'Composer\\Installers\\BaseInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/BaseInstaller.php',
    'Composer\\Installers\\BitrixInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/BitrixInstaller.php',
    'Composer\\Installers\\BonefishInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/BonefishInstaller.php',
    'Composer\\Installers\\CakePHPInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/CakePHPInstaller.php',
    'Composer\\Installers\\ChefInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/ChefInstaller.php',
    'Composer\\Installers\\ClanCatsFrameworkInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/ClanCatsFrameworkInstaller.php',
    'Composer\\Installers\\CockpitInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/CockpitInstaller.php',
    'Composer\\Installers\\CodeIgniterInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/CodeIgniterInstaller.php',
    'Composer\\Installers\\Concrete5Installer' => $vendorDir . '/composer/installers/src/Composer/Installers/Concrete5Installer.php',
    'Composer\\Installers\\CraftInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/CraftInstaller.php',
    'Composer\\Installers\\CroogoInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/CroogoInstaller.php',
    'Composer\\Installers\\DecibelInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/DecibelInstaller.php',
    'Composer\\Installers\\DokuWikiInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/DokuWikiInstaller.php',
    'Composer\\Installers\\DolibarrInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/DolibarrInstaller.php',
    'Composer\\Installers\\DrupalInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/DrupalInstaller.php',
    'Composer\\Installers\\ElggInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/ElggInstaller.php',
    'Composer\\Installers\\ExpressionEngineInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/ExpressionEngineInstaller.php',
    'Composer\\Installers\\FuelInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/FuelInstaller.php',
    'Composer\\Installers\\FuelphpInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/FuelphpInstaller.php',
    'Composer\\Installers\\GravInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/GravInstaller.php',
    'Composer\\Installers\\HuradInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/HuradInstaller.php',
    'Composer\\Installers\\ImageCMSInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/ImageCMSInstaller.php',
    'Composer\\Installers\\Installer' => $vendorDir . '/composer/installers/src/Composer/Installers/Installer.php',
    'Composer\\Installers\\JoomlaInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/JoomlaInstaller.php',
    'Composer\\Installers\\KirbyInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/KirbyInstaller.php',
    'Composer\\Installers\\KodiCMSInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/KodiCMSInstaller.php',
    'Composer\\Installers\\KohanaInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/KohanaInstaller.php',
    'Composer\\Installers\\LaravelInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/LaravelInstaller.php',
    'Composer\\Installers\\LithiumInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/LithiumInstaller.php',
    'Composer\\Installers\\MODULEWorkInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/MODULEWorkInstaller.php',
    'Composer\\Installers\\MODXEvoInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/MODXEvoInstaller.php',
    'Composer\\Installers\\MagentoInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/MagentoInstaller.php',
    'Composer\\Installers\\MakoInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/MakoInstaller.php',
    'Composer\\Installers\\MauticInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/MauticInstaller.php',
    'Composer\\Installers\\MediaWikiInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/MediaWikiInstaller.php',
    'Composer\\Installers\\MicroweberInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/MicroweberInstaller.php',
    'Composer\\Installers\\MoodleInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/MoodleInstaller.php',
    'Composer\\Installers\\OctoberInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/OctoberInstaller.php',
    'Composer\\Installers\\OxidInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/OxidInstaller.php',
    'Composer\\Installers\\PPIInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/PPIInstaller.php',
    'Composer\\Installers\\PhiftyInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/PhiftyInstaller.php',
    'Composer\\Installers\\PhpBBInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/PhpBBInstaller.php',
    'Composer\\Installers\\PimcoreInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/PimcoreInstaller.php',
    'Composer\\Installers\\PiwikInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/PiwikInstaller.php',
    'Composer\\Installers\\PlentymarketsInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/PlentymarketsInstaller.php',
    'Composer\\Installers\\Plugin' => $vendorDir . '/composer/installers/src/Composer/Installers/Plugin.php',
    'Composer\\Installers\\PrestashopInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/PrestashopInstaller.php',
    'Composer\\Installers\\PuppetInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/PuppetInstaller.php',
    'Composer\\Installers\\RadPHPInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/RadPHPInstaller.php',
    'Composer\\Installers\\ReIndexInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/ReIndexInstaller.php',
    'Composer\\Installers\\RedaxoInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/RedaxoInstaller.php',
    'Composer\\Installers\\RoundcubeInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/RoundcubeInstaller.php',
    'Composer\\Installers\\SMFInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/SMFInstaller.php',
    'Composer\\Installers\\ShopwareInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/ShopwareInstaller.php',
    'Composer\\Installers\\SilverStripeInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/SilverStripeInstaller.php',
    'Composer\\Installers\\Symfony1Installer' => $vendorDir . '/composer/installers/src/Composer/Installers/Symfony1Installer.php',
    'Composer\\Installers\\TYPO3CmsInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/TYPO3CmsInstaller.php',
    'Composer\\Installers\\TYPO3FlowInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/TYPO3FlowInstaller.php',
    'Composer\\Installers\\TheliaInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/TheliaInstaller.php',
    'Composer\\Installers\\TuskInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/TuskInstaller.php',
    'Composer\\Installers\\VanillaInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/VanillaInstaller.php',
    'Composer\\Installers\\WHMCSInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/WHMCSInstaller.php',
    'Composer\\Installers\\WolfCMSInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/WolfCMSInstaller.php',
    'Composer\\Installers\\WordPressInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/WordPressInstaller.php',
    'Composer\\Installers\\YawikInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/YawikInstaller.php',
    'Composer\\Installers\\ZendInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/ZendInstaller.php',
    'Composer\\Installers\\ZikulaInstaller' => $vendorDir . '/composer/installers/src/Composer/Installers/ZikulaInstaller.php',
    'ICLMenusSync' => $baseDir . '/inc/wp-nav-menus/menus-sync.php',
    'ICL_AdminNotifier' => $baseDir . '/inc/icl-admin-notifier.php',
    'ICanLocalizeQuery' => $baseDir . '/lib/icl_api.php',
    'IWPML_AJAX_Action' => $baseDir . '/classes/ajax/interface-wpml-ajax-action.php',
    'IWPML_AJAX_Action_Loader' => $baseDir . '/classes/action-filter-loader/interface-iwpml-ajax-action-loader.php',
    'IWPML_Action' => $baseDir . '/classes/action-filter-loader/interface-iwpml-action.php',
    'IWPML_Action_Loader_Factory' => $baseDir . '/classes/action-filter-loader/interface-iwpml-action-loader-factory.php',
    'IWPML_Backend_Action_Loader' => $baseDir . '/classes/action-filter-loader/interface-iwpml-backend-action-loader.php',
    'IWPML_Deferred_Action_Loader' => $baseDir . '/classes/action-filter-loader/interface-iwpml-deferred-action-loader.php',
    'IWPML_Frontend_Action_Loader' => $baseDir . '/classes/action-filter-loader/interface-iwpml-frontend-action-loader.php',
    'IWPML_Template_Service' => $baseDir . '/classes/templates/interface-iwpml-template-service.php',
    'IWPML_URL_Converter_Strategy' => $baseDir . '/classes/url-handling/converter/strategy/interface-iwpml-url-converter-strategy.php',
    'IWPML_Upgrade_Command' => $baseDir . '/classes/upgrade/interface-iwpml-upgrade-command.php',
    'Icl_Stepper' => $baseDir . '/inc/upgrade-functions/2.0.0/stepper.php',
    'SitePress' => $baseDir . '/sitepress.class.php',
    'SitePressLanguageSwitcher' => $baseDir . '/inc/language-switcher.php',
    'SitePress_Setup' => $baseDir . '/inc/setup/sitepress-setup.class.php',
    'TranslationManagement' => $baseDir . '/inc/translation-management/translation-management.class.php',
    'Twig_Autoloader' => $vendorDir . '/twig/twig/lib/Twig/Autoloader.php',
    'Twig_BaseNodeVisitor' => $vendorDir . '/twig/twig/lib/Twig/BaseNodeVisitor.php',
    'Twig_CacheInterface' => $vendorDir . '/twig/twig/lib/Twig/CacheInterface.php',
    'Twig_Cache_Filesystem' => $vendorDir . '/twig/twig/lib/Twig/Cache/Filesystem.php',
    'Twig_Cache_Null' => $vendorDir . '/twig/twig/lib/Twig/Cache/Null.php',
    'Twig_Compiler' => $vendorDir . '/twig/twig/lib/Twig/Compiler.php',
    'Twig_CompilerInterface' => $vendorDir . '/twig/twig/lib/Twig/CompilerInterface.php',
    'Twig_ContainerRuntimeLoader' => $vendorDir . '/twig/twig/lib/Twig/ContainerRuntimeLoader.php',
    'Twig_Environment' => $vendorDir . '/twig/twig/lib/Twig/Environment.php',
    'Twig_Error' => $vendorDir . '/twig/twig/lib/Twig/Error.php',
    'Twig_Error_Loader' => $vendorDir . '/twig/twig/lib/Twig/Error/Loader.php',
    'Twig_Error_Runtime' => $vendorDir . '/twig/twig/lib/Twig/Error/Runtime.php',
    'Twig_Error_Syntax' => $vendorDir . '/twig/twig/lib/Twig/Error/Syntax.php',
    'Twig_ExistsLoaderInterface' => $vendorDir . '/twig/twig/lib/Twig/ExistsLoaderInterface.php',
    'Twig_ExpressionParser' => $vendorDir . '/twig/twig/lib/Twig/ExpressionParser.php',
    'Twig_Extension' => $vendorDir . '/twig/twig/lib/Twig/Extension.php',
    'Twig_ExtensionInterface' => $vendorDir . '/twig/twig/lib/Twig/ExtensionInterface.php',
    'Twig_Extension_Core' => $vendorDir . '/twig/twig/lib/Twig/Extension/Core.php',
    'Twig_Extension_Debug' => $vendorDir . '/twig/twig/lib/Twig/Extension/Debug.php',
    'Twig_Extension_Escaper' => $vendorDir . '/twig/twig/lib/Twig/Extension/Escaper.php',
    'Twig_Extension_GlobalsInterface' => $vendorDir . '/twig/twig/lib/Twig/Extension/GlobalsInterface.php',
    'Twig_Extension_InitRuntimeInterface' => $vendorDir . '/twig/twig/lib/Twig/Extension/InitRuntimeInterface.php',
    'Twig_Extension_Optimizer' => $vendorDir . '/twig/twig/lib/Twig/Extension/Optimizer.php',
    'Twig_Extension_Profiler' => $vendorDir . '/twig/twig/lib/Twig/Extension/Profiler.php',
    'Twig_Extension_Sandbox' => $vendorDir . '/twig/twig/lib/Twig/Extension/Sandbox.php',
    'Twig_Extension_Staging' => $vendorDir . '/twig/twig/lib/Twig/Extension/Staging.php',
    'Twig_Extension_StringLoader' => $vendorDir . '/twig/twig/lib/Twig/Extension/StringLoader.php',
    'Twig_FactoryRuntimeLoader' => $vendorDir . '/twig/twig/lib/Twig/FactoryRuntimeLoader.php',
    'Twig_FileExtensionEscapingStrategy' => $vendorDir . '/twig/twig/lib/Twig/FileExtensionEscapingStrategy.php',
    'Twig_Filter' => $vendorDir . '/twig/twig/lib/Twig/Filter.php',
    'Twig_FilterCallableInterface' => $vendorDir . '/twig/twig/lib/Twig/FilterCallableInterface.php',
    'Twig_FilterInterface' => $vendorDir . '/twig/twig/lib/Twig/FilterInterface.php',
    'Twig_Filter_Function' => $vendorDir . '/twig/twig/lib/Twig/Filter/Function.php',
    'Twig_Filter_Method' => $vendorDir . '/twig/twig/lib/Twig/Filter/Method.php',
    'Twig_Filter_Node' => $vendorDir . '/twig/twig/lib/Twig/Filter/Node.php',
    'Twig_Function' => $vendorDir . '/twig/twig/lib/Twig/Function.php',
    'Twig_FunctionCallableInterface' => $vendorDir . '/twig/twig/lib/Twig/FunctionCallableInterface.php',
    'Twig_FunctionInterface' => $vendorDir . '/twig/twig/lib/Twig/FunctionInterface.php',
    'Twig_Function_Function' => $vendorDir . '/twig/twig/lib/Twig/Function/Function.php',
    'Twig_Function_Method' => $vendorDir . '/twig/twig/lib/Twig/Function/Method.php',
    'Twig_Function_Node' => $vendorDir . '/twig/twig/lib/Twig/Function/Node.php',
    'Twig_Lexer' => $vendorDir . '/twig/twig/lib/Twig/Lexer.php',
    'Twig_LexerInterface' => $vendorDir . '/twig/twig/lib/Twig/LexerInterface.php',
    'Twig_LoaderInterface' => $vendorDir . '/twig/twig/lib/Twig/LoaderInterface.php',
    'Twig_Loader_Array' => $vendorDir . '/twig/twig/lib/Twig/Loader/Array.php',
    'Twig_Loader_Chain' => $vendorDir . '/twig/twig/lib/Twig/Loader/Chain.php',
    'Twig_Loader_Filesystem' => $vendorDir . '/twig/twig/lib/Twig/Loader/Filesystem.php',
    'Twig_Loader_String' => $vendorDir . '/twig/twig/lib/Twig/Loader/String.php',
    'Twig_Markup' => $vendorDir . '/twig/twig/lib/Twig/Markup.php',
    'Twig_Node' => $vendorDir . '/twig/twig/lib/Twig/Node.php',
    'Twig_NodeCaptureInterface' => $vendorDir . '/twig/twig/lib/Twig/NodeCaptureInterface.php',
    'Twig_NodeInterface' => $vendorDir . '/twig/twig/lib/Twig/NodeInterface.php',
    'Twig_NodeOutputInterface' => $vendorDir . '/twig/twig/lib/Twig/NodeOutputInterface.php',
    'Twig_NodeTraverser' => $vendorDir . '/twig/twig/lib/Twig/NodeTraverser.php',
    'Twig_NodeVisitorInterface' => $vendorDir . '/twig/twig/lib/Twig/NodeVisitorInterface.php',
    'Twig_NodeVisitor_Escaper' => $vendorDir . '/twig/twig/lib/Twig/NodeVisitor/Escaper.php',
    'Twig_NodeVisitor_Optimizer' => $vendorDir . '/twig/twig/lib/Twig/NodeVisitor/Optimizer.php',
    'Twig_NodeVisitor_SafeAnalysis' => $vendorDir . '/twig/twig/lib/Twig/NodeVisitor/SafeAnalysis.php',
    'Twig_NodeVisitor_Sandbox' => $vendorDir . '/twig/twig/lib/Twig/NodeVisitor/Sandbox.php',
    'Twig_Node_AutoEscape' => $vendorDir . '/twig/twig/lib/Twig/Node/AutoEscape.php',
    'Twig_Node_Block' => $vendorDir . '/twig/twig/lib/Twig/Node/Block.php',
    'Twig_Node_BlockReference' => $vendorDir . '/twig/twig/lib/Twig/Node/BlockReference.php',
    'Twig_Node_Body' => $vendorDir . '/twig/twig/lib/Twig/Node/Body.php',
    'Twig_Node_CheckSecurity' => $vendorDir . '/twig/twig/lib/Twig/Node/CheckSecurity.php',
    'Twig_Node_Do' => $vendorDir . '/twig/twig/lib/Twig/Node/Do.php',
    'Twig_Node_Embed' => $vendorDir . '/twig/twig/lib/Twig/Node/Embed.php',
    'Twig_Node_Expression' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression.php',
    'Twig_Node_Expression_Array' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Array.php',
    'Twig_Node_Expression_AssignName' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/AssignName.php',
    'Twig_Node_Expression_Binary' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Binary.php',
    'Twig_Node_Expression_Binary_Add' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Binary/Add.php',
    'Twig_Node_Expression_Binary_And' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Binary/And.php',
    'Twig_Node_Expression_Binary_BitwiseAnd' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Binary/BitwiseAnd.php',
    'Twig_Node_Expression_Binary_BitwiseOr' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Binary/BitwiseOr.php',
    'Twig_Node_Expression_Binary_BitwiseXor' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Binary/BitwiseXor.php',
    'Twig_Node_Expression_Binary_Concat' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Binary/Concat.php',
    'Twig_Node_Expression_Binary_Div' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Binary/Div.php',
    'Twig_Node_Expression_Binary_EndsWith' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Binary/EndsWith.php',
    'Twig_Node_Expression_Binary_Equal' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Binary/Equal.php',
    'Twig_Node_Expression_Binary_FloorDiv' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Binary/FloorDiv.php',
    'Twig_Node_Expression_Binary_Greater' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Binary/Greater.php',
    'Twig_Node_Expression_Binary_GreaterEqual' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Binary/GreaterEqual.php',
    'Twig_Node_Expression_Binary_In' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Binary/In.php',
    'Twig_Node_Expression_Binary_Less' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Binary/Less.php',
    'Twig_Node_Expression_Binary_LessEqual' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Binary/LessEqual.php',
    'Twig_Node_Expression_Binary_Matches' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Binary/Matches.php',
    'Twig_Node_Expression_Binary_Mod' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Binary/Mod.php',
    'Twig_Node_Expression_Binary_Mul' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Binary/Mul.php',
    'Twig_Node_Expression_Binary_NotEqual' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Binary/NotEqual.php',
    'Twig_Node_Expression_Binary_NotIn' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Binary/NotIn.php',
    'Twig_Node_Expression_Binary_Or' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Binary/Or.php',
    'Twig_Node_Expression_Binary_Power' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Binary/Power.php',
    'Twig_Node_Expression_Binary_Range' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Binary/Range.php',
    'Twig_Node_Expression_Binary_StartsWith' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Binary/StartsWith.php',
    'Twig_Node_Expression_Binary_Sub' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Binary/Sub.php',
    'Twig_Node_Expression_BlockReference' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/BlockReference.php',
    'Twig_Node_Expression_Call' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Call.php',
    'Twig_Node_Expression_Conditional' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Conditional.php',
    'Twig_Node_Expression_Constant' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Constant.php',
    'Twig_Node_Expression_ExtensionReference' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/ExtensionReference.php',
    'Twig_Node_Expression_Filter' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Filter.php',
    'Twig_Node_Expression_Filter_Default' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Filter/Default.php',
    'Twig_Node_Expression_Function' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Function.php',
    'Twig_Node_Expression_GetAttr' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/GetAttr.php',
    'Twig_Node_Expression_MethodCall' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/MethodCall.php',
    'Twig_Node_Expression_Name' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Name.php',
    'Twig_Node_Expression_NullCoalesce' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/NullCoalesce.php',
    'Twig_Node_Expression_Parent' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Parent.php',
    'Twig_Node_Expression_TempName' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/TempName.php',
    'Twig_Node_Expression_Test' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Test.php',
    'Twig_Node_Expression_Test_Constant' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Test/Constant.php',
    'Twig_Node_Expression_Test_Defined' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Test/Defined.php',
    'Twig_Node_Expression_Test_Divisibleby' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Test/Divisibleby.php',
    'Twig_Node_Expression_Test_Even' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Test/Even.php',
    'Twig_Node_Expression_Test_Null' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Test/Null.php',
    'Twig_Node_Expression_Test_Odd' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Test/Odd.php',
    'Twig_Node_Expression_Test_Sameas' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Test/Sameas.php',
    'Twig_Node_Expression_Unary' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Unary.php',
    'Twig_Node_Expression_Unary_Neg' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Unary/Neg.php',
    'Twig_Node_Expression_Unary_Not' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Unary/Not.php',
    'Twig_Node_Expression_Unary_Pos' => $vendorDir . '/twig/twig/lib/Twig/Node/Expression/Unary/Pos.php',
    'Twig_Node_Flush' => $vendorDir . '/twig/twig/lib/Twig/Node/Flush.php',
    'Twig_Node_For' => $vendorDir . '/twig/twig/lib/Twig/Node/For.php',
    'Twig_Node_ForLoop' => $vendorDir . '/twig/twig/lib/Twig/Node/ForLoop.php',
    'Twig_Node_If' => $vendorDir . '/twig/twig/lib/Twig/Node/If.php',
    'Twig_Node_Import' => $vendorDir . '/twig/twig/lib/Twig/Node/Import.php',
    'Twig_Node_Include' => $vendorDir . '/twig/twig/lib/Twig/Node/Include.php',
    'Twig_Node_Macro' => $vendorDir . '/twig/twig/lib/Twig/Node/Macro.php',
    'Twig_Node_Module' => $vendorDir . '/twig/twig/lib/Twig/Node/Module.php',
    'Twig_Node_Print' => $vendorDir . '/twig/twig/lib/Twig/Node/Print.php',
    'Twig_Node_Sandbox' => $vendorDir . '/twig/twig/lib/Twig/Node/Sandbox.php',
    'Twig_Node_SandboxedPrint' => $vendorDir . '/twig/twig/lib/Twig/Node/SandboxedPrint.php',
    'Twig_Node_Set' => $vendorDir . '/twig/twig/lib/Twig/Node/Set.php',
    'Twig_Node_SetTemp' => $vendorDir . '/twig/twig/lib/Twig/Node/SetTemp.php',
    'Twig_Node_Spaceless' => $vendorDir . '/twig/twig/lib/Twig/Node/Spaceless.php',
    'Twig_Node_Text' => $vendorDir . '/twig/twig/lib/Twig/Node/Text.php',
    'Twig_Node_With' => $vendorDir . '/twig/twig/lib/Twig/Node/With.php',
    'Twig_Parser' => $vendorDir . '/twig/twig/lib/Twig/Parser.php',
    'Twig_ParserInterface' => $vendorDir . '/twig/twig/lib/Twig/ParserInterface.php',
    'Twig_Profiler_Dumper_Blackfire' => $vendorDir . '/twig/twig/lib/Twig/Profiler/Dumper/Blackfire.php',
    'Twig_Profiler_Dumper_Html' => $vendorDir . '/twig/twig/lib/Twig/Profiler/Dumper/Html.php',
    'Twig_Profiler_Dumper_Text' => $vendorDir . '/twig/twig/lib/Twig/Profiler/Dumper/Text.php',
    'Twig_Profiler_NodeVisitor_Profiler' => $vendorDir . '/twig/twig/lib/Twig/Profiler/NodeVisitor/Profiler.php',
    'Twig_Profiler_Node_EnterProfile' => $vendorDir . '/twig/twig/lib/Twig/Profiler/Node/EnterProfile.php',
    'Twig_Profiler_Node_LeaveProfile' => $vendorDir . '/twig/twig/lib/Twig/Profiler/Node/LeaveProfile.php',
    'Twig_Profiler_Profile' => $vendorDir . '/twig/twig/lib/Twig/Profiler/Profile.php',
    'Twig_RuntimeLoaderInterface' => $vendorDir . '/twig/twig/lib/Twig/RuntimeLoaderInterface.php',
    'Twig_Sandbox_SecurityError' => $vendorDir . '/twig/twig/lib/Twig/Sandbox/SecurityError.php',
    'Twig_Sandbox_SecurityNotAllowedFilterError' => $vendorDir . '/twig/twig/lib/Twig/Sandbox/SecurityNotAllowedFilterError.php',
    'Twig_Sandbox_SecurityNotAllowedFunctionError' => $vendorDir . '/twig/twig/lib/Twig/Sandbox/SecurityNotAllowedFunctionError.php',
    'Twig_Sandbox_SecurityNotAllowedMethodError' => $vendorDir . '/twig/twig/lib/Twig/Sandbox/SecurityNotAllowedMethodError.php',
    'Twig_Sandbox_SecurityNotAllowedPropertyError' => $vendorDir . '/twig/twig/lib/Twig/Sandbox/SecurityNotAllowedPropertyError.php',
    'Twig_Sandbox_SecurityNotAllowedTagError' => $vendorDir . '/twig/twig/lib/Twig/Sandbox/SecurityNotAllowedTagError.php',
    'Twig_Sandbox_SecurityPolicy' => $vendorDir . '/twig/twig/lib/Twig/Sandbox/SecurityPolicy.php',
    'Twig_Sandbox_SecurityPolicyInterface' => $vendorDir . '/twig/twig/lib/Twig/Sandbox/SecurityPolicyInterface.php',
    'Twig_SimpleFilter' => $vendorDir . '/twig/twig/lib/Twig/SimpleFilter.php',
    'Twig_SimpleFunction' => $vendorDir . '/twig/twig/lib/Twig/SimpleFunction.php',
    'Twig_SimpleTest' => $vendorDir . '/twig/twig/lib/Twig/SimpleTest.php',
    'Twig_Source' => $vendorDir . '/twig/twig/lib/Twig/Source.php',
    'Twig_SourceContextLoaderInterface' => $vendorDir . '/twig/twig/lib/Twig/SourceContextLoaderInterface.php',
    'Twig_Template' => $vendorDir . '/twig/twig/lib/Twig/Template.php',
    'Twig_TemplateInterface' => $vendorDir . '/twig/twig/lib/Twig/TemplateInterface.php',
    'Twig_TemplateWrapper' => $vendorDir . '/twig/twig/lib/Twig/TemplateWrapper.php',
    'Twig_Test' => $vendorDir . '/twig/twig/lib/Twig/Test.php',
    'Twig_TestCallableInterface' => $vendorDir . '/twig/twig/lib/Twig/TestCallableInterface.php',
    'Twig_TestInterface' => $vendorDir . '/twig/twig/lib/Twig/TestInterface.php',
    'Twig_Test_Function' => $vendorDir . '/twig/twig/lib/Twig/Test/Function.php',
    'Twig_Test_IntegrationTestCase' => $vendorDir . '/twig/twig/lib/Twig/Test/IntegrationTestCase.php',
    'Twig_Test_Method' => $vendorDir . '/twig/twig/lib/Twig/Test/Method.php',
    'Twig_Test_Node' => $vendorDir . '/twig/twig/lib/Twig/Test/Node.php',
    'Twig_Test_NodeTestCase' => $vendorDir . '/twig/twig/lib/Twig/Test/NodeTestCase.php',
    'Twig_Token' => $vendorDir . '/twig/twig/lib/Twig/Token.php',
    'Twig_TokenParser' => $vendorDir . '/twig/twig/lib/Twig/TokenParser.php',
    'Twig_TokenParserBroker' => $vendorDir . '/twig/twig/lib/Twig/TokenParserBroker.php',
    'Twig_TokenParserBrokerInterface' => $vendorDir . '/twig/twig/lib/Twig/TokenParserBrokerInterface.php',
    'Twig_TokenParserInterface' => $vendorDir . '/twig/twig/lib/Twig/TokenParserInterface.php',
    'Twig_TokenParser_AutoEscape' => $vendorDir . '/twig/twig/lib/Twig/TokenParser/AutoEscape.php',
    'Twig_TokenParser_Block' => $vendorDir . '/twig/twig/lib/Twig/TokenParser/Block.php',
    'Twig_TokenParser_Do' => $vendorDir . '/twig/twig/lib/Twig/TokenParser/Do.php',
    'Twig_TokenParser_Embed' => $vendorDir . '/twig/twig/lib/Twig/TokenParser/Embed.php',
    'Twig_TokenParser_Extends' => $vendorDir . '/twig/twig/lib/Twig/TokenParser/Extends.php',
    'Twig_TokenParser_Filter' => $vendorDir . '/twig/twig/lib/Twig/TokenParser/Filter.php',
    'Twig_TokenParser_Flush' => $vendorDir . '/twig/twig/lib/Twig/TokenParser/Flush.php',
    'Twig_TokenParser_For' => $vendorDir . '/twig/twig/lib/Twig/TokenParser/For.php',
    'Twig_TokenParser_From' => $vendorDir . '/twig/twig/lib/Twig/TokenParser/From.php',
    'Twig_TokenParser_If' => $vendorDir . '/twig/twig/lib/Twig/TokenParser/If.php',
    'Twig_TokenParser_Import' => $vendorDir . '/twig/twig/lib/Twig/TokenParser/Import.php',
    'Twig_TokenParser_Include' => $vendorDir . '/twig/twig/lib/Twig/TokenParser/Include.php',
    'Twig_TokenParser_Macro' => $vendorDir . '/twig/twig/lib/Twig/TokenParser/Macro.php',
    'Twig_TokenParser_Sandbox' => $vendorDir . '/twig/twig/lib/Twig/TokenParser/Sandbox.php',
    'Twig_TokenParser_Set' => $vendorDir . '/twig/twig/lib/Twig/TokenParser/Set.php',
    'Twig_TokenParser_Spaceless' => $vendorDir . '/twig/twig/lib/Twig/TokenParser/Spaceless.php',
    'Twig_TokenParser_Use' => $vendorDir . '/twig/twig/lib/Twig/TokenParser/Use.php',
    'Twig_TokenParser_With' => $vendorDir . '/twig/twig/lib/Twig/TokenParser/With.php',
    'Twig_TokenStream' => $vendorDir . '/twig/twig/lib/Twig/TokenStream.php',
    'Twig_Util_DeprecationCollector' => $vendorDir . '/twig/twig/lib/Twig/Util/DeprecationCollector.php',
    'Twig_Util_TemplateDirIterator' => $vendorDir . '/twig/twig/lib/Twig/Util/TemplateDirIterator.php',
    'WPML_404_Guess' => $baseDir . '/classes/query-filtering/class-wpml-404-guess.php',
    'WPML_AJAX_Action_Validation' => $baseDir . '/classes/action-filter-loader/class-wpml-ajax-action-validation.php',
    'WPML_AJAX_Base_Factory' => $baseDir . '/classes/action-filter-loader/class-wpml-ajax-action-base-factory.php',
    'WPML_Absolute_To_Permalinks' => $baseDir . '/classes/url-handling/class-wpml-absolute-to-permalinks.php',
    'WPML_Action_Filter_Loader' => $baseDir . '/classes/action-filter-loader/class-wpml-action-filter-loader.php',
    'WPML_Active_Plugin_Provider' => $baseDir . '/classes/class-wpml-active-plugin-provider.php',
    'WPML_Admin_Post_Actions' => $baseDir . '/inc/post-translation/wpml-admin-post-actions.class.php',
    'WPML_Ajax_Factory' => $baseDir . '/classes/ajax/class-wpml-ajax-factory.php',
    'WPML_Ajax_Response' => $baseDir . '/classes/ajax/class-wpml-ajax-response.php',
    'WPML_Ajax_Route' => $baseDir . '/classes/ajax/class-wpml-ajax-route.php',
    'WPML_Allowed_Redirect_Hosts' => $baseDir . '/classes/url-handling/class-wpml-allowed-redirect-hosts.php',
    'WPML_BBPress_API' => $baseDir . '/classes/compatibility/bbpress/class-wpml-bbpress-api.php',
    'WPML_BBPress_Filters' => $baseDir . '/classes/compatibility/bbpress/class-wpml-bbpress-filters.php',
    'WPML_Backend_Request' => $baseDir . '/inc/request-handling/wpml-backend-request.class.php',
    'WPML_Browser_Redirect' => $baseDir . '/classes/class-wpml-browser-redirect.php',
    'WPML_Cache_Directory' => $baseDir . '/classes/caching/class-wpml-cache-directory.php',
    'WPML_Cache_Factory' => $baseDir . '/classes/utilities/class-wpml-cache-factory.php',
    'WPML_Canonicals' => $baseDir . '/classes/canonicals/class-wpml-canonicals.php',
    'WPML_Canonicals_Hooks' => $baseDir . '/classes/canonicals/class-wpml-canonicals-hooks.php',
    'WPML_Color_Picker' => $baseDir . '/inc/utilities/wpml-color-picker.class.php',
    'WPML_Comment_Duplication' => $baseDir . '/inc/post-translation/wpml-comment-duplication.class.php',
    'WPML_Compatibility_2017' => $baseDir . '/compatibility/twentyseventeen/class-wpml-compatibility-2017.php',
    'WPML_Compatibility_Theme_Enfold' => $baseDir . '/compatibility/enfold/class-wpml-compatibility-theme-enfold.php',
    'WPML_Config' => $baseDir . '/classes/class-wpml-config.php',
    'WPML_Config_Update' => $baseDir . '/classes/class-wpml-config-update.php',
    'WPML_Config_Update_Integrator' => $baseDir . '/classes/class-wpml-config-update-integrator.php',
    'WPML_Cookie' => $baseDir . '/classes/cookie/class-wpml-cookie.php',
    'WPML_Cookie_Admin_Scripts' => $baseDir . '/classes/cookie/class-wpml-cookie-admin-scripts.php',
    'WPML_Cookie_Admin_UI' => $baseDir . '/classes/cookie/class-wpml-cookie-admin-ui.php',
    'WPML_Cookie_Scripts' => $baseDir . '/classes/cookie/class-wpml-cookie-scripts.php',
    'WPML_Cookie_Setting' => $baseDir . '/classes/cookie/class-wpml-cookie-setting.php',
    'WPML_Cookie_Setting_Ajax' => $baseDir . '/classes/cookie/class-wpml-cookie-setting-ajax.php',
    'WPML_Copy_Once_Custom_Field' => $baseDir . '/classes/custom-field-translation/class-wpml-copy-once-custom-field.php',
    'WPML_Copy_Once_Custom_Field_Factory' => $baseDir . '/classes/custom-field-translation/class-wpml-copy-once-custom-field-factory.php',
    'WPML_Create_Post_Helper' => $baseDir . '/inc/post-translation/wpml-create-post-helper.class.php',
    'WPML_Custom_Columns' => $baseDir . '/classes/menu-elements/class-wpml-custom-columns.php',
    'WPML_Custom_Columns_Hooks' => $baseDir . '/classes/menu-elements/class-wpml-custom-columns-hooks.php',
    'WPML_Custom_Field_Setting' => $baseDir . '/classes/settings/class-wpml-custom-field-setting.php',
    'WPML_Custom_Field_Setting_Factory' => $baseDir . '/classes/settings/class-wpml-custom-field-setting-factory.php',
    'WPML_Custom_Field_XML_Settings_Import' => $baseDir . '/classes/settings/class-wpml-custom-field-xml-settings-import.php',
    'WPML_DB_Chunk' => $baseDir . '/classes/class-wpml-db-chunk.php',
    'WPML_Data_Encryptor' => $baseDir . '/inc/utilities/wpml-data-encryptor.class.php',
    'WPML_Debug_BackTrace' => $baseDir . '/classes/utilities/class-wpml-debug-backtrace.php',
    'WPML_Debug_Information' => $baseDir . '/classes/troubleshoot/class-wpml-debug-information.php',
    'WPML_Dependencies' => $vendorDir . '/wpml-shared/wpml-lib-dependencies/src/dependencies/class-wpml-dependencies.php',
    'WPML_Download_Localization' => $baseDir . '/classes/localization/class-wpml-download-localization.php',
    'WPML_Duplicable_Element' => $baseDir . '/classes/translations/interface-wpml-duplicable-element.php',
    'WPML_Element_Translation' => $baseDir . '/classes/core-abstract-classes/class-wpml-element-translation.php',
    'WPML_Element_Type_Translation' => $baseDir . '/classes/translations/class-wpml-element-type-translation.php',
    'WPML_File' => $baseDir . '/classes/class-wpml-file.php',
    'WPML_Fix_Type_Assignments' => $baseDir . '/classes/troubleshoot/class-wpml-fix-type-assignments.php',
    'WPML_Flags' => $baseDir . '/classes/utilities/class-wpml-flags.php',
    'WPML_Flags_Factory' => $baseDir . '/classes/utilities/class-wpml-flags-factory.php',
    'WPML_Frontend_Post_Actions' => $baseDir . '/inc/post-translation/wpml-frontend-post-actions.class.php',
    'WPML_Frontend_Redirection' => $baseDir . '/classes/request-handling/class-wpml-frontend-redirection.php',
    'WPML_Frontend_Request' => $baseDir . '/classes/request-handling/class-wpml-frontend-request.php',
    'WPML_Frontend_Tax_Filters' => $baseDir . '/inc/taxonomy-term-translation/wpml-frontend-tax-filters.class.php',
    'WPML_Full_PT_API' => $baseDir . '/classes/core-abstract-classes/class-wpml-full-pt-api.php',
    'WPML_Full_Translation_API' => $baseDir . '/classes/core-abstract-classes/class-wpml-full-translation-api.php',
    'WPML_Get_Page_By_Path' => $baseDir . '/classes/query-filtering/class-wpml-get-page-by-path.php',
    'WPML_Global_AJAX' => $baseDir . '/classes/utilities/class-wpml-global-ajax.php',
    'WPML_Helper' => $baseDir . '/classes/class-wpml-helper.php',
    'WPML_Hierarchy_Sync' => $baseDir . '/classes/core-abstract-classes/class-wpml-hierarchy-sync.php',
    'WPML_ICL_Client' => $baseDir . '/classes/icl/class-wpml-icl-client.php',
    'WPML_ICL_Languages' => $baseDir . '/classes/records/class-wpml-icl-languages.php',
    'WPML_Include_Url' => $baseDir . '/classes/url-handling/class-wpml-include-url.php',
    'WPML_Installation' => $baseDir . '/inc/setup/wpml-installation.class.php',
    'WPML_Integrations' => $baseDir . '/classes/requirements/class-wpml-integrations.php',
    'WPML_Integrations_Requirements' => $baseDir . '/classes/requirements/class-wpml-integrations-requirements.php',
    'WPML_Integrations_Requirements_Scripts' => $baseDir . '/classes/requirements/wpml-integrations-requirements-scripts.php',
    'WPML_LS_Actions' => $baseDir . '/classes/language-switcher/public-api/class-wpml-ls-actions.php',
    'WPML_LS_Admin_UI' => $baseDir . '/classes/language-switcher/class-wpml-ls-admin-ui.php',
    'WPML_LS_Assets' => $baseDir . '/classes/language-switcher/class-wpml-ls-assets.php',
    'WPML_LS_Dependencies_Factory' => $baseDir . '/classes/language-switcher/class-wpml-ls-dependencies-factory.php',
    'WPML_LS_Footer_Slot' => $baseDir . '/classes/language-switcher/slots/class-wpml-ls-footer-slot.php',
    'WPML_LS_Inline_Styles' => $baseDir . '/classes/language-switcher/class-wpml-ls-inline-styles.php',
    'WPML_LS_Menu_Item' => $baseDir . '/classes/language-switcher/class-wpml-ls-menu-item.php',
    'WPML_LS_Menu_Slot' => $baseDir . '/classes/language-switcher/slots/class-wpml-ls-menu-slot.php',
    'WPML_LS_Migration' => $baseDir . '/classes/language-switcher/class-wpml-ls-migration.php',
    'WPML_LS_Model_Build' => $baseDir . '/classes/language-switcher/class-wpml-ls-model-build.php',
    'WPML_LS_Post_Translations_Slot' => $baseDir . '/classes/language-switcher/slots/class-wpml-ls-post-translations-slot.php',
    'WPML_LS_Public_API' => $baseDir . '/classes/language-switcher/public-api/class-wpml-ls-public-api.php',
    'WPML_LS_Render' => $baseDir . '/classes/language-switcher/class-wpml-ls-render.php',
    'WPML_LS_Settings' => $baseDir . '/classes/language-switcher/class-wpml-ls-settings.php',
    'WPML_LS_Settings_Color_Presets' => $baseDir . '/classes/language-switcher/class-wpml-ls-settings-color-presets.php',
    'WPML_LS_Settings_Sanitize' => $baseDir . '/classes/language-switcher/class-wpml-ls-settings-sanitize.php',
    'WPML_LS_Settings_Strings' => $baseDir . '/classes/language-switcher/class-wpml-ls-settings-strings.php',
    'WPML_LS_Shortcode_Actions_Slot' => $baseDir . '/classes/language-switcher/slots/class-wpml-ls-shortcode-actions-slot.php',
    'WPML_LS_Shortcodes' => $baseDir . '/classes/language-switcher/public-api/class-wpml-ls-shortcodes.php',
    'WPML_LS_Sidebar_Slot' => $baseDir . '/classes/language-switcher/slots/class-wpml-ls-sidebar-slot.php',
    'WPML_LS_Slot' => $baseDir . '/classes/language-switcher/slots/class-wpml-ls-slot.php',
    'WPML_LS_Slot_Factory' => $baseDir . '/classes/language-switcher/slots/class-wpml-ls-slot-factory.php',
    'WPML_LS_Template' => $baseDir . '/classes/language-switcher/class-wpml-ls-template.php',
    'WPML_LS_Templates' => $baseDir . '/classes/language-switcher/class-wpml-ls-templates.php',
    'WPML_LS_Widget' => $baseDir . '/classes/language-switcher/class-wpml-ls-widget.php',
    'WPML_Lang_Domain_Filters' => $baseDir . '/classes/url-handling/converter/filters/class-wpml-lang-domain-filters.php',
    'WPML_Lang_Domains_Box' => $baseDir . '/classes/menu-elements/class-wpml-lang-domains-box.php',
    'WPML_Lang_Parameter_Filters' => $baseDir . '/classes/url-handling/converter/filters/class-wpml-lang-parameter-filters.php',
    'WPML_Lang_URL_Validator' => $baseDir . '/inc/url-handling/wpml-lang-url-validator.class.php',
    'WPML_Language_Code' => $baseDir . '/classes/user-language/class-wpml-language-code.php',
    'WPML_Language_Domain_Validation' => $baseDir . '/classes/request-handling/class-wpml-language-domain-validation.php',
    'WPML_Language_Per_Domain_SSO' => $baseDir . '/classes/request-handling/class-wpml-language-per-domain-sso.php',
    'WPML_Language_Resolution' => $baseDir . '/classes/request-handling/class-wpml-language-resolution.php',
    'WPML_Language_Switcher' => $baseDir . '/classes/language-switcher/class-wpml-language-switcher.php',
    'WPML_Languages' => $baseDir . '/inc/utilities/wpml-languages.class.php',
    'WPML_Languages_AJAX' => $baseDir . '/classes/languages/class-wpml-languages-ajax.php',
    'WPML_Languages_Notices' => $baseDir . '/classes/utilities/wpml-languages-notices.php',
    'WPML_Locale' => $baseDir . '/classes/utilities/class-wpml-locale.php',
    'WPML_MO_File_Search' => $baseDir . '/classes/class-wpml-mo-file-search.php',
    'WPML_Menu_Element' => $baseDir . '/classes/translations/class-wpml-menu-element.php',
    'WPML_Menu_Item_Sync' => $baseDir . '/inc/wp-nav-menus/menu-item-sync.class.php',
    'WPML_Menu_Sync_Functionality' => $baseDir . '/inc/wp-nav-menus/wpml-menu-sync-functionality.class.php',
    'WPML_Mobile_Detect' => $baseDir . '/lib/mobile-detect.php',
    'WPML_Name_Query_Filter' => $baseDir . '/inc/query-filtering/wpml-name-query-filter.class.php',
    'WPML_Name_Query_Filter_Translated' => $baseDir . '/inc/query-filtering/wpml-name-query-filter-translated.class.php',
    'WPML_Name_Query_Filter_Untranslated' => $baseDir . '/inc/query-filtering/wpml-name-query-filter-untranslated.class.php',
    'WPML_Nav_Menu' => $baseDir . '/inc/wp-nav-menus/class-wpml-nav-menu.php',
    'WPML_Nav_Menu_Actions' => $baseDir . '/inc/taxonomy-term-translation/nav-menu-translation/wpml-nav-menu-actions.class.php',
    'WPML_Not_Doing_Ajax_On_Send_Exception' => $baseDir . '/classes/ajax/class-wpml-ajax-response.php',
    'WPML_Notice' => $baseDir . '/classes/notices/class-wpml-notice.php',
    'WPML_Notice_Action' => $baseDir . '/classes/notices/class-wpml-notice-action.php',
    'WPML_Notice_Render' => $baseDir . '/classes/notices/class-wpml-notice-render.php',
    'WPML_Notices' => $baseDir . '/classes/notices/class-wpml-notices.php',
    'WPML_Page_Name_Query_Filter' => $baseDir . '/inc/query-filtering/wpml-pagename-query-filter.class.php',
    'WPML_Plugin_Integration_Nexgen_Gallery' => $baseDir . '/inc/plugin-integration-nextgen.php',
    'WPML_Post_Comments' => $baseDir . '/inc/wpml-post-comments.class.php',
    'WPML_Post_Custom_Field_Setting' => $baseDir . '/classes/settings/class-wpml-post-custom-field-setting.php',
    'WPML_Post_Duplication' => $baseDir . '/inc/post-translation/wpml-post-duplication.class.php',
    'WPML_Post_Edit_Ajax' => $baseDir . '/inc/wpml-post-edit-ajax.class.php',
    'WPML_Post_Element' => $baseDir . '/classes/translations/class-wpml-post-element.php',
    'WPML_Post_Hierarchy_Sync' => $baseDir . '/inc/post-translation/wpml-post-hierarchy-sync.class.php',
    'WPML_Post_Status' => $baseDir . '/classes/post-translation/class-wpml-post-status.php',
    'WPML_Post_Synchronization' => $baseDir . '/inc/post-translation/wpml-post-synchronization.class.php',
    'WPML_Post_Translation' => $baseDir . '/inc/post-translation/wpml-post-translation.class.php',
    'WPML_Post_Types' => $baseDir . '/classes/post-types/class-wpml-post-types.php',
    'WPML_Pre_Option_Page' => $baseDir . '/classes/post-translation/class-wpml-pre-option-page.php',
    'WPML_Query_Filter' => $baseDir . '/inc/query-filtering/wpml-query-filter.class.php',
    'WPML_Query_Parser' => $baseDir . '/classes/query-filtering/class-wpml-query-parser.php',
    'WPML_Query_Utils' => $baseDir . '/inc/query-filtering/wpml-query-utils.class.php',
    'WPML_Records' => $baseDir . '/classes/records/class-wpml-records.php',
    'WPML_Redirect_By_Domain' => $baseDir . '/inc/request-handling/redirection/wpml-redirect-by-domain.class.php',
    'WPML_Redirect_By_Param' => $baseDir . '/inc/request-handling/redirection/wpml-redirect-by-param.class.php',
    'WPML_Redirect_By_Subdir' => $baseDir . '/inc/request-handling/redirection/wpml-redirect-by-subdir.class.php',
    'WPML_Redirection' => $baseDir . '/inc/request-handling/redirection/wpml-redirection.class.php',
    'WPML_Remove_Pages_Not_In_Current_Language' => $baseDir . '/classes/wp-core-hooks/post/class-wpml-remove-pages-not-in-current-language.php',
    'WPML_Request' => $baseDir . '/inc/request-handling/wpml-request.class.php',
    'WPML_Requirements' => $baseDir . '/classes/requirements/class-wpml-requirements.php',
    'WPML_Requirements_Notification' => $baseDir . '/classes/requirements/class-wpml-requirements-notifications.php',
    'WPML_Resolve_Object_Url_Helper' => $baseDir . '/classes/url-handling/converter/helper/class-wpml-resolve-object-url-helper.php',
    'WPML_Resolve_Object_Url_Helper_Factory' => $baseDir . '/classes/url-handling/converter/helper/class-wpml-resolve-object-url-helper-factory.php',
    'WPML_Rewrite_Rules_Filter' => $baseDir . '/classes/url-handling/converter/class-wpml-rewrite-rules-filter.php',
    'WPML_Root_Page' => $baseDir . '/classes/url-handling/class-wpml-root-page.php',
    'WPML_Root_Page_Actions' => $baseDir . '/inc/post-translation/wpml-root-page-actions.class.php',
    'WPML_Rootpage_Redirect_By_Subdir' => $baseDir . '/inc/request-handling/redirection/wpml-rootpage-redirect-by-subdir.class.php',
    'WPML_SEO_HeadLangs' => $baseDir . '/classes/seo/class-wpml-seo-headlangs.php',
    'WPML_SP_And_PT_User' => $baseDir . '/classes/core-abstract-classes/class-wpml-sp-and-pt-user.php',
    'WPML_SP_User' => $baseDir . '/classes/core-abstract-classes/class-wpml-sp-user.php',
    'WPML_Score_Hierarchy' => $baseDir . '/classes/url-handling/class-wpml-score-hierarchy.php',
    'WPML_Set_Language' => $baseDir . '/classes/core-abstract-classes/class-wpml-set-language.php',
    'WPML_Settings_Helper' => $baseDir . '/inc/setup/wpml-settings-helper.class.php',
    'WPML_Setup_Step_One_Menu' => $baseDir . '/classes/menu-elements/class-wpml-setup-step-one-menu.php',
    'WPML_Simple_Language_Selector' => $baseDir . '/classes/utilities/class-wpml-simple-language-selector.php',
    'WPML_Slash_Management' => $baseDir . '/classes/utilities/class-wpml-slash-management.php',
    'WPML_Slug_Filter' => $baseDir . '/inc/url-handling/wpml-slug-filter.class.php',
    'WPML_Slug_Resolution' => $baseDir . '/inc/query-filtering/wpml-slug-resolution.class.php',
    'WPML_Sunrise_Lang_In_Domains' => $baseDir . '/inc/tools/sunrise.php',
    'WPML_Support_Page' => $baseDir . '/classes/menu-elements/class-wpml-support-page.php',
    'WPML_Sync_Term_Meta_Action' => $baseDir . '/classes/taxonomy-term-translation/class-wpml-sync-term-meta-action.php',
    'WPML_TM_Post_Edit_Custom_Field_Settings_Menu' => $baseDir . '/classes/menu-elements/class-wpml-tm-post-edit-custom-field-settings-menu.php',
    'WPML_TM_Settings_Post_Process' => $baseDir . '/classes/settings/class-wpml-tm-settings-post-process.php',
    'WPML_TM_Settings_Update' => $baseDir . '/classes/settings/class-wpml-tm-settings-update.php',
    'WPML_TM_User' => $baseDir . '/classes/core-abstract-classes/class-wpml-tm-user.php',
    'WPML_Tax_Permalink_Filters' => $baseDir . '/classes/url-handling/converter/filters/class-wpml-tax-permlink-filters.php',
    'WPML_Taxonomy_Translation' => $baseDir . '/classes/menu-elements/class-wpml-taxonomy-translation.php',
    'WPML_Taxonomy_Translation_Help_Notice' => $baseDir . '/classes/taxonomy-term-translation/class-wpml-taxonomy-translation-help-notice.php',
    'WPML_Taxonomy_Translation_Screen_Data' => $baseDir . '/classes/menu-elements/class-wpml-taxonomy-translation-screen-data.php',
    'WPML_Taxonomy_Translation_UI' => $baseDir . '/classes/menu-elements/class-wpml-taxonomy-translation-ui.php',
    'WPML_Templates_Factory' => $baseDir . '/classes/templating/class-wpml-templates-factory.php',
    'WPML_Temporary_Switch_Admin_Language' => $baseDir . '/classes/utilities/class-wpml-temporary-switch-admin-language.php',
    'WPML_Temporary_Switch_Language' => $baseDir . '/classes/utilities/class-wpml-temporary-switch-language.php',
    'WPML_Term_Actions' => $baseDir . '/classes/taxonomy-term-translation/class-wpml-term-actions.php',
    'WPML_Term_Custom_Field_Setting' => $baseDir . '/classes/settings/class-wpml-term-custom-field-setting.php',
    'WPML_Term_Element' => $baseDir . '/classes/translations/class-wpml-term-element.php',
    'WPML_Term_Filters' => $baseDir . '/inc/taxonomy-term-translation/wpml-term-filters.class.php',
    'WPML_Term_Hierarchy_Duplication' => $baseDir . '/inc/taxonomy-term-translation/wpml-term-hierarchy-duplication.class.php',
    'WPML_Term_Hierarchy_Sync' => $baseDir . '/inc/taxonomy-term-translation/wpml-term-hierarchy-sync.class.php',
    'WPML_Term_Language_Synchronization' => $baseDir . '/classes/taxonomy-term-translation/class-wpml-term-language-synchronization.php',
    'WPML_Term_Translation' => $baseDir . '/inc/taxonomy-term-translation/wpml-term-translation.class.php',
    'WPML_Term_Translation_Utils' => $baseDir . '/inc/taxonomy-term-translation/wpml-term-translation-utils.class.php',
    'WPML_Terms_Translations' => $baseDir . '/inc/taxonomy-term-translation/wpml-term-translations.class.php',
    'WPML_Theme_Localization_Type' => $baseDir . '/classes/class-wpml-theme-localization-type.php',
    'WPML_Third_Party_Dependencies' => $baseDir . '/classes/requirements/class-wpml-third-party-dependencies.php',
    'WPML_Translate_Independently' => $baseDir . '/classes/class-wpml-translate-independently.php',
    'WPML_Translate_Link_Targets' => $baseDir . '/classes/utilities/class-wpml-translate-link-targets.php',
    'WPML_Translate_Link_Targets_Hooks' => $baseDir . '/classes/translation-management/class-wpml-translate-link-targets-hooks.php',
    'WPML_Translate_Link_Targets_In_Custom_Fields' => $baseDir . '/classes/custom-field-translation/class-wpml-translate-link-targets-in-custom-fields.php',
    'WPML_Translate_Link_Targets_In_Custom_Fields_Hooks' => $baseDir . '/classes/custom-field-translation/class-wpml-translate-link-targets-in-custom-fields-hooks.php',
    'WPML_Translation_Element' => $baseDir . '/classes/translations/class-wpml-translation-element.php',
    'WPML_Translation_Management_Filters_And_Actions' => $baseDir . '/classes/translation-management/class-wpml-translation-management-filters-and-actions.php',
    'WPML_Translation_Tree' => $baseDir . '/classes/menu-elements/class-wpml-translation-tree.php',
    'WPML_Translations' => $baseDir . '/classes/translations/class-wpml-translations.php',
    'WPML_Translator' => $baseDir . '/inc/translation-management/wpml-translator.class.php',
    'WPML_Troubleshoot_Action' => $baseDir . '/classes/troubleshoot/class-wpml-troubleshoot-action.php',
    'WPML_Troubleshoot_Sync_Posts_Taxonomies' => $baseDir . '/classes/troubleshoot/class-wpml-troubleshoot-sync-posts-taxonomies.php',
    'WPML_Twig' => $baseDir . '/classes/deprecated/class-wpml-twig.php',
    'WPML_Twig_Template' => $baseDir . '/classes/templates/class-wpml-twig-template.php',
    'WPML_Twig_Template_Loader' => $baseDir . '/classes/templates/wpml-twig-template-loader.php',
    'WPML_Twig_WP_Plugin_Extension' => $baseDir . '/classes/twig-extensions/wpml-twig-wp-plugin-extension.php',
    'WPML_UI_Help_Tab' => $baseDir . '/classes/ui-elements/class-wpml-ui-help-tab.php',
    'WPML_UI_Pagination' => $baseDir . '/classes/ui-elements/class-wpml-ui-pagination.php',
    'WPML_UI_Screen_Options_Factory' => $baseDir . '/classes/ui-elements/class-wpml-ui-screen-options-factory.php',
    'WPML_UI_Screen_Options_Pagination' => $baseDir . '/classes/ui-elements/class-wpml-ui-screen-options-pagination.php',
    'WPML_URL_Cached_Converter' => $baseDir . '/classes/url-handling/converter/class-wpml-url-cached-converter.php',
    'WPML_URL_Converter' => $baseDir . '/classes/url-handling/converter/class-wpml-url-converter.php',
    'WPML_URL_Converter_Abstract_Strategy' => $baseDir . '/classes/url-handling/converter/strategy/class-wpml-url-converter-abstract-strategy.php',
    'WPML_URL_Converter_CPT' => $baseDir . '/classes/url-handling/converter/class-wpml-url-converter-cpt.php',
    'WPML_URL_Converter_Domain_Strategy' => $baseDir . '/classes/url-handling/converter/strategy/class-wpml-url-converter-domain-strategy.php',
    'WPML_URL_Converter_Factory' => $baseDir . '/classes/url-handling/converter/class-wpml-url-converter-factory.php',
    'WPML_URL_Converter_Lang_Param_Helper' => $baseDir . '/classes/url-handling/converter/helper/class-wpml-url-converter-lang-param-helper.php',
    'WPML_URL_Converter_Parameter_Strategy' => $baseDir . '/classes/url-handling/converter/strategy/class-wpml-url-converter-parameter-strategy.php',
    'WPML_URL_Converter_Subdir_Strategy' => $baseDir . '/classes/url-handling/converter/strategy/class-wpml-url-converter-subdir-strategy.php',
    'WPML_URL_Converter_Test_Strategy' => $baseDir . '/classes/url-handling/converter/strategy/class-wpml-url-converter-test-strategy.php',
    'WPML_URL_Converter_Url_Helper' => $baseDir . '/classes/url-handling/converter/helper/class-wpml-url-converter-url-helper.php',
    'WPML_URL_Converter_User' => $baseDir . '/classes/core-abstract-classes/class-wpml-url-converter-user.php',
    'WPML_URL_Filters' => $baseDir . '/inc/url-handling/wpml-url-filters.class.php',
    'WPML_Update_Term_Action' => $baseDir . '/inc/taxonomy-term-translation/wpml-update-term-action.class.php',
    'WPML_Update_Term_Count' => $baseDir . '/classes/taxonomy-term-translation/class-wpml-update-term-count.php',
    'WPML_Upgrade' => $baseDir . '/classes/upgrade/class-wpml-upgrade.php',
    'WPML_Upgrade_Admin_Users_Languages' => $baseDir . '/classes/upgrade/wpml-upgrade-admin-users-languages.php',
    'WPML_Upgrade_Command_Definition' => $baseDir . '/classes/upgrade/class-wpml-upgrade-command-definition.php',
    'WPML_Upgrade_Command_Factory' => $baseDir . '/classes/upgrade/class-wpml-upgrade-command-factory.php',
    'WPML_Upgrade_Localization_Files' => $baseDir . '/classes/upgrade/class-wpml-upgrade-localizations-files.php',
    'WPML_User_Language' => $baseDir . '/classes/user-language/class-wpml-user-language.php',
    'WPML_User_Language_Switcher' => $baseDir . '/classes/user-language/class-wpml-user-language-switcher.php',
    'WPML_User_Language_Switcher_Hooks' => $baseDir . '/classes/user-language/class-wpml-user-language-switcher-hooks.php',
    'WPML_User_Language_Switcher_Resources' => $baseDir . '/classes/user-language/class-wpml-user-language-switcher-resources.php',
    'WPML_User_Language_Switcher_UI' => $baseDir . '/classes/user-language/class-wpml-user-language-switcher-ui.php',
    'WPML_User_Options_Menu' => $baseDir . '/classes/menu-elements/class-wpml-user-options-menu.php',
    'WPML_Users_Languages' => $baseDir . '/classes/user-language/class-wpml-users-languages.php',
    'WPML_Users_Languages_Dependencies' => $baseDir . '/classes/user-language/class-wpml-users-languages-dependencies.php',
    'WPML_WPDB_And_SP_User' => $baseDir . '/classes/core-abstract-classes/class-wpml-wpdb-and-sp-user.php',
    'WPML_WPDB_User' => $baseDir . '/classes/core-abstract-classes/class-wpml-wpdb-user.php',
    'WPML_WPSEO_Filters' => $baseDir . '/classes/compatibility/wpseo/class-wpml-wpseo-filters.php',
    'WPML_WPSEO_Redirection' => $baseDir . '/classes/compatibility/wpseo/class-wpml-wpseo-redirection.php',
    'WPML_WPSEO_XML_Sitemaps_Filter' => $baseDir . '/classes/compatibility/wpseo/class-wpml-wpseo-xml-sitemaps-filter.php',
    'WPML_WP_API' => $baseDir . '/classes/wpml-wp/class-wpml-wp-api.php',
    'WPML_WP_Cache' => $baseDir . '/classes/utilities/class-wpml-wp-cache.php',
    'WPML_WP_Comments' => $baseDir . '/classes/comments/wpml-wp-comments.php',
    'WPML_WP_Filter_State' => $baseDir . '/classes/utilities/class-wpml-wp-filter-state.php',
    'WPML_WP_Post' => $baseDir . '/classes/utilities/class-wpml-wp-post.php',
    'WPML_WP_Query_API' => $baseDir . '/classes/utilities/class-wpml-wp-query-api.php',
    'WPML_WP_Taxonomy_Query' => $baseDir . '/classes/utilities/class-wpml-wp-taxonomy-query.php',
    'WPML_WordPress_Actions' => $baseDir . '/inc/post-translation/wpml-wordpress-actions.class.php',
    'WPML_XDomain_Data_Parser' => $baseDir . '/classes/url-handling/class-wpml-xdomain-data-parser.php',
    'WPML_XML2Array' => $baseDir . '/classes/utilities/class-wpml-xml2array.php',
    'WPML_XMLRPC' => $baseDir . '/classes/class-wpml-xmlrpc.php',
    'WPML_custom_post_sync_settings' => $baseDir . '/classes/class-wpml-custom-post-sync-settings.php',
    'dqml2tree' => $baseDir . '/lib/dqml2tree.php',
    'icl_cache' => $baseDir . '/inc/cache.php',
    'xrstf\\Composer52\\AutoloadGenerator' => $vendorDir . '/xrstf/composer-php52/lib/xrstf/Composer52/AutoloadGenerator.php',
    'xrstf\\Composer52\\Generator' => $vendorDir . '/xrstf/composer-php52/lib/xrstf/Composer52/Generator.php',
);
