<p>
    <input id="icl_run_st_db_cache_command"
           type="button" class="button-secondary"
           value="{{ buttonLabel }}"
           data-success-message="{{ successMsg }}"
           data-nonce="{{ nonce }}"
    />
    <br/>
    <small style="margin-left:10px;">{{ description }}</small>
</p>