/* These are overrides to get the select2 to behave how we
 * want in the css editor
 */

.select2-drop-mask {
    
    z-index: 19998;
}

.select2-drop {
    z-index: 19999;
}


.select2-search {
    z-index: 20000;
}

.select2-results li {
    margin-bottom: 0px !important;
}

.select2-results {
    padding-left: 0px !important;
}

