<?php
/**
 * Module Name: SEO Tools
 * Module Description: Better results on search engines and social media.
 * Jumpstart Description: Better results on search engines and social media.
 * Sort Order: 35
 * Recommendation Order: 15
 * First Introduced: 4.4
 * Requires Connection: Yes
 * Auto Activate: No
 * Module Tags: Social, Appearance
 * Feature: Traffic, Jumpstart
 * Additional Search Queries: search engine optimization, social preview, meta description, custom title format
 */

include dirname( __FILE__ ) . '/seo-tools/jetpack-seo.php';

new Jetpack_SEO;
