.vc_layout-panel-switcher() {
  .vc_layout-btn {
    display: inline-block;
    background-position: center center;
    background-repeat: no-repeat;
    background-color: white;
    cursor: pointer;
    padding: 2px;
    margin: 1px 4px 1px 0;
    &:hover {
      background-color: #00aeed;
    }
    .icon {
      width: 23px;
      height: 11px;
      background: transparent url('../vc/fe/layout_sprite.png') left top no-repeat;
      display: inline-block;
    }
    &:hover {
      .icon {
        background-position: right top;
      }
    }
    &.l_12_12 {
      .icon {
        background-position: left -12px;
      }
      &:hover {
        .icon {
          background-position: right -12px;
        }
      }
    }
    &.l_23_13 {
      .icon {
        background-position: left -24px;
      }
      &:hover {
        .icon {
          background-position: right -24px;
        }
      }
    }
    &.l_13_13_13 {
      .icon {
        background-position: left -36px;
      }
      &:hover {
        .icon {
          background-position: right -36px;
        }
      }
    }
    &.l_14_14_14_14 {
      .icon {
        background-position: left -48px;
      }
      &:hover {
        .icon {
          background-position: right -48px;
        }
      }
    }
    &.l_14_34 {
      .icon {
        background-position: left -60px;
      }
      &:hover {
        .icon {
          background-position: right -60px;
        }
      }
    }
    &.l_14_12_14 {
      .icon {
        background-position: left -72px;
      }
      &:hover {
        .icon {
          background-position: right -72px;
        }
      }
    }
    &.l_56_16 {
      .icon {
        background-position: left -84px;
      }
      &:hover {
        .icon {
          background-position: right -84px;
        }
      }
    }
    &.l_16_16_16_16_16_16 {
      .icon {
        background-position: left -96px;
      }
      &:hover {
        .icon {
          background-position: right -96px;
        }
      }
    }
    &.l_16_46_16 {
      .icon {
        background-position: left -108px;
      }
      &:hover {
        .icon {
          background-position: right -108px;
        }
      }
    }
    &.l_16_16_16_12 {
      .icon {
        background-position: left -120px;
      }
      &:hover {
        .icon {
          background-position: right -120px;
        }
      }
    }
  }
  .vc_custom-layout-btn {
    background-color: transparent;
    display: block;
    width: auto;
    height: auto;
    margin: 4px 0 3px;
    font-size: 11px;
    text-align: center;
  }
}

#vc_row-layout-panel {
  width: 420px;
  z-index: 100001;
  top: 90px;
  left: 50%;
  .vc_row_layout {
    width: 317px;
  }
  .vc_layout-panel-switcher {
    .vc_layout-panel-switcher;
  }
}

#vc_row-layout-update {
  vertical-align: top;
}