
@media only screen and (min-width:690px) {
	#redux-header img {
		display: inline-block;
		position: relative;
		top: 3px;
	}
	#redux-header {
		background-color: #19a1f7!important;
	}
	.redux-container #redux-intro-text, .redux-main #redux-sticky #info_bar .expand_options { display: none;}
	.redux-container #redux-header {
		padding: 0;
		border: none;
		text-align: left;
	}
	.redux-container .display_header {
		background-color: #1898e9;
		margin: 0!important;
		padding: 20px 25px;
		float: none;
		display: inline-block;
	}
	.redux-container .notice-yellow {
		background-color: #fff;
		color: #77cc6d;
	}
	.form-table td {
		padding-left: 20px;
	}
	.redux_field_th {
		line-height: 20px;
	}
	.redux-container #info_bar, .redux-main, .redux-container #redux-footer {
		background-color: #fff!important;
	}
	.redux-container .secondary-header {
		float: none;
		color: rgba(255,255,255,0.7);
		padding: 20px 20px 0px 20px;
		display: inline-block;
	}
	html .redux-main .redux-container-switch .cb-disable.selected, .wp-customizer .redux-container-switch .cb-disable.selected, 
	html .redux-main .redux-container-switch .cb-enable.selected {
		background-image: none!Important;
		box-shadow: none!important;
	}
	.admin-color-fresh .select2-results .select2-highlighted, .wp-customizer .select2-results .select2-highlighted {
		background-color: #19a1f7!important;
	}
	.admin-color-fresh .redux-main .redux-container-switch .cb-enable.selected {
		background-color: #19a1f7!important;
		border-color: #198ad1!important;
	}
	.admin-color-fresh .redux-container-image_select .redux-image-select-selected img, .wp-customizer .redux-container-image_select .redux-image-select-selected img {
		border-color: #19a1f7!important;
	}
	.admin-color-fresh .redux-container .redux-main .button {
		text-shadow: none!important;
		box-shadow: none!important;
		border: none;
		opacity: 1;
		background-color: #ebebeb;
		margin: 6px 3px;
		transition: all 0.13s linear;
	}
	.redux-main #redux_ajax_overlay {
		background-color: #fff;
		opacity: 0.55;
	}
	.redux-container .wp-picker-container input[type=text].wp-color-picker {
		margin-left: 5px;
	}
	.admin-color-fresh .redux-container .redux-main .wp-picker-clear {
		margin-top: 0!important;
		margin-bottom: 0!important;
	}
	.redux-container .redux-main .button {
		margin: 6px 3px;
	}
	.admin-color-fresh .redux-container .redux-main .button:hover {
		background-color: #f4f4f4;
	}
	.admin-color-fresh .redux-container .redux-main .button.button-primary:hover {
		opacity: 0.8;
		border: none;
	}
	.admin-color-fresh  .redux-main .button.remove-image, .redux-main .removeCSS {
	    color: #fff!important;
	    background-color: #3d434f!important;
	}
	.admin-color-fresh .redux-container .redux-main .theme-browser .button-primary {
		background-color: #19a1f7!important;
		background-image: none!Important;
		text-shadow: none!important;
		box-shadow: none!important;
		color: #fff!important;
		transition: all 0.13s linear;
		border: none;
	}
	.admin-color-fresh .redux-container .redux-main .theme-browser .button-primary:hover {
		opacity: 0.8;
	}
	.admin-color-fresh .redux-container .redux-main .button.button-primary {
		background-color: #77cc6d!important;
		background-image: none!Important;
		text-shadow: none!important;
		box-shadow: none!important;
		color: #fff!important;
		border: none;
	}
	.admin-color-fresh .noUi-connect {
		background-color: #19a1f7!important;
		background-image: none!Important;
	}
	.redux-container #redux-header .display_header h2 {
		font-size: 16px;
	}
	.redux-container  #redux-header .display_header span {
		color: #fff;
	}
	.redux-container .secondary-header h4 {
		text-shadow: none;
		font-weight: 300!important;
	}
	.redux-container .redux-sidebar, .redux-container .display_header {
		width: 255px;
		box-sizing: border-box;
	}
	.redux-sidebar .redux-group-menu li.active a, .redux-sidebar .redux-group-menu li.active a:hover, .redux-sidebar .redux-group-menu li.activeChild a, .redux-sidebar .redux-group-menu li.activeChild a:hover {
		width: 255px;
		box-sizing: border-box;
	}

	.redux-container #redux-header .display_header span.redux-dev-mode-notice {
		font-weight: 300!important;
	}

	#redux-header h2 {
		max-width: 170px;
		margin-left: 5px;
		display: inline-block;
	}

	.redux-main {
		margin-left: 255px;
	}

	.redux-container #redux-header .display_header .redux-dev-mode-notice-container {
		bottom: 13px;
		left: auto;
		right: 25px;
		top: 34px;
		font-size: 12px;
	}

	.redux-container .el-chevron-down {
		font-size: 8px!important;
		right: 20px!important;
		margin-top: -6px!important;
	}

	 .redux-sidebar .redux-group-menu li.activeChild.hasSubSections a, .wp-customizer .redux-sidebar .redux-group-menu li.activeChild.hasSubSections a {
		text-shadow: none;
	}

	.redux-sidebar .redux-group-tab-link-a i { 
		font-size: 18px;
		line-height: 18px;
	}
	.redux-image-select label {
		font-size: 12px;
	}

	 tr.five-columns {
	    width: 20%;
	    margin-top: 20px;
	    min-width: 160px;
	    float: none;
	}

	tr.five-columns th {
		display: block;
		width: auto!important;
	}

	.redux-container-image_select .redux-image-select img {
		margin: 5px;
	}

	.redux-container-image_select .redux-image-select {
		padding: 5px;
	}

	.redux-image-select label span {
		padding: 5px;
	}

	.redux-main #redux-sticky #info_bar {
		height: 38px;
   	   padding-top: 6px;
	}
	.redux-sidebar .redux-group-menu li a {
		padding: 16px 4px 16px 25px;
	}
	.redux-sidebar .redux-group-tab-link-a span.group_title {
		padding-left: 30px;
	}
	.redux-main {
		border-left: none!important;
	}
	.redux-container .redux-sidebar {
	    position: relative;
	}

	.redux-container {
		background-color: #3d434f!important;
		background-image: none!important;
	}
	body .redux-container  .redux-sidebar .redux-group-menu li a {
		background-color: #3d434f;
		border-color: rgba(255,255,255,0.06);
		color: rgba(255,255,255,0.75);
		text-shadow: none!Important;
		opacity: 1;
	}

	html .redux-container  .redux-sidebar .redux-group-menu * {
		font-weight: 300!important;
	}

	html .redux-container  .redux-sidebar .redux-group-menu li.activeChild.hasSubSections ul.subsection li a, .wp-customizer .redux-sidebar .redux-group-menu li.activeChild.hasSubSections ul.subsection li a {
		background-color: #f6f6f6;
		color: rgba(0,0,0,1);
	}
	html body .redux-container  .redux-sidebar .redux-group-menu li.activeChild.hasSubSections ul.subsection li a:hover {
		background-color: #e9e9e9!important;
		color: rgba(0,0,0,1)!important;
	}
	html .redux-container  .redux-sidebar .redux-group-menu li.activeChild.hasSubSections ul.subsection li.active a, .wp-customizer .redux-sidebar .redux-group-menu li.activeChild.hasSubSections ul.subsection li.active a {
		background-color: #f6f6f6!important;
		color: rgba(0,0,0,1);
		font-weight: 600!important;
	}
	html .redux-sidebar .redux-group-menu li.activeChild.hasSubSections ul.subsection li.active a span, .wp-customizer .redux-sidebar .redux-group-menu li.activeChild.hasSubSections ul.subsection li.active a span {
	font-weight: 600!important;
	}

	html .redux-container .redux-sidebar .redux-group-tab-link-a i {
		color: #75819b;
		text-shadow: none!important;
	}

	html .redux-container .redux-sidebar .redux-group-tab-link-li.activeChild i, html .redux-container  .redux-sidebar .redux-group-tab-link-li.active i {
		color: #19a1f7!important;
	}


	body .redux-sidebar .redux-group-menu li > a:hover {
		background-color: #49505e;
		color: #fff;
	}
	html .redux-sidebar .redux-group-menu li.redux-group-tab-link-li.active > a,  html .redux-container .redux-sidebar .redux-group-menu li.activeChild.hasSubSections a  {
		background-color: #fff;
		color: #000;
	}
	 html .redux-sidebar .redux-group-menu li.active.hasSubSections .active a:after,  html .redux-container  .redux-sidebar .redux-group-menu li.activeChild.hasSubSections .active a:after, .wp-customizer .redux-sidebar .redux-group-menu li.active.hasSubSections .active a:after, .wp-customizer .redux-sidebar .redux-group-menu li.activeChild.hasSubSections .active a:after {
		display: none!important;
	}

}