.vc_gitem-shortcode {
  .wpb_vc_gitem_zone_c, .wpb_vc_gitem_zone_a, .wpb_vc_gitem_zone_b {
    background-color: #f5f5f5;
    padding: 4px;
    margin: 0;
    .vc_element-icon {
      background: transparent;
    }
    > .wpb_element_wrapper > .vc_container_for_children {
      margin: 0;
    }
  }
}

.wpb_vc_gitem_zone_c {
  position: relative;
  margin-top: 24px;
  min-height: 100%;
  box-sizing: border-box;
  > .vc_controls {
    position: absolute;
    top: -24px;
    left: 0;
    padding: 0;
    margin: 0;
    .vc_control {
      background-color: #f5f5f5;
      padding: 4px;
      .border-top-radius(@vc_gitem_round_radius);
    }
    .column_edit, .column_delete {
      float: right;
    }
    &.bottom-controls {
      position: static;
    }
  }
  > .vc_css-helper {
    position: absolute;
    top: 3px;
    right: 55px;
    &.vc_featured {
      background-image: url('../vc/vc_gitem_image.png');
      background-size: cover;
      margin-top: 3px;
      width: 16px;
      height: 16px;
      display: inline-block;
      margin-right: 3px;
      border-radius: 8px;
      right: 95px;
    }
    + .vc_css-helper {
      right: 75px;
    }
  }
  > .vc_color-helper {
    position: absolute;
    top: -25px;
    right: 55px;
  }
}

.wpb_vc_gitem_zone_a, .wpb_vc_gitem_zone_b {
  position: relative;
  .border-top-radius(@vc_gitem_round_radius);
  .border-bottom-radius(@vc_gitem_round_radius);
  > .vc_css-helper {
    position: absolute;
    top: 3px;
    right: 0;
    &.vc_featured {
      background-image: url('../vc/vc_gitem_image.png');
      background-size: cover;
      margin-top: 3px;
      width: 16px;
      height: 16px;
      display: inline-block;
      margin-right: 3px;
      border-radius: 8px;
    }
    + .vc_css-helper {
      right: 20px;
    }
    + .vc_featured {
      right: 40px;
    }
  }
  > .vc_controls {
    display: none;
  }
  > .wpb_element_wrapper {
    > .vc_container_for_children {
      margin: 0;
    }
  }
}