<?php
class Foobar { use function Baz }
class Foobar { use function abstract }
class Foobar { use function and }
class Foobar { use function array }
class Foobar { use function as }
class Foobar { use function break }
class Foobar { use function callable }
class Foobar { use function case }
class Foobar { use function catch }
class Foobar { use function class }
class Foobar { use function clone }
class Foobar { use function const }
class Foobar { use function continue }
class Foobar { use function declare }
class Foobar { use function default }
class Foobar { use function do }
class Foobar { use function else }
class Foobar { use function elseif }
class Foobar { use function enddeclare }
class Foobar { use function endfor }
class Foobar { use function endforeach }
class Foobar { use function endif }
class Foobar { use function endswitch }
class Foobar { use function endwhile }
class Foobar { use function extends }
class Foobar { use function final }
class Foobar { use function finally }
class Foobar { use function for }
class Foobar { use function foreach }
class Foobar { use function function }
class Foobar { use function global }
class Foobar { use function goto }
class Foobar { use function if }
class Foobar { use function implements }
class Foobar { use function interface }
class Foobar { use function instanceof }
class Foobar { use function insteadof }
class Foobar { use function namespace }
class Foobar { use function new }
class Foobar { use function or }
class Foobar { use function private }
class Foobar { use function protected }
class Foobar { use function public }
class Foobar { use function static }
class Foobar { use function switch }
class Foobar { use function throw }
class Foobar { use function trait }
class Foobar { use function try }
class Foobar { use function use }
class Foobar { use function var }
class Foobar { use function while }
class Foobar { use function xor }
class Foobar { use function __CLASS__ }
class Foobar { use function __DIR__ }
class Foobar { use function __FILE__ }
class Foobar { use function __FUNCTION__ }
class Foobar { use function __METHOD__ }
class Foobar { use function __NAMESPACE__ }
