.redux-container-color_gradient {
    .colorGradient {
        display: inline-block;
    }
    .toLabel {
        padding-left: 18px;
    }
}

@media screen and (max-width: 660px) {
    .redux-container-color_gradient {
        .colorGradient {
            display: block;
            text-align: center !important;
        }
    }
}