<?php
interface Baz {}
interface abstract {}
interface and {}
interface array {}
interface as {}
interface break {}
interface callable {}
interface case {}
interface catch {}
interface class {}
interface clone {}
interface const {}
interface continue {}
interface declare {}
interface default {}
interface do {}
interface else {}
interface elseif {}
interface enddeclare {}
interface endfor {}
interface endforeach {}
interface endif {}
interface endswitch {}
interface endwhile {}
interface extends {}
interface final {}
interface finally {}
interface for {}
interface foreach {}
interface function {}
interface global {}
interface goto {}
interface if {}
interface implements {}
interface interface {}
interface instanceof {}
interface insteadof {}
interface namespace {}
interface new {}
interface or {}
interface private {}
interface protected {}
interface public {}
interface static {}
interface switch {}
interface throw {}
interface trait {}
interface try {}
interface use {}
interface var {}
interface while {}
interface xor {}
interface __CLASS__ {}
interface __DIR__ {}
interface __FILE__ {}
interface __FUNCTION__ {}
interface __METHOD__ {}
interface __NAMESPACE__ {}
