<?php
use Foobar as Baz;
use Foobar as abstract;
use Foobar as and;
use Foobar as array;
use Foobar as as;
use Foobar as break;
use Foobar as callable;
use Foobar as case;
use Foobar as catch;
use Foobar as class;
use Foobar as clone;
use Foobar as const;
use Foobar as continue;
use Foobar as declare;
use Foobar as default;
use Foobar as do;
use Foobar as else;
use Foobar as elseif;
use Foobar as enddeclare;
use Foobar as endfor;
use Foobar as endforeach;
use Foobar as endif;
use Foobar as endswitch;
use Foobar as endwhile;
use Foobar as extends;
use Foobar as final;
use Foobar as finally;
use Foobar as for;
use Foobar as foreach;
use Foobar as function;
use Foobar as global;
use Foobar as goto;
use Foobar as if;
use Foobar as implements;
use Foobar as interface;
use Foobar as instanceof;
use Foobar as insteadof;
use Foobar as namespace;
use Foobar as new;
use Foobar as or;
use Foobar as private;
use Foobar as protected;
use Foobar as public;
use Foobar as static;
use Foobar as switch;
use Foobar as throw;
use Foobar as trait;
use Foobar as try;
use Foobar as use;
use Foobar as var;
use Foobar as while;
use Foobar as xor;
use Foobar as __CLASS__;
use Foobar as __DIR__;
use Foobar as __FILE__;
use Foobar as __FUNCTION__;
use Foobar as __METHOD__;
use Foobar as __NAMESPACE__;
