/* Product of Orbisius.com. Visit http://club.orbisius.com/ */
.orbisius_child_theme_creator_container .app-hide {
    display: none;
}

.orbisius_child_theme_creator_container .app-hide-force {
    display: none !important;
}

.orbisius_child_theme_creator_container .app-form-field-error {
    border-color: red;
}

.orbisius_child_theme_creator_container .app-serious-notice {
    color: red;
    font-weight: bold;
}

/* Common */
.orbisius_child_theme_creator_container .app-alert-error {
    background: #D54E21;
    border: 1px solid #eee;
    color: white;
    padding: 3px;
    /*text-align: center;*/
}

.orbisius_child_theme_creator_container .app-alert-success {
    background: green;
    border: 1px solid #eee;
    color: white;
    padding: 3px;
    /*text-align: center;*/
}

.orbisius_child_theme_creator_container .app-alert-success a, .orbisius_child_theme_creator_container .app-alert-error a {
    color: white;
}

.orbisius_child_theme_creator_container .app-alert-notice {
    background: #FFEC8B;
    border: 1px solid #666;
    padding: 3px;
    /*text-align: center;*/
}

.orbisius_child_theme_creator_container .app-button-positive {
    background: green;
    color: white;
    padding: 3px;
    text-decoration: none;
}

.orbisius_child_theme_creator_container .app-button-negative {
    background: red;
    color: white;
    padding: 3px;
    text-decoration: none;
}

.orbisius_child_theme_creator_container .highlight {
    background: #FFFF33;
}

/* dlg button colouring */
.orbisius_child_theme_creator_container .app-dialog-button-ok {
    background: green !important;
    color: white !important;
}

.orbisius_child_theme_creator_container .app-dialog-button-cancel {
    background: red !important;
    color: white !important;
}

.orbisius_child_theme_creator_container .app-button-left, .app-align-left{
    float: left;
}

.orbisius_child_theme_creator_container .app-button-right, .orbisius_child_theme_creator_container .app-align-right {
    float: right;
}

.orbisius_child_theme_creator_container .app-button-container {
    padding:10px;
    background: #ccc;
    margin-top: 15px;
    margin-bottom: 15px;
}

.orbisius_child_theme_creator_container .available-theme {
    padding:10px;
    margin:5px;
    border: 2px solid white; /* we need this because there is a shift otherwise on hover. */
    display:inline-block; /* so 3 themes fit on one row */
    width: 28%;
}

.orbisius_child_theme_creator_container .available-theme img.screenshot {
    max-height: 75%;
    max-width: 75%;
}

.orbisius_child_theme_creator_container .available-theme:hover {
    border: 2px solid #444;
    background: #ccc;
}

.orbisius_child_theme_creator_container .saving_action {
    background: #ccc;
}

/* Theme Editor */
.orbisius_ctc_theme_editor_container .highlight {
    background: #FFFF33;
}

.orbisius_ctc_theme_editor_container .app-dialog-button-ok {
    background: green !important;
    color: white !important;
}

.orbisius_ctc_theme_editor_container .app-dialog-button-cancel {
    background: red !important;
    color: white !important;
}

/* The dropdowns move to a new line when files are longer */
.orbisius_ctc_theme_editor_container #theme_1, .orbisius_ctc_theme_editor_container #theme_2, 
	.orbisius_ctc_theme_editor_container #theme_1_file, .orbisius_ctc_theme_editor_container #theme_2_file {
	max-width:35%;
}

.orbisius_ctc_theme_editor_container .primary_buttons {
    margin-top:5px;
}

.orbisius_ctc_theme_editor_theme_1_form .modified_content,
.orbisius_ctc_theme_editor_theme_2_form .modified_content {
    border: 1px dashed #D54E21/* !important*/;
}