.wpml-ls-legacy-list-vertical {
  display: table;
  max-width: 100%;
  border: 1px solid transparent;
  border-bottom: 0;
  & > ul {
    position: relative;
    padding: 0;
    margin: 0 !important;
    list-style-type: none;
  }

  .wpml-ls-item {
    padding: 0;
    margin: 0;
    list-style-type: none;
  }

  a {
    display: block;
    text-decoration: none;
    border-bottom: 1px solid transparent;
    padding: 5px 10px;
    line-height: 1;
    span {
      vertical-align: middle;
    }
  }

  .wpml-ls-flag {
    display: inline;
    vertical-align: middle;
    width: 18px;
    height: 12px;
  }

  .wpml-ls-flag + span {
    margin-left: .4em;
    .rtl & {
      margin-left: 0;
      margin-right: .4em;
    }
  }

  // Special styles for widget in footer (e.g. Twenty Sixteen theme has ::after black stripe there covering LS)
  &.wpml-ls-statics-footer {
    margin-bottom: 30px;
  }
}