��X<?php exit; ?>a:1:{s:7:"content";a:38:{s:17:"_vc_post_settings";a:1:{i:0;s:30:"a:1:{s:10:"vc_grid_id";a:0:{}}";}s:10:"_edit_last";a:1:{i:0;s:1:"1";}s:17:"_wp_page_template";a:1:{i:0;s:0:"";}s:32:"nectar-metabox-portfolio-display";a:1:{i:0;s:20:"a:1:{i:0;s:3:"all";}";}s:41:"nectar-metabox-portfolio-display-sortable";a:1:{i:0;s:3:"off";}s:22:"_nectar_slider_bg_type";a:1:{i:0;s:8:"image_bg";}s:21:"_nectar_canvas_shapes";a:1:{i:0;s:0:"";}s:25:"_nectar_media_upload_webm";a:1:{i:0;s:0:"";}s:24:"_nectar_media_upload_mp4";a:1:{i:0;s:0:"";}s:24:"_nectar_media_upload_ogv";a:1:{i:0;s:0:"";}s:28:"_nectar_slider_preview_image";a:1:{i:0;s:0:"";}s:17:"_nectar_header_bg";a:1:{i:0;s:0:"";}s:23:"_nectar_header_parallax";a:1:{i:0;s:3:"off";}s:23:"_nectar_header_box_roll";a:1:{i:0;s:3:"off";}s:24:"_nectar_header_bg_height";a:1:{i:0;s:3:"200";}s:25:"_nectar_header_fullscreen";a:1:{i:0;s:3:"off";}s:20:"_nectar_header_title";a:1:{i:0;s:12:"網頁設計";}s:23:"_nectar_header_subtitle";a:1:{i:0;s:33:"符合不同設備的網頁設計";}s:31:"_nectar_page_header_text-effect";a:1:{i:0;s:4:"none";}s:32:"_nectar_particle_rotation_timing";a:1:{i:0;s:0:"";}s:34:"_nectar_particle_disable_explosion";a:1:{i:0;s:3:"off";}s:29:"_nectar_page_header_alignment";a:1:{i:0;s:6:"center";}s:31:"_nectar_page_header_alignment_v";a:1:{i:0;s:6:"middle";}s:32:"_nectar_page_header_bg_alignment";a:1:{i:0;s:6:"center";}s:23:"_nectar_header_bg_color";a:1:{i:0;s:0:"";}s:25:"_nectar_header_font_color";a:1:{i:0;s:7:"#00afcb";}s:27:"_disable_transparent_header";a:1:{i:0;s:3:"off";}s:25:"_force_transparent_header";a:1:{i:0;s:3:"off";}s:17:"_wpb_vc_js_status";a:1:{i:0;s:4:"true";}s:26:"_wpb_shortcodes_custom_css";a:1:{i:0;s:228:".vc_custom_1467688975614{margin-bottom: 18px !important;}.vc_custom_1467697234880{margin-bottom: 18px !important;}.vc_custom_1467689233559{margin-bottom: 18px !important;}.vc_custom_1467697569338{margin-bottom: 18px !important;}";}s:10:"_edit_lock";a:1:{i:0;s:12:"1471413600:1";}s:31:"_yoast_wpseo_focuskw_text_input";a:1:{i:0;s:102:"網頁設計, web design, website design, 網頁設計公司, 網頁製作, 網站設計, 網站製作";}s:20:"_yoast_wpseo_focuskw";a:1:{i:0;s:102:"網頁設計, web design, website design, 網頁設計公司, 網頁製作, 網站設計, 網站製作";}s:21:"_yoast_wpseo_metadesc";a:1:{i:0;s:198:"香港網頁設計公司，我們有超過十年不同類型的網頁設計經驗，對影像、視像、文字、表格、商業思維、網路平台及搜尋引擎的整合，給您十足信心。";}s:20:"_yoast_wpseo_linkdex";a:1:{i:0;s:2:"65";}s:26:"_yoast_wpseo_content_score";a:1:{i:0;s:2:"90";}s:25:"_yoast_wpseo_metakeywords";a:1:{i:0;s:102:"網頁設計, web design, website design, 網頁設計公司, 網頁製作, 網站設計, 網站製作";}s:18:"_yoast_wpseo_title";a:1:{i:0;s:110:"網頁設計, web design, website design, 網頁設計公司, 網頁製作, 網站設計, 網站製作 - Vbits";}}}