.icl_tm_wrap {
  border: 1px solid #CCCCCC;
  padding: 10px;
  background-color: #ffffff; }

#icl_tm_adduser {
  margin-top: 4px; }
#icl_tm_adduser .icl_tm_lang_pairs {
  display: none;
  padding: 5px; }
#icl_tm_adduser .icl_tm_lang_pairs li ul li {
  display: inline; }

.icl_tm_lang_pairs_to {
  display: none;
  padding: 4px;
  margin-top: 1px;
  border-radius: 4px;
  /* autoprefixer: off */
  background: url("data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4gPHN2ZyB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGRlZnM+PGxpbmVhckdyYWRpZW50IGlkPSJncmFkIiBncmFkaWVudFVuaXRzPSJvYmplY3RCb3VuZGluZ0JveCIgeDE9IjAuNSIgeTE9IjEuMCIgeDI9IjAuNSIgeTI9IjAuMCI+PHN0b3Agb2Zmc2V0PSIwJSIgc3RvcC1jb2xvcj0iI2VjZWNlYyIvPjxzdG9wIG9mZnNldD0iMTAwJSIgc3RvcC1jb2xvcj0iI2Y5ZjlmOSIvPjwvbGluZWFyR3JhZGllbnQ+PC9kZWZzPjxyZWN0IHg9IjAiIHk9IjAiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIGZpbGw9InVybCgjZ3JhZCkiIC8+PC9zdmc+IA==") repeat scroll 0 0 #ededed;
  background: linear-gradient(to bottom, #ededed, #dfdfdf) repeat scroll 0 0 #ededed; }

.icl_tm_no_to {
  display: none;
  background-color: pink;
  padding: 5px;
  margin-bottom: 5px;
  border-radius: 4px; }

.form-table td, .form-table th {
  border-bottom: none; }

.icl_tj_select_translator_controls {
  display: none; }

.icl_tm_admin_options li ul {
  margin-left: 20px; }

#local_translations_add_translator_toggle {
  border: 1px solid #CCCCCC;
  padding: 10px; }
