/*!
 * jQuery UI Bootstrap (0.5)
 * http://addyosmani.github.com/jquery-ui-bootstrap
 *
 * Copyright 2012 - 2013, Addy Osmani
 * Dual licensed under the MIT or GPL Version 2 licenses.
 *
 * Portions copyright jQuery UI & Twitter Bootstrap
 */

.redux-main {
    /* Interaction Cues
----------------------------------*/
    .ui-state-disabled { cursor: default !important; }


    /* Icons
    ----------------------------------*/

    /* states and images */
    .ui-icon {
        display: block;
        text-indent: -99999px;
        overflow: hidden;
        background-repeat: no-repeat;
    }


    /* Misc visuals
    ----------------------------------*/


    /*
     * jQuery UI CSS Framework 1.10.0
     *
     * Copyright 2013, AUTHORS.txt (http://jqueryui.com/about)
     * Dual licensed under the MIT or GPL Version 2 licenses.
     * http://jquery.org/license
     *
     *
     *
     * To view and modify this theme, visit http://jqueryui.com/themeroller/
     */

    /* Component containers
    ----------------------------------*/
    .ui-widget {   font-family: "Helvetica Neue", Helvetica, Arial, sans-serif; font-size:13px; }
    .ui-widget .ui-widget { font-size: 1em; }
    .ui-widget input, .ui-widget select, .ui-widget textarea, .ui-widget button { font-family: "Helvetica Neue", Helvetica, Arial, sans-serif; font-size: 1em; }
    .ui-widget-content { border: 1px solid #aaaaaa; background: #ffffff url(images/ui-bg_glass_75_ffffff_1x400.png) 50% 50% repeat-x; color: #404040; }
    .ui-widget-content a { color: #404040; }
    .ui-widget-header {
        font-weight:bold;
        border-color: #0064cd #0064cd #003f81;
        border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
        border:1px solid #666;
    }
    .ui-widget-header a { color: #222222; }

    /* Interaction states
    ----------------------------------*/
    .ui-state-default, .ui-widget-content .ui-state-default, .ui-widget-header .ui-state-default {

        background-color: #e6e6e6;
        background-repeat: no-repeat;
        background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ffffff), color-stop(25%, #ffffff), to(#e6e6e6));
        background-image: -webkit-linear-gradient(#ffffff, #ffffff 25%, #e6e6e6);
        background-image: -moz-linear-gradient(top, #ffffff, #ffffff 25%, #e6e6e6);
        background-image: -ms-linear-gradient(#ffffff, #ffffff 25%, #e6e6e6);
        background-image: -o-linear-gradient(#ffffff, #ffffff 25%, #e6e6e6);
        background-image: linear-gradient(#ffffff, #ffffff 25%, #e6e6e6);
        filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffff', endColorstr='#e6e6e6', GradientType=0);

        text-shadow: 0 1px 1px rgba(255, 255, 255, 0.75);

        color: #333;
        font-size: 13px;
        line-height: normal;
        border: 1px solid #ccc;
        border-bottom-color: #bbb;
        -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
        -moz-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
        box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
        -webkit-transition: 0.1s linear background-image;
        -moz-transition: 0.1s linear background-image;
        -ms-transition: 0.1s linear background-image;
        -o-transition: 0.1s linear background-image;
        transition: 0.1s linear background-image;
        overflow: visible;

    }


    .ui-state-default a, .ui-state-default a:link, .ui-state-default a:visited { color: #555555; text-decoration: none; }
    .ui-state-hover, .ui-widget-content .ui-state-hover, .ui-widget-header .ui-state-hover, .ui-state-focus, .ui-widget-content .ui-state-focus, .ui-widget-header .ui-state-focus {
        background-position: 0 -15px;
        color: #333;
        text-decoration: none;
    }

    .ui-state-hover a, .ui-state-hover a:hover, .ui-state-hover a:link, .ui-state-hover a:visited { color: #212121; text-decoration: none; }
    .ui-state-active, .ui-widget-content .ui-state-active, .ui-widget-header .ui-state-active { border: 1px solid #aaaaaa;  font-weight: normal; color: #212121; }
    .ui-state-active a, .ui-state-active a:link, .ui-state-active a:visited { color: #212121; text-decoration: none; }
    .ui-widget :active { outline: none; }

    /* Interaction Cues
    ----------------------------------*/


    .ui-state-highlight p, .ui-state-error p, .ui-state-default p{
        font-size: 13px;
        font-weight: normal;
        line-height: 18px;
        margin:7px 15px;
    }
    .ui-state-highlight, .ui-widget-content .ui-state-highlight, .ui-widget-header .ui-state-highlight  {


        position: relative;
        margin-bottom: 18px;
        color: #404040;
        background-color: #eedc94;
        background-repeat: repeat-x;
        background-image: -khtml-gradient(linear, left top, left bottom, from(#fceec1), to(#eedc94));
        background-image: -moz-linear-gradient(top, #fceec1, #eedc94);
        background-image: -ms-linear-gradient(top, #fceec1, #eedc94);
        background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #fceec1), color-stop(100%, #eedc94));
        background-image: -webkit-linear-gradient(top, #fceec1, #eedc94);
        background-image: -o-linear-gradient(top, #fceec1, #eedc94);
        background-image: linear-gradient(top, #fceec1, #eedc94);
        filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fceec1', endColorstr='#eedc94', GradientType=0);
        text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
        border-color: #eedc94 #eedc94 #e4c652;
        border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
        text-shadow: 0 1px 0 rgba(255, 255, 255, 0.5);
        border-width: 1px;
        border-style: solid;
        -webkit-border-radius: 4px;
        -moz-border-radius: 4px;
        border-radius: 4px;
        -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.25);
        -moz-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.25);
        box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.25);


    }
    .ui-state-highlight a, .ui-widget-content .ui-state-highlight a,.ui-widget-header .ui-state-highlight a { color: #363636; }
    .ui-state-error, .ui-widget-content .ui-state-error, .ui-widget-header .ui-state-error {


        position: relative;
        margin-bottom: 18px;
        color: #ffffff;
        border-width: 1px;
        border-style: solid;
        -webkit-border-radius: 4px;
        -moz-border-radius: 4px;
        border-radius: 4px;
        -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.25);
        -moz-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.25);
        box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.25);
        background-color: #c43c35;
        background-repeat: repeat-x;
        background-image: -khtml-gradient(linear, left top, left bottom, from(#ee5f5b), to(#c43c35));
        background-image: -moz-linear-gradient(top, #ee5f5b, #c43c35);
        background-image: -ms-linear-gradient(top, #ee5f5b, #c43c35);
        background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #ee5f5b), color-stop(100%, #c43c35));
        background-image: -webkit-linear-gradient(top, #ee5f5b, #c43c35);
        background-image: -o-linear-gradient(top, #ee5f5b, #c43c35);
        background-image: linear-gradient(top, #ee5f5b, #c43c35);
        filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ee5f5b', endColorstr='#c43c35', GradientType=0);
        text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
        border-color: #c43c35 #c43c35 #882a25;
        border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);


    }
    .ui-state-error a, .ui-widget-content .ui-state-error a, .ui-widget-header .ui-state-error a { color: #cd0a0a; }
    .ui-state-error-text, .ui-widget-content .ui-state-error-text, .ui-widget-header .ui-state-error-text { color: #cd0a0a; }
    .ui-priority-primary, .ui-widget-content .ui-priority-primary, .ui-widget-header .ui-priority-primary { font-weight: bold; }
    .ui-priority-secondary, .ui-widget-content .ui-priority-secondary,  .ui-widget-header .ui-priority-secondary { opacity: .7; filter:Alpha(Opacity=70); font-weight: normal; }
    .ui-state-disabled, .ui-widget-content .ui-state-disabled, .ui-widget-header .ui-state-disabled { opacity: .35; filter:Alpha(Opacity=35); background-image: none;  }
    .ui-state-disabled .ui-icon { filter:Alpha(Opacity=35); } /* For IE8 - See #6059 */


    /* Icons
    ----------------------------------*/

    /* states and images */
    .ui-icon { width: 16px; height: 16px; background-image: url(images/ui-icons_222222_256x240.png); }
    .ui-widget-content .ui-icon {background-image: url(images/ui-icons_222222_256x240.png); }
    .ui-widget-header .ui-icon {background-image: url(images/ui-icons_222222_256x240.png); }
    .ui-state-default .ui-icon { background-image: url(images/ui-icons_888888_256x240.png); }
    .ui-state-hover .ui-icon, .ui-state-focus .ui-icon {background-image: url(images/ui-icons_454545_256x240.png); }
    .ui-state-active .ui-icon {background-image: url(images/ui-icons_454545_256x240.png); }
    .ui-state-highlight .ui-icon {background-image: url(images/ui-icons_2e83ff_256x240.png); }
    .ui-state-error .ui-icon, .ui-state-error-text .ui-icon {background-image: url(images/ui-icons_f6cf3b_256x240.png); }

    /* positioning */
    .ui-icon-carat-1-n { background-position: 0 0; }
    .ui-icon-carat-1-ne { background-position: -16px 0; }
    .ui-icon-carat-1-e { background-position: -32px 0; }
    .ui-icon-carat-1-se { background-position: -48px 0; }
    .ui-icon-carat-1-s { background-position: -64px 0; }
    .ui-icon-carat-1-sw { background-position: -80px 0; }
    .ui-icon-carat-1-w { background-position: -96px 0; }
    .ui-icon-carat-1-nw { background-position: -112px 0; }
    .ui-icon-carat-2-n-s { background-position: -128px 0; }
    .ui-icon-carat-2-e-w { background-position: -144px 0; }
    .ui-icon-triangle-1-n { background-position: 0 -16px; }
    .ui-icon-triangle-1-ne { background-position: -16px -16px; }
    .ui-icon-triangle-1-e { background-position: -32px -16px; }
    .ui-icon-triangle-1-se { background-position: -48px -16px; }
    .ui-icon-triangle-1-s { background-position: -64px -16px; }
    .ui-icon-triangle-1-sw { background-position: -80px -16px; }
    .ui-icon-triangle-1-w { background-position: -96px -16px; }
    .ui-icon-triangle-1-nw { background-position: -112px -16px; }
    .ui-icon-triangle-2-n-s { background-position: -128px -16px; }
    .ui-icon-triangle-2-e-w { background-position: -144px -16px; }
    .ui-icon-arrow-1-n { background-position: 0 -32px; }
    .ui-icon-arrow-1-ne { background-position: -16px -32px; }
    .ui-icon-arrow-1-e { background-position: -32px -32px; }
    .ui-icon-arrow-1-se { background-position: -48px -32px; }
    .ui-icon-arrow-1-s { background-position: -64px -32px; }
    .ui-icon-arrow-1-sw { background-position: -80px -32px; }
    .ui-icon-arrow-1-w { background-position: -96px -32px; }
    .ui-icon-arrow-1-nw { background-position: -112px -32px; }
    .ui-icon-arrow-2-n-s { background-position: -128px -32px; }
    .ui-icon-arrow-2-ne-sw { background-position: -144px -32px; }
    .ui-icon-arrow-2-e-w { background-position: -160px -32px; }
    .ui-icon-arrow-2-se-nw { background-position: -176px -32px; }
    .ui-icon-arrowstop-1-n { background-position: -192px -32px; }
    .ui-icon-arrowstop-1-e { background-position: -208px -32px; }
    .ui-icon-arrowstop-1-s { background-position: -224px -32px; }
    .ui-icon-arrowstop-1-w { background-position: -240px -32px; }
    .ui-icon-arrowthick-1-n { background-position: 0 -48px; }
    .ui-icon-arrowthick-1-ne { background-position: -16px -48px; }
    .ui-icon-arrowthick-1-e { background-position: -32px -48px; }
    .ui-icon-arrowthick-1-se { background-position: -48px -48px; }
    .ui-icon-arrowthick-1-s { background-position: -64px -48px; }
    .ui-icon-arrowthick-1-sw { background-position: -80px -48px; }
    .ui-icon-arrowthick-1-w { background-position: -96px -48px; }
    .ui-icon-arrowthick-1-nw { background-position: -112px -48px; }
    .ui-icon-arrowthick-2-n-s { background-position: -128px -48px; }
    .ui-icon-arrowthick-2-ne-sw { background-position: -144px -48px; }
    .ui-icon-arrowthick-2-e-w { background-position: -160px -48px; }
    .ui-icon-arrowthick-2-se-nw { background-position: -176px -48px; }
    .ui-icon-arrowthickstop-1-n { background-position: -192px -48px; }
    .ui-icon-arrowthickstop-1-e { background-position: -208px -48px; }
    .ui-icon-arrowthickstop-1-s { background-position: -224px -48px; }
    .ui-icon-arrowthickstop-1-w { background-position: -240px -48px; }
    .ui-icon-arrowreturnthick-1-w { background-position: 0 -64px; }
    .ui-icon-arrowreturnthick-1-n { background-position: -16px -64px; }
    .ui-icon-arrowreturnthick-1-e { background-position: -32px -64px; }
    .ui-icon-arrowreturnthick-1-s { background-position: -48px -64px; }
    .ui-icon-arrowreturn-1-w { background-position: -64px -64px; }
    .ui-icon-arrowreturn-1-n { background-position: -80px -64px; }
    .ui-icon-arrowreturn-1-e { background-position: -96px -64px; }
    .ui-icon-arrowreturn-1-s { background-position: -112px -64px; }
    .ui-icon-arrowrefresh-1-w { background-position: -128px -64px; }
    .ui-icon-arrowrefresh-1-n { background-position: -144px -64px; }
    .ui-icon-arrowrefresh-1-e { background-position: -160px -64px; }
    .ui-icon-arrowrefresh-1-s { background-position: -176px -64px; }
    .ui-icon-arrow-4 { background-position: 0 -80px; }
    .ui-icon-arrow-4-diag { background-position: -16px -80px; }
    .ui-icon-extlink { background-position: -32px -80px; }
    .ui-icon-newwin { background-position: -48px -80px; }
    .ui-icon-refresh { background-position: -64px -80px; }
    .ui-icon-shuffle { background-position: -80px -80px; }
    .ui-icon-transfer-e-w { background-position: -96px -80px; }
    .ui-icon-transferthick-e-w { background-position: -112px -80px; }
    .ui-icon-folder-collapsed { background-position: 0 -96px; }
    .ui-icon-folder-open { background-position: -16px -96px; }
    .ui-icon-document { background-position: -32px -96px; }
    .ui-icon-document-b { background-position: -48px -96px; }
    .ui-icon-note { background-position: -64px -96px; }
    .ui-icon-mail-closed { background-position: -80px -96px; }
    .ui-icon-mail-open { background-position: -96px -96px; }
    .ui-icon-suitcase { background-position: -112px -96px; }
    .ui-icon-comment { background-position: -128px -96px; }
    .ui-icon-person { background-position: -144px -96px; }
    .ui-icon-print { background-position: -160px -96px; }
    .ui-icon-trash { background-position: -176px -96px; }
    .ui-icon-locked { background-position: -192px -96px; }
    .ui-icon-unlocked { background-position: -208px -96px; }
    .ui-icon-bookmark { background-position: -224px -96px; }
    .ui-icon-tag { background-position: -240px -96px; }
    .ui-icon-home { background-position: 0 -112px; }
    .ui-icon-flag { background-position: -16px -112px; }
    .ui-icon-calendar { background-position: -32px -112px; }
    .ui-icon-cart { background-position: -48px -112px; }
    .ui-icon-pencil { background-position: -64px -112px; }
    .ui-icon-clock { background-position: -80px -112px; }
    .ui-icon-disk { background-position: -96px -112px; }
    .ui-icon-calculator { background-position: -112px -112px; }
    .ui-icon-zoomin { background-position: -128px -112px; }
    .ui-icon-zoomout { background-position: -144px -112px; }
    .ui-icon-search { background-position: -160px -112px; }
    .ui-icon-wrench { background-position: -176px -112px; }
    .ui-icon-gear { background-position: -192px -112px; }
    .ui-icon-heart { background-position: -208px -112px; }
    .ui-icon-star { background-position: -224px -112px; }
    .ui-icon-link { background-position: -240px -112px; }
    .ui-icon-cancel { background-position: 0 -128px; }
    .ui-icon-plus { background-position: -16px -128px; }
    .ui-icon-plusthick { background-position: -32px -128px; }
    .ui-icon-minus { background-position: -48px -128px; }
    .ui-icon-minusthick { background-position: -64px -128px; }
    .ui-icon-close { background-position: -80px -128px; }
    .ui-icon-closethick { background-position: -96px -128px; }
    .ui-icon-key { background-position: -112px -128px; }
    .ui-icon-lightbulb { background-position: -128px -128px; }
    .ui-icon-scissors { background-position: -144px -128px; }
    .ui-icon-clipboard { background-position: -160px -128px; }
    .ui-icon-copy { background-position: -176px -128px; }
    .ui-icon-contact { background-position: -192px -128px; }
    .ui-icon-image { background-position: -208px -128px; }
    .ui-icon-video { background-position: -224px -128px; }
    .ui-icon-script { background-position: -240px -128px; }
    .ui-icon-alert { background-position: 0 -144px; }
    .ui-icon-info { background-position: -16px -144px; }
    .ui-icon-notice { background-position: -32px -144px; }
    .ui-icon-help { background-position: -48px -144px; }
    .ui-icon-check { background-position: -64px -144px; }
    .ui-icon-bullet { background-position: -80px -144px; }
    .ui-icon-radio-off { background-position: -96px -144px; }
    .ui-icon-radio-on { background-position: -112px -144px; }
    .ui-icon-pin-w { background-position: -128px -144px; }
    .ui-icon-pin-s { background-position: -144px -144px; }
    .ui-icon-play { background-position: 0 -160px; }
    .ui-icon-pause { background-position: -16px -160px; }
    .ui-icon-seek-next { background-position: -32px -160px; }
    .ui-icon-seek-prev { background-position: -48px -160px; }
    .ui-icon-seek-end { background-position: -64px -160px; }
    .ui-icon-seek-start { background-position: -80px -160px; }
    /* ui-icon-seek-first is deprecated, use ui-icon-seek-start instead */
    .ui-icon-seek-first { background-position: -80px -160px; }
    .ui-icon-stop { background-position: -96px -160px; }
    .ui-icon-eject { background-position: -112px -160px; }
    .ui-icon-volume-off { background-position: -128px -160px; }
    .ui-icon-volume-on { background-position: -144px -160px; }
    .ui-icon-power { background-position: 0 -176px; }
    .ui-icon-signal-diag { background-position: -16px -176px; }
    .ui-icon-signal { background-position: -32px -176px; }
    .ui-icon-battery-0 { background-position: -48px -176px; }
    .ui-icon-battery-1 { background-position: -64px -176px; }
    .ui-icon-battery-2 { background-position: -80px -176px; }
    .ui-icon-battery-3 { background-position: -96px -176px; }
    .ui-icon-circle-plus { background-position: 0 -192px; }
    .ui-icon-circle-minus { background-position: -16px -192px; }
    .ui-icon-circle-close { background-position: -32px -192px; }
    .ui-icon-circle-triangle-e { background-position: -48px -192px; }
    .ui-icon-circle-triangle-s { background-position: -64px -192px; }
    .ui-icon-circle-triangle-w { background-position: -80px -192px; }
    .ui-icon-circle-triangle-n { background-position: -96px -192px; }
    .ui-icon-circle-arrow-e { background-position: -112px -192px; }
    .ui-icon-circle-arrow-s { background-position: -128px -192px; }
    .ui-icon-circle-arrow-w { background-position: -144px -192px; }
    .ui-icon-circle-arrow-n { background-position: -160px -192px; }
    .ui-icon-circle-zoomin { background-position: -176px -192px; }
    .ui-icon-circle-zoomout { background-position: -192px -192px; }
    .ui-icon-circle-check { background-position: -208px -192px; }
    .ui-icon-circlesmall-plus { background-position: 0 -208px; }
    .ui-icon-circlesmall-minus { background-position: -16px -208px; }
    .ui-icon-circlesmall-close { background-position: -32px -208px; }
    .ui-icon-squaresmall-plus { background-position: -48px -208px; }
    .ui-icon-squaresmall-minus { background-position: -64px -208px; }
    .ui-icon-squaresmall-close { background-position: -80px -208px; }
    .ui-icon-grip-dotted-vertical { background-position: 0 -224px; }
    .ui-icon-grip-dotted-horizontal { background-position: -16px -224px; }
    .ui-icon-grip-solid-vertical { background-position: -32px -224px; }
    .ui-icon-grip-solid-horizontal { background-position: -48px -224px; }
    .ui-icon-gripsmall-diagonal-se { background-position: -64px -224px; }
    .ui-icon-grip-diagonal-se { background-position: -80px -224px; }


    /* Misc visuals
    ----------------------------------*/

    /* Corner radius */
    .ui-corner-all,
    .ui-corner-top,
    .ui-corner-left,
    .ui-corner-tl {
        -moz-border-radius-topleft: 4px;
        -webkit-border-top-left-radius: 4px;
        -khtml-border-top-left-radius: 4px;
        border-top-left-radius: 4px;
    }
    .ui-corner-all,
    .ui-corner-top,
    .ui-corner-right,
    .ui-corner-tr {
        -moz-border-radius-topright: 4px;
        -webkit-border-top-right-radius: 4px;
        -khtml-border-top-right-radius: 4px;
        border-top-right-radius: 4px;
    }
    .ui-corner-all,
    .ui-corner-bottom,
    .ui-corner-left,
    .ui-corner-bl {
        -moz-border-radius-bottomleft: 4px;
        -webkit-border-bottom-left-radius: 4px;
        -khtml-border-bottom-left-radius: 4px;
        border-bottom-left-radius: 4px;
    }
    .ui-corner-all,
    .ui-corner-bottom,
    .ui-corner-right,
    .ui-corner-br {
        -moz-border-radius-bottomright: 4px;
        -webkit-border-bottom-right-radius: 4px;
        -khtml-border-bottom-right-radius: 4px;
        border-bottom-right-radius: 4px;
    }


    /* Overlays */

    .ui-widget-overlay {
        background: #aaaaaa url(images/ui-bg_flat_0_aaaaaa_40x100.png) 50% 50% repeat-x;
        opacity: .30;
        filter:Alpha(Opacity=30);
    }

    .ui-widget-shadow {
        margin: -8px 0 0 -8px;
        padding: 8px;
        background: #aaaaaa url(images/ui-bg_flat_0_aaaaaa_40x100.png) 50% 50% repeat-x;
        opacity: .30;filter:Alpha(Opacity=30);
        -moz-border-radius: 8px;
        -khtml-border-radius: 8px;
        -webkit-border-radius: 8px;
        border-radius: 8px;
    }

    /*
     * jQuery UI Accordion 1.10.0
     *
     * Copyright 2013, AUTHORS.txt (http://jqueryui.com/about)
     * Dual licensed under the MIT or GPL Version 2 licenses.
     * http://jquery.org/license
     *
     * http://jqueryui.com/accordion/
     */

    /* IE/Win - Fix animation bug - #4615 */

    .ui-accordion {
        width: 100%;
    }
    .ui-accordion .ui-accordion-header {
        cursor: pointer;
        position: relative;
        margin-top: 1px;
        zoom: 1;
        font-weight:bold;
    }
    .ui-accordion .ui-accordion-li-fix {
        display: inline;
    }
    .ui-accordion .ui-accordion-header-active {
        border-bottom: 0 !important;
    }
    .ui-accordion .ui-accordion-header a {
        display: block;
        font-size: 1em;
        padding: .5em .5em .5em 1.7em;
    }
    .ui-accordion-icons .ui-accordion-header a {
        padding-left: 2.2em;
    }
    .ui-accordion .ui-accordion-header .ui-icon {
        position: absolute;
        left: .5em;
        top: 50%;
        margin-top: -8px;
    }
    .ui-accordion .ui-accordion-content {
        padding: 1em 2.2em;
        border-top: 0;
        margin-top: -2px;
        position: relative;
        top: 1px;
        margin-bottom: 2px;
        overflow: auto;
        display: none;
        zoom: 1;
    }
    .ui-accordion .ui-accordion-content-active {
        display: block;
    }


    /*
     * jQuery UI Button 1.10.0
     *
     * Copyright 2013, AUTHORS.txt (http://jqueryui.com/about)
     * Dual licensed under the MIT or GPL Version 2 licenses.
     * http://jquery.org/license
     *
     * http://docs.jquery.com/UI/Button#theming
     */

    .ui-button {

        cursor: pointer;
        display: inline-block;
        background-color: #e6e6e6;
        background-repeat: no-repeat;
        background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ffffff), color-stop(25%, #ffffff), to(#e6e6e6));
        background-image: -webkit-linear-gradient(#ffffff, #ffffff 25%, #e6e6e6);
        background-image: -moz-linear-gradient(top, #ffffff, #ffffff 25%, #e6e6e6);
        background-image: -ms-linear-gradient(#ffffff, #ffffff 25%, #e6e6e6);
        background-image: -o-linear-gradient(#ffffff, #ffffff 25%, #e6e6e6);
        background-image: linear-gradient(#ffffff, #ffffff 25%, #e6e6e6);
        filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffff', endColorstr='#e6e6e6', GradientType=0);
        padding: 5px 14px 6px;
        margin: 0;
        text-shadow: 0 1px 1px rgba(255, 255, 255, 0.75);
        color: #333;
        font-size: 13px;
        line-height: normal;
        border: 1px solid #ccc;
        border-bottom-color: #bbb;

        -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
        -moz-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
        box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
        -webkit-transition: 0.1s linear background-image;
        -moz-transition: 0.1s linear background-image;
        -ms-transition: 0.1s linear background-image;
        -o-transition: 0.1s linear background-image;
        transition: 0.1s linear background-image;
        overflow: visible;
    } /* the overflow property removes extra width in IE */

    .ui-button-primary {
        color: #ffffff;
        background-color: #0064cd;
        background-repeat: repeat-x;
        background-image: -khtml-gradient(linear, left top, left bottom, from(#049cdb), to(#0064cd));
        background-image: -moz-linear-gradient(top, #049cdb, #0064cd);
        background-image: -ms-linear-gradient(top, #049cdb, #0064cd);
        background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #049cdb), color-stop(100%, #0064cd));
        background-image: -webkit-linear-gradient(top, #049cdb, #0064cd);
        background-image: -o-linear-gradient(top, #049cdb, #0064cd);
        background-image: linear-gradient(top, #049cdb, #0064cd);
        filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#049cdb', endColorstr='#0064cd', GradientType=0);
        text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
        border-color: #0064cd #0064cd #003f81;
        border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
    }


    .ui-button-success{
        color:#ffffff;
        background-color: #57a957;
        background-repeat: repeat-x;
        background-image: -khtml-gradient(linear, left top, left bottom, from(#62c462), to(#57a957));
        background-image: -moz-linear-gradient(top, #62c462, #57a957);
        background-image: -ms-linear-gradient(top, #62c462, #57a957);
        background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #62c462), color-stop(100%, #57a957));
        background-image: -webkit-linear-gradient(top, #62c462, #57a957);
        background-image: -o-linear-gradient(top, #62c462, #57a957);
        background-image: linear-gradient(top, #62c462, #57a957);
        filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#62c462', endColorstr='#57a957', GradientType=0);
        text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
        border-color: #57a957 #57a957 #3d773d;
        border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
    }

    .ui-button-error{
        color:#ffffff;
        background-color: #c43c35;
        background-repeat: repeat-x;
        background-image: -khtml-gradient(linear, left top, left bottom, from(#ee5f5b), to(#c43c35));
        background-image: -moz-linear-gradient(top, #ee5f5b, #c43c35);
        background-image: -ms-linear-gradient(top, #ee5f5b, #c43c35);
        background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #ee5f5b), color-stop(100%, #c43c35));
        background-image: -webkit-linear-gradient(top, #ee5f5b, #c43c35);
        background-image: -o-linear-gradient(top, #ee5f5b, #c43c35);
        background-image: linear-gradient(top, #ee5f5b, #c43c35);
        filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ee5f5b', endColorstr='#c43c35', GradientType=0);
        text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
        border-color: #c43c35 #c43c35 #882a25;
        border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
    }

    .ui-button-icon-only { width: 2.2em; } /* to make room for the icon, a width needs to be set here */
    button.ui-button-icon-only { } /* button elements seem to need a little more width */
    .ui-button-icons-only { width: 3.4em; }
    button.ui-button-icons-only { width: 3.7em; }

    /*button text element */

    .ui-button .ui-button-text { display: block;   }
    .ui-button-text-only .ui-button-text {  }
    .ui-button-icon-only .ui-button-text, .ui-button-icons-only .ui-button-text { padding: .4em; text-indent: -9999999px; /*tempfix*/ display:none;}
    .ui-button-text-icon-primary .ui-button-text, .ui-button-text-icons .ui-button-text { padding: .4em 1em .4em 2.1em; }
    .ui-button-text-icon-secondary .ui-button-text, .ui-button-text-icons .ui-button-text { padding: .4em 2.1em .4em 1em; }
    .ui-button-text-icons .ui-button-text { padding-left: 2.1em; padding-right: 2.1em; }
    /* no icon support for input elements, provide padding by default */
    /* input.ui-button { padding: .4em 1em; } */

    /*button icon element(s) */
    .ui-button-icon-only .ui-icon, .ui-button-text-icon-primary .ui-icon, .ui-button-text-icon-secondary .ui-icon, .ui-button-text-icons .ui-icon, .ui-button-icons-only .ui-icon { top: 50%; margin-top:-3px; margin-bottom:3px; }
    .ui-button-icon-only .ui-icon { left: 50%; margin-left: -8px; }
    .ui-button-text-icon-primary .ui-button-icon-primary, .ui-button-text-icons .ui-button-icon-primary, .ui-button-icons-only .ui-button-icon-primary { left: .5em; }
    .ui-button-text-icon-secondary .ui-button-icon-secondary, .ui-button-text-icons .ui-button-icon-secondary, .ui-button-icons-only .ui-button-icon-secondary { right: .5em; }
    .ui-button-text-icons .ui-button-icon-secondary, .ui-button-icons-only .ui-button-icon-secondary { right: .5em; }

    /*button sets*/


    .ui-buttonset { margin-right: 7px; }
    .ui-buttonset .ui-state-active {
        color: #ffffff;
        background-color: #0064cd;
        background-repeat: repeat-x;
        background-image: -khtml-gradient(linear, left top, left bottom, from(#049cdb), to(#0064cd));
        background-image: -moz-linear-gradient(top, #049cdb, #0064cd);
        background-image: -ms-linear-gradient(top, #049cdb, #0064cd);
        background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #049cdb), color-stop(100%, #0064cd));
        background-image: -webkit-linear-gradient(top, #049cdb, #0064cd);
        background-image: -o-linear-gradient(top, #049cdb, #0064cd);
        background-image: linear-gradient(top, #049cdb, #0064cd);
        filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#049cdb', endColorstr='#0064cd', GradientType=0);
        text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
        border-color: #0064cd #0064cd #003f81;
        border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
    }
    .ui-buttonset .ui-button { margin-left: 0; margin-right: 0; }

    /* workarounds */
    button.ui-button::-moz-focus-inner { border: 0; padding: 0; } /* reset extra padding in Firefox */

    /*
     * jQuery UI Datepicker 1.9.0
     *
     * Copyright 2012-10-11, AUTHORS.txt (http://jqueryui.com/about)
     * Dual licensed under the MIT or GPL Version 2 licenses.
     * http://jquery.org/license
     *
     * http://jqueryui.com/datepicker/
     */
    .ui-datepicker { width: 17em; padding: .2em .2em 0; display: none; }
    .ui-datepicker .ui-datepicker-header { position:relative; padding:.2em 0; border:0px; font-weight: bold; width: 100%; padding: 4px 0; background-color: #f5f5f5; color: #808080; }
    .ui-datepicker .ui-datepicker-prev, .ui-datepicker .ui-datepicker-next { position:absolute; top: 2px; width: 1.8em; height: 1.8em; }

    .ui-datepicker .ui-datepicker-prev-hover, .ui-datepicker .ui-datepicker-next-hover { /*top: 1px;*/ }
    .ui-datepicker .ui-datepicker-prev { left:2px; }
    .ui-datepicker .ui-datepicker-next { right:2px; }

    .ui-datepicker .ui-datepicker-prev-hover { /*left:1px;*/ }
    .ui-datepicker .ui-datepicker-next-hover { /*right:1px;*/ }

    .ui-datepicker .ui-datepicker-prev span, .ui-datepicker .ui-datepicker-next span { display: block; position: absolute; left: 50%; margin-left: -8px; top: 50%; margin-top: -8px;  }
    .ui-datepicker .ui-datepicker-title { margin: 0 2.3em; line-height: 1.8em; text-align: center; }
    .ui-datepicker .ui-datepicker-title select { font-size:1em; margin:1px 0; }
    .ui-datepicker select.ui-datepicker-month-year {width: 100%;}
    .ui-datepicker select.ui-datepicker-month,
    .ui-datepicker select.ui-datepicker-year { width: 49%;}
    .ui-datepicker table {width: 100%; font-size: .9em; border-collapse: collapse; margin:0 0 .4em; }
    .ui-datepicker th { padding: .7em .3em; text-align: center; font-weight: bold; border: 0;  }
    .ui-datepicker td { border: 0; padding: 1px; }
    .ui-datepicker td span, .ui-datepicker td a { display: block; padding: .2em; text-align: right; text-decoration: none; }
    .ui-datepicker .ui-datepicker-buttonpane { background-image: none; margin: .7em 0 0 0; padding:0 .2em; border-left: 0; border-right: 0; border-bottom: 0; }
    .ui-datepicker .ui-datepicker-buttonpane button { float: right; margin: .5em .2em .4em; cursor: pointer; padding: .2em .6em .3em .6em; width:auto; overflow:visible; }
    .ui-datepicker .ui-datepicker-buttonpane button.ui-datepicker-current { float:left; }

    /* with multiple calendars */
    .ui-datepicker.ui-datepicker-multi { width:auto; }
    .ui-datepicker-multi .ui-datepicker-group { float:left; }
    .ui-datepicker-multi .ui-datepicker-group table { width:95%; margin:0 auto .4em; }
    .ui-datepicker-multi-2 .ui-datepicker-group { width:50%; }
    .ui-datepicker-multi-3 .ui-datepicker-group { width:33.3%; }
    .ui-datepicker-multi-4 .ui-datepicker-group { width:25%; }
    .ui-datepicker-multi .ui-datepicker-group-last .ui-datepicker-header { border-left-width:0; }
    .ui-datepicker-multi .ui-datepicker-group-middle .ui-datepicker-header { border-left-width:0; }
    .ui-datepicker-multi .ui-datepicker-buttonpane { clear:left; }
    .ui-datepicker-row-break { clear:both; width:100%; font-size:0em; }

    /* RTL support */
    .ui-datepicker-rtl { direction: rtl; }
    .ui-datepicker-rtl .ui-datepicker-prev { right: 2px; left: auto; }
    .ui-datepicker-rtl .ui-datepicker-next { left: 2px; right: auto; }
    .ui-datepicker-rtl .ui-datepicker-prev:hover { right: 1px; left: auto; }
    .ui-datepicker-rtl .ui-datepicker-next:hover { left: 1px; right: auto; }
    .ui-datepicker-rtl .ui-datepicker-buttonpane { clear:right; }
    .ui-datepicker-rtl .ui-datepicker-buttonpane button { float: left; }
    .ui-datepicker-rtl .ui-datepicker-buttonpane button.ui-datepicker-current { float:right; }
    .ui-datepicker-rtl .ui-datepicker-group { float:right; }
    .ui-datepicker-rtl .ui-datepicker-group-last .ui-datepicker-header { border-right-width:0; border-left-width:1px; }
    .ui-datepicker-rtl .ui-datepicker-group-middle .ui-datepicker-header { border-right-width:0; border-left-width:1px; }

    /* IE6 IFRAME FIX (taken from datepicker 1.5.3 */
    .ui-datepicker-cover {
        display: none; /*sorry for IE5*/
        display: block; /*sorry for IE5*/
        position: absolute; /*must have*/
        z-index: -1; /*must have*/
        filter: mask(); /*must have*/
        top: -4px; /*must have*/
        left: -4px; /*must have*/
        width: 200px; /*must have*/
        height: 200px; /*must have*/
    }

    .ui-datepicker th{
        font-weight: bold;
        color: gray;
    }

    .ui-datepicker-today a:hover{
        background-color: #808080;
        color: #ffffff;

    }
    .ui-datepicker-today a{
        background-color: #BFBFBF;
        cursor: pointer;
        padding: 0 4px;
        margin-bottom:0px;

    }


    .ui-datepicker td a{
        margin-bottom:0px;
        border:0px;
    }

    .ui-datepicker td:hover{
        color: #ffffff;
    }

    .ui-datepicker td .ui-state-default {
        border:0px;
        background:none;
        margin-bottom:0px;
        padding:5px;
        color:gray;
        text-align: center;
        filter:none;
    }


    .ui-datepicker td .ui-state-active{
        background:#BFBFBF;
        margin-bottom:0px;
        font-size:normal;
        text-shadow: 0px;
        color: #ffffff;
        -webkit-border-radius: 4px;
        -moz-border-radius: 4px;
        border-radius: 4px;
    }

    .ui-datepicker td .ui-state-hover {
        color: #ffffff;
        background: #0064cd;
        background-color: #0064cd;
        background-repeat: repeat-x;
        background-image: -khtml-gradient(linear, left top, left bottom, from(#049cdb), to(#0064cd));
        background-image: -moz-linear-gradient(top, #049cdb, #0064cd);
        background-image: -ms-linear-gradient(top, #049cdb, #0064cd);
        background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #049cdb), color-stop(100%, #0064cd));
        background-image: -webkit-linear-gradient(top, #049cdb, #0064cd);
        background-image: -o-linear-gradient(top, #049cdb, #0064cd);
        background-image: linear-gradient(top, #049cdb, #0064cd);
        filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#049cdb', endColorstr='#0064cd', GradientType=0);
        text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
        border-color: #0064cd #0064cd #003f81;
        border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
        -webkit-border-radius: 4px;
        -moz-border-radius: 4px;
        -khtml-border-radius: 4px;
        border-radius: 4px;
    }

    .ui-widget-content {
        border: 1px solid #dfdfdf;
    }
    .ui-datepicker table { background: #fff; }

    .placeholder {
        background:#f9f9f9 !important;
        border: 1px dashed #bbb !important;
    }

}