<?php
use Baz;
use abstract;
use and;
use array;
use as;
use break;
use callable;
use case;
use catch;
use class;
use clone;
use const;
use continue;
use declare;
use default;
use do;
use else;
use elseif;
use enddeclare;
use endfor;
use endforeach;
use endif;
use endswitch;
use endwhile;
use extends;
use final;
use finally;
use for;
use foreach;
use function;
use global;
use goto;
use if;
use implements;
use interface;
use instanceof;
use insteadof;
use namespace;
use new;
use or;
use private;
use protected;
use public;
use static;
use switch;
use throw;
use trait;
use try;
use use;
use var;
use while;
use xor;
use __CLASS__;
use __DIR__;
use __FILE__;
use __FUNCTION__;
use __METHOD__;
use __NAMESPACE__;
