// ==========================================================================
// Admin nav iconx
// ==========================================================================

@font-face {
	font-family: "jetpack";
	src: url("../_inc/fonts/jetpack/jetpack.eot");
	src: url("../_inc/fonts/jetpack/jetpack.eot?#iefix") format("embedded-opentype"),
		url("../_inc/fonts/jetpack/jetpack.woff") format("woff"),
		url("../_inc/fonts/jetpack/jetpack.ttf") format("truetype"),
		url("../_inc/fonts/jetpack/jetpack.svg#jetpack") format("svg");
	font-weight: normal;
	font-style: normal;
}

@media screen and (-webkit-min-device-pixel-ratio:0) {
	@font-face {
		font-family: "jetpack";
		src: url("../_inc/fonts/jetpack/jetpack.svg#jetpack") format("svg");
	}
}

li.toplevel_page_jetpack .wp-menu-image:before {
	font-family: 'jetpack' !important;
	content: '\f102';
}
#menu-posts-feedback .wp-menu-image:before {
	font-family: dashicons !important;
	content: '\f175';
}
#adminmenu #menu-posts-feedback div.wp-menu-image {
	background: none !important;
	background-repeat: no-repeat;
}
