X��X<?php exit; ?>a:6:{s:10:"last_error";s:0:"";s:10:"last_query";s:214:"SELECT   wp_posts.* FROM wp_posts  WHERE 1=1  AND wp_posts.ID IN (6800,6802,6811,6854,6860,6866,6870,6873) AND wp_posts.post_type = 'page' AND ((wp_posts.post_status = 'publish'))  ORDER BY wp_posts.post_date DESC ";s:11:"last_result";a:8:{i:0;O:8:"stdClass":23:{s:2:"ID";s:4:"6873";s:11:"post_author";s:1:"1";s:9:"post_date";s:19:"2016-07-12 15:49:45";s:13:"post_date_gmt";s:19:"2016-07-12 07:49:45";s:12:"post_content";s:1726:"[vc_row type="full_width_background" scene_position="center" text_color="light" text_align="left" color_overlay="#00afcb" overlay_strength="0.95"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][divider line_type="No Line"][vc_column_text]
<h2>弘迅科技資訊有限公司</h2>
<h2>Vision Beta IT Solutions Ltd.</h2>
<h5>九龍官塘創業街36號華基中心1602室</h5>
[/vc_column_text][vc_column_text]<iframe style="border: 0;" src="https://www.google.com/maps/embed?pb=!1m18!1m12!1m3!1d3691.0403696915528!2d114.2169883153857!3d22.314312948024053!2m3!1f0!2f0!3f0!3m2!1i1024!2i768!4f13.1!3m3!1m2!1s0x34040148ef0a1209%3A0xe6b85b5693db5906!2sVbits+-+Vision+Beta+IT+Solutions+Ltd.!5e0!3m2!1sen!2shk!4v1468312710249" width="600" height="200" frameborder="0" allowfullscreen="allowfullscreen"></iframe>[/vc_column_text][divider line_type="No Line"][vc_column_text][icon color="Accent-Color" animation_speed="Slow" size="small" icon_size="" animation_delay="" image="fa-envelope-o"] 電郵 : cs@vbits.com.hk[/vc_column_text][divider line_type="No Line"][vc_column_text][icon color="Accent-Color" animation_speed="Slow" size="small" icon_size="" animation_delay="" image="fa-phone"] 電話 : 3622 5593[/vc_column_text][divider line_type="No Line"][vc_column_text][icon color="Accent-Color" animation_speed="Slow" size="small" icon_size="" animation_delay="" image="fa-fax"] 傳真 : 3753 5415[/vc_column_text][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][contact-form-7 id="6878"][/vc_column][/vc_row]";s:10:"post_title";s:12:"聯絡我們";s:12:"post_excerpt";s:0:"";s:11:"post_status";s:7:"publish";s:14:"comment_status";s:6:"closed";s:11:"ping_status";s:6:"closed";s:13:"post_password";s:0:"";s:9:"post_name";s:7:"contact";s:7:"to_ping";s:0:"";s:6:"pinged";s:0:"";s:13:"post_modified";s:19:"2016-08-04 13:05:55";s:17:"post_modified_gmt";s:19:"2016-08-04 05:05:55";s:21:"post_content_filtered";s:0:"";s:11:"post_parent";s:1:"0";s:4:"guid";s:41:"http://web2.vbits.com.hk/zh/?page_id=6873";s:10:"menu_order";s:1:"0";s:9:"post_type";s:4:"page";s:14:"post_mime_type";s:0:"";s:13:"comment_count";s:1:"0";}i:1;O:8:"stdClass":23:{s:2:"ID";s:4:"6870";s:11:"post_author";s:1:"1";s:9:"post_date";s:19:"2016-07-12 15:41:04";s:13:"post_date_gmt";s:19:"2016-07-12 07:41:04";s:12:"post_content";s:1920:"[vc_row type="full_width_background" bg_image="9" bg_position="center center" bg_repeat="no-repeat" scene_position="center" video_bg="use_video" enable_video_color_overlay="true" video_overlay_color="#0d598d" video_webm="http://www.vbits.com.hk/wp-content/uploads/2016/fp-clouds.webmhd.webm" video_mp4="http://www.vbits.com.hk/wp-content/uploads/2016/fp-clouds.mp4" video_image="6770" text_color="light" text_align="left" top_padding="5%" bottom_padding="5%" overlay_strength="0.3"][vc_column centered_text="true" column_padding="padding-3-percent" column_padding_position="left-right" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][vc_column_text]
<h1>Vbits</h1>
[/vc_column_text][vc_column_text]
<h2>Your <span style="color: #00afcb;">i</span>nnova<span style="color: #00afcb;">t</span>ive partner</h2>
<h5>網頁設計, IT解決方案, SEO 搜索引擎優化, 網路營銷, 品牌設計</h5>
[/vc_column_text][divider line_type="No Line"][vc_column_text]
<h5>我們的願景是運用持續更新、不斷完善的趨時高新IT科技提供資訊科技方案。</h5>
[/vc_column_text][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][image_with_animation image_url="6223" alignment="" animation="Fade In" delay="150"][divider line_type="No Line"][vc_column_text]
<h2>Vbits是什麼</h2>
<h5></h5>
[/vc_column_text][divider line_type="No Line"][vc_column_text]
<h5>/' V bits/</h5>
Vbits 是我們公司名字的英文縮寫 (Vision Beta IT Solutions Ltd.)
<h5>/' V/</h5>
"V" 是 願景(Vision)
<h5>/' bits/</h5>
<ol>
 	<li>bits是beta IT solutions的英文縮寫，beta 是持續更新的意思</li>
 	<li>bit也是電腦的最小位元，用0和1去記錄。bits也代表了每一項的資訊科技方案</li>
</ol>
[/vc_column_text][/vc_column][/vc_row]";s:10:"post_title";s:12:"關於我們";s:12:"post_excerpt";s:0:"";s:11:"post_status";s:7:"publish";s:14:"comment_status";s:6:"closed";s:11:"ping_status";s:6:"closed";s:13:"post_password";s:0:"";s:9:"post_name";s:5:"about";s:7:"to_ping";s:0:"";s:6:"pinged";s:0:"";s:13:"post_modified";s:19:"2016-08-04 13:06:17";s:17:"post_modified_gmt";s:19:"2016-08-04 05:06:17";s:21:"post_content_filtered";s:0:"";s:11:"post_parent";s:1:"0";s:4:"guid";s:41:"http://web2.vbits.com.hk/zh/?page_id=6870";s:10:"menu_order";s:1:"0";s:9:"post_type";s:4:"page";s:14:"post_mime_type";s:0:"";s:13:"comment_count";s:1:"0";}i:2;O:8:"stdClass":23:{s:2:"ID";s:4:"6866";s:11:"post_author";s:1:"1";s:9:"post_date";s:19:"2016-07-12 14:46:53";s:13:"post_date_gmt";s:19:"2016-07-12 06:46:53";s:12:"post_content";s:3723:"[vc_row type="full_width_background" scene_position="center" text_color="dark" text_align="center" bottom_padding="3%" overlay_strength="0.95"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/1"][vc_column_text]
<h2>細訴您的大計，其餘的事給我們</h2>
[/vc_column_text][/vc_column][/vc_row][vc_row type="full_width_background" scene_position="center" text_color="dark" text_align="left" bottom_padding="3%" overlay_strength="0.95"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][image_with_animation image_url="6292" alignment="right" animation="Fade In" delay="150"][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][vc_column_text]
<h5>品牌設計類別</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color"]
<ul>
 	<li>品牌形象設計</li>
 	<li>小冊子和產品目錄</li>
 	<li>標誌設計</li>
 	<li>咭片設計</li>
 	<li>單張及明信片設計</li>
 	<li>企業形象指南</li>
 	<li>包裝設計</li>
 	<li>插圖繪畫</li>
 	<li>其他平面設計</li>
</ul>
[/fancy-ul][/vc_column][/vc_row][vc_row type="full_width_background" scene_position="center" text_color="dark" text_align="center" top_padding="3%" bottom_padding="3%" color_overlay="#00afcb" overlay_strength="0.3"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/1"][split_line_heading]
<h2>作品參考</h2>
[/split_line_heading][divider line_type="No Line"][clients columns="4" fade_in_animation="true" carousel="true"][client image="6632" title="Client" tab_id="1467099424346-4" name="Energywatt - Tag" id="1467100705963-9"] Click the edit button to add your testimonial. [/client][client image="6638" title="Client" tab_id="1467099424500-1" name="Energywatt" id="1467100967717-3"] Click the edit button to add your testimonial. [/client][client image="6658" title="Client" tab_id="1467101016768-5" name="i Water - Productshot" id="1467128724605-7"][/client][client image="6644" title="Client" tab_id="1467101964602-1" name="element water - Booth" id="1467103000257-3"][/client][client image="6646" title="Client" tab_id="1467102957922-0" name="Energywatt" id="1467103055326-10"][/client][client image="6655" title="Client" tab_id="1467103724630-0" name="Energywatt" id="1467103781766-7"][/client][client image="6660" title="Client" tab_id="1467104284174-6" name="Energywatt" id="1468305766214-4"][/client][client image="6662" title="Client" tab_id="1467128731598-0" name="Energywatt" id="1468306020498-7"][/client][/clients][clients columns="4" fade_in_animation="true" carousel="true"][client image="6930" title="Client" tab_id="1467099424346-4" name="Energywatt" id="1468561513918-5"] Click the edit button to add your testimonial. [/client][client image="6931" title="Client" tab_id="1467099424500-1" name="Energywatt" id="1468561513938-1"] Click the edit button to add your testimonial. [/client][client image="6932" title="Client" tab_id="1467101016768-5" name="Energywatt" id="1468561513949-0"][/client][client image="6933" title="Client" tab_id="1467101964602-1" name="Energywatt" id="1468561513970-0"][/client][client image="6934" title="Client" tab_id="1467102957922-0" name="Energywatt" id="1468561513996-9"][/client][client image="6938" title="Client" tab_id="1467103724630-0" name="Energywatt" id="1468563119807-9"][/client][/clients][/vc_column][/vc_row]";s:10:"post_title";s:12:"品牌設計";s:12:"post_excerpt";s:0:"";s:11:"post_status";s:7:"publish";s:14:"comment_status";s:6:"closed";s:11:"ping_status";s:6:"closed";s:13:"post_password";s:0:"";s:9:"post_name";s:14:"brand-identity";s:7:"to_ping";s:0:"";s:6:"pinged";s:0:"";s:13:"post_modified";s:19:"2016-08-04 13:04:10";s:17:"post_modified_gmt";s:19:"2016-08-04 05:04:10";s:21:"post_content_filtered";s:0:"";s:11:"post_parent";s:1:"0";s:4:"guid";s:41:"http://web2.vbits.com.hk/zh/?page_id=6866";s:10:"menu_order";s:1:"0";s:9:"post_type";s:4:"page";s:14:"post_mime_type";s:0:"";s:13:"comment_count";s:1:"0";}i:3;O:8:"stdClass":23:{s:2:"ID";s:4:"6860";s:11:"post_author";s:1:"1";s:9:"post_date";s:19:"2016-07-12 13:57:23";s:13:"post_date_gmt";s:19:"2016-07-12 05:57:23";s:12:"post_content";s:1226:"[vc_row type="full_width_background" scene_position="center" text_color="dark" text_align="left" bottom_padding="5%" overlay_strength="0.95"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="2/3"][vc_column_text]
<h2>客戶關係就是這樣建立了</h2>
我們在社交平台行銷有著不同管理經驗，在Facebook、Youtube、Twitter、Instagam、甚至新近年來微訊創立的微訊公眾平台，各有各不同的整合方式。

我們擁有多年投放在網上及社交媒體行銷的經驗及資源，總能為您以不同形式推廣到不同的目標客戶。[/vc_column_text][divider line_type="No Line"][vc_column_text][button open_new_tab="true" color="see-through-2" hover_text_color_override="#fff" image="default-arrow" size="large" url="http://www.vbits.com.hk/contact/" text="聯絡我們" color_override=""][/vc_column_text][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/3"][image_with_animation image_url="6549" alignment="right" animation="Fade In" delay="150"][/vc_column][/vc_row]";s:10:"post_title";s:18:"社交網絡行銷";s:12:"post_excerpt";s:0:"";s:11:"post_status";s:7:"publish";s:14:"comment_status";s:6:"closed";s:11:"ping_status";s:6:"closed";s:13:"post_password";s:0:"";s:9:"post_name";s:22:"social-media-marketing";s:7:"to_ping";s:0:"";s:6:"pinged";s:0:"";s:13:"post_modified";s:19:"2016-08-04 13:04:46";s:17:"post_modified_gmt";s:19:"2016-08-04 05:04:46";s:21:"post_content_filtered";s:0:"";s:11:"post_parent";s:1:"0";s:4:"guid";s:41:"http://web2.vbits.com.hk/zh/?page_id=6860";s:10:"menu_order";s:1:"0";s:9:"post_type";s:4:"page";s:14:"post_mime_type";s:0:"";s:13:"comment_count";s:1:"0";}i:4;O:8:"stdClass":23:{s:2:"ID";s:4:"6854";s:11:"post_author";s:1:"1";s:9:"post_date";s:19:"2016-07-07 13:57:06";s:13:"post_date_gmt";s:19:"2016-07-07 05:57:06";s:12:"post_content";s:1481:"[vc_row type="full_width_background" scene_position="center" text_color="dark" text_align="left" bottom_padding="5%" overlay_strength="0.3"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="2/3"][vc_column_text]
<h2>以最醒目的方法換取更高的投資回報率</h2>
搜尋引擎最佳化(Search Engine Optimization，簡稱SEO)，是一種透過了解搜尋引擎的運作規則來調整網站，以及提高目的網站在有關搜尋引擎內排名的方式。

投放網上廣告只是提高網站瀏量的其中一種方法，透過我們的搜索引擎優化服務，你不只會得到一份以您現有網站為主的制定的SEO報告，我們還會提供建議更改或重新設計網站以達到報告的效果。更好的網站排名比投放網上廣告更有效率、長遠來看更節省了網上廣告的開支。[/vc_column_text][divider line_type="No Line"][vc_column_text][button open_new_tab="true" color="see-through-2" hover_text_color_override="#fff" image="default-arrow" size="large" url="http://www.vbits.com.hk/contact/" text="聯絡我們" color_override=""][/vc_column_text][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/3"][image_with_animation image_url="6540" alignment="right" animation="Fade In" delay="150"][/vc_column][/vc_row]";s:10:"post_title";s:22:"SEO 搜索引擎優化";s:12:"post_excerpt";s:0:"";s:11:"post_status";s:7:"publish";s:14:"comment_status";s:6:"closed";s:11:"ping_status";s:6:"closed";s:13:"post_password";s:0:"";s:9:"post_name";s:3:"seo";s:7:"to_ping";s:0:"";s:6:"pinged";s:0:"";s:13:"post_modified";s:19:"2016-08-04 13:03:15";s:17:"post_modified_gmt";s:19:"2016-08-04 05:03:15";s:21:"post_content_filtered";s:0:"";s:11:"post_parent";s:1:"0";s:4:"guid";s:41:"http://web2.vbits.com.hk/zh/?page_id=6854";s:10:"menu_order";s:1:"0";s:9:"post_type";s:4:"page";s:14:"post_mime_type";s:0:"";s:13:"comment_count";s:1:"0";}i:5;O:8:"stdClass":23:{s:2:"ID";s:4:"6811";s:11:"post_author";s:1:"1";s:9:"post_date";s:19:"2016-07-05 14:04:13";s:13:"post_date_gmt";s:19:"2016-07-05 06:04:13";s:12:"post_content";s:21781:"[vc_row type="full_width_background" scene_position="center" text_color="light" text_align="left" color_overlay="#00afcb" overlay_strength="0.95"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/1"][page_submenu sticky="true"][page_link link_url="#it-outsourcing" title="IT外判" tab_id="1466414153530-3" id="1467700142480-2"] [/page_link][page_link link_url="#networking" title="網路工程" tab_id="1466414153918-10" id="1467704817061-10"] [/page_link][page_link title="伺服器部署" tab_id="1466498762904-5" link_url="#server-deployment" id="1467705126788-10"][/page_link][page_link title="新辦公室IT設置" tab_id="1466583163302-0" link_url="#new-office-setup" id="1467710986497-1"][/page_link][page_link title="電腦及週邊產品" tab_id="1466585451279-9" link_url="#it-product" id="1467861466157-8"][/page_link][page_link title="使用授權" tab_id="1466585560752-0" link_url="#licensing" id="1467862890725-0"][/page_link][/page_submenu][/vc_column][/vc_row][vc_row type="full_width_background" scene_position="center" text_color="light" text_align="left" top_padding="5%" id="it-outsourcing" color_overlay="#00afcb" overlay_strength="0.95"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][vc_column_text]
<h2>IT外判</h2>
[/vc_column_text][vc_column_text]透過我們的IT外判服務，你可以用一個合理的投資得到一個IT部門的支援。我們還會定時評估及更新貴公司的IT狀況，與不斷更新的IT資訊接軌。[/vc_column_text][image_with_animation image_url="6426" alignment="center" animation="Fade In" delay="150"][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1467699700362{margin-bottom: 18px !important;}"]
<h5>技術支援</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Extra-Color-3" enable_animation="true"]
<ul>
 	<li><span style="color: #a2d8e6;">定時上門檢查</span></li>
 	<li><span style="color: #a2d8e6;">遠端技術支援</span></li>
 	<li><span style="color: #a2d8e6;">防毒軟件更新</span></li>
 	<li><span style="color: #a2d8e6;">電腦維修排解</span></li>
 	<li><span style="color: #a2d8e6;">技術支援記錄</span></li>
</ul>
[/fancy-ul][vc_column_text css=".vc_custom_1467700166399{margin-bottom: 18px !important;}"]
<h5>網路安全</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Extra-Color-3" enable_animation="true"]
<ul>
 	<li><span style="color: #a2d8e6;">防火牆管理</span></li>
 	<li><span style="color: #a2d8e6;">網路流量管理</span></li>
 	<li><span style="color: #a2d8e6;">VPN 虛擬私人網路管理</span></li>
 	<li><span style="color: #a2d8e6;">網路流量控制</span></li>
 	<li><span style="color: #a2d8e6;">使用者網上行為管理</span></li>
</ul>
[/fancy-ul][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1467699980626{margin-bottom: 18px !important;}"]
<h5>伺服器保養</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Extra-Color-3" enable_animation="true"]
<ul>
 	<li><span style="color: #a2d8e6;">伺服器效能檢查</span></li>
 	<li><span style="color: #a2d8e6;">伺服器安全性檢查</span></li>
 	<li><span style="color: #a2d8e6;">伺服器備份方案</span></li>
 	<li><span style="color: #a2d8e6;">Windows伺服器部署</span></li>
 	<li><span style="color: #a2d8e6;">Linux伺服器部署</span></li>
</ul>
[/fancy-ul][vc_column_text css=".vc_custom_1467700460259{margin-bottom: 18px !important;}"]
<h5>主動式IT風險評估</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Extra-Color-3" enable_animation="true"]
<ul>
 	<li><span style="color: #a2d8e6;">軟件/系統更新</span></li>
 	<li><span style="color: #a2d8e6;">IT工作環境評估</span></li>
 	<li><span style="color: #a2d8e6;">硬件生命週期管理</span></li>
 	<li><span style="color: #a2d8e6;">軟件許可證管理</span></li>
 	<li><span style="color: #a2d8e6;">IT 培訓</span></li>
</ul>
[/fancy-ul][/vc_column][/vc_row][vc_row type="full_width_background" scene_position="center" text_color="dark" text_align="left" top_padding="5%" bottom_padding="5%" id="networking" overlay_strength="0.3"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][vc_column_text]
<h2>網路工程</h2>
[/vc_column_text][vc_column_text]我們有不同的網路架構的豐富經驗，如區域網路(LAN)、無線區域網路(WLAN)及閉路電視系統(CCTV)，無論是小型公司網路或全層的網路架構，我們都能順利解決。[/vc_column_text][image_with_animation image_url="6448" alignment="center" animation="Fade In" delay="150"][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1467702027365{margin-bottom: 18px !important;}"]
<h5>區域網路工程(LAN)</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">結構化佈線設計Cat5e/Cat6</span></li>
 	<li><span style="color: #00afcb;">網路面版安裝</span></li>
 	<li><span style="color: #00afcb;">網路佈線</span></li>
 	<li><span style="color: #00afcb;">階段式工程報告</span></li>
 	<li><span style="color: #00afcb;">網線測試</span></li>
</ul>
[/fancy-ul][vc_column_text css=".vc_custom_1467703317600{margin-bottom: 18px !important;}"]
<h5>閉路電視系統工程(CCTV)</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">鏡頭安裝</span></li>
 	<li><span style="color: #00afcb;">鏡頭設置</span></li>
 	<li><span style="color: #00afcb;">數碼視頻錄像(DVR)設置</span></li>
 	<li><span style="color: #00afcb;">網線喉管佈設及安裝</span></li>
 	<li><span style="color: #00afcb;">後備電源設備安裝</span></li>
</ul>
[/fancy-ul][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1467702062222{margin-bottom: 18px !important;}"]
<h5>無線區域網路工程(WLAN)</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">無線區域網路規劃</span></li>
 	<li><span style="color: #00afcb;">無線存取點安裝</span></li>
 	<li><span style="color: #00afcb;">無線區域網路管理</span></li>
 	<li><span style="color: #00afcb;">無線區域網路信號規劃</span></li>
 	<li><span style="color: #00afcb;">無線區域網路規劃測試</span></li>
</ul>
[/fancy-ul][vc_column_text css=".vc_custom_1467703851330{margin-bottom: 18px !important;}"]
<h5>網路設備設置</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">寬頻安裝及設定</span></li>
 	<li><span style="color: #00afcb;">防火牆/整合式威脅管理設定</span></li>
 	<li><span style="color: #00afcb;">網路交換器安裝</span></li>
 	<li><span style="color: #00afcb;">伺服器機櫃安裝</span></li>
 	<li><span style="color: #00afcb;">後備電源設備安裝</span></li>
</ul>
[/fancy-ul][/vc_column][/vc_row][vc_row type="full_width_background" scene_position="center" text_color="dark" text_align="left" top_padding="5%" bottom_padding="5%" id="server-deployment" color_overlay="#00afcb" overlay_strength="0.3"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][vc_column_text]
<h2>伺服器部署</h2>
[/vc_column_text][vc_column_text]我們對部署伺服器規劃擁有非常豐富的經驗，由小型的NAS部署到機房級別的伺服器架構，都能為你辦妥。[/vc_column_text][image_with_animation image_url="6462" alignment="center" animation="Fade In" delay="150"][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1467705508516{margin-bottom: 18px !important;}"]
<h5>微軟視窗伺服器</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">Windows Domain controller server</span></li>
 	<li><span style="color: #00afcb;">Windows File server</span></li>
 	<li><span style="color: #00afcb;">Windows Hyper-V server</span></li>
 	<li><span style="color: #00afcb;">Windows DNS server</span></li>
 	<li><span style="color: #00afcb;">Windows DHCP server</span></li>
 	<li><span style="color: #00afcb;">Windows FTP server</span></li>
 	<li><span style="color: #00afcb;">Windows Remote Terminal server</span></li>
 	<li><span style="color: #00afcb;">Windows System Center server</span></li>
 	<li><span style="color: #00afcb;">Windows Data Protection server</span></li>
 	<li><span style="color: #00afcb;">Windows Exchange server</span></li>
</ul>
[/fancy-ul][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1467705877445{margin-bottom: 18px !important;}"]
<h5>Linux 伺服器</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">Linux Apache server</span></li>
 	<li><span style="color: #00afcb;">LAMP server stack</span></li>
 	<li><span style="color: #00afcb;">BIND DNS server</span></li>
 	<li><span style="color: #00afcb;">Mail / POP3 server</span></li>
 	<li><span style="color: #00afcb;">Database server</span></li>
 	<li><span style="color: #00afcb;">Linux FTP server</span></li>
</ul>
[/fancy-ul][vc_column_text css=".vc_custom_1467706078230{margin-bottom: 18px !important;}"]
<h5>NAS 網路儲存裝置</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">NAS雲端文件伺服器設置</span></li>
 	<li><span style="color: #00afcb;">NAS雲端軟件市場</span></li>
 	<li><span style="color: #00afcb;">個人化NAS服務應用</span></li>
 	<li><span style="color: #00afcb;">NAS Apps部署</span></li>
 	<li><span style="color: #00afcb;">NAS設置</span></li>
</ul>
[/fancy-ul][/vc_column][/vc_row][vc_row type="full_width_background" scene_position="center" text_color="dark" text_align="left" top_padding="5%" bottom_padding="5%" id="new-office-setup" overlay_strength="0.3"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][vc_column_text]
<h2>新辦公室IT設置</h2>
[/vc_column_text][vc_column_text]我們能提供開新公司所需要的一站式的IT配套解決方案，讓您可以専注業務發展。IT的事項交給我們吧！我們不止辦得到，而且辦得妥。
一站式的IT配套解決方案包括IT顧問服務、品牌及平面設計、網站規劃、網路工程規劃、軟硬件採購、商業軟件配套等等。[/vc_column_text][image_with_animation image_url="6472" alignment="center" animation="Fade In" delay="150"][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1467710000974{margin-bottom: 18px !important;}"]
<h5>網頁設計</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">域名申請及註冊</span></li>
 	<li><span style="color: #00afcb;">網頁設計</span></li>
 	<li><span style="color: #00afcb;">部落格設計</span></li>
 	<li><span style="color: #00afcb;">網上商店設計</span></li>
 	<li><span style="color: #00afcb;">內容管理系統設計</span></li>
</ul>
[/fancy-ul][vc_column_text css=".vc_custom_1467710801113{margin-bottom: 18px !important;}"]
<h5>網路工程及設置</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">由路器/防火牆設置</span></li>
 	<li><span style="color: #00afcb;">區域網路規劃</span></li>
 	<li><span style="color: #00afcb;">無線區域網路規劃</span></li>
 	<li><span style="color: #00afcb;">防盜系統設置</span></li>
 	<li><span style="color: #00afcb;">伺服器/網路設備専櫃安裝</span></li>
</ul>
[/fancy-ul][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1467710531184{margin-bottom: 18px !important;}"]
<h5>電腦相關硬件/軟件</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">桌上電腦/手提電腦</span></li>
 	<li><span style="color: #00afcb;">伺服器</span></li>
 	<li><span style="color: #00afcb;">電腦軟件</span></li>
 	<li><span style="color: #00afcb;">公司軟件使用權証</span></li>
 	<li><span style="color: #00afcb;">其他電腦週邊設備</span></li>
</ul>
[/fancy-ul][vc_column_text css=".vc_custom_1467711009043{margin-bottom: 18px !important;}"]
<h5>商業軟件應用</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">企業資源計劃方案(ERP)</span></li>
 	<li><span style="color: #00afcb;">客戶關係管理方案(CRM)</span></li>
 	<li><span style="color: #00afcb;">銷售系統方案(POS)</span></li>
 	<li><span style="color: #00afcb;">電郵解決方案(Email)</span></li>
 	<li><span style="color: #00afcb;">協同合作解決方案(Collaboration)</span></li>
</ul>
[/fancy-ul][/vc_column][/vc_row][vc_row type="full_width_background" scene_position="center" text_color="light" text_align="left" top_padding="5%" bottom_padding="5%" id="it-product" color_overlay="#00afcb" overlay_strength="0.95"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][vc_column_text]
<h2>電腦及週邊產品</h2>
[/vc_column_text][vc_column_text]不用再自己找電腦商場購買電腦產品，安心専注您們的核心業務，我們為您安排！
搜羅全球品牌，擁有多年電腦及週邊產品的銷售經驗，我們會因應不同工作環境提供合適的產品。產品包括伺服器、桌上電腦、手提電腦、平板電腦、硬碟、記憶體、滑鼠，甚至只是一條網線都能為您效勞。[/vc_column_text][image_with_animation image_url="6489" alignment="center" animation="Fade In" delay="150"][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1467860001791{margin-bottom: 18px !important;}"]
<h5>電腦硬件</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Extra-Color-3" enable_animation="true"]
<ul>
 	<li><span style="color: #a2d8e6;">品牌電腦/手提電腦</span></li>
 	<li><span style="color: #a2d8e6;">蘋果電腦</span></li>
 	<li><span style="color: #a2d8e6;">平板電腦</span></li>
 	<li><span style="color: #a2d8e6;">掌上電腦設備</span></li>
 	<li><span style="color: #a2d8e6;">自組電腦</span></li>
</ul>
[/fancy-ul][vc_column_text css=".vc_custom_1467860286184{margin-bottom: 18px !important;}"]
<h5>電腦軟件</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Extra-Color-3" enable_animation="true"]
<ul>
 	<li><span style="color: #a2d8e6;">電腦操作系統</span></li>
 	<li><span style="color: #a2d8e6;">伺服器操作系統</span></li>
 	<li><span style="color: #a2d8e6;">繪圖軟件</span></li>
 	<li><span style="color: #a2d8e6;">文書處理軟件</span></li>
 	<li><span style="color: #a2d8e6;">防毒軟件</span></li>
</ul>
[/fancy-ul][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1467860155698{margin-bottom: 18px !important;}"]
<h5>網路相關設備</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Extra-Color-3" enable_animation="true"]
<ul>
 	<li><span style="color: #a2d8e6;">網路器材</span></li>
 	<li><span style="color: #a2d8e6;">網路機櫃</span></li>
 	<li><span style="color: #a2d8e6;">網路線材/線材週邊配件</span></li>
 	<li><span style="color: #a2d8e6;">網路攝錄器材</span></li>
 	<li><span style="color: #a2d8e6;">後備電線及配件</span></li>
</ul>
[/fancy-ul][vc_column_text css=".vc_custom_1467860455628{margin-bottom: 18px !important;}"]
<h5>電腦配件</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Extra-Color-3" enable_animation="true"]
<ul>
 	<li><span style="color: #a2d8e6;">儲存設備</span></li>
 	<li><span style="color: #a2d8e6;">打印機</span></li>
 	<li><span style="color: #a2d8e6;">顯示器</span></li>
 	<li><span style="color: #a2d8e6;">投影器</span></li>
 	<li><span style="color: #a2d8e6;">輸入裝置(滑鼠/鍵盤/手寫系統)</span></li>
</ul>
[/fancy-ul][/vc_column][/vc_row][vc_row type="full_width_background" scene_position="center" text_color="dark" text_align="left" top_padding="5%" id="licensing" overlay_strength="0.3"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][vc_column_text]
<h2>使用授權</h2>
[/vc_column_text][vc_column_text]有使用授權的煩惱？我們是不同知名品牌的經綃商，能夠幫您找到最理想的使用授權方案！[/vc_column_text][image_with_animation image_url="6508" alignment="center" animation="Fade In" delay="150"][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1467860990705{margin-bottom: 18px !important;}"]
<h5>軟件授權</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">Microsoft Open License</span></li>
 	<li><span style="color: #00afcb;">Microsoft Full Packaged Product (FPP) Software</span></li>
 	<li><span style="color: #00afcb;">Autodesk AutoCAD Product</span></li>
 	<li><span style="color: #00afcb;">CorelDRAW Graphic Suite</span></li>
 	<li><span style="color: #00afcb;">Symantec License</span></li>
 	<li><span style="color: #00afcb;">Kaspersky License</span></li>
 	<li><span style="color: #00afcb;">ESET NOD32 License</span></li>
</ul>
[/fancy-ul][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1467861104683{margin-bottom: 18px !important;}"]
<h5>網路軟件續期/授權</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">Sonicwall</span></li>
 	<li><span style="color: #00afcb;">FortiGate</span></li>
 	<li><span style="color: #00afcb;">Sophos</span></li>
 	<li><span style="color: #00afcb;">Netgear</span></li>
 	<li><span style="color: #00afcb;">Watchguard</span></li>
</ul>
[/fancy-ul][/vc_column][/vc_row][vc_row type="full_width_background" scene_position="center" text_color="dark" text_align="left" top_padding="40" bottom_padding="40" overlay_strength="1"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/1"][clients columns="6" carousel="true"][client image="6519" title="Client" tab_id="1451662966191-10" name="Dell" id="1466931216835-2"] Click the edit button to add your testimonial. [/client][client image="6522" title="Client" tab_id="1451663132415-1" name="APC" id="1466931413922-0"][/client][client image="6520" title="Client" tab_id="1451663143506-0" name="Adobe" id="1466931284237-6"][/client][client image="6527" title="Client" tab_id="1466931353621-0" name="Microsoft" id="1466931598150-0"][/client][client image="6528" title="Client" tab_id="1466931384037-3" name="Autodesk" id="1466931493068-0"][/client][client image="6530" title="Client" tab_id="1466931509584-3" name="Symantec" id="1466931598175-1"][/client][client image="6533" title="Client" tab_id="1466931571980-4" name="Trend Micro" id="1466931633164-10"][/client][client image="6535" title="Client" tab_id="1466931604541-2" name="Watchguard" id="1467000202494-0"][/client][/clients][/vc_column][/vc_row]";s:10:"post_title";s:14:"IT解決方案";s:12:"post_excerpt";s:0:"";s:11:"post_status";s:7:"publish";s:14:"comment_status";s:6:"closed";s:11:"ping_status";s:6:"closed";s:13:"post_password";s:0:"";s:9:"post_name";s:12:"it-solutions";s:7:"to_ping";s:0:"";s:6:"pinged";s:0:"";s:13:"post_modified";s:19:"2016-08-15 16:55:49";s:17:"post_modified_gmt";s:19:"2016-08-15 08:55:49";s:21:"post_content_filtered";s:0:"";s:11:"post_parent";s:1:"0";s:4:"guid";s:41:"http://web2.vbits.com.hk/zh/?page_id=6811";s:10:"menu_order";s:1:"0";s:9:"post_type";s:4:"page";s:14:"post_mime_type";s:0:"";s:13:"comment_count";s:1:"0";}i:6;O:8:"stdClass":23:{s:2:"ID";s:4:"6802";s:11:"post_author";s:1:"1";s:9:"post_date";s:19:"2016-07-05 12:15:57";s:13:"post_date_gmt";s:19:"2016-07-05 04:15:57";s:12:"post_content";s:8260:"[vc_row type="full_width_background" scene_position="center" text_color="dark" text_align="center" bottom_padding="5%" color_overlay="#ffffff" overlay_strength="0.3"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/1"][vc_column_text]
<h2>符合不同設備的網頁設計</h2>
<h5><span style="color: #bbbbbb;">無論是桌上電腦，平板電腦還是手機，都看得舒適</span></h5>
[/vc_column_text][divider line_type="No Line"][image_with_animation image_url="6274" alignment="center" animation="Fade In" delay="150"][/vc_column][/vc_row][vc_row type="full_width_background" scene_position="center" text_color="dark" text_align="center" top_padding="5%" bottom_padding="5%" color_overlay="#00afcb" overlay_strength="0.3"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][split_line_heading]
<h2>對的網頁設計,是踏出成功的第一步</h2>
[/split_line_heading][vc_row_inner top_padding="15" bottom_padding="25"][vc_column_inner enable_animation="true" animation="fade-in-from-bottom" column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" width="1/1"][vc_column_text][icon enable_animation="true" color="Accent-Color" animation_speed="Medium" icon_size="128" animation_delay="400" image="basic_lightbulb.svg"]

作為香港網頁設計公司，我們有超過十年不同類型的網頁設計及網站製作經驗，對影像、視像、文字、表格、商業思維、網路平台及搜尋引擎的整合，給您十足信心。[/vc_column_text][/vc_column_inner][/vc_row_inner][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][image_with_animation image_url="6357" alignment="center" animation="Fade In" delay="150"][/vc_column][/vc_row][vc_row type="full_width_background" bg_color="#ffffff" scene_position="center" text_color="dark" text_align="left" top_padding="5%" bottom_padding="5%" color_overlay="#ededed" overlay_strength="0.3"][vc_column column_padding="padding-2-percent" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][split_line_heading]
<h2>設計符合不同要求及風格，讓我們為您辦妥</h2>
[/split_line_heading][image_with_animation image_url="6370" alignment="center" animation="Fade In" delay="150"][vc_row_inner][vc_column_inner enable_animation="true" animation="fade-in-from-bottom" column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" width="1/1"][vc_column_text]
<h6 style="color: #1e83ec;">需要其他服務嗎?</h6>
<span style="color: rgba(0,0,0,0.45);">IT解決方案 | 搜索引擎優化 | 社交網絡行銷 | 品牌設計</span>[/vc_column_text][/vc_column_inner][/vc_row_inner][/vc_column][vc_column column_padding="padding-2-percent" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" top_margin="5%" width="1/4"][vc_column_text css=".vc_custom_1467688975614{margin-bottom: 18px !important;}"]
<h5>不同型式的網頁設計</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #999999;">網頁設計</span></li>
 	<li><span style="color: #999999;">部落格設計</span></li>
 	<li><span style="color: #999999;">網上商店</span></li>
 	<li><span style="color: #999999;">活動介紹網頁</span></li>
 	<li><span style="color: #999999;">產品展示網頁</span></li>
</ul>
[/fancy-ul][vc_column_text css=".vc_custom_1467697234880{margin-bottom: 18px !important;}"]
<h5>商業分析 / 網站管理</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #999999;">網頁流量分析</span></li>
 	<li><span style="color: #999999;">搜尋引擎內容管理</span></li>
 	<li><span style="color: #999999;">網頁內容管理</span></li>
</ul>
[/fancy-ul][/vc_column][vc_column column_padding="padding-2-percent" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" top_margin="5%" width="1/4"][vc_column_text css=".vc_custom_1467689233559{margin-bottom: 18px !important;}"]
<h5>網頁特色</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #999999;">全面支援HTML5</span></li>
 	<li><span style="color: #999999;">自動符合頁面尺寸的設計</span></li>
 	<li><span style="color: #999999;">符合搜尋引擎的後台編程</span></li>
 	<li><span style="color: #999999;">Google服務嵌入</span></li>
 	<li><span style="color: #999999;">多國語言設計</span></li>
</ul>
[/fancy-ul][vc_column_text css=".vc_custom_1467697569338{margin-bottom: 18px !important;}"]
<h5>進階網站功能</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #999999;">網上支付系統</span></li>
 	<li><span style="color: #999999;">電郵訂閱系統</span></li>
 	<li><span style="color: #999999;">會員登入系統</span></li>
</ul>
[/fancy-ul][/vc_column][/vc_row][vc_row type="full_width_background" scene_position="center" text_color="dark" text_align="center" top_padding="5%" color_overlay="#00afcb" overlay_strength="0.3"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/1"][vc_column_text]
<h2>網頁設計參考</h2>
[/vc_column_text][/vc_column][/vc_row][vc_row type="full_width_background" scene_position="center" text_color="dark" text_align="left" top_padding="2%" color_overlay="#00afcb" overlay_strength="0.3"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/3"][fancy_box image_url="6330" link_new_tab="true" color="Accent-Color" link_url="http://energywatt.hk" link_text="energywatt.hk"]
<h3>Energywatt</h3>
Hong Kong famous sports Drink[/fancy_box][fancy_box image_url="6403" link_new_tab="true" color="Accent-Color" link_url="http://www.hangpotc.com" link_text="hangpotc.com"]
<h3>Hangpo</h3>
Hong Kong shuttle bus service[/fancy_box][fancy_box image_url="6410" link_new_tab="true" color="Accent-Color" link_url="http://www.kingsproduction.com.hk" link_text="kingsproduction.com.hk"]
<h3>Kings Production</h3>
Hong Kong Photographer[/fancy_box][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/3"][fancy_box image_url="6399" link_new_tab="true" color="Accent-Color" link_url="http://www.the-studio.com.hk" link_text="the-studio.com.hk"]
<h3>THE STUDIO</h3>
Hong Kong Photography Brand[/fancy_box][fancy_box image_url="6775" link_new_tab="true" color="Accent-Color" link_url="http://www.unisonpro.com.hk" link_text="unisonpro.com.hk"]
<h3>Unison Production</h3>
Hong Kong Live music brand[/fancy_box][fancy_box image_url="6412" link_new_tab="true" color="Accent-Color" link_url="http://www.faceshk.com" link_text="faceshk.com"]
<h3>Faces Blog</h3>
Hong Kong Makeup blog[/fancy_box][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/3"][fancy_box image_url="6401" link_new_tab="true" color="Accent-Color" link_url="http://www.cocoonbridal.com" link_text="cocoonbridal.com"]
<h3>Cocoon Bridal</h3>
Hong Kong Bridal company[/fancy_box][fancy_box image_url="6777" link_new_tab="true" color="Accent-Color" link_url="http://www.cherwish.hk" link_text="cherwish.hk"]
<h3>Cherwish</h3>
Hong Kong Online Fashion store[/fancy_box][fancy_box image_url="6779" link_new_tab="true" color="Accent-Color" link_url="http://www.odo.hk" link_text="odo.hk"]
<h3>ODO</h3>
Indian handmade fashion and accessories[/fancy_box][/vc_column][/vc_row]";s:10:"post_title";s:12:"網頁設計";s:12:"post_excerpt";s:0:"";s:11:"post_status";s:7:"publish";s:14:"comment_status";s:6:"closed";s:11:"ping_status";s:6:"closed";s:13:"post_password";s:0:"";s:9:"post_name";s:10:"web-design";s:7:"to_ping";s:0:"";s:6:"pinged";s:0:"";s:13:"post_modified";s:19:"2016-08-17 14:02:12";s:17:"post_modified_gmt";s:19:"2016-08-17 06:02:12";s:21:"post_content_filtered";s:0:"";s:11:"post_parent";s:1:"0";s:4:"guid";s:41:"http://web2.vbits.com.hk/zh/?page_id=6802";s:10:"menu_order";s:1:"0";s:9:"post_type";s:4:"page";s:14:"post_mime_type";s:0:"";s:13:"comment_count";s:1:"0";}i:7;O:8:"stdClass":23:{s:2:"ID";s:4:"6800";s:11:"post_author";s:1:"1";s:9:"post_date";s:19:"2016-07-05 12:15:02";s:13:"post_date_gmt";s:19:"2016-07-05 04:15:02";s:12:"post_content";s:5793:"[vc_row type="full_width_content" bg_image="9" bg_position="center center" bg_repeat="no-repeat" scene_position="center" video_bg="use_video" enable_video_color_overlay="true" video_overlay_color="#0d598d" video_webm="http://www.vbits.com.hk/wp-content/uploads/2016/fp-clouds.webmhd.webm" video_mp4="http://www.vbits.com.hk/wp-content/uploads/2016/fp-clouds.mp4" video_image="6770" text_color="light" text_align="left" top_padding="5%" bottom_padding="5%" overlay_strength="0.3"][vc_column centered_text="true" column_padding="no-extra-padding" column_padding_position="left-right" background_color_opacity="1" background_hover_color_opacity="1" width="1/1"][vc_column_text]
<h1>Vbits</h1>
[/vc_column_text][vc_column_text]
<h2>Your <span style="color: #00afcb;">i</span>nnova<span style="color: #00afcb;">t</span>ive partner</h2>
<h5>網頁設計, IT解決方案, SEO 搜索引擎優化, 社交網絡行銷, 品牌設計</h5>
[/vc_column_text][/vc_column][/vc_row][vc_row type="full_width_content" scene_position="center" text_color="dark" text_align="center" overlay_strength="0.3"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color="#00d4ff" background_color_opacity="1" background_hover_color_opacity="1" width="1/3"][divider line_type="No Line"][vc_column_text]
<h2>網頁設計</h2>
<h5><span style="color: #ffffff;">符合不同設備的網頁設計</span></h5>
[/vc_column_text][image_with_animation image_url="6712" alignment="center" animation="Fade In" delay="150"][divider line_type="No Line"][vc_column_text][button open_new_tab="true" color="see-through-2" hover_text_color_override="#fff" image="default-arrow" size="large" url="http://www.vbits.com.hk/web-design/" text="詳情.." color_override=""][/vc_column_text][divider line_type="No Line"][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/3"][divider line_type="No Line"][vc_column_text]
<h2 style="text-align: center;">IT解決方案</h2>
<h5 style="text-align: center;"><span style="color: #00afcb;">超過十年的IT解決方案經驗</span></h5>
[/vc_column_text][image_with_animation image_url="6710" alignment="center" animation="Fade In" delay="150"][divider line_type="No Line"][vc_column_text][button open_new_tab="true" color="see-through-2" hover_text_color_override="#fff" image="default-arrow" size="large" url="http://www.vbits.com.hk/it-solutions/" text="詳情.." color_override=""][/vc_column_text][divider line_type="No Line"][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color="#00afcb" background_color_opacity="1" background_hover_color_opacity="1" width="1/3"][divider line_type="No Line"][vc_column_text]
<h2 style="text-align: center;">SEO 搜索引擎優化</h2>
<h5 style="text-align: center;"><span style="color: #ffffff;">提升銷售的最佳方法
</span></h5>
[/vc_column_text][image_with_animation image_url="6284" alignment="center" animation="Fade In" delay="150"][divider line_type="No Line"][vc_column_text][button open_new_tab="true" color="see-through-2" hover_text_color_override="#fff" image="default-arrow" size="large" url="http://www.vbits.com.hk/seo/" text="詳情.." color_override=""][/vc_column_text][divider line_type="No Line"][/vc_column][/vc_row][vc_row type="full_width_content" scene_position="center" text_color="dark" text_align="center" overlay_strength="0.3"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/3"][divider line_type="No Line"][vc_column_text]
<h2 style="text-align: center;">社交網絡行銷</h2>
<h5 style="text-align: center;"><span style="color: #00afcb;">想做網路營銷? 交給我們吧!</span></h5>
[/vc_column_text][image_with_animation image_url="6715" alignment="center" animation="Fade In" delay="150"][divider line_type="No Line"][vc_column_text][button open_new_tab="true" color="see-through-2" hover_text_color_override="#fff" image="default-arrow" size="large" url="http://www.vbits.com.hk/social-media-marketing/" text="詳情.." color_override=""][/vc_column_text][divider line_type="No Line"][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color="#00afcb" background_color_opacity="1" background_hover_color_opacity="1" width="1/3"][divider line_type="No Line"][vc_column_text]
<h2 style="text-align: center;">品牌設計</h2>
<h5 style="text-align: center;"><span style="color: #ffffff;">我們喜歡細節,即使是1px的修飾</span></h5>
[/vc_column_text][image_with_animation image_url="6716" alignment="center" animation="Fade In" delay="150"][divider line_type="No Line"][vc_column_text][button open_new_tab="true" color="see-through-2" hover_text_color_override="#fff" image="default-arrow" size="large" url="http://www.vbits.com.hk/brand-identity/" text="詳情.." color_override=""][/vc_column_text][divider line_type="No Line"][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/3"][divider line_type="No Line"][vc_column_text]
<h2>聯絡我們</h2>
<h5><span style="color: #00afcb;">Vbits, Your innovative partner
</span></h5>
[/vc_column_text][image_with_animation image_url="6718" alignment="center" animation="Fade In"][divider line_type="No Line"][vc_column_text][button open_new_tab="true" color="see-through-2" hover_text_color_override="#fff" image="default-arrow" size="large" url="http://www.vbits.com.hk/contact/" text="聯絡我們" color_override=""][/vc_column_text][divider line_type="No Line"][/vc_column][/vc_row]";s:10:"post_title";s:6:"主頁";s:12:"post_excerpt";s:0:"";s:11:"post_status";s:7:"publish";s:14:"comment_status";s:6:"closed";s:11:"ping_status";s:6:"closed";s:13:"post_password";s:0:"";s:9:"post_name";s:18:"%e4%b8%bb%e9%a0%81";s:7:"to_ping";s:0:"";s:6:"pinged";s:0:"";s:13:"post_modified";s:19:"2016-08-04 13:01:57";s:17:"post_modified_gmt";s:19:"2016-08-04 05:01:57";s:21:"post_content_filtered";s:0:"";s:11:"post_parent";s:1:"0";s:4:"guid";s:41:"http://web2.vbits.com.hk/zh/?page_id=6800";s:10:"menu_order";s:1:"0";s:9:"post_type";s:4:"page";s:14:"post_mime_type";s:0:"";s:13:"comment_count";s:1:"0";}}s:8:"col_info";a:23:{i:0;O:8:"stdClass":13:{s:4:"name";s:2:"ID";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:4;s:8:"not_null";i:1;s:11:"primary_key";i:1;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:1;s:4:"blob";i:0;s:4:"type";s:3:"int";s:8:"unsigned";i:1;s:8:"zerofill";i:0;}i:1;O:8:"stdClass":13:{s:4:"name";s:11:"post_author";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:1;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:1;s:10:"unique_key";i:0;s:7:"numeric";i:1;s:4:"blob";i:0;s:4:"type";s:3:"int";s:8:"unsigned";i:1;s:8:"zerofill";i:0;}i:2;O:8:"stdClass":13:{s:4:"name";s:9:"post_date";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:19;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:0;s:4:"type";s:8:"datetime";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:3;O:8:"stdClass":13:{s:4:"name";s:13:"post_date_gmt";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:19;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:0;s:4:"type";s:8:"datetime";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:4;O:8:"stdClass":13:{s:4:"name";s:12:"post_content";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:21781;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:1;s:4:"type";s:4:"blob";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:5;O:8:"stdClass":13:{s:4:"name";s:10:"post_title";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:22;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:1;s:4:"type";s:4:"blob";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:6;O:8:"stdClass":13:{s:4:"name";s:12:"post_excerpt";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:0;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:1;s:4:"type";s:4:"blob";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:7;O:8:"stdClass":13:{s:4:"name";s:11:"post_status";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:7;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:0;s:4:"type";s:6:"string";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:8;O:8:"stdClass":13:{s:4:"name";s:14:"comment_status";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:6;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:0;s:4:"type";s:6:"string";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:9;O:8:"stdClass":13:{s:4:"name";s:11:"ping_status";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:6;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:0;s:4:"type";s:6:"string";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:10;O:8:"stdClass":13:{s:4:"name";s:13:"post_password";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:0;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:0;s:4:"type";s:6:"string";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:11;O:8:"stdClass":13:{s:4:"name";s:9:"post_name";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:22;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:1;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:0;s:4:"type";s:6:"string";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:12;O:8:"stdClass":13:{s:4:"name";s:7:"to_ping";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:0;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:1;s:4:"type";s:4:"blob";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:13;O:8:"stdClass":13:{s:4:"name";s:6:"pinged";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:0;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:1;s:4:"type";s:4:"blob";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:14;O:8:"stdClass":13:{s:4:"name";s:13:"post_modified";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:19;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:0;s:4:"type";s:8:"datetime";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:15;O:8:"stdClass":13:{s:4:"name";s:17:"post_modified_gmt";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:19;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:0;s:4:"type";s:8:"datetime";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:16;O:8:"stdClass":13:{s:4:"name";s:21:"post_content_filtered";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:0;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:1;s:4:"type";s:4:"blob";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:17;O:8:"stdClass":13:{s:4:"name";s:11:"post_parent";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:1;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:1;s:10:"unique_key";i:0;s:7:"numeric";i:1;s:4:"blob";i:0;s:4:"type";s:3:"int";s:8:"unsigned";i:1;s:8:"zerofill";i:0;}i:18;O:8:"stdClass":13:{s:4:"name";s:4:"guid";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:41;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:0;s:4:"type";s:6:"string";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:19;O:8:"stdClass":13:{s:4:"name";s:10:"menu_order";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:1;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:1;s:4:"blob";i:0;s:4:"type";s:3:"int";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:20;O:8:"stdClass":13:{s:4:"name";s:9:"post_type";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:4;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:1;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:0;s:4:"type";s:6:"string";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:21;O:8:"stdClass":13:{s:4:"name";s:14:"post_mime_type";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:0;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:0;s:4:"blob";i:0;s:4:"type";s:6:"string";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}i:22;O:8:"stdClass":13:{s:4:"name";s:13:"comment_count";s:5:"table";s:8:"wp_posts";s:3:"def";s:0:"";s:10:"max_length";i:1;s:8:"not_null";i:1;s:11:"primary_key";i:0;s:12:"multiple_key";i:0;s:10:"unique_key";i:0;s:7:"numeric";i:1;s:4:"blob";i:0;s:4:"type";s:3:"int";s:8:"unsigned";i:0;s:8:"zerofill";i:0;}}s:8:"num_rows";i:8;s:10:"return_val";i:8;}