ԗ�X<?php exit; ?>a:1:{s:7:"content";O:8:"stdClass":24:{s:2:"ID";i:6201;s:11:"post_author";s:1:"1";s:9:"post_date";s:19:"2016-06-06 14:06:09";s:13:"post_date_gmt";s:19:"2016-06-06 06:06:09";s:12:"post_content";s:21223:"[vc_row type="full_width_background" scene_position="center" text_color="light" text_align="left" color_overlay="#00afcb" overlay_strength="0.95"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/1"][page_submenu sticky="true"][page_link link_url="#it-outsourcing" title="IT Outsourcing" tab_id="1466414153530-3" id="1466926223000-10"] [/page_link][page_link link_url="#networking" title="Networking" tab_id="1466414153918-10" id="1466587020406-0"] [/page_link][page_link title="Server deployment" tab_id="1466498762904-5" link_url="#server-deployment" id="1466499552380-1"][/page_link][page_link title="New Office setup" tab_id="1466583163302-0" link_url="#new-office-setup" id="1466585552881-0"][/page_link][page_link title="IT Product" tab_id="1466585451279-9" link_url="#it-product" id="1468914571813-9"][/page_link][page_link title="Licensing" tab_id="1466585560752-0" link_url="#licensing" id="1466671636908-8"][/page_link][/page_submenu][/vc_column][/vc_row][vc_row type="full_width_background" scene_position="center" text_color="light" text_align="left" top_padding="5%" id="it-outsourcing" color_overlay="#00afcb" overlay_strength="0.95"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][vc_column_text]
<h2>IT Outsourcing</h2>
[/vc_column_text][vc_column_text]Through our IT outsourcing services, you can use an affordable price to build up your IT team. We will evaluate your company's IT environment regularly,  deploy up-to-day IT solutions to fit your business need.[/vc_column_text][image_with_animation image_url="6426" alignment="center" animation="Fade In" delay="150"][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1465288213082{margin-bottom: 18px !important;}"]
<h5>Technical Support</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Extra-Color-3" enable_animation="true"]
<ul>
 	<li><span style="color: #a2d8e6;">Regular onsite support</span></li>
 	<li><span style="color: #a2d8e6;">Remote support</span></li>
 	<li><span style="color: #a2d8e6;">Anti virus update</span></li>
 	<li><span style="color: #a2d8e6;">Trouble shooting</span></li>
 	<li><span style="color: #a2d8e6;">Regular support log / docs</span></li>
</ul>
[/fancy-ul][vc_column_text css=".vc_custom_1465288179382{margin-bottom: 18px !important;}"]
<h5>Network security checking</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Extra-Color-3" enable_animation="true"]
<ul>
 	<li><span style="color: #a2d8e6;">Firewall management</span></li>
 	<li><span style="color: #a2d8e6;">Network traffic control</span></li>
 	<li><span style="color: #a2d8e6;">VPN Setup</span></li>
 	<li><span style="color: #a2d8e6;">Network filter</span></li>
 	<li><span style="color: #a2d8e6;">Internet user behaviour control</span></li>
</ul>
[/fancy-ul][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1465287342539{margin-bottom: 18px !important;}"]
<h5>Server Maintainence</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Extra-Color-3" enable_animation="true"]
<ul>
 	<li><span style="color: #a2d8e6;">Server performance checking</span></li>
 	<li><span style="color: #a2d8e6;">Server security checking</span></li>
 	<li><span style="color: #a2d8e6;">Server Backup solutions</span></li>
 	<li><span style="color: #a2d8e6;">Windows server deployment</span></li>
 	<li><span style="color: #a2d8e6;">Linux server deployment</span></li>
</ul>
[/fancy-ul][vc_column_text css=".vc_custom_1465288269705{margin-bottom: 18px !important;}"]
<h5>Proactive IT risk assessment</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Extra-Color-3" enable_animation="true"]
<ul>
 	<li><span style="color: #a2d8e6;">Software Update</span></li>
 	<li><span style="color: #a2d8e6;">IT Environment assessment</span></li>
 	<li><span style="color: #a2d8e6;">Hardware lifecycle management</span></li>
 	<li><span style="color: #a2d8e6;">Software license management</span></li>
 	<li><span style="color: #a2d8e6;">IT Training</span></li>
</ul>
[/fancy-ul][/vc_column][/vc_row][vc_row type="full_width_background" scene_position="center" text_color="dark" text_align="left" top_padding="5%" bottom_padding="5%" id="networking" overlay_strength="0.3"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][vc_column_text]
<h2>Network Construction</h2>
[/vc_column_text][vc_column_text]We are experienced in LAN / WLAN / CCTV solutions, from small office to large floor network construction.[/vc_column_text][image_with_animation image_url="6448" alignment="center" animation="Fade In" delay="150"][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1466489324850{margin-bottom: 18px !important;}"]
<h5>LAN Construction</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">SCS cabling design Cat5e/Cat6</span></li>
 	<li><span style="color: #00afcb;">Faceplate installation</span></li>
 	<li><span style="color: #00afcb;">Cabling installation</span></li>
 	<li><span style="color: #00afcb;">Inprogess Reporting</span></li>
 	<li><span style="color: #00afcb;">Cable Testing</span></li>
</ul>
[/fancy-ul][vc_column_text css=".vc_custom_1466489356805{margin-bottom: 18px !important;}"]
<h5>CCTV Construction</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">Camera setup</span></li>
 	<li><span style="color: #00afcb;">View Angle &amp; Focus adjustment</span></li>
 	<li><span style="color: #00afcb;">DVR configuration</span></li>
 	<li><span style="color: #00afcb;">PVC conduit work</span></li>
 	<li><span style="color: #00afcb;">UPS installation</span></li>
</ul>
[/fancy-ul][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1466489336430{margin-bottom: 18px !important;}"]
<h5>WLAN Construction</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">WLAN planning</span></li>
 	<li><span style="color: #00afcb;">AP Installation</span></li>
 	<li><span style="color: #00afcb;">AP management</span></li>
 	<li><span style="color: #00afcb;">WLAN coverage planning</span></li>
 	<li><span style="color: #00afcb;">WLAN Testing</span></li>
</ul>
[/fancy-ul][vc_column_text css=".vc_custom_1466492071786{margin-bottom: 18px !important;}"]
<h5>Network Configuration</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">Broadband setup</span></li>
 	<li><span style="color: #00afcb;">Firewall / UTM setup</span></li>
 	<li><span style="color: #00afcb;">Network switch installation</span></li>
 	<li><span style="color: #00afcb;">Server rack cabinet installation</span></li>
 	<li><span style="color: #00afcb;">UPS installation</span></li>
</ul>
[/fancy-ul][/vc_column][/vc_row][vc_row type="full_width_background" scene_position="center" text_color="dark" text_align="left" top_padding="5%" bottom_padding="5%" id="server-deployment" color_overlay="#00afcb" overlay_strength="0.3"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][vc_column_text]
<h2>Server deployment</h2>
[/vc_column_text][vc_column_text]We are experienced in various server deployment , from tiny NAS to rack mountable server.[/vc_column_text][image_with_animation image_url="6462" alignment="center" animation="Fade In" delay="150"][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1466499521321{margin-bottom: 18px !important;}"]
<h5>Windows Server</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">Windows Domain controller server</span></li>
 	<li><span style="color: #00afcb;">Windows File server</span></li>
 	<li><span style="color: #00afcb;">Windows Hyper-V server</span></li>
 	<li><span style="color: #00afcb;">Windows DNS server</span></li>
 	<li><span style="color: #00afcb;">Windows DHCP server</span></li>
 	<li><span style="color: #00afcb;">Windows FTP server</span></li>
 	<li><span style="color: #00afcb;">Windows Remote Terminal server</span></li>
 	<li><span style="color: #00afcb;">Windows System Center server</span></li>
 	<li><span style="color: #00afcb;">Windows Data Protection server</span></li>
 	<li><span style="color: #00afcb;">Windows Exchange server</span></li>
</ul>
[/fancy-ul][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1466499546558{margin-bottom: 18px !important;}"]
<h5>Linux Server</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">Linux Apache server</span></li>
 	<li><span style="color: #00afcb;">LAMP server stack</span></li>
 	<li><span style="color: #00afcb;">BIND DNS server</span></li>
 	<li><span style="color: #00afcb;">Mail / POP3 server</span></li>
 	<li><span style="color: #00afcb;">Database server</span></li>
 	<li><span style="color: #00afcb;">Linux FTP server</span></li>
</ul>
[/fancy-ul][vc_column_text css=".vc_custom_1466499907609{margin-bottom: 18px !important;}"]
<h5>NAS Server</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">NAS Cloud setup</span></li>
 	<li><span style="color: #00afcb;">NAS Market place</span></li>
 	<li><span style="color: #00afcb;">Trailor made NAS solutions</span></li>
 	<li><span style="color: #00afcb;">NAS Apps deployment</span></li>
 	<li><span style="color: #00afcb;">NAS storage configuration</span></li>
</ul>
[/fancy-ul][/vc_column][/vc_row][vc_row type="full_width_background" scene_position="center" text_color="dark" text_align="left" top_padding="5%" bottom_padding="5%" id="new-office-setup" overlay_strength="0.3"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][vc_column_text]
<h2>New Office setup</h2>
[/vc_column_text][vc_column_text]Don't worry about any IT solutions adoption on company establishment. We can provide all-in-one solutions for you. Across personalize IT consultant, brand design, web solutions, IT solutions, network construction and business application deployment.[/vc_column_text][image_with_animation image_url="6472" alignment="center" animation="Fade In" delay="150"][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1466575607435{margin-bottom: 18px !important;}"]
<h5>Website design</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">Domain name registration</span></li>
 	<li><span style="color: #00afcb;">Website design</span></li>
 	<li><span style="color: #00afcb;">Blog design</span></li>
 	<li><span style="color: #00afcb;">Shopping cart design</span></li>
 	<li><span style="color: #00afcb;">CMS design</span></li>
</ul>
[/fancy-ul][vc_column_text css=".vc_custom_1466575586689{margin-bottom: 18px !important;}"]
<h5>Network Construction</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">Router / Firwall setup</span></li>
 	<li><span style="color: #00afcb;">LAN setup</span></li>
 	<li><span style="color: #00afcb;">WLAN / Wifi setup</span></li>
 	<li><span style="color: #00afcb;">CCTV setup</span></li>
 	<li><span style="color: #00afcb;">Server / Network rack installation</span></li>
</ul>
[/fancy-ul][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1466575555452{margin-bottom: 18px !important;}"]
<h5>Hardware / Software</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">PC / laptop acquisition</span></li>
 	<li><span style="color: #00afcb;">Server acquisition</span></li>
 	<li><span style="color: #00afcb;">Software acquisition</span></li>
 	<li><span style="color: #00afcb;">Corporate license acquisition</span></li>
 	<li><span style="color: #00afcb;">Computer related equipment </span></li>
</ul>
[/fancy-ul][vc_column_text css=".vc_custom_1466575633713{margin-bottom: 18px !important;}"]
<h5>Business application selection</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">ERP solutions</span></li>
 	<li><span style="color: #00afcb;">CRM solutions</span></li>
 	<li><span style="color: #00afcb;">POS solutions</span></li>
 	<li><span style="color: #00afcb;">Email solutions</span></li>
 	<li><span style="color: #00afcb;">Collaboration solutions</span></li>
</ul>
[/fancy-ul][/vc_column][/vc_row][vc_row type="full_width_background" scene_position="center" text_color="light" text_align="left" top_padding="5%" bottom_padding="5%" id="it-product" color_overlay="#00afcb" overlay_strength="0.95"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][vc_column_text]
<h2>Sale of IT products</h2>
[/vc_column_text][vc_column_text]We source and sell IT equipment for decades. We have a wide range of IT products for your selection, from server to PC, Laptop, tablet, harddisk, memory, mouse and even one piece of network cable.
No need to walk around shopping mall, sit back and just focus on your work, we will ship it for you.[/vc_column_text][image_with_animation image_url="6489" alignment="center" animation="Fade In" delay="150"][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1466666323226{margin-bottom: 18px !important;}"]
<h5>Hardware</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Extra-Color-3" enable_animation="true"]
<ul>
 	<li><span style="color: #a2d8e6;">Branded PC / Laptop</span></li>
 	<li><span style="color: #a2d8e6;">Mac</span></li>
 	<li><span style="color: #a2d8e6;">Tablet</span></li>
 	<li><span style="color: #a2d8e6;">Handheld devices</span></li>
 	<li><span style="color: #a2d8e6;">DIY PC</span></li>
</ul>
[/fancy-ul][vc_column_text css=".vc_custom_1466587281569{margin-bottom: 18px !important;}"]
<h5>Software</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Extra-Color-3" enable_animation="true"]
<ul>
 	<li><span style="color: #a2d8e6;">Operating system</span></li>
 	<li><span style="color: #a2d8e6;">Server based system</span></li>
 	<li><span style="color: #a2d8e6;">Graphic design tools</span></li>
 	<li><span style="color: #a2d8e6;">Office suite</span></li>
 	<li><span style="color: #a2d8e6;">Antivirus program</span></li>
</ul>
[/fancy-ul][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1466587289490{margin-bottom: 18px !important;}"]
<h5>Network</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Extra-Color-3" enable_animation="true"]
<ul>
 	<li><span style="color: #a2d8e6;">Networking</span></li>
 	<li><span style="color: #a2d8e6;">Cabinets</span></li>
 	<li><span style="color: #a2d8e6;">Cable / cable assemblies</span></li>
 	<li><span style="color: #a2d8e6;">IP Camera</span></li>
 	<li><span style="color: #a2d8e6;">Power management</span></li>
</ul>
[/fancy-ul][vc_column_text css=".vc_custom_1466587330166{margin-bottom: 18px !important;}"]
<h5>Computer accessories</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Extra-Color-3" enable_animation="true"]
<ul>
 	<li><span style="color: #a2d8e6;">Storage device</span></li>
 	<li><span style="color: #a2d8e6;">Printer</span></li>
 	<li><span style="color: #a2d8e6;">Monitor</span></li>
 	<li><span style="color: #a2d8e6;">Projector</span></li>
 	<li><span style="color: #a2d8e6;">Input device(Mouse / Keyboard / Pen)</span></li>
</ul>
[/fancy-ul][/vc_column][/vc_row][vc_row type="full_width_background" scene_position="center" text_color="dark" text_align="left" top_padding="5%" id="licensing" overlay_strength="0.3"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/2"][vc_column_text]
<h2>Licensing</h2>
[/vc_column_text][vc_column_text]Having licensing issue? Just find us! We resell the most famous brand licensing.[/vc_column_text][image_with_animation image_url="6508" alignment="center" animation="Fade In" delay="150"][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1466669111047{margin-bottom: 18px !important;}"]
<h5>Software license</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">Microsoft Open License</span></li>
 	<li><span style="color: #00afcb;">Microsoft Full Packaged Product (FPP) Software</span></li>
 	<li><span style="color: #00afcb;">Autodesk AutoCAD Product</span></li>
 	<li><span style="color: #00afcb;">CorelDRAW Graphic Suite</span></li>
 	<li><span style="color: #00afcb;">Symantec License</span></li>
 	<li><span style="color: #00afcb;">Kaspersky License</span></li>
 	<li><span style="color: #00afcb;">ESET NOD32 License</span></li>
</ul>
[/fancy-ul][/vc_column][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/4"][vc_column_text css=".vc_custom_1466670991332{margin-bottom: 18px !important;}"]
<h5>Network license</h5>
[/vc_column_text][fancy-ul icon_type="standard_dash" color="Accent-Color" enable_animation="true"]
<ul>
 	<li><span style="color: #00afcb;">Sonicwall</span></li>
 	<li><span style="color: #00afcb;">FortiGate</span></li>
 	<li><span style="color: #00afcb;">Sophos</span></li>
 	<li><span style="color: #00afcb;">Netgear</span></li>
 	<li><span style="color: #00afcb;">Watchguard</span></li>
</ul>
[/fancy-ul][/vc_column][/vc_row][vc_row type="full_width_background" scene_position="center" text_color="dark" text_align="left" top_padding="40" bottom_padding="40" overlay_strength="1"][vc_column column_padding="no-extra-padding" column_padding_position="all" background_color_opacity="1" background_hover_color_opacity="1" width="1/1"][clients columns="6" carousel="true"][client image="6519" title="Client" tab_id="1451662966191-10" name="Dell" id="1466931216835-2"] Click the edit button to add your testimonial. [/client][client image="6522" title="Client" tab_id="1451663132415-1" name="APC" id="1466931413922-0"][/client][client image="6520" title="Client" tab_id="1451663143506-0" name="Adobe" id="1466931284237-6"][/client][client image="6527" title="Client" tab_id="1466931353621-0" name="Microsoft" id="1466931598150-0"][/client][client image="6528" title="Client" tab_id="1466931384037-3" name="Autodesk" id="1466931493068-0"][/client][client image="6530" title="Client" tab_id="1466931509584-3" name="Symantec" id="1466931598175-1"][/client][client image="6533" title="Client" tab_id="1466931571980-4" name="Trend Micro" id="1466931633164-10"][/client][client image="6535" title="Client" tab_id="1466931604541-2" name="Watchguard" id="1467000202494-0"][/client][/clients][/vc_column][/vc_row]";s:10:"post_title";s:12:"IT Solutions";s:12:"post_excerpt";s:0:"";s:11:"post_status";s:7:"publish";s:14:"comment_status";s:6:"closed";s:11:"ping_status";s:6:"closed";s:13:"post_password";s:0:"";s:9:"post_name";s:12:"it-solutions";s:7:"to_ping";s:0:"";s:6:"pinged";s:0:"";s:13:"post_modified";s:19:"2016-07-29 17:35:15";s:17:"post_modified_gmt";s:19:"2016-07-29 09:35:15";s:21:"post_content_filtered";s:0:"";s:11:"post_parent";i:0;s:4:"guid";s:38:"http://web2.vbits.com.hk/?page_id=6201";s:10:"menu_order";i:0;s:9:"post_type";s:4:"page";s:14:"post_mime_type";s:0:"";s:13:"comment_count";s:1:"0";s:6:"filter";s:3:"raw";}}