// ==========================================================================
// Jetpack Connection Landing Page ('Please connect jetpack')
//===========================================================================

// ==========================================================================
// Jetpack NUX Page(s) (main jetpack admin page + jumpstart)
//===========================================================================

// Needs to be cleaned. Let's remove those important tags and unneeded classes that we can utilize from core. Properly nest elements. migrate into _main.scss
// Once everything is tested, I'll remove all the comments below as well. - @jeffgolenski

// wrapping these common element names temporarily until I can audit - jeff
.jp-content {
	.hide {
		display: none;
	}

	.landing {
		margin: 0 auto;
		z-index: 2;
		position: relative;
	}

	h1 {
		font-weight: 400;
		line-height: 1.75em;
		position: relative;
		z-index: 3;
		width: 100%;
		text-align: center;

		&.success {
			color: $green;
		}
	}
	.footer {
		padding-top: 0;
		margin-top: 0;
		background-image: none;

		&:before {
			height: inherit;
		}
	}

	.more-info:before {
		content: none;
	}
} //.jp-content

.landing {
	.wpcom-connect {
		min-height: 400px;
	}
}

.wpcom-connect {
	.j-col {
		padding: 0;
	}
}

// Breakpoints
@include breakpoint(large-desktop) {
	.jp-content {
		.landing {
			padding: 0 2em;
		}

		.footer {
			padding-top: 1.5em;
		}
	}
} // large-desktop

@include breakpoint(large-phone) {
	.jp-content {
		.landing {
			padding: 0 .5em;
		}
	}
} // large-phone
